import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, OnInit, QueryList } from '@angular/core';
import { LfI18n, LfRouter, LfStorage, PathBased } from '@lightweightform/core';
import { Value } from './value';
/**
 * Abstract class used to represent typical "inline-able" values.
 */
export declare abstract class InlineValue extends Value implements OnInit, AfterViewInit, OnDestroy {
    protected lfRouter: LfRouter | null;
    /**
     * Whether the component should be hidden when its value isn't required.
     * **NOT READY FOR USE**
     */
    _hideWhenNotRequired: boolean;
    /**
     * Event emitter which emits an event whenever the component's DOM input is
     * focused.
     */
    focus: EventEmitter<FocusEvent>;
    /**
     * Event emitter which emits an event whenever the component's DOM input is
     * blurred.
     */
    blur: EventEmitter<FocusEvent>;
    /**
     * Add an `lf-inline-value` class to components.
     */
    _classLfInlineValue: boolean;
    /**
     * Target elements that should be the target of focus/blur events; the first
     * element of que query list is the one that will be focused on route change
     * or when demanded via `focus()`.
     */
    protected targets: QueryList<ElementRef>;
    /**
     * Disposer for the "auto-focus" of the field when it becomes active.
     */
    private disposeOnActive;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n, lfRouter: LfRouter | null);
    /**
     * Whether this component should be displayed.
     */
    get shouldDisplay(): boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Scrolls this component into the center of the viewport and focuses it.
     */
    triggerFocus(): void;
    /**
     * Action to run whenever a focusable part of the field is focused.
     * @param evt `focus` event.
     */
    _onFocus(evt: FocusEvent): void;
    /**
     * Action to run whenever a focusable part of the field is blurred.
     * @param evt `blur` event.
     * @param setTouched Whether to try and set the value as "touched". Defaults
     * to `true`.
     */
    _onBlur(evt: FocusEvent, setTouched?: boolean): void;
    /**
     * Method that directives can implement which is called whenever the
     * directive's path becomes active. Returning `false` prevents the default
     * behaviour of focusing this directive's target element.
     * @param activatedPath Full activated path (may be a child of the directive's
     * path).
     * @returns Nothing or `false` to prevent the default focus behaviour.
     */
    protected onActivate?(activatedPath: string): false | void;
}
