import { ElementRef } from '@angular/core';
/**
 * Available styles for an `lf-button`.
 */
export declare type ButtonStyle = 'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'light' | 'dark' | 'link' | 'outline-primary' | 'outline-secondary' | 'outline-success' | 'outline-danger' | 'outline-warning' | 'outline-info' | 'outline-light' | 'outline-dark';
/**
 * Available sizes for an `lf-button`.
 */
export declare type ButtonSize = 'sm' | 'lg';
/**
 * Bootstrap button component.
 */
export declare class ButtonComponent {
    /**
     * Button style. See available styles at [Bootstrap documentation](
     * https://getbootstrap.com/docs/4.0/components/buttons/#examples).
     */
    style?: ButtonStyle;
    /**
     * Button size. See available sizes at [Bootstrap documentation](
     * https://getbootstrap.com/docs/4.0/components/buttons/#sizes).
     */
    size?: ButtonSize;
    /**
     * HTML button type.
     */
    type: 'button' | 'submit' | 'reset';
    /**
     * Match the width of parent if `true`.
     */
    block: boolean;
    /**
     * Display a dropdown icon (this is automatic if `dropdownToggleSplit` is
     * set).
     */
    dropdownToggle: boolean;
    /**
     * Reduces the padding of the button so it can be used as the dropdown part of
     * a split dropdown.
     */
    dropdownToggleSplit: boolean;
    /**
     * Set the button as disabled.
     */
    isDisabled: boolean;
    /**
     * Set the button as active.
     */
    isActive: boolean;
    /**
     * Always add the class `btn` to LF buttons.
     */
    _hostClassBtn: boolean;
    /**
     * Tag of the element (`'button'` or `'a'`).
     */
    protected _tagName: string;
    constructor(_host: ElementRef);
    get _role(): "button" | undefined;
    get _hostClassBtnPrimary(): boolean;
    get _hostClassBtnSecondary(): boolean;
    get _hostClassBtnSuccess(): boolean;
    get _hostClassBtnDanger(): boolean;
    get _hostClassBtnWarning(): boolean;
    get _hostClassBtnInfo(): boolean;
    get _hostClassBtnLight(): boolean;
    get _hostClassBtnDark(): boolean;
    get _hostClassBtnLink(): boolean;
    get _hostClassBtnOutlinePrimary(): boolean;
    get _hostClassBtnOutlineSecondary(): boolean;
    get _hostClassBtnOutlineSuccess(): boolean;
    get _hostClassBtnOutlineDanger(): boolean;
    get _hostClassBtnOutlineWarning(): boolean;
    get _hostClassBtnOutlineInfo(): boolean;
    get _hostClassBtnOutlineLight(): boolean;
    get _hostClassBtnOutlineDark(): boolean;
    get _hostClassBtnSm(): boolean;
    get _hostClassBtnLg(): boolean;
    get _hostClassDropdownToggle(): boolean;
    get _hostType(): "button" | "reset" | "submit" | undefined;
    get _hostDisabled(): "" | undefined;
    get _hostAriaDisabled(): "true" | undefined;
    get _hostAriaPressed(): "true" | undefined;
}
