import { __awaiter, __decorate, __param } from 'tslib';
import { ViewportRuler, ScrollingModule } from '@angular/cdk/scrolling';
import { CommonModule } from '@angular/common';
import { Inject, Input, Component, ChangeDetectionStrategy, EventEmitter, Output, Directive, Optional, SkipSelf, HostBinding, ViewChild, ElementRef, ViewChildren, ɵɵdefineInjectable, ɵɵinject, Injectable, ContentChild, HostListener, NgModule } from '@angular/core';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { Router, RouterModule } from '@angular/router';
import { LfI18n, PathBased, LfStorage, LfRouter, LfFileStorage, LfFileHolder, LfCoreModule, I18N_UNLOAD_ALERT_MESSAGE_KEY } from '@lightweightform/core';
import { asap, ScrollbarUtils, TableHeaderDirective, LfTableHeaderModule } from '@lightweightform/theme-common';
import { observable, computed, action, MobxAngularModule } from 'mobx-angular';
import { BsLocaleService, BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TooltipModule } from 'ngx-bootstrap/tooltip';
import { MarkdownService, MarkdownModule } from 'ngx-markdown';
import { runInAction, observe, autorun, comparer, reaction } from 'mobx';
import { isRecordSchema, isNullableSchema, pathError, isListSchema, isBooleanSchema, tupleSchema, dateSchema, isTupleSchema, isDateSchema, isStringSchema, isNumberSchema, getRowId, isTableSchema, appendToPath, isComplexSchema, isReservedStateProp, getStateProperty, resolvePath, IS_REJECTED_CODE, IS_REQUIRED_CODE, DISALLOWED_VALUE_CODE, DATE_OUT_OF_BOUNDS_CODE, SIZE_OUT_OF_BOUNDS_CODE, NUMBER_OUT_OF_BOUNDS_CODE, LENGTH_OUT_OF_BOUNDS_CODE } from '@lightweightform/storage';
import { PENDING, isPromiseBasedObservable } from 'mobx-utils';
import 'bootstrap/js/dist/dropdown.js';
import $ from 'jquery';
import 'bootstrap/js/dist/modal.js';
import { NumericInput } from '@lightweightform/numeric-input';
import { animationFrameScheduler, asapScheduler } from 'rxjs';
import { auditTime } from 'rxjs/operators';
import { defineLocale } from 'ngx-bootstrap/chronos';
import { esLocale, ptBrLocale } from 'ngx-bootstrap/locale';

// App =========================================================================
/**
 * I18n key used to set the locale used by `ngx-bootstrap`.
 */
const I18N_BS_LOCALE_KEY = 'bsLocale';
// Value =======================================================================
/**
 * I18n key used to associate a label with a value.
 */
const I18N_VALUE_LABEL_KEY = 'label';
/**
 * I18n key used to associate a code with a value.
 */
const I18N_VALUE_CODE_KEY = 'code';
/**
 * I18n key used to associate a help message with a value.
 */
const I18N_VALUE_HELP_MESSAGE_KEY = 'helpMessage';
/**
 * I18n key used to associate a legend with a value.
 */
const I18N_VALUE_LEGEND_KEY = 'legend';
/**
 * I18n key used to associate messages with validation errors.
 */
const I18N_VALIDATIONS_KEY = 'validations';
/**
 * I18n key used to ask the user to retry validating the value.
 */
const I18N_VALUE_RETRY_VALIDATE_TEXT_KEY = 'retryValidateText';
// Tree-nav ====================================================================
/**
 * I18n key used to set the text of the dropdown button used to add optional
 * forms.
 */
const I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY = 'addOptionalValueButtonText';
/**
 * I18n key used to set the text of the button used to add forms to a list of
 * forms.
 */
const I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY = 'addValueToListButtonText';
// Closeable ===================================================================
/**
 * I18n key used to set the text of the tooltip of the "close" button in
 * components.
 */
const I18N_CLOSE_BUTTON_TOOLTIP_KEY = 'closeButtonTooltip';
// Actions-menu ================================================================
/**
 * I18n key used to set the text of the actions-menu button when it is in
 * "mobile" mode.
 */
const I18N_ACTIONS_MENU_BUTTON_TEXT_KEY = 'actionsButtonText';
/**
 * I18n key used to translate the text of the buttons.
 */
const I18N_ACTIONS_MENU_KEY = 'actionsMenu';
/**
 * I18n key used to translate the text of the options of the buttons.
 */
const I18N_ACTIONS_MENU_OPTIONS_KEY = 'actionsMenuOptions';
// Validation panel ============================================================
/**
 * I18n key used to set the "errors" title of validation panel.
 */
const I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY = 'errorsText';
/**
 * I18n key used to set the "warnings" title of validation panel.
 */
const I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY = 'warningsText';
/**
 * I18n key used to set the text that shows up in the validation panel when
 * there are no errors or warnings.
 */
const I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY = 'noIssuesText';
/**
 * I18n key used to set the text of the tooltip of the "focus" button in the
 * validation panel.
 */
const I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY = 'focusButtonTooltip';
/**
 * I18n key used to set the text of the tooltip of the "next" button in the
 * validation panel.
 */
const I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY = 'nextButtonTooltip';
/**
 * I18n key used to set the text of the tooltip of the "previous" button in the
 * validation panel.
 */
const I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY = 'prevButtonTooltip';
// Form ========================================================================
/**
 * I18n key used to set the text of a form component's help action.
 */
const I18N_FORM_HELP_ACTION_TEXT_KEY = 'helpActionText';
/**
 * I18n key used to set the text of a form component's remove action.
 */
const I18N_FORM_REMOVE_ACTION_TEXT_KEY = 'removeActionText';
/**
 * I18n key used to set the message displayed to the user in a form component to
 * confirm removal of a form.
 */
const I18N_FORM_ENSURE_REMOVE_TEXT_KEY = 'ensureRemoveText';
/**
 * I18n key used to set the text of a form component's "cancel" button in the
 * removal modal.
 */
const I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY = 'cancelRemoveButtonText';
/**
 * I18n key used to set the text of a form component's "confirm" button in the
 * removal modal.
 */
const I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY = 'confirmRemoveButtonText';
// Date ========================================================================
/**
 * I18n key used to set the format of a date component.
 */
const I18N_DATE_FORMAT_KEY = 'format';
/**
 * I18n key used to set the placeholder of a date component's input field.
 */
const I18N_DATE_PLACEHOLDER_KEY = 'placeholder';
// Date range ==================================================================
/**
 * I18n keys used to set the separator of the date range.
 */
const I18N_DATE_RANGE_SEPARATOR_KEY = 'separator';
// File ========================================================================
/**
 * I18n key used to set the "Choose file" placeholder of the file input.
 */
const I18N_FILE_CHOOSE_PLACEHOLDER_KEY = 'choosePlaceholder';
/**
 * I18n key used to set the "Browse" text of the file input.
 */
const I18N_FILE_BROWSE_TEXT_KEY = 'browseText';
/**
 * I18n key used to set the "No file chosen" text of the file input.
 */
const I18N_FILE_NONE_CHOSEN_KEY = 'noneChosenText';
/**
 * I18n key used to set the "Clear" button tooltip text.
 */
const I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY = 'clearButtonTooltip';
// Number ======================================================================
/**
 * I18n key used to set the prefix of a number component.
 */
const I18N_NUMBER_PREFIX_KEY = 'prefix';
/**
 * I18n key used to set the suffix of a number component.
 */
const I18N_NUMBER_SUFFIX_KEY = 'suffix';
/**
 * I18n key used to set the decimal separator of a number component.
 */
const I18N_NUMBER_DECIMAL_SEPARATOR_KEY = 'decimalSeparator';
/**
 * I18n key used to set the "thousands separator" of a number component.
 */
const I18N_NUMBER_THOUSANDS_SEPARATOR_KEY = 'thousandsSeparator';
// Table =======================================================================
/**
 * I18n key used to translate the "add row" text of the table component.
 */
const I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY = 'addRowActionText';
/**
 * I18n key used to translate the "remove rows" text of the table component.
 */
const I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY = 'removeRowsActionText';
/**
 * I18n key used to translate the "no rows" text of the table component.
 */
const I18N_TABLE_NO_ROWS_TEXT_KEY = 'noRowsText';
/**
 * I18n key used to set the labels of the table columns in the table component.
 */
const I18N_TABLE_COLUMN_LABELS_KEY = 'columnLabels';
// Selection ===================================================================
/**
 * I18n key used to specify the list of options.
 */
const I18N_SELECTION_OPTIONS_KEY = 'options';
/**
 * I18n key used to translate the "no options" message on components that
 * require options.
 */
const I18N_SELECTION_NO_OPTIONS_TEXT_KEY = 'noOptionsText';

/**
 * Component that responsively displays a menu of actions.
 */
let ActionsMenuComponent = class ActionsMenuComponent {
    constructor(lfI18n) {
        this.lfI18n = lfI18n;
        /**
         * Screen size at which the actions-menu should collapse.
         */
        this.collapseSize = 'md';
        /**
         * Screen size at which the actions-menu button should collapse.
         */
        this.actionsLabelCollapseSize = 'sm';
        /**
         * Whether the actions-menu (when collapsed) should align its menu to the
         * right.
         */
        this.alignMenusRight = false;
        /**
         * Actions currently executing.
         */
        this.runningActions = new Set();
    }
    get actionsLabel() {
        return this.lfI18n.get(I18N_ACTIONS_MENU_BUTTON_TEXT_KEY);
    }
    actionText(act) {
        return act.text != null
            ? act.text
            : act.id != null
                ? this.lfI18n.get(`${I18N_ACTIONS_MENU_KEY}.${act.id}`)
                : '';
    }
    actionOptionText(act, option) {
        return option.text != null
            ? option.text
            : act.id != null && option.id != null
                ? this.lfI18n.get(`${I18N_ACTIONS_MENU_OPTIONS_KEY}.${act.id}.${option.id}`)
                : '';
    }
    _runAction(act, value) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = act.callback && act.callback(value);
            if (res && typeof res.then === 'function') {
                const actionId = this.actionId(act);
                try {
                    this.runningActions.add(actionId);
                    yield res;
                }
                finally {
                    runInAction(() => this.runningActions.delete(actionId));
                }
            }
        });
    }
    _runActionOption(act, option) {
        return __awaiter(this, void 0, void 0, function* () {
            const optionId = this.actionId(act, option);
            const optionRes = option.callback && option.callback();
            this.runningActions.add(optionId);
            try {
                if (optionRes && typeof optionRes === 'function') {
                    yield optionRes;
                }
                yield this._runAction(act, option.value);
            }
            finally {
                runInAction(() => this.runningActions.delete(optionId));
            }
        });
    }
    get _isAnyActionRunning() {
        return this.runningActions.size > 0;
    }
    _isActionRunning(act) {
        return this.runningActions.has(this.actionId(act));
    }
    _isChildOptionRunning(act) {
        for (const id of this.runningActions) {
            if (id.startsWith(`${this.actionId(act)}.`)) {
                return true;
            }
        }
        return false;
    }
    _isActionOptionRunning(act, option) {
        return this.runningActions.has(this.actionId(act, option));
    }
    actionId(act, option) {
        const actionId = act.id || this.actionText(act);
        const optionId = option && (option.id || this.actionOptionText(act, option));
        return optionId ? `${actionId}.${optionId}` : `${actionId}`;
    }
};
ActionsMenuComponent.ctorParameters = () => [
    { type: LfI18n, decorators: [{ type: Inject, args: [LfI18n,] }] }
];
__decorate([
    observable.struct,
    Input()
], ActionsMenuComponent.prototype, "actions", void 0);
__decorate([
    observable,
    Input()
], ActionsMenuComponent.prototype, "buttonsSize", void 0);
__decorate([
    observable,
    Input()
], ActionsMenuComponent.prototype, "collapseSize", void 0);
__decorate([
    observable,
    Input()
], ActionsMenuComponent.prototype, "actionsLabelCollapseSize", void 0);
__decorate([
    observable,
    Input()
], ActionsMenuComponent.prototype, "alignMenusRight", void 0);
__decorate([
    observable
], ActionsMenuComponent.prototype, "runningActions", void 0);
__decorate([
    computed
], ActionsMenuComponent.prototype, "actionsLabel", null);
__decorate([
    action
], ActionsMenuComponent.prototype, "_runAction", null);
__decorate([
    action
], ActionsMenuComponent.prototype, "_runActionOption", null);
__decorate([
    computed
], ActionsMenuComponent.prototype, "_isAnyActionRunning", null);
ActionsMenuComponent = __decorate([
    Component({
        selector: 'lf-actions-menu',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <!-- Large screen: inline buttons -->\n  <div\n    *ngIf=\"actions && actions.length > 0 && collapseSize !== 'every'\"\n    class=\"btn-group {{\n      collapseSize === 'none' ? '' : 'd-none d-' + collapseSize + '-block'\n    }}\"\n  >\n    <ng-template ngFor let-action [ngForOf]=\"actions\">\n      <!-- Anchor action -->\n      <a\n        lf-button\n        *ngIf=\"action.href\"\n        [class]=\"action.class || ''\"\n        [style]=\"action.style\"\n        [size]=\"buttonsSize\"\n        [href]=\"action.href\"\n      >\n        <lf-icon *ngIf=\"action.icon\" [icon]=\"action.icon\"></lf-icon>\n        {{ actionText(action) }}\n      </a>\n      <!-- Regular action (button) -->\n      <button\n        lf-button\n        *ngIf=\"!action.options && !action.href\"\n        [class]=\"action.class || ''\"\n        [style]=\"action.style\"\n        [size]=\"buttonsSize\"\n        [isActive]=\"action.isActive && action.isActive()\"\n        [isDisabled]=\"\n          _isActionRunning(action) || (action.isDisabled && action.isDisabled())\n        \"\n        (click)=\"_runAction(action)\"\n      >\n        <div *ngIf=\"_isActionRunning(action)\" class=\"action-loading\"></div>\n        <lf-icon\n          *ngIf=\"!_isActionRunning(action) && action.icon\"\n          [icon]=\"action.icon\"\n        >\n        </lf-icon>\n        {{ actionText(action) }}\n      </button>\n      <!-- Action with options (dropdown) -->\n      <lf-dropdown *ngIf=\"action.options\">\n        <button\n          lf-button\n          [class]=\"action.class || ''\"\n          [style]=\"action.style\"\n          [size]=\"buttonsSize\"\n          [isDisabled]=\"action.isDisabled && action.isDisabled()\"\n          [dropdownToggle]=\"true\"\n        >\n          <div\n            *ngIf=\"_isActionRunning(action) || _isChildOptionRunning(action)\"\n            class=\"action-loading\"\n          ></div>\n          <lf-icon\n            *ngIf=\"\n              !_isActionRunning(action) &&\n              !_isChildOptionRunning(action) &&\n              action.icon\n            \"\n            [icon]=\"action.icon\"\n          ></lf-icon>\n          {{ actionText(action) }}\n        </button>\n        <lf-dropdown-menu\n          [alignRight]=\"\n            action.alignRight == null ? alignMenusRight : action.alignRight\n          \"\n        >\n          <ng-container *ngFor=\"let option of action.options\">\n            <!-- Anchor option -->\n            <a\n              lf-dropdown-item\n              *ngIf=\"option.href\"\n              [class]=\"option.class || ''\"\n              [href]=\"option.href\"\n            >\n              <lf-icon\n                *ngIf=\"option.icon\"\n                [icon]=\"option.icon\"\n                [fixedWidth]=\"true\"\n              >\n              </lf-icon>\n              {{ actionOptionText(action, option) }}\n            </a>\n            <!-- Regular option (button) -->\n            <button\n              lf-dropdown-item\n              *ngIf=\"!option.href\"\n              type=\"button\"\n              [class]=\"option.class || ''\"\n              [isActive]=\"option.isActive && option.isActive()\"\n              [isDisabled]=\"\n                _isActionOptionRunning(action, option) ||\n                (option.isDisabled && option.isDisabled())\n              \"\n              (click)=\"_runActionOption(action, option)\"\n            >\n              <div\n                *ngIf=\"_isActionOptionRunning(action, option)\"\n                class=\"d-inline-block fa-fw\"\n              >\n                <div class=\"action-loading\"></div>\n              </div>\n              <lf-icon\n                *ngIf=\"!_isActionOptionRunning(action, option) && option.icon\"\n                [icon]=\"option.icon\"\n                [fixedWidth]=\"true\"\n              >\n              </lf-icon>\n              {{ actionOptionText(action, option) }}\n            </button>\n          </ng-container>\n        </lf-dropdown-menu>\n      </lf-dropdown>\n    </ng-template>\n  </div>\n\n  <!-- Small screen: menu buttons -->\n  <div\n    *ngIf=\"actions && actions.length > 0 && collapseSize !== 'none'\"\n    [class]=\"\n      collapseSize === 'every' ? '' : 'd-' + collapseSize + '-none d-block'\n    \"\n  >\n    <lf-dropdown>\n      <button\n        lf-button\n        [style]=\"'outline-secondary'\"\n        [size]=\"buttonsSize\"\n        [dropdownToggle]=\"true\"\n      >\n        <div *ngIf=\"_isAnyActionRunning\" class=\"action-loading\"></div>\n        <lf-icon *ngIf=\"!_isAnyActionRunning\" icon=\"gear\"></lf-icon>\n        <!-- Show a label for the actions toggle depending on screen size -->\n        <span\n          *ngIf=\"actionsLabelCollapseSize !== 'every'\"\n          [class]=\"\n            actionsLabelCollapseSize === 'none'\n              ? ''\n              : 'd-none d-' + actionsLabelCollapseSize + '-inline'\n          \"\n        >\n          {{ actionsLabel }}\n        </span>\n      </button>\n      <lf-dropdown-menu [alignRight]=\"alignMenusRight\">\n        <ng-container *ngFor=\"let action of actions; let i = index\">\n          <!-- Anchor action -->\n          <a\n            lf-dropdown-item\n            *ngIf=\"action.href\"\n            [class]=\"action.class || ''\"\n            [href]=\"action.href\"\n          >\n            <lf-icon\n              *ngIf=\"action.icon\"\n              [icon]=\"action.icon\"\n              [fixedWidth]=\"true\"\n            >\n            </lf-icon>\n            {{ actionText(action) }}\n          </a>\n          <!-- Regular action (button) -->\n          <button\n            lf-dropdown-item\n            type=\"button\"\n            *ngIf=\"!action.options && !action.href\"\n            [class]=\"action.class || ''\"\n            [isActive]=\"action.isActive && action.isActive()\"\n            [isDisabled]=\"\n              _isActionRunning(action) ||\n              (action.isDisabled && action.isDisabled())\n            \"\n            (click)=\"_runAction(action)\"\n          >\n            <div *ngIf=\"_isActionRunning(action)\" class=\"d-inline-block fa-fw\">\n              <div class=\"action-loading\"></div>\n            </div>\n            <lf-icon\n              *ngIf=\"!_isActionRunning(action) && action.icon\"\n              [icon]=\"action.icon\"\n              [fixedWidth]=\"true\"\n            >\n            </lf-icon>\n            {{ actionText(action) }}\n          </button>\n          <!-- Action with options -->\n          <ng-container *ngIf=\"action.options\">\n            <!-- Surround actions with options with dividers -->\n            <div lf-dropdown-item *ngIf=\"i > 0\" [itemType]=\"'divider'\"></div>\n            <h6\n              lf-dropdown-item\n              [class]=\"action.class || ''\"\n              [itemType]=\"'header'\"\n            >\n              <lf-icon\n                *ngIf=\"action.icon\"\n                [icon]=\"action.icon\"\n                [fixedWidth]=\"true\"\n              >\n              </lf-icon>\n              {{ actionText(action) }}\n            </h6>\n            <ng-container *ngFor=\"let option of action.options\">\n              <!-- Anchor option -->\n              <a\n                lf-dropdown-item\n                *ngIf=\"option.href\"\n                [class]=\"option.class || ''\"\n                [href]=\"option.href\"\n              >\n                {{ actionOptionText(action, option) }}\n              </a>\n              <!-- Regular option (button) -->\n              <button\n                lf-dropdown-item\n                type=\"button\"\n                *ngIf=\"!option.href\"\n                [class]=\"option.class || ''\"\n                [isActive]=\"option.isActive && option.isActive()\"\n                [isDisabled]=\"\n                  _isActionOptionRunning(action, option) ||\n                  (option.isDisabled && option.isDisabled())\n                \"\n                (click)=\"_runActionOption(action, option)\"\n              >\n                <div\n                  *ngIf=\"_isActionOptionRunning(action, option)\"\n                  class=\"d-inline-block fa-fw\"\n                >\n                  <div class=\"action-loading\"></div>\n                </div>\n                {{ actionOptionText(action, option) }}\n              </button>\n            </ng-container>\n            <div\n              lf-dropdown-item\n              *ngIf=\"i < actions.length - 1 && !actions[i + 1].options\"\n              [itemType]=\"'divider'\"\n            ></div>\n          </ng-container>\n        </ng-container>\n      </lf-dropdown-menu>\n    </lf-dropdown>\n  </div>\n</ng-container>\n"
    }),
    __param(0, Inject(LfI18n))
], ActionsMenuComponent);

/**
 * Abstract class for components that are toggleable and path based.
 */
let Toggleable = 
// tslint:disable-next-line: directive-class-suffix
class Toggleable extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        /**
         * Whether the toggleable element should start visible.
         */
        this.startVisible = false;
        /**
         * Event emitter which emits an event whenever the toggleable is set to be
         * shown.
         */
        // tslint:disable-next-line:no-output-rename
        this._show = new EventEmitter();
        /**
         * Event emitter which emits an event whenever the toggleable is set to be
         * hidden.
         */
        // tslint:disable-next-line:no-output-rename
        this._hide = new EventEmitter();
    }
    /**
     * Whether the toggleable is visible.
     */
    get isVisible() {
        return this._isVisible;
    }
    set isVisible(setVisible) {
        if (!this._isVisible && setVisible) {
            this._isVisible = true;
            this._show.emit();
        }
        else if (this._isVisible && !setVisible) {
            this._isVisible = false;
            this._hide.emit();
        }
    }
    ngOnInit() {
        this._isVisible = this.startVisible;
    }
    /**
     * Show the toggleable element.
     */
    show() {
        this.isVisible = true;
    }
    /**
     * Hide the toggleable element.
     */
    hide() {
        this.isVisible = false;
    }
    /**
     * Toggle the visibility of the toggleable element.
     */
    toggle() {
        this.isVisible = !this.isVisible;
    }
};
Toggleable.ctorParameters = () => [
    { type: PathBased },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    Input()
], Toggleable.prototype, "startVisible", void 0);
__decorate([
    Output('show')
], Toggleable.prototype, "_show", void 0);
__decorate([
    Output('hide')
], Toggleable.prototype, "_hide", void 0);
__decorate([
    observable
], Toggleable.prototype, "_isVisible", void 0);
__decorate([
    computed
], Toggleable.prototype, "isVisible", null);
__decorate([
    action
], Toggleable.prototype, "show", null);
__decorate([
    action
], Toggleable.prototype, "hide", null);
__decorate([
    action
], Toggleable.prototype, "toggle", null);
Toggleable = __decorate([
    Directive()
    // tslint:disable-next-line: directive-class-suffix
], Toggleable);

var AlertComponent_1;
/**
 * LF alert component.
 */
let AlertComponent = AlertComponent_1 = class AlertComponent extends Toggleable {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
    }
    get closeButtonTooltip() {
        return this.translate(I18N_CLOSE_BUTTON_TOOLTIP_KEY);
    }
};
AlertComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    observable,
    Input()
], AlertComponent.prototype, "style", void 0);
__decorate([
    observable,
    Input()
], AlertComponent.prototype, "showCloseButton", void 0);
__decorate([
    computed
], AlertComponent.prototype, "closeButtonTooltip", null);
AlertComponent = AlertComponent_1 = __decorate([
    Component({
        selector: 'lf-alert',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: AlertComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <div\n    class=\"alert {{ style ? 'alert-' + style : '' }}\"\n    role=\"alert\"\n    *ngIf=\"isVisible\"\n  >\n    <button\n      type=\"button\"\n      class=\"close\"\n      [title]=\"closeButtonTooltip\"\n      [attr.aria-label]=\"closeButtonTooltip\"\n      *ngIf=\"showCloseButton\"\n      (click)=\"hide()\"\n    >\n      <span aria-hidden=\"true\">&times;</span>\n    </button>\n    <ng-content></ng-content>\n  </div>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], AlertComponent);

/**
 * Abstract class that all components which "encapsulate" a storage value should
 * inherit.
 */
let Value = 
// tslint:disable-next-line: directive-class-suffix
class Value extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        /**
         * Whether the component should render in "read-only" mode (this has no effect
         * if this component is within an already "read-only" component).
         */
        // tslint:disable-next-line:no-input-rename
        this._isReadOnly = false;
        /**
         * Add an `lf-value` class to all value components.
         */
        this._classLfValue = true;
    }
    /**
     * Label associated with this value.
     */
    get label() {
        return this.translate(I18N_VALUE_LABEL_KEY);
    }
    /**
     * Code associated with this value.
     */
    get code() {
        return this.translate(I18N_VALUE_CODE_KEY);
    }
    /**
     * Help message associated with this value.
     */
    get helpMessage() {
        return this.translate(I18N_VALUE_HELP_MESSAGE_KEY);
    }
    /**
     * Legend associated with this value.
     */
    get legend() {
        return this.translate(I18N_VALUE_LEGEND_KEY);
    }
    /**
     * Message used to ask the user to retry validating the value.
     */
    get retryValidateText() {
        return this.translate(I18N_VALUE_RETRY_VALIDATE_TEXT_KEY);
    }
    /**
     * Whether the component should render in "read-only" mode. Inherits the
     * "read-only" state of parent components (meaning that it's not possible to
     * have an "editable" component within a "read-only" one). Furthermore, if the
     * component's value is computed, the component will always be in "read-only"
     * mode.
     */
    get isReadOnly() {
        return ((this.parentPathBasedComponent !== null &&
            this.parentPathBasedComponent.isReadOnly) ||
            this.relativeStorage.isComputed() ||
            this._isReadOnly);
    }
};
Value.ctorParameters = () => [
    { type: PathBased },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    observable,
    Input('isReadOnly')
], Value.prototype, "_isReadOnly", void 0);
__decorate([
    HostBinding('class.lf-value')
], Value.prototype, "_classLfValue", void 0);
__decorate([
    computed
], Value.prototype, "label", null);
__decorate([
    computed
], Value.prototype, "code", null);
__decorate([
    computed
], Value.prototype, "helpMessage", null);
__decorate([
    computed
], Value.prototype, "legend", null);
__decorate([
    computed
], Value.prototype, "retryValidateText", null);
__decorate([
    computed
], Value.prototype, "isReadOnly", null);
Value = __decorate([
    Directive()
    // tslint:disable-next-line: directive-class-suffix
], Value);

/**
 * Validation panel component.
 */
let ValidationPanelComponent = class ValidationPanelComponent extends Toggleable {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.lfRouter = lfRouter;
    }
    get errorsText() {
        return this.translate(I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY);
    }
    get warningsText() {
        return this.translate(I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY);
    }
    get noIssuesText() {
        return this.translate(I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY);
    }
    get focusButtonTooltip() {
        return this.translate(I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY);
    }
    get nextButtonTooltip() {
        return this.translate(I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY);
    }
    get prevButtonTooltip() {
        return this.translate(I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY);
    }
    get closeButtonTooltip() {
        return this.translate(I18N_CLOSE_BUTTON_TOOLTIP_KEY);
    }
    get isPending() {
        return this.relativeStorage.validationStatus() === PENDING;
    }
    get currentPath() {
        return this._currentPath && this._validationIssues[this._currentPath]
            ? this._currentPath
            : this._pages[0];
    }
    get currentLabel() {
        return this.currentPath && this.labelOf(this.currentPath);
    }
    get hasNext() {
        return this._pages.length - 1 > this._pages.indexOf(this.currentPath);
    }
    get hasPrevious() {
        return this._pages.indexOf(this.currentPath) > 0;
    }
    get errors() {
        return ((this._validationIssues[this.currentPath] || []).filter(issue => !issue.isWarning) || []);
    }
    get warnings() {
        return ((this._validationIssues[this.currentPath] || []).filter(issue => issue.isWarning) || []);
    }
    get hasNoIssues() {
        return this._pages.length === 0;
    }
    get panelType() {
        return this.isPending
            ? 'secondary'
            : this.errors.length > 0
                ? 'danger'
                : this.warnings.length > 0
                    ? 'warning'
                    : 'success';
    }
    get _pages() {
        return Object.keys(this._validationIssues);
    }
    get _validationIssues() {
        return this.relativeStorage.validationIssues() || {};
    }
    show() {
        super.show();
        this.navigateToCurrentPath();
    }
    triggerFocus() {
        this.navigateToCurrentPath();
    }
    next() {
        if (this.hasNext) {
            this._currentPath = this._pages[this._pages.indexOf(this.currentPath) + 1];
            this.navigateToCurrentPath();
        }
    }
    previous() {
        if (this.hasPrevious) {
            this._currentPath = this._pages[this._pages.indexOf(this.currentPath) - 1];
            this.navigateToCurrentPath();
        }
    }
    /**
     * Label associated with the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    labelOf(path) {
        return this.lfI18n.getFromPath(path, I18N_VALUE_LABEL_KEY) || path;
    }
    navigateToCurrentPath() {
        if (this.currentPath) {
            // Check if the first route that matches the path is navigateable, if not
            // don't navigate
            const firstMatching = this.lfRouter.matchingRoutes(this.currentPath, {
                navigateToParent: true
            })[0];
            const navigateable = firstMatching &&
                this.lfRouter.navigateableRouteFromMatchingRoutes([firstMatching]);
            if (navigateable) {
                this.lfRouter.navigateFromNavigateableRoute(navigateable, {
                    queryParamsHandling: 'merge'
                });
            }
            else {
                // Remove fragment TODO: Find a better way of doing it
                this.lfRouter.navigate('.', { queryParamsHandling: 'merge' });
            }
        }
    }
};
ValidationPanelComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter }
];
__decorate([
    observable
], ValidationPanelComponent.prototype, "_currentPath", void 0);
__decorate([
    computed
], ValidationPanelComponent.prototype, "errorsText", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "warningsText", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "noIssuesText", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "focusButtonTooltip", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "nextButtonTooltip", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "prevButtonTooltip", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "closeButtonTooltip", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "isPending", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "currentPath", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "currentLabel", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "hasNext", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "hasPrevious", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "errors", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "warnings", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "hasNoIssues", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "panelType", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "_pages", null);
__decorate([
    computed
], ValidationPanelComponent.prototype, "_validationIssues", null);
__decorate([
    action
], ValidationPanelComponent.prototype, "show", null);
__decorate([
    action
], ValidationPanelComponent.prototype, "triggerFocus", null);
__decorate([
    action
], ValidationPanelComponent.prototype, "next", null);
__decorate([
    action
], ValidationPanelComponent.prototype, "previous", null);
ValidationPanelComponent = __decorate([
    Component({
        selector: 'lf-validation-panel',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <div class=\"validation-panel-container\" *ngIf=\"isVisible\">\n    <div class=\"card border-{{ panelType }}\">\n      <div\n        class=\"card-header bg-{{ panelType }} text-white d-inline-flex\n               justify-content-between\"\n      >\n        <span class=\"header-title\">{{ currentLabel }}</span>\n        <div class=\"actions-bar d-inline-flex justify-content-between\">\n          <button\n            lf-button\n            class=\"panel-focus\"\n            size=\"sm\"\n            [title]=\"focusButtonTooltip\"\n            [attr.aria-label]=\"focusButtonTooltip\"\n            [style]=\"'outline-light'\"\n            (click)=\"triggerFocus()\"\n          >\n            <lf-icon icon=\"crosshairs\"></lf-icon>\n          </button>\n          <div class=\"btn-group mx-4\">\n            <button\n              lf-button\n              class=\"panel-prev\"\n              size=\"sm\"\n              [title]=\"prevButtonTooltip\"\n              [attr.aria-label]=\"prevButtonTooltip\"\n              [style]=\"'outline-light'\"\n              [isDisabled]=\"!hasPrevious\"\n              (click)=\"previous()\"\n            >\n              <lf-icon icon=\"chevron-left\"></lf-icon>\n            </button>\n            <button\n              lf-button\n              class=\"panel-next\"\n              size=\"sm\"\n              [title]=\"nextButtonTooltip\"\n              [attr.aria-label]=\"nextButtonTooltip\"\n              [style]=\"'outline-light'\"\n              [isDisabled]=\"!hasNext\"\n              (click)=\"next()\"\n            >\n              <lf-icon icon=\"chevron-right\"></lf-icon>\n            </button>\n          </div>\n          <button\n            lf-button\n            class=\"panel-close\"\n            size=\"sm\"\n            [title]=\"closeButtonTooltip\"\n            [attr.aria-label]=\"closeButtonTooltip\"\n            [style]=\"'outline-light'\"\n            (click)=\"hide()\"\n          >\n            <lf-icon icon=\"times\"></lf-icon>\n          </button>\n        </div>\n      </div>\n      <div class=\"card-body bg-{{ panelType }}\">\n        <div *ngIf=\"isPending\" class=\"pending\"></div>\n        <ng-container *ngIf=\"!isPending && errors.length > 0\">\n          <strong>\n            <lf-icon icon=\"exclamation-circle\"></lf-icon> {{ errorsText }}\n          </strong>\n          <ul>\n            <li\n              *ngFor=\"let error of errors\"\n              class=\"validation-issue\"\n              lfValidationIssue\n              [path]=\"currentPath\"\n              [issue]=\"error\"\n            ></li>\n          </ul>\n        </ng-container>\n        <ng-container *ngIf=\"!isPending && warnings.length > 0\">\n          <strong>\n            <lf-icon icon=\"exclamation-triangle\"></lf-icon> {{ warningsText }}\n          </strong>\n          <ul>\n            <li\n              *ngFor=\"let warning of warnings\"\n              class=\"validation-issue\"\n              lfValidationIssue\n              [path]=\"currentPath\"\n              [issue]=\"warning\"\n            ></li>\n          </ul>\n        </ng-container>\n        <ng-container *ngIf=\"!isPending && hasNoIssues\">\n          {{ noIssuesText }}\n        </ng-container>\n      </div>\n    </div>\n  </div>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased))
], ValidationPanelComponent);

var AppComponent_1;
/**
 * Lf app component.
 */
let AppComponent = AppComponent_1 = class AppComponent extends Value {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.lfRouter = lfRouter;
        // State of the tree nav visibility
        this._isTreeNavVisible = false;
        // Whether the backdrop element should be in visible or invisible state
        this._isBackdropVisible = false;
        // Whether the backdrop element should exist
        this._shouldBackdropExist = false;
    }
    get isTreeNavVisible() {
        return this._isTreeNavVisible;
    }
    // Current `translateX` value of the tree nav
    get treeNavTranslateX() {
        // Obtain `tx` from `'matrix(a, b, c, d, tx, ty)'`
        return +window
            .getComputedStyle(this._treeNavContainer.nativeElement)
            .getPropertyValue('transform')
            .split(',')[4];
    }
    ngOnInit() {
        if (this._path === undefined) {
            this._path = '/';
        }
        super.ngOnInit();
    }
    ngAfterViewInit() {
        // Hide tree nav when `Escape` is pressed
        this.onPressEsc = evt => {
            if (this.isTreeNavVisible && evt.key === 'Escape') {
                this.hideTreeNav();
            }
        };
        window.addEventListener('keyup', this.onPressEsc);
        // Scroll viewport to the top whenever the router path changes
        if (this.lfRouter !== null) {
            this.disposeOnRouterPathChange = observe(this.lfRouter, 'path', () => {
                this.scrollTo({ top: 0, left: 0 });
            });
        }
    }
    ngOnDestroy() {
        this.onPressEsc && window.removeEventListener('keyup', this.onPressEsc);
        this.disposeOnRouterPathChange && this.disposeOnRouterPathChange();
    }
    showTreeNav() {
        if (!this._isTreeNavVisible) {
            this._isTreeNavVisible = true;
            this._isBackdropVisible = true;
            this._shouldBackdropExist = true;
            this.lastTreeNavTranslateX = this.treeNavTranslateX;
        }
    }
    hideTreeNav() {
        if (this._isTreeNavVisible) {
            this._isTreeNavVisible = false;
            // When there was no time for an animation and `transitionend` isn't called
            if (this.lastTreeNavTranslateX === this.treeNavTranslateX) {
                this._onTreeNavTransitionEnd();
            }
        }
    }
    validate() {
        this.relativeStorage.setTouched('.', true);
        this._validationPanel.show();
    }
    /**
     * Scroll the main content area.
     * @param options Options for the scrolling.
     */
    scrollTo(options) {
        // Depending on whether we're in mobile or desktop mode, the scrollable
        // element differs
        this._mainContainer.nativeElement.scrollTo(options);
        this._mainContent.nativeElement.scrollTo(options);
    }
    // Action to run after the tree nav finishes hiding (hide backdrop)
    _onTreeNavTransitionEnd() {
        if (!this.isTreeNavVisible && this._isBackdropVisible) {
            runInAction('hideTreeNavBackdrop', () => (this._isBackdropVisible = false));
        }
    }
    // Action to run after the backdrop finishes hiding (delete backdrop)
    _onBackdropTransitionEnd() {
        runInAction('removeTreeNavBackdrop', () => (this._shouldBackdropExist = false));
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isRecordSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "record" type and not "nullable"');
        }
    }
};
AppComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    ViewChild(ValidationPanelComponent)
], AppComponent.prototype, "_validationPanel", void 0);
__decorate([
    ViewChild('treeNavContainer')
], AppComponent.prototype, "_treeNavContainer", void 0);
__decorate([
    ViewChild('mainContainer')
], AppComponent.prototype, "_mainContainer", void 0);
__decorate([
    ViewChild('mainContent')
], AppComponent.prototype, "_mainContent", void 0);
__decorate([
    observable
], AppComponent.prototype, "_isTreeNavVisible", void 0);
__decorate([
    observable
], AppComponent.prototype, "_isBackdropVisible", void 0);
__decorate([
    observable
], AppComponent.prototype, "_shouldBackdropExist", void 0);
__decorate([
    computed
], AppComponent.prototype, "isTreeNavVisible", null);
__decorate([
    action
], AppComponent.prototype, "showTreeNav", null);
__decorate([
    action
], AppComponent.prototype, "hideTreeNav", null);
__decorate([
    action
], AppComponent.prototype, "validate", null);
AppComponent = AppComponent_1 = __decorate([
    Component({
        selector: 'lf-app',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: AppComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <div class=\"d-flex flex-column h-100\">\n    <!-- Application header -->\n    <header id=\"lf-header\">\n      <ng-content select=\"lf-top-bar\"></ng-content>\n    </header>\n\n    <!-- Content -->\n    <div #mainContainer id=\"lf-main-container\" class=\"container-fluid\">\n      <div id=\"lf-main-row\" class=\"row\">\n        <!-- Container of the tree nav (collapsible from the `top-bar`) -->\n        <div\n          #treeNavContainer\n          id=\"lf-tree-nav-container\"\n          class=\"col-xl-2 col-md-3 col-sm-12\"\n          [class.show]=\"isTreeNavVisible\"\n          [class.animate]=\"_shouldBackdropExist\"\n          (transitionend)=\"_onTreeNavTransitionEnd()\"\n        >\n          <ng-content select=\"lf-tree-nav\"></ng-content>\n        </div>\n\n        <!-- Main content -->\n        <div\n          #mainContent\n          id=\"lf-main-content\"\n          class=\"col-xl-10 col-md-9 col-sm-12\"\n        >\n          <ng-content></ng-content>\n\n          <!-- Validation panel -->\n          <lf-validation-panel></lf-validation-panel>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div\n    *ngIf=\"_shouldBackdropExist\"\n    class=\"modal-backdrop fade d-md-none\"\n    [class.show]=\"_isBackdropVisible\"\n    (click)=\"hideTreeNav()\"\n    (transitionend)=\"_onBackdropTransitionEnd()\"\n  ></div>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], AppComponent);

/**
 * LF component used to display the "top-bar" of an application.
 */
let TopBarComponent = class TopBarComponent {
    constructor(lfStorage, lfRouter, lfI18n, lfFileStorage, _appComponent) {
        this.lfStorage = lfStorage;
        this.lfRouter = lfRouter;
        this.lfI18n = lfI18n;
        this.lfFileStorage = lfFileStorage;
        this._appComponent = _appComponent;
    }
    get retryValidationText() {
        return this.lfI18n.get(I18N_VALUE_RETRY_VALIDATE_TEXT_KEY);
    }
    get rootUrl() {
        try {
            return this.lfRouter.createUrl('/');
        }
        catch (err) {
            return '/';
        }
    }
    get appIsPending() {
        return (this.lfStorage.shouldShowPending() ||
            (this.lfFileStorage && this.lfFileStorage.isLoading));
    }
    get shouldShowAppRecompute() {
        return !!this.lfStorage.shouldShowRejected();
    }
    get isTreeNavVisible() {
        return this._appComponent.isTreeNavVisible;
    }
    recomputeAppStateProperties() {
        this.lfStorage.recomputeStateProperties();
    }
    showTreeNav() {
        this._appComponent.showTreeNav();
    }
};
TopBarComponent.ctorParameters = () => [
    { type: LfStorage },
    { type: LfRouter },
    { type: LfI18n, decorators: [{ type: Inject, args: [LfI18n,] }] },
    { type: LfFileStorage, decorators: [{ type: Optional }, { type: Inject, args: [LfFileStorage,] }] },
    { type: AppComponent, decorators: [{ type: Inject, args: [AppComponent,] }] }
];
__decorate([
    observable.struct,
    Input()
], TopBarComponent.prototype, "actions", void 0);
__decorate([
    computed
], TopBarComponent.prototype, "retryValidationText", null);
__decorate([
    computed
], TopBarComponent.prototype, "rootUrl", null);
__decorate([
    computed
], TopBarComponent.prototype, "appIsPending", null);
__decorate([
    computed
], TopBarComponent.prototype, "shouldShowAppRecompute", null);
__decorate([
    computed
], TopBarComponent.prototype, "isTreeNavVisible", null);
__decorate([
    action
], TopBarComponent.prototype, "recomputeAppStateProperties", null);
__decorate([
    action
], TopBarComponent.prototype, "showTreeNav", null);
TopBarComponent = __decorate([
    Component({
        selector: 'lf-top-bar',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <nav class=\"navbar navbar-expand-lg justify-content-between\">\n    <!-- Tree toggle + title + pending icon -->\n    <div class=\"navbar-brand\">\n      <!-- Small screen: show tree-nav button -->\n      <button\n        lf-button\n        class=\"tree-nav-show d-md-none\"\n        [style]=\"'outline-secondary'\"\n        (click)=\"showTreeNav()\"\n      >\n        <lf-icon icon=\"bars\"></lf-icon>\n      </button>\n\n      <!-- Title -->\n      <a\n        class=\"navbar-title\"\n        [routerLink]=\"rootUrl\"\n        queryParamsHandling=\"merge\"\n      >\n        <ng-content></ng-content>\n      </a>\n\n      <!-- Pending app validation -->\n      <div class=\"pending-app\" *ngIf=\"appIsPending\"></div>\n\n      <!-- Rejected app validation -->\n      <div\n        class=\"rejected-app\"\n        *ngIf=\"shouldShowAppRecompute\"\n        (click)=\"recomputeAppStateProperties()\"\n      >\n        <lf-tooltip [help]=\"retryValidationText\" placement=\"right\">\n          <lf-icon icon=\"warning\"></lf-icon>\n        </lf-tooltip>\n      </div>\n    </div>\n\n    <!-- Application actions -->\n    <lf-actions-menu [actions]=\"actions\" [alignMenusRight]=\"true\">\n    </lf-actions-menu>\n  </nav>\n</ng-container>\n"
    }),
    __param(2, Inject(LfI18n)),
    __param(3, Optional()), __param(3, Inject(LfFileStorage)),
    __param(4, Inject(AppComponent))
], TopBarComponent);

/**
 * Bootstrap button component.
 */
let ButtonComponent = class ButtonComponent {
    constructor(_host) {
        /**
         * HTML button type.
         */
        this.type = 'button';
        /**
         * Match the width of parent if `true`.
         */
        this.block = false;
        /**
         * Display a dropdown icon (this is automatic if `dropdownToggleSplit` is
         * set).
         */
        this.dropdownToggle = false;
        /**
         * Reduces the padding of the button so it can be used as the dropdown part of
         * a split dropdown.
         */
        this.dropdownToggleSplit = false;
        /**
         * Set the button as disabled.
         */
        this.isDisabled = false;
        /**
         * Set the button as active.
         */
        this.isActive = false;
        /**
         * Always add the class `btn` to LF buttons.
         */
        this._hostClassBtn = true;
        this._tagName = _host.nativeElement.tagName.toLowerCase();
    }
    // Set the role as `'button'` when the element is an `a`.
    get _role() {
        return this._tagName === 'a' ? 'button' : undefined;
    }
    // Set the corresponding style class depending on the button style (setting
    // individual classes instead of `class` itself makes it possible for the user
    // to still set `class` on the component without it being overridden)
    get _hostClassBtnPrimary() {
        return this.style === 'primary';
    }
    get _hostClassBtnSecondary() {
        return this.style === 'secondary';
    }
    get _hostClassBtnSuccess() {
        return this.style === 'success';
    }
    get _hostClassBtnDanger() {
        return this.style === 'danger';
    }
    get _hostClassBtnWarning() {
        return this.style === 'warning';
    }
    get _hostClassBtnInfo() {
        return this.style === 'info';
    }
    get _hostClassBtnLight() {
        return this.style === 'light';
    }
    get _hostClassBtnDark() {
        return this.style === 'dark';
    }
    get _hostClassBtnLink() {
        return this.style === 'link';
    }
    get _hostClassBtnOutlinePrimary() {
        return this.style === 'outline-primary';
    }
    get _hostClassBtnOutlineSecondary() {
        return this.style === 'outline-secondary';
    }
    get _hostClassBtnOutlineSuccess() {
        return this.style === 'outline-success';
    }
    get _hostClassBtnOutlineDanger() {
        return this.style === 'outline-danger';
    }
    get _hostClassBtnOutlineWarning() {
        return this.style === 'outline-warning';
    }
    get _hostClassBtnOutlineInfo() {
        return this.style === 'outline-info';
    }
    get _hostClassBtnOutlineLight() {
        return this.style === 'outline-light';
    }
    get _hostClassBtnOutlineDark() {
        return this.style === 'outline-dark';
    }
    // Set the corresponding style class
    get _hostClassBtnSm() {
        return this.size === 'sm';
    }
    get _hostClassBtnLg() {
        return this.size === 'lg';
    }
    // Set the dropdown toggle class when possible
    get _hostClassDropdownToggle() {
        return (this._tagName !== 'input' &&
            (this.dropdownToggle || this.dropdownToggleSplit));
    }
    // Set type to `'button'` by default (on `button`s and `input`s)
    get _hostType() {
        return this._tagName !== 'a' ? this.type || 'button' : undefined;
    }
    get _hostDisabled() {
        return this._tagName !== 'a' && this.isDisabled ? '' : undefined;
    }
    get _hostAriaDisabled() {
        return this._tagName !== 'a' && this.isDisabled ? 'true' : undefined;
    }
    get _hostAriaPressed() {
        return this.isActive ? 'true' : undefined;
    }
};
ButtonComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    observable,
    Input()
], ButtonComponent.prototype, "style", void 0);
__decorate([
    observable,
    Input()
], ButtonComponent.prototype, "size", void 0);
__decorate([
    observable,
    Input()
], ButtonComponent.prototype, "type", void 0);
__decorate([
    observable,
    Input(),
    HostBinding('class.btn-block')
], ButtonComponent.prototype, "block", void 0);
__decorate([
    observable,
    Input()
], ButtonComponent.prototype, "dropdownToggle", void 0);
__decorate([
    observable,
    Input(),
    HostBinding('class.dropdown-toggle-split')
], ButtonComponent.prototype, "dropdownToggleSplit", void 0);
__decorate([
    observable,
    Input()
], ButtonComponent.prototype, "isDisabled", void 0);
__decorate([
    observable,
    Input(),
    HostBinding('class.active')
], ButtonComponent.prototype, "isActive", void 0);
__decorate([
    HostBinding('class.btn')
], ButtonComponent.prototype, "_hostClassBtn", void 0);
__decorate([
    HostBinding('attr.role')
], ButtonComponent.prototype, "_role", null);
__decorate([
    computed,
    HostBinding('class.btn-primary')
], ButtonComponent.prototype, "_hostClassBtnPrimary", null);
__decorate([
    computed,
    HostBinding('class.btn-secondary')
], ButtonComponent.prototype, "_hostClassBtnSecondary", null);
__decorate([
    computed,
    HostBinding('class.btn-success')
], ButtonComponent.prototype, "_hostClassBtnSuccess", null);
__decorate([
    computed,
    HostBinding('class.btn-danger')
], ButtonComponent.prototype, "_hostClassBtnDanger", null);
__decorate([
    computed,
    HostBinding('class.btn-warning')
], ButtonComponent.prototype, "_hostClassBtnWarning", null);
__decorate([
    computed,
    HostBinding('class.btn-info')
], ButtonComponent.prototype, "_hostClassBtnInfo", null);
__decorate([
    computed,
    HostBinding('class.btn-light')
], ButtonComponent.prototype, "_hostClassBtnLight", null);
__decorate([
    computed,
    HostBinding('class.btn-dark')
], ButtonComponent.prototype, "_hostClassBtnDark", null);
__decorate([
    computed,
    HostBinding('class.btn-link')
], ButtonComponent.prototype, "_hostClassBtnLink", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-primary')
], ButtonComponent.prototype, "_hostClassBtnOutlinePrimary", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-secondary')
], ButtonComponent.prototype, "_hostClassBtnOutlineSecondary", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-success')
], ButtonComponent.prototype, "_hostClassBtnOutlineSuccess", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-danger')
], ButtonComponent.prototype, "_hostClassBtnOutlineDanger", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-warning')
], ButtonComponent.prototype, "_hostClassBtnOutlineWarning", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-info')
], ButtonComponent.prototype, "_hostClassBtnOutlineInfo", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-light')
], ButtonComponent.prototype, "_hostClassBtnOutlineLight", null);
__decorate([
    computed,
    HostBinding('class.btn-outline-dark')
], ButtonComponent.prototype, "_hostClassBtnOutlineDark", null);
__decorate([
    computed,
    HostBinding('class.btn-sm')
], ButtonComponent.prototype, "_hostClassBtnSm", null);
__decorate([
    computed,
    HostBinding('class.btn-lg')
], ButtonComponent.prototype, "_hostClassBtnLg", null);
__decorate([
    computed,
    HostBinding('class.dropdown-toggle')
], ButtonComponent.prototype, "_hostClassDropdownToggle", null);
__decorate([
    computed,
    HostBinding('attr.type')
], ButtonComponent.prototype, "_hostType", null);
__decorate([
    computed,
    HostBinding('attr.disabled')
], ButtonComponent.prototype, "_hostDisabled", null);
__decorate([
    computed,
    HostBinding('attr.aria-disabled')
], ButtonComponent.prototype, "_hostAriaDisabled", null);
__decorate([
    computed,
    HostBinding('attr.aria-pressed')
], ButtonComponent.prototype, "_hostAriaPressed", null);
ButtonComponent = __decorate([
    Component({
        // tslint:disable-next-line:component-selector
        selector: 'button[lf-button], input[lf-button], a[lf-button]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
    })
], ButtonComponent);

var CardContentComponent_1;
/**
 * Content of an `lf-card`.
 */
let CardContentComponent = CardContentComponent_1 = class CardContentComponent extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
    }
    // Classes for each type of card content
    get _hostClassCardHeader() {
        return this.contentType === 'header';
    }
    get _hostClassCardBody() {
        return this.contentType === 'body';
    }
    get _hostClassCardFooter() {
        return this.contentType === 'footer';
    }
    get _hostClassCardTitle() {
        return this.contentType === 'title';
    }
    get _hostClassCardSubtitle() {
        return this.contentType === 'subtitle';
    }
    get _hostClassCardText() {
        return this.contentType === 'text';
    }
    get _hostClassCardLink() {
        return this.contentType === 'link';
    }
    get _hostClassCardImg() {
        return this.contentType === 'img';
    }
    get _hostClassCardImgOverlay() {
        return this.contentType === 'img-overlay';
    }
    get _hostClassCardImgTop() {
        return this.contentType === 'img-top';
    }
    get _hostClassCardImgBottom() {
        return this.contentType === 'img-bottom';
    }
};
CardContentComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    observable,
    Input()
], CardContentComponent.prototype, "contentType", void 0);
__decorate([
    computed,
    HostBinding('class.card-header')
], CardContentComponent.prototype, "_hostClassCardHeader", null);
__decorate([
    computed,
    HostBinding('class.card-body')
], CardContentComponent.prototype, "_hostClassCardBody", null);
__decorate([
    computed,
    HostBinding('class.card-footer')
], CardContentComponent.prototype, "_hostClassCardFooter", null);
__decorate([
    computed,
    HostBinding('class.card-title')
], CardContentComponent.prototype, "_hostClassCardTitle", null);
__decorate([
    computed,
    HostBinding('class.card-subtitle')
], CardContentComponent.prototype, "_hostClassCardSubtitle", null);
__decorate([
    computed,
    HostBinding('class.card-text')
], CardContentComponent.prototype, "_hostClassCardText", null);
__decorate([
    computed,
    HostBinding('class.card-link')
], CardContentComponent.prototype, "_hostClassCardLink", null);
__decorate([
    computed,
    HostBinding('class.card-img')
], CardContentComponent.prototype, "_hostClassCardImg", null);
__decorate([
    computed,
    HostBinding('class.card-img-overlay')
], CardContentComponent.prototype, "_hostClassCardImgOverlay", null);
__decorate([
    computed,
    HostBinding('class.card-img-top')
], CardContentComponent.prototype, "_hostClassCardImgTop", null);
__decorate([
    computed,
    HostBinding('class.card-img-bottom')
], CardContentComponent.prototype, "_hostClassCardImgBottom", null);
CardContentComponent = CardContentComponent_1 = __decorate([
    Component({
        selector: 'lf-card-content, [lf-card-content]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: CardContentComponent_1 }],
        template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], CardContentComponent);

var CardComponent_1;
/**
 * Bootstrap card component, see options on how to further customise the card
 * with background and border utilities at [Bootstrap documentation](
 * https://getbootstrap.com/docs/4.1/components/card/#card-styles).
 */
let CardComponent = CardComponent_1 = class CardComponent extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        /**
         * Always add the class `card` to LF cards.
         */
        this._hostClassCard = true;
    }
};
CardComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    HostBinding('class.card')
], CardComponent.prototype, "_hostClassCard", void 0);
CardComponent = CardComponent_1 = __decorate([
    Component({
        selector: 'lf-card, [lf-card]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: CardComponent_1 }],
        template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], CardComponent);

/**
 * Abstract class used to represent typical "inline-able" values.
 */
let InlineValue = 
// tslint:disable-next-line: directive-class-suffix
class InlineValue extends Value {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.lfRouter = lfRouter;
        /**
         * Whether the component should be hidden when its value isn't required.
         * **NOT READY FOR USE**
         */
        // TODO: What about components that aren't nullable? Example: tables, text, we
        // should use minSize/minLength instead. Allow each component to implement its
        // own "isRequired" functionality?
        this._hideWhenNotRequired = false;
        /**
         * Event emitter which emits an event whenever the component's DOM input is
         * focused.
         */
        this.focus = new EventEmitter();
        /**
         * Event emitter which emits an event whenever the component's DOM input is
         * blurred.
         */
        this.blur = new EventEmitter();
        /**
         * Add an `lf-inline-value` class to components.
         */
        this._classLfInlineValue = true;
    }
    /**
     * Whether this component should be displayed.
     */
    get shouldDisplay() {
        return (this.relativeStorage.has() &&
            (!this._hideWhenNotRequired ||
                this.relativeStorage.getStateProperty('.', 'isRequired')));
    }
    ngOnInit() {
        super.ngOnInit();
    }
    ngAfterViewInit() {
        if (this.lfRouter !== null) {
            // Auto-focus the field when this component's path is activated
            this.disposeOnActive = autorun(() => {
                if (this.lfRouter.isActiveWithFragment(this.path)) {
                    const res = this.onActivate &&
                        this.onActivate(this.lfRouter.pathWithFragment);
                    // Trigger the `focus` only when path matches exactly
                    if (res !== false &&
                        this.lfRouter.isActiveWithFragment(this.path, true)) {
                        asap(() => this.triggerFocus());
                    }
                }
            }, { name: 'fieldAutorunFocusOnActive' });
        }
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        this.disposeOnActive && this.disposeOnActive();
    }
    /**
     * Scrolls this component into the center of the viewport and focuses it.
     */
    triggerFocus() {
        if (this.targets && this.targets.length > 0) {
            const target = this.targets.first.nativeElement;
            target.scrollIntoView({ block: 'center' });
            target.focus();
        }
    }
    /**
     * Action to run whenever a focusable part of the field is focused.
     * @param evt `focus` event.
     */
    _onFocus(evt) {
        this.focus.emit(evt);
    }
    /**
     * Action to run whenever a focusable part of the field is blurred.
     * @param evt `blur` event.
     * @param setTouched Whether to try and set the value as "touched". Defaults
     * to `true`.
     */
    _onBlur(evt, setTouched = true) {
        var _a;
        if (setTouched && !this.relativeStorage.isComputed()) {
            this.relativeStorage.setTouched();
        }
        // Remove the fragment when the path exactly matches the URL
        if ((_a = this.lfRouter) === null || _a === void 0 ? void 0 : _a.isActiveWithFragment(this.path, true)) {
            this.lfRouter.navigate('.', { queryParamsHandling: 'merge' });
        }
        this.blur.emit(evt);
    }
};
InlineValue.ctorParameters = () => [
    { type: PathBased },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter }
];
__decorate([
    observable,
    Input()
], InlineValue.prototype, "_hideWhenNotRequired", void 0);
__decorate([
    Output()
], InlineValue.prototype, "focus", void 0);
__decorate([
    Output()
], InlineValue.prototype, "blur", void 0);
__decorate([
    HostBinding('class.lf-inline-value')
], InlineValue.prototype, "_classLfInlineValue", void 0);
__decorate([
    ViewChildren('focusTarget')
], InlineValue.prototype, "targets", void 0);
__decorate([
    computed
], InlineValue.prototype, "shouldDisplay", null);
InlineValue = __decorate([
    Directive()
    // tslint:disable-next-line: directive-class-suffix
], InlineValue);

/**
 * Class which represents a component whose value may be restricted by a set of
 * options.
 */
let SelectionValue = 
// tslint:disable-next-line: directive-class-suffix
class SelectionValue extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Selectable options (possibly fetched asynchronously).
     */
    // Not `computed` due to `useState` (cannot be used within a `computed`)
    get options() {
        return this.translate(I18N_SELECTION_OPTIONS_KEY, { useState: true }) || [];
    }
    /**
     * Text to be shown when there are no options available.
     */
    get noOptionsText() {
        return this.translate(I18N_SELECTION_NO_OPTIONS_TEXT_KEY);
    }
    /**
     * Promise-status of the options.
     */
    get optionsStatus() {
        return this.translationStatus(I18N_SELECTION_OPTIONS_KEY);
    }
};
SelectionValue.ctorParameters = () => [
    { type: PathBased },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter }
];
__decorate([
    computed
], SelectionValue.prototype, "noOptionsText", null);
__decorate([
    computed
], SelectionValue.prototype, "optionsStatus", null);
SelectionValue = __decorate([
    Directive()
    // tslint:disable-next-line: directive-class-suffix
], SelectionValue);

/**
 * Component used for selecting a list of options by using inputs of type
 * `checkbox`.
 */
let CheckboxGroupComponent = class CheckboxGroupComponent extends SelectionValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
        /**
         * Whether the list of checkbox inputs should be displayed inline. The
         * component will still display in "block" mode in small screens.
         */
        this.displayInline = false;
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        const minSize = this.relativeStorage.getStateProperty('.', 'minSize');
        return minSize !== undefined && minSize > 0;
    }
    /**
     * Whether a given option is selected.
     * @param option Option to check if it is selected.
     */
    isSelected(option) {
        return this.relativeStorage
            .get()
            .some(el => comparer.structural(el, option.value));
    }
    /**
     * Action to run whenever a checkbox `input` changes.
     * @param option Option that changed.
     */
    _onOptionChange(option, evt) {
        const checked = !!evt.target.checked;
        const isSelected = this.isSelected(option);
        if (isSelected && !checked) {
            this.relativeStorage.filter('.', el => !comparer.structural(el, option.value));
        }
        else if (!isSelected && checked) {
            this.relativeStorage.push('.', option.value);
        }
        this.relativeStorage.setDirty();
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isListSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "list" type and not "nullable"');
        }
    }
};
CheckboxGroupComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    observable,
    Input()
], CheckboxGroupComponent.prototype, "displayInline", void 0);
__decorate([
    computed
], CheckboxGroupComponent.prototype, "showIsRequired", null);
__decorate([
    action
], CheckboxGroupComponent.prototype, "_onOptionChange", null);
CheckboxGroupComponent = __decorate([
    Component({
        selector: 'lf-checkbox-group',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"lf-checkable-group input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Checkboxes -->\n      <div\n        class=\"lf-checkables form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [class.display-inline]=\"displayInline\"\n      >\n        <!-- Text for when there are no options -->\n        <div\n          *ngIf=\"optionsStatus !== 'pending' && options.length === 0\"\n          class=\"no-options\"\n        >\n          {{ noOptionsText }}\n        </div>\n\n        <!-- Pending options -->\n        <div *ngIf=\"optionsStatus === 'pending'\" class=\"pending-options\"></div>\n\n        <div\n          class=\"lf-checkable input-group input-group-sm\"\n          *ngFor=\"let option of options; let i = index\"\n        >\n          <!-- Code of each checkbox -->\n          <div *ngIf=\"option.code\" class=\"input-group-prepend\">\n            <div class=\"input-group-text\">{{ option.code }}</div>\n          </div>\n\n          <!-- Checkbox -->\n          <label\n            class=\"form-control custom-control custom-checkbox\"\n            [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n            [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n            [class.is-readonly]=\"isReadOnly\"\n          >\n            <!-- Actual checkbox -->\n            <!--\n              Note that checkboxes don't support `readonly`, so we use\n              the `disabled` attribute\n            -->\n            <input\n              #focusTarget\n              type=\"checkbox\"\n              class=\"custom-control-input\"\n              [name]=\"path + '[' + i + ']'\"\n              [value]=\"i\"\n              [checked]=\"isSelected(option)\"\n              [disabled]=\"isReadOnly\"\n              (change)=\"_onOptionChange(option, $event)\"\n              (focus)=\"_onFocus($event)\"\n              (blur)=\"_onBlur($event)\"\n            />\n\n            <!-- Checkbox label -->\n            <span class=\"custom-control-label\">\n              {{ option.label }}\n              <lf-help-tooltip\n                *ngIf=\"option.helpMessage\"\n                [help]=\"option.helpMessage\"\n              ></lf-help-tooltip>\n            </span>\n          </label>\n        </div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], CheckboxGroupComponent);

/**
 * LF checkbox component.
 */
let CheckboxComponent = class CheckboxComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        if (!this.relativeStorage.isNullable()) {
            const allowedValues = this.relativeStorage.getStateProperty('.', 'allowedValues');
            return (allowedValues && allowedValues.length === 1 && allowedValues[0] === true);
        }
        const isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
        return !!isRequired;
    }
    /**
     * Action to run whenever the value of the checkbox changes.
     * @param evt `change` event.
     */
    _onCheckboxChange(evt) {
        this.relativeStorage.set('.', !!evt.target.checked);
        this.relativeStorage.setDirty();
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isBooleanSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "boolean" type');
        }
    }
};
CheckboxComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    computed
], CheckboxComponent.prototype, "showIsRequired", null);
__decorate([
    action
], CheckboxComponent.prototype, "_onCheckboxChange", null);
CheckboxComponent = __decorate([
    Component({
        selector: 'lf-checkbox',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"lf-checkable input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Checkbox -->\n      <label\n        class=\"form-control custom-control custom-checkbox\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n      >\n        <!-- Actual checkbox -->\n        <!--\n          Note that checkboxes don't support `readonly`, so we use the\n          `disabled` attribute\n        -->\n        <input\n          #focusTarget\n          type=\"checkbox\"\n          class=\"custom-control-input\"\n          [name]=\"path\"\n          [checked]=\"relativeStorage.get()\"\n          [indeterminate]=\"relativeStorage.get() === null\"\n          (change)=\"_onCheckboxChange($event)\"\n          [disabled]=\"isReadOnly\"\n          (focus)=\"_onFocus($event)\"\n          (blur)=\"_onBlur($event)\"\n        />\n\n        <!-- Label -->\n        <span class=\"custom-control-label\">\n          <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n          <lf-help-tooltip\n            *ngIf=\"helpMessage\"\n            [help]=\"helpMessage\"\n          ></lf-help-tooltip>\n        </span>\n      </label>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], CheckboxComponent);

/**
 * Automatically change `ngx-bootstrap` locale based on current language.
 */
let BsLocaleChanger = class BsLocaleChanger {
    constructor(bsLocaleService, lfI18n) {
        this.bsLocaleService = bsLocaleService;
        this.lfI18n = lfI18n;
        observe(this.lfI18n, 'currentLanguage', () => {
            this.bsLocaleService.use(this.lfI18n.get(I18N_BS_LOCALE_KEY) || 'en');
        }, true);
    }
};
BsLocaleChanger.ctorParameters = () => [
    { type: BsLocaleService },
    { type: LfI18n }
];
BsLocaleChanger.ɵprov = ɵɵdefineInjectable({ factory: function BsLocaleChanger_Factory() { return new BsLocaleChanger(ɵɵinject(BsLocaleService), ɵɵinject(LfI18n)); }, token: BsLocaleChanger, providedIn: "root" });
BsLocaleChanger = __decorate([
    Injectable({ providedIn: 'root' })
], BsLocaleChanger);

/**
 * Creates a new date-range schema object.
 * @param options Options used to create the schema.
 * @returns Date-range schema.
 */
function dateRangeSchema(options = {}) {
    const initialState = options.initialState || {};
    const startDateOptions = options.startDateOptions || {};
    const endDateOptions = options.endDateOptions || {};
    // When the date-range isn't computed, we apply `minDate` and `maxDate` to the
    // inner tuple elements for automatic validation
    if (options.computedValue === undefined) {
        if (options.minDate) {
            initialState.minDate =
                typeof options.minDate === 'function'
                    ? (ctx) => options.minDate(ctx.relativeStorage('..'))
                    : options.minDate;
        }
        if (options.maxDate) {
            initialState.maxDate =
                typeof options.maxDate === 'function'
                    ? (ctx) => options.maxDate(ctx.relativeStorage('..'))
                    : options.maxDate;
        }
        const minDate = typeof options.minDate === 'function'
            ? (ctx) => ctx.getStateProperty('.', 'minDate')
            : options.minDate;
        const maxDate = typeof options.maxDate === 'function'
            ? (ctx) => ctx.getStateProperty('.', 'maxDate')
            : options.maxDate;
        startDateOptions.minDate = minDate;
        // Disallow an end date that comes before the start date
        endDateOptions.minDate = ctx => ctx.get('0');
        endDateOptions.maxDate = maxDate;
    }
    return tupleSchema([dateSchema(startDateOptions), dateSchema(endDateOptions)], Object.assign(Object.assign({}, options), { initialState }));
}
/**
 * Returns whether a given schema is a date-range schema.
 * @param schema Schema to check.
 * @returns `true` when the provided schema is a date-range schema.
 */
function isDateRangeSchema(schema) {
    return (isTupleSchema(schema) &&
        schema.elementsSchemas.length === 2 &&
        isDateSchema(schema.elementsSchemas[0]) &&
        isDateSchema(schema.elementsSchemas[1]));
}

/**
 * Converts a date representing a certain day in local time to a date that
 * represents that same day in UTC. Used to fix:
 * https://github.com/valor-software/ngx-bootstrap/issues/3609
 * @param date Date to convert.
 * @returns Date in UTC.
 */
function localDateToUTC(date) {
    return new Date(Date.UTC(date.getFullYear(), date.getMonth(), date.getDate()));
}

/**
 * LF date-range component.
 */
let DateRangeComponent = class DateRangeComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, _bsLocaleChanger) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Format for a single date.
     */
    get dateFormat() {
        return this.translate(I18N_DATE_FORMAT_KEY);
    }
    /**
     * Separator used between the dates in the date-range.
     */
    get separator() {
        return this.translate(I18N_DATE_RANGE_SEPARATOR_KEY) || '-';
    }
    /**
     * Placeholder of the `input` field.
     */
    get placeholder() {
        const datePlaceholder = this.translate(I18N_DATE_PLACEHOLDER_KEY);
        return datePlaceholder
            ? `${datePlaceholder}${this.separator}${datePlaceholder}`
            : '';
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        const isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
        return !!isRequired;
    }
    /**
     * Configuration to use by Bootstrap datepicker.
     */
    get bsConfig() {
        return {
            containerClass: 'theme-default',
            rangeInputFormat: this.dateFormat,
            rangeSeparator: this.separator
        };
    }
    ngOnInit() {
        super.ngOnInit();
        this.disposeBsConfigObserve = observe(this, 'bsConfig', () => {
            asap(() => {
                this._bsDateRangePicker.setConfig();
                this._bsDateRangePicker.bsValueChange.emit(this.relativeStorage.has() ? this.relativeStorage.get() : null);
            });
        }, true);
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        this.disposeBsConfigObserve && this.disposeBsConfigObserve();
    }
    /**
     * Action to run whenever the date range is modified via the Bootstrap
     * datepicker UI.
     * @param dateRange Tuple representing the range.
     */
    _onDateRangePickerChange(dateRange) {
        if (dateRange) {
            // XXX: When the `rangeInputFormat` is not the default one, manually
            // setting the input causes `dateRange` to contain `[null, null]`; this
            // should probably be fixed from ngx-bootstrap's side
            if (!dateRange[0] || !dateRange[1]) {
                dateRange = null;
            }
            else {
                // XXX: We convert the dates to UTC due to:
                // https://github.com/valor-software/ngx-bootstrap/issues/3609
                dateRange[0] = localDateToUTC(dateRange[0]);
                dateRange[1] = localDateToUTC(dateRange[1]);
            }
        }
        // FIXME: This function is being called as soon as the component loads, thus
        // the comparison against the current date range (which shouldn't be
        // needed).
        const currentDateRange = this.relativeStorage.get();
        if (!comparer.structural(currentDateRange, dateRange)) {
            this.relativeStorage.set('.', dateRange);
            this.relativeStorage.setDirty('.', true);
        }
    }
    _onFocus(evt) {
        super._onFocus(evt);
        this._bsDateRangePicker.show();
    }
    /**
     * Set touched when the date picker is hidden rather than on blur (it is
     * possible to change the value via the popup without actually focusing the
     * input; besides, otherwise the input may go invalid when the user selects
     * the first date of the range, but before the second).
     */
    _onDateRangePickerHidden() {
        if (!this.relativeStorage.isComputed()) {
            this.relativeStorage.setTouched('.', true);
        }
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isDateRangeSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "date-range" type and "nullable"');
        }
    }
};
DateRangeComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
    { type: BsLocaleChanger }
];
__decorate([
    ViewChild('drp')
], DateRangeComponent.prototype, "_bsDateRangePicker", void 0);
__decorate([
    computed
], DateRangeComponent.prototype, "dateFormat", null);
__decorate([
    computed
], DateRangeComponent.prototype, "separator", null);
__decorate([
    computed
], DateRangeComponent.prototype, "placeholder", null);
__decorate([
    computed
], DateRangeComponent.prototype, "showIsRequired", null);
__decorate([
    computed
], DateRangeComponent.prototype, "bsConfig", null);
__decorate([
    action
], DateRangeComponent.prototype, "_onDateRangePickerChange", null);
__decorate([
    action
], DateRangeComponent.prototype, "_onDateRangePickerHidden", null);
DateRangeComponent = __decorate([
    Component({
        selector: 'lf-date-range',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <!--\n        We disable the directive's `triggers` since it doesn't work well on\n        focus (using \"focus\" as a trigger will cause the menu to disappear if it\n        was already shown since the trigger calls `toggle`). Instead we manually\n        call `show` on focus.\n      -->\n      <input\n        #focusTarget\n        bsDaterangepicker\n        #drp=\"bsDaterangepicker\"\n        triggers=\"\"\n        [bsConfig]=\"bsConfig\"\n        [bsValue]=\"relativeStorage.get()\"\n        [isDisabled]=\"isReadOnly\"\n        (bsValueChange)=\"_onDateRangePickerChange($event)\"\n        (onHidden)=\"_onDateRangePickerHidden()\"\n        type=\"text\"\n        class=\"form-control date-input text-right\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [minDate]=\"relativeStorage.getStateProperty('.', 'minDate')\"\n        [maxDate]=\"relativeStorage.getStateProperty('.', 'maxDate')\"\n        [placeholder]=\"placeholder\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event, false)\"\n      />\n\n      <!-- Date icon -->\n      <div class=\"input-group-append\" (click)=\"drp.toggle()\">\n        <div class=\"input-group-text\"><lf-icon icon=\"calendar\"></lf-icon></div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], DateRangeComponent);

/**
 * LF date component.
 */
let DateComponent = class DateComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, _bsLocaleChanger) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Format of the date.
     */
    get dateFormat() {
        return this.translate(I18N_DATE_FORMAT_KEY) || 'YYYY-MM-DD';
    }
    /**
     * Placeholder of the `input` field.
     */
    get placeholder() {
        return this.translate(I18N_DATE_PLACEHOLDER_KEY) || '';
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        const isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
        return !!isRequired;
    }
    /**
     * Config for the `BsDatepicker`.
     */
    get bsConfig() {
        return {
            containerClass: 'theme-default',
            dateInputFormat: this.dateFormat
        };
    }
    ngOnInit() {
        super.ngOnInit();
        this.disposeBsConfigObserve = observe(this, 'bsConfig', () => {
            asap(() => {
                this._bsDatePicker.setConfig();
                this._bsDatePicker.bsValueChange.emit(this.relativeStorage.has() ? this.relativeStorage.get() : null);
            });
        }, true);
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        this.disposeBsConfigObserve && this.disposeBsConfigObserve();
    }
    /**
     * Action to run whenever the date `input` changes.
     * @param date Date to set.
     */
    _onDatePickerChange(date) {
        // XXX: We convert the date to UTC due to:
        // https://github.com/valor-software/ngx-bootstrap/issues/3609
        date = !date || isNaN(+date) ? null : localDateToUTC(date);
        // FIXME: This function is being called as soon as the component loads, thus
        // the comparison against the current date (which shouldn't be needed).
        const currentDate = this.relativeStorage.get();
        if (!comparer.structural(currentDate, date)) {
            this.relativeStorage.set('.', date);
            this.relativeStorage.setDirty();
        }
    }
    _onFocus(evt) {
        super._onFocus(evt);
        this._bsDatePicker.show();
    }
    /**
     * Set touched when the date picker is hidden rather than on blur (it is
     * possible to change the value via the popup without actually focusing the
     * input).
     */
    _onDatePickerHidden() {
        if (!this.relativeStorage.isComputed()) {
            this.relativeStorage.setTouched();
        }
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isDateSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "date" type and "nullable"');
        }
    }
};
DateComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
    { type: BsLocaleChanger }
];
__decorate([
    ViewChild('dp')
], DateComponent.prototype, "_bsDatePicker", void 0);
__decorate([
    computed
], DateComponent.prototype, "dateFormat", null);
__decorate([
    computed
], DateComponent.prototype, "placeholder", null);
__decorate([
    computed
], DateComponent.prototype, "showIsRequired", null);
__decorate([
    computed
], DateComponent.prototype, "bsConfig", null);
__decorate([
    action
], DateComponent.prototype, "_onDatePickerChange", null);
__decorate([
    action
], DateComponent.prototype, "_onDatePickerHidden", null);
DateComponent = __decorate([
    Component({
        selector: 'lf-date',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <!--\n        We disable the directive's `triggers` since it doesn't work well on\n        focus (using \"focus\" as a trigger will cause the menu to disappear if it\n        was already shown since the trigger calls `toggle`). Instead we manually\n        call `show` on focus.\n      -->\n      <input\n        #focusTarget\n        bsDatepicker\n        #dp=\"bsDatepicker\"\n        triggers=\"\"\n        [bsConfig]=\"bsConfig\"\n        [bsValue]=\"relativeStorage.get()\"\n        [isDisabled]=\"isReadOnly\"\n        (bsValueChange)=\"_onDatePickerChange($event)\"\n        (onHidden)=\"_onDatePickerHidden()\"\n        type=\"text\"\n        class=\"form-control date-input text-right\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [minDate]=\"relativeStorage.getStateProperty('.', 'minDate')\"\n        [maxDate]=\"relativeStorage.getStateProperty('.', 'maxDate')\"\n        [placeholder]=\"placeholder\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event, false)\"\n      />\n\n      <!-- Date icon -->\n      <div class=\"input-group-append\" (click)=\"dp.toggle()\">\n        <div class=\"input-group-text\"><lf-icon icon=\"calendar\"></lf-icon></div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], DateComponent);

let DropdownItemComponent = class DropdownItemComponent {
    constructor(_host) {
        this.itemType = 'item';
        this.isActive = false;
        this.isDisabled = false;
        this._tagName = _host.nativeElement.tagName.toLowerCase();
    }
    // Classes for each type of dropdown item
    get _hostClassDropdownItem() {
        return this.itemType === 'item';
    }
    get _hostClassDropdownDivider() {
        return this.itemType === 'divider';
    }
    get _hostClassDropdownItemText() {
        return this.itemType === 'text';
    }
    get _hostClassDropdownHeader() {
        return this.itemType === 'header';
    }
    // Set disable (attribute for buttons, class for others)
    get _hostClassDisabled() {
        return (this.itemType === 'item' && this._tagName !== 'button' && this.isDisabled);
    }
    get _hostDisabled() {
        return this.itemType === 'item' &&
            this._tagName === 'button' &&
            this.isDisabled
            ? ''
            : undefined;
    }
};
DropdownItemComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    observable,
    Input()
], DropdownItemComponent.prototype, "itemType", void 0);
__decorate([
    observable,
    Input(),
    HostBinding('class.active')
], DropdownItemComponent.prototype, "isActive", void 0);
__decorate([
    observable,
    Input()
], DropdownItemComponent.prototype, "isDisabled", void 0);
__decorate([
    computed,
    HostBinding('class.dropdown-item')
], DropdownItemComponent.prototype, "_hostClassDropdownItem", null);
__decorate([
    computed,
    HostBinding('class.dropdown-divider')
], DropdownItemComponent.prototype, "_hostClassDropdownDivider", null);
__decorate([
    computed,
    HostBinding('class.dropdown-item-text')
], DropdownItemComponent.prototype, "_hostClassDropdownItemText", null);
__decorate([
    computed,
    HostBinding('class.dropdown-header')
], DropdownItemComponent.prototype, "_hostClassDropdownHeader", null);
__decorate([
    computed,
    HostBinding('class.disabled')
], DropdownItemComponent.prototype, "_hostClassDisabled", null);
__decorate([
    computed,
    HostBinding('attr.disabled')
], DropdownItemComponent.prototype, "_hostDisabled", null);
DropdownItemComponent = __decorate([
    Component({
        selector: 'lf-dropdown-item, [lf-dropdown-item]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
    })
], DropdownItemComponent);

let DropdownMenuComponent = class DropdownMenuComponent {
    constructor() {
        this.alignRight = false;
        this._hostClassDropdownMenu = true;
    }
};
__decorate([
    observable,
    Input(),
    HostBinding('class.dropdown-menu-right')
], DropdownMenuComponent.prototype, "alignRight", void 0);
__decorate([
    HostBinding('class.dropdown-menu')
], DropdownMenuComponent.prototype, "_hostClassDropdownMenu", void 0);
DropdownMenuComponent = __decorate([
    Component({
        selector: 'lf-dropdown-menu, [lf-dropdown-menu]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
    })
], DropdownMenuComponent);

var DropdownComponent_1;
/**
 * LF dropdown component.
 */
let DropdownComponent = DropdownComponent_1 = class DropdownComponent extends Toggleable {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, host) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.host = host;
        this.position = 'down';
        this.offset = 0;
        this.flip = true;
        this.boundary = 'scrollParent';
        this.reference = 'toggle';
        this.display = 'dynamic';
        this.shown = new EventEmitter();
        this.hidden = new EventEmitter();
        this._hostClassBtnGroup = true;
    }
    get _hostClassDropleft() {
        return this.position === 'left';
    }
    get _hostClassDropright() {
        return this.position === 'right';
    }
    get _hostClassDropup() {
        return this.position === 'up';
    }
    ngAfterViewInit() {
        this.createDropdown();
    }
    ngOnDestroy() {
        this.destroyDropdown();
        super.ngOnDestroy();
    }
    /**
     * Creates a new dropdown and starts listening to events.
     */
    createDropdown() {
        const target = this._toggle
            ? this._toggle.nativeElement
            : this.host.nativeElement.children[0];
        this.$toggle = $(target)
            .attr('data-toggle', 'dropdown')
            .attr('aria-haspopup', 'true')
            .attr('aria-expanded', 'false')
            .dropdown({
            offset: this.offset,
            flip: this.flip,
            boundary: this.boundary instanceof ElementRef
                ? this.boundary.nativeElement
                : this.boundary,
            reference: this.reference instanceof ElementRef
                ? this.reference.nativeElement
                : this.reference,
            display: this.display
        });
        this.$host = $(this.host.nativeElement);
        // Make UI match state at startup
        if (this.isVisible) {
            this.$toggle.dropdown('toggle');
        }
        // There seems to be no way of updating these settings, so the most we can
        // do is destroy and reconstruct the modal whenever they change. TODO:
        // Figure out a better approach for this
        this.disposeOnOptionsChange = reaction(() => [
            this.offset,
            this.flip,
            this.boundary,
            this.reference,
            this.display
        ], () => {
            this.destroyDropdown();
            this.createDropdown();
        }, { name: 'dropdownReactionOnOptionsChange' });
        // Set the component's state if the dropdown is shown without calling
        // `show()`
        this.$host.on('show.bs.dropdown', () => {
            this.isAnimating = true;
            if (!this.isVisible) {
                this.show();
            }
        });
        // Set the component's state if the dropdown is hidden without calling
        // `hide()`
        this.$host.on('hide.bs.dropdown', () => {
            this.isAnimating = true;
            if (this.isVisible) {
                this.hide();
            }
        });
        // Runs when the showing animation ends
        this.$host.on('shown.bs.dropdown', () => {
            this.isAnimating = false;
            this.shown.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (!this.isVisible) {
                this.hide();
            }
        });
        // Runs when the hiding animation ends
        this.$host.on('hidden.bs.dropdown', () => {
            this.isAnimating = false;
            this.hidden.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (this.isVisible) {
                this.show();
            }
        });
        // Open the dropdown when `show` is called
        this.showSubscription = this._show.subscribe(() => {
            if (!this.isAnimating && !this.$host.hasClass('show')) {
                this.$toggle.dropdown('toggle');
            }
        });
        // Close the dropdown when `hide` is called
        this.hideSubscription = this._hide.subscribe(() => {
            if (!this.isAnimating && this.$host.hasClass('show')) {
                this.$toggle.dropdown('toggle');
            }
        });
    }
    /**
     * Unsubscribes from all events and destroys the dropdown.
     */
    destroyDropdown() {
        this.disposeOnOptionsChange && this.disposeOnOptionsChange();
        if (this.$host) {
            this.$host.off('show.bs.dropdown');
            this.$host.off('hide.bs.dropdown');
            this.$host.off('shown.bs.dropdown');
            this.$host.off('hidden.bs.dropdown');
        }
        this.showSubscription && this.showSubscription.unsubscribe();
        this.hideSubscription && this.hideSubscription.unsubscribe();
        this.$toggle &&
            this.$toggle
                .removeAttr('data-toggle')
                .removeAttr('aria-haspopup')
                .removeAttr('aria-expanded')
                .dropdown('dispose');
    }
};
DropdownComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: ElementRef }
];
__decorate([
    observable,
    Input()
], DropdownComponent.prototype, "position", void 0);
__decorate([
    observable,
    Input()
], DropdownComponent.prototype, "offset", void 0);
__decorate([
    observable,
    Input()
], DropdownComponent.prototype, "flip", void 0);
__decorate([
    observable,
    Input()
], DropdownComponent.prototype, "boundary", void 0);
__decorate([
    observable,
    Input()
], DropdownComponent.prototype, "reference", void 0);
__decorate([
    observable,
    Input()
], DropdownComponent.prototype, "display", void 0);
__decorate([
    Output()
], DropdownComponent.prototype, "shown", void 0);
__decorate([
    Output()
], DropdownComponent.prototype, "hidden", void 0);
__decorate([
    HostBinding('class.btn-group')
], DropdownComponent.prototype, "_hostClassBtnGroup", void 0);
__decorate([
    ContentChild('dropdownToggle', { read: ElementRef })
], DropdownComponent.prototype, "_toggle", void 0);
__decorate([
    computed,
    HostBinding('class.dropleft')
], DropdownComponent.prototype, "_hostClassDropleft", null);
__decorate([
    computed,
    HostBinding('class.dropright')
], DropdownComponent.prototype, "_hostClassDropright", null);
__decorate([
    computed,
    HostBinding('class.dropup')
], DropdownComponent.prototype, "_hostClassDropup", null);
DropdownComponent = DropdownComponent_1 = __decorate([
    Component({
        selector: 'lf-dropdown, [lf-dropdown]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: DropdownComponent_1 }],
        template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], DropdownComponent);

var FileComponent_1;
/**
 * Component used for selecting files.
 */
let FileComponent = FileComponent_1 = class FileComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, lfFileHolder) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
        this.lfFileHolder = lfFileHolder;
        /**
         * One or more unique file type specifiers describing file types to allow.
         */
        this.accept = '';
        // Unique id per component, used for the label to target the file input
        this._id = `lf-file-input-${FileComponent_1.idCounter++}`;
        this._selectedFile = null;
    }
    /**
     * "Choose file" placeholder text.
     */
    get choosePlaceholder() {
        return this.translate(I18N_FILE_CHOOSE_PLACEHOLDER_KEY);
    }
    /**
     * "Browse" text.
     */
    get browseText() {
        return this.translate(I18N_FILE_BROWSE_TEXT_KEY);
    }
    /**
     * "No file chosen" text.
     */
    get noneChosenText() {
        return this.translate(I18N_FILE_NONE_CHOSEN_KEY);
    }
    /**
     * "Clear" button tooltip.
     */
    get clearButtonTooltip() {
        return this.translate(I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY);
    }
    get value() {
        return this.relativeStorage.has() ? this.relativeStorage.get() : undefined;
    }
    ngAfterViewInit() {
        super.ngAfterViewInit();
        // Update the selected file when the value changes. If the file is in the
        // file holder then we switch to it, otherwise we set the file as `null`,
        // since it doesn't exist
        this.disposeObserveValue = observe(this, 'value', ({ newValue }) => {
            const file = this.lfFileHolder.get(this.relativeStorage.currentPath);
            if (file && newValue === file.name) {
                this._selectedFile = file;
            }
            else {
                this.setFile(null);
            }
        }, true);
        // Remove selected file when a file was selected but the `minSize`/`maxSize`
        // changed and made the selected file invalid
        this.disposeOnMinMaxSizeChange = reaction(() => [this.value, this.minSize, this.maxSize], () => {
            const file = this.lfFileHolder.get(this.relativeStorage.currentPath);
            if (file && !this.hasValidSize(file)) {
                this.setFile(null);
            }
        }, { name: 'fileReactionOnMinMaxSizeChange' });
    }
    ngOnDestroy() {
        this.disposeObserveValue && this.disposeObserveValue();
        this.disposeOnMinMaxSizeChange && this.disposeOnMinMaxSizeChange();
        super.ngOnDestroy();
    }
    /**
     * Action to run on every `input` event of the file input.
     * @param evt `input` event.
     */
    _onInput(evt) {
        this.setFile(evt.target.files[0] || null);
        this.relativeStorage.setDirty();
    }
    _onClickClear(evt) {
        evt.preventDefault();
        this.setFile(null);
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isStringSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "string" type and "nullable"');
        }
    }
    setFile(file) {
        var _a;
        const fileInput = this.targets.first.nativeElement;
        // Disallow files with wrong sizes
        if (!this.hasValidSize(file)) {
            // Access file input via `#focusTarget`
            fileInput.value = '';
            file = null;
        }
        this._selectedFile = file;
        // Set file in file holder service
        if (file != null) {
            this.lfFileHolder.set(this.relativeStorage.currentPath, file);
        }
        else {
            this.lfFileHolder.delete(this.relativeStorage.currentPath);
            fileInput.value = '';
        }
        this.relativeStorage.set('.', ((_a = file) === null || _a === void 0 ? void 0 : _a.name) || null);
    }
    hasValidSize(file) {
        var _a, _b;
        return (!file ||
            (file.size >= (_a = this.minSize, (_a !== null && _a !== void 0 ? _a : 0)) &&
                file.size <= (_b = this.maxSize, (_b !== null && _b !== void 0 ? _b : Infinity))));
    }
};
FileComponent.idCounter = 0;
FileComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
    { type: LfFileHolder }
];
__decorate([
    observable,
    Input()
], FileComponent.prototype, "accept", void 0);
__decorate([
    observable,
    Input()
], FileComponent.prototype, "minSize", void 0);
__decorate([
    observable,
    Input()
], FileComponent.prototype, "maxSize", void 0);
__decorate([
    observable
], FileComponent.prototype, "_selectedFile", void 0);
__decorate([
    computed
], FileComponent.prototype, "choosePlaceholder", null);
__decorate([
    computed
], FileComponent.prototype, "browseText", null);
__decorate([
    computed
], FileComponent.prototype, "noneChosenText", null);
__decorate([
    computed
], FileComponent.prototype, "clearButtonTooltip", null);
__decorate([
    computed
], FileComponent.prototype, "value", null);
__decorate([
    action
], FileComponent.prototype, "_onInput", null);
__decorate([
    action
], FileComponent.prototype, "setFile", null);
FileComponent = FileComponent_1 = __decorate([
    Component({
        selector: 'lf-file',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"\n        this.relativeStorage.getStateProperty('.', 'isRequired') && !isReadOnly\n      \"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- File input -->\n      <div class=\"custom-file\" [title]=\"_selectedFile?.name || noneChosenText\">\n        <input\n          #focusTarget\n          type=\"file\"\n          [accept]=\"accept\"\n          [id]=\"_id\"\n          class=\"custom-file-input\"\n          [attr.aria-describedby]=\"_id\"\n          [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n          [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n          [class.is-readonly]=\"isReadOnly\"\n          [name]=\"path\"\n          [disabled]=\"isReadOnly\"\n          (input)=\"_onInput($event)\"\n          (focus)=\"_onFocus($event)\"\n          (blur)=\"_onBlur($event)\"\n        />\n        <label\n          class=\"custom-file-label\"\n          [attr.for]=\"_id\"\n          [attr.data-browse]=\"browseText\"\n        >\n          <span\n            class=\"custom-file-label-content\"\n            [class.placeholder]=\"!_selectedFile\"\n            >{{ _selectedFile?.name || choosePlaceholder }}</span\n          >\n\n          <!-- Clear button -->\n          <button\n            *ngIf=\"_selectedFile && !isReadOnly\"\n            type=\"button\"\n            class=\"close\"\n            [title]=\"clearButtonTooltip\"\n            [attr.aria-label]=\"clearButtonTooltip\"\n            (click)=\"_onClickClear($event)\"\n          >\n            <span aria-hidden=\"true\">\u00D7</span>\n          </button>\n\n          <!-- Browse text -->\n          <div class=\"browse-text\">{{ browseText }}</div>\n        </label>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], FileComponent);

var FormComponent_1;
/**
 * LF form component.
 */
let FormComponent = FormComponent_1 = class FormComponent extends Value {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
    }
    /**
     * Text used for the "help" action.
     */
    get helpActionText() {
        return this.translate(I18N_FORM_HELP_ACTION_TEXT_KEY);
    }
    /**
     * Text used for the "remove" action.
     */
    get removeActionText() {
        return this.translate(I18N_FORM_REMOVE_ACTION_TEXT_KEY);
    }
    /**
     * Message displayed to the user to confirm removal of the form.
     */
    get ensureRemoveText() {
        return this.translate(I18N_FORM_ENSURE_REMOVE_TEXT_KEY);
    }
    /**
     * Text for the "cancel" button in the removal modal.
     */
    get cancelRemoveButtonText() {
        return this.translate(I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY);
    }
    /**
     * Text for the "confirm" button in the removal modal.
     */
    get confirmRemoveButtonText() {
        return this.translate(I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY);
    }
    /**
     * Whether this form can be removed (if it is `nullable` or its parent is a
     * list or map).
     */
    get isRemovable() {
        return (this.relativeStorage.isNullable() || this.relativeStorage.isRemovable());
    }
    /**
     * Form-related actions shown on the top of the form.
     */
    get _formActions() {
        const actions = [];
        // Help action
        if (this.helpMessage !== undefined) {
            actions.push({
                text: this.helpActionText,
                class: 'help',
                style: 'outline-primary',
                icon: 'question-circle',
                callback: () => this.showHelpModal()
            });
        }
        // Remove form action
        if (this.isRemovable) {
            actions.push({
                text: this.removeActionText,
                class: 'remove-form',
                style: 'outline-danger',
                icon: 'trash',
                callback: () => this.showRemoveModal()
            });
        }
        return actions;
    }
    /**
     * Removes this form by either setting it to `null` (when it is `nullable` or
     * removing it from its parent list or map).
     */
    remove() {
        if (this.relativeStorage.isNullable()) {
            this.relativeStorage.set('.', null);
        }
        else {
            this.relativeStorage.remove();
        }
    }
    _cancelRemove() {
        this._removeModal.hide();
    }
    _confirmRemove() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._removeModal.hide();
            this.remove();
        });
    }
    showHelpModal() {
        this._helpModal.show();
    }
    showRemoveModal() {
        this._removeModal.show();
    }
};
FormComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    ViewChild('helpModal')
], FormComponent.prototype, "_helpModal", void 0);
__decorate([
    ViewChild('removeModal')
], FormComponent.prototype, "_removeModal", void 0);
__decorate([
    computed
], FormComponent.prototype, "helpActionText", null);
__decorate([
    computed
], FormComponent.prototype, "removeActionText", null);
__decorate([
    computed
], FormComponent.prototype, "ensureRemoveText", null);
__decorate([
    computed
], FormComponent.prototype, "cancelRemoveButtonText", null);
__decorate([
    computed
], FormComponent.prototype, "confirmRemoveButtonText", null);
__decorate([
    computed
], FormComponent.prototype, "isRemovable", null);
__decorate([
    computed
], FormComponent.prototype, "_formActions", null);
__decorate([
    action
], FormComponent.prototype, "remove", null);
FormComponent = FormComponent_1 = __decorate([
    Component({
        selector: 'lf-form',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: FormComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <form\n    *ngIf=\"relativeStorage.has() && relativeStorage.get() !== null\"\n    class=\"container\"\n    [name]=\"path\"\n    (submit)=\"$event.preventDefault()\"\n  >\n    <!-- Form title -->\n    <div class=\"form-title-container\">\n      <h1 class=\"form-title\">{{ label }}</h1>\n      <!-- Form actions -->\n      <lf-actions-menu\n        class=\"form-actions\"\n        [actions]=\"_formActions\"\n        buttonsSize=\"sm\"\n        [alignMenusRight]=\"true\"\n      >\n      </lf-actions-menu>\n    </div>\n\n    <!-- Form content -->\n    <ng-content></ng-content>\n  </form>\n\n  <!-- Help modal -->\n  <lf-modal #helpModal class=\"help-modal\" size=\"lg\" *ngIf=\"helpMessage\">\n    <lf-modal-header>{{ helpActionText }}</lf-modal-header>\n    <lf-modal-body [innerHTML]=\"helpMessage\"></lf-modal-body>\n  </lf-modal>\n\n  <!-- Modal to confirm form deletion -->\n  <lf-modal *ngIf=\"isRemovable\" #removeModal class=\"remove-modal\">\n    <lf-modal-header>{{ removeActionText }}</lf-modal-header>\n    <lf-modal-body>\n      <p>{{ ensureRemoveText }}</p>\n    </lf-modal-body>\n    <lf-modal-footer>\n      <button\n        lf-button\n        class=\"cancel-remove\"\n        [style]=\"'outline-secondary'\"\n        size=\"sm\"\n        (click)=\"_cancelRemove()\"\n      >\n        {{ cancelRemoveButtonText }}\n      </button>\n      <button\n        lf-button\n        class=\"confirm-remove\"\n        [style]=\"'outline-danger'\"\n        size=\"sm\"\n        (click)=\"_confirmRemove()\"\n      >\n        {{ confirmRemoveButtonText }}\n      </button>\n    </lf-modal-footer>\n  </lf-modal>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], FormComponent);

let HelpTooltipComponent = class HelpTooltipComponent {
};
__decorate([
    Input()
], HelpTooltipComponent.prototype, "help", void 0);
HelpTooltipComponent = __decorate([
    Component({
        selector: 'lf-help-tooltip',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<lf-tooltip [help]=\"help\" boundary=\"window\">\n  <lf-icon icon=\"question-circle\"></lf-icon>\n</lf-tooltip>\n"
    })
], HelpTooltipComponent);

/**
 * LF icon component.
 */
let IconComponent = class IconComponent {
    constructor() {
        this.fixedWidth = false;
        this.spin = false;
        this.pulse = false;
        this.ariaHidden = true;
    }
    get classes() {
        const classes = {
            fa: true,
            ['fa-' + this.icon]: true,
            'fa-fw': this.fixedWidth,
            'fa-spin': this.spin,
            'fa-pulse': this.pulse
        };
        if (this.size) {
            classes['fa-' + this.size] = true;
        }
        return classes;
    }
};
__decorate([
    observable,
    Input()
], IconComponent.prototype, "icon", void 0);
__decorate([
    observable,
    Input()
], IconComponent.prototype, "size", void 0);
__decorate([
    observable,
    Input()
], IconComponent.prototype, "fixedWidth", void 0);
__decorate([
    observable,
    Input()
], IconComponent.prototype, "spin", void 0);
__decorate([
    observable,
    Input()
], IconComponent.prototype, "pulse", void 0);
__decorate([
    observable,
    Input()
], IconComponent.prototype, "ariaHidden", void 0);
__decorate([
    computed
], IconComponent.prototype, "classes", null);
IconComponent = __decorate([
    Component({
        selector: 'lf-icon',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <i\n    *ngIf=\"icon\"\n    [ngClass]=\"classes\"\n    [attr.aria-hidden]=\"ariaHidden ? 'true' : 'false'\"\n  >\n  </i>\n</ng-container>\n"
    })
], IconComponent);

/**
 * Component that represents the body of a Bootstrap modal.
 */
let ModalBodyComponent = class ModalBodyComponent {
    constructor() {
        this._hostClassModalBody = true;
    }
};
__decorate([
    HostBinding('class.modal-body')
], ModalBodyComponent.prototype, "_hostClassModalBody", void 0);
ModalBodyComponent = __decorate([
    Component({
        selector: 'lf-modal-body, [lf-modal-body]',
        template: '<ng-content></ng-content>'
    })
], ModalBodyComponent);

/**
 * Component that represents the footer of a Bootstrap modal.
 */
let ModalFooterComponent = class ModalFooterComponent {
    constructor() {
        this._hostClassModalFooter = true;
    }
};
__decorate([
    HostBinding('class.modal-footer')
], ModalFooterComponent.prototype, "_hostClassModalFooter", void 0);
ModalFooterComponent = __decorate([
    Component({
        selector: 'lf-modal-footer, [lf-modal-footer]',
        template: '<ng-content></ng-content>'
    })
], ModalFooterComponent);

var ModalComponent_1;
/**
 * LF modal component.
 */
let ModalComponent = ModalComponent_1 = class ModalComponent extends Toggleable {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        /**
         * Whether to center the modal vertically on screen.
         */
        this.isCentered = false;
        /**
         * Whether to animate the modal component.
         */
        this.animate = true;
        /**
         * Whether to enable closing the modal by pressing the `Esc` key.
         */
        this.closeWithEsc = true;
        /**
         * Whether to show a dark background underneath the modal when it appears.
         */
        this.showBackdrop = true;
        /**
         * Whether to disable closing the modal by clicking on the backdrop.
         */
        this.ignoreBackdropClick = false;
        /**
         * If the modal contains `<input>`, `<select>`, or `<textarea>` elements
         * within, focus the first found element after the modal opens.
         */
        this.autoFocus = false;
        /**
         * Event emitter which emits an event whenever the modal finishes showing.
         */
        this.shown = new EventEmitter();
        /**
         * Event emitter which emits an event whenever the modal finishes hiding.
         */
        this.hidden = new EventEmitter();
    }
    ngAfterViewInit() {
        this.createModal();
    }
    ngOnDestroy() {
        this.destroyModal();
        super.ngOnDestroy();
    }
    /**
     * Method to call on long modals when their content changes, which forces
     * their height to also change.
     */
    refresh() {
        this.$modal.modal('handleUpdate');
    }
    show() {
        return new Promise((resolve) => {
            super.show();
            if (this.isAnimating) {
                this.$modal.one('shown.bs.modal', resolve);
            }
            else {
                resolve();
            }
        });
    }
    hide() {
        return new Promise((resolve) => {
            super.hide();
            if (this.isAnimating) {
                this.$modal.one('hidden.bs.modal', resolve);
            }
            else {
                resolve();
            }
        });
    }
    toggle() {
        return this.isVisible ? this.hide() : this.show();
    }
    /**
     * Creates a new modal and starts listening to events.
     */
    createModal() {
        this.$modal = $(this._modal.nativeElement).modal({
            backdrop: this.showBackdrop && this.ignoreBackdropClick
                ? 'static'
                : this.showBackdrop,
            keyboard: this.closeWithEsc,
            show: this.isVisible
        });
        // There seems to be no way of updating these settings, so the most we can
        // do is destroy and reconstruct the modal whenever they change. TODO:
        // Figure out a better approach for this, perhaps implement this
        // functionality ourselves
        this.disposeOnOptionsChange = reaction(() => [this.closeWithEsc, this.showBackdrop, this.ignoreBackdropClick], () => this.destroyModal().then(() => this.createModal()), { name: 'modalReactionOnOptionsChange' });
        // Set the component's state if the modal is shown unconventionally
        // (i.e. without calling `show()`)
        this.$modal.on('show.bs.modal', () => {
            this.isAnimating = true;
            if (!this.isVisible) {
                this.show();
            }
        });
        // Set the component's state if the modal is hidden unconventionally
        // (i.e. without calling `hide()`), this happens, for instance, when
        // pressing `Esc` or when pressing the area outside the modal
        this.$modal.on('hide.bs.modal', () => {
            this.isAnimating = true;
            if (this.isVisible) {
                this.hide();
            }
        });
        // Runs when the showing animation ends
        this.$modal.on('shown.bs.modal', () => {
            this.isAnimating = false;
            this.shown.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (!this.isVisible) {
                this.hide();
            }
            // Focus the first input of the modal's body once it opens
            if (this.autoFocus) {
                const firstInput = $('.modal-body input, .modal-body select, .modal-body textarea', this.$modal).get(0);
                if (firstInput) {
                    firstInput.focus();
                }
            }
        });
        // Runs when the hiding animation ends
        this.$modal.on('hidden.bs.modal', () => {
            this.isAnimating = false;
            this.hidden.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (this.isVisible) {
                this.show();
            }
        });
        // Open the modal when `show` is called
        this.onShowSubscription = this._show.subscribe(() => {
            if (!this.isAnimating) {
                this.$modal.modal('show');
            }
        });
        // Close the modal when `hide` is called
        this.onHideSubscription = this._hide.subscribe(() => {
            if (!this.isAnimating) {
                this.$modal.modal('hide');
            }
        });
    }
    /**
     * Unsubscribes from all events and destroys the modal (returns a promise that
     * resolves after the modal has been destroyed).
     * @returns Promise that resolves when the modal has been destroyed.
     */
    // FIXME: This returns a promise because we are forced to hide the modal prior
    // to removing it; otherwise a leftover backdrop will stay within the document
    // (this is probably an upstream Bootstrap bug)
    destroyModal() {
        this.disposeOnOptionsChange && this.disposeOnOptionsChange();
        if (this.$modal) {
            this.$modal.off('show.bs.modal');
            this.$modal.off('hide.bs.modal');
            this.$modal.off('shown.bs.modal');
            this.$modal.off('hidden.bs.modal');
        }
        this.onShowSubscription && this.onShowSubscription.unsubscribe();
        this.onHideSubscription && this.onHideSubscription.unsubscribe();
        if (this.isVisible) {
            return new Promise(resolve => {
                // If we don't hide the modal prior to disposing of it, then a leftover
                // backdrop will stay in the document
                this.hide();
                this.$modal.one('hidden.bs.modal', () => {
                    $(this).modal('dispose');
                    resolve();
                });
            });
        }
        else {
            this.$modal.modal('dispose');
            return Promise.resolve();
        }
    }
};
ModalComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "size", void 0);
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "isCentered", void 0);
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "animate", void 0);
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "closeWithEsc", void 0);
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "showBackdrop", void 0);
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "ignoreBackdropClick", void 0);
__decorate([
    observable,
    Input()
], ModalComponent.prototype, "autoFocus", void 0);
__decorate([
    Output()
], ModalComponent.prototype, "shown", void 0);
__decorate([
    Output()
], ModalComponent.prototype, "hidden", void 0);
__decorate([
    ViewChild('modal')
], ModalComponent.prototype, "_modal", void 0);
ModalComponent = ModalComponent_1 = __decorate([
    Component({
        selector: 'lf-modal',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: ModalComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <div\n    #modal\n    class=\"modal\"\n    [class.fade]=\"animate\"\n    tabindex=\"-1\"\n    role=\"dialog\"\n    aria-hidden=\"true\"\n  >\n    <div\n      class=\"modal-dialog {{ size ? 'modal-' + size : '' }}\"\n      [class.modal-dialog-centered]=\"isCentered\"\n    >\n      <div class=\"modal-content\" role=\"document\"><ng-content></ng-content></div>\n    </div>\n  </div>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], ModalComponent);

/**
 * Component that represents the header of a Bootstrap modal.
 */
let ModalHeaderComponent = class ModalHeaderComponent {
    constructor(modalComponent) {
        this.modalComponent = modalComponent;
        /**
         * Whether to display a button to close the modal.
         */
        this.showCloseButton = true;
        // The modal header must always have the `modal-header` class.
        this._hostClassModalHeader = true;
    }
    /**
     * Tooltip text used by the modal's close button.
     */
    get closeButtonTooltip() {
        return this.modalComponent.translate(I18N_CLOSE_BUTTON_TOOLTIP_KEY);
    }
    /**
     * Hides the modal.
     */
    hide() {
        this.modalComponent.hide();
    }
};
ModalHeaderComponent.ctorParameters = () => [
    { type: ModalComponent }
];
__decorate([
    observable,
    Input()
], ModalHeaderComponent.prototype, "showCloseButton", void 0);
__decorate([
    HostBinding('class.modal-header')
], ModalHeaderComponent.prototype, "_hostClassModalHeader", void 0);
__decorate([
    computed
], ModalHeaderComponent.prototype, "closeButtonTooltip", null);
ModalHeaderComponent = __decorate([
    Component({
        selector: 'lf-modal-header, [lf-modal-header]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <!-- Title -->\n  <h5 class=\"modal-title\"><ng-content></ng-content></h5>\n\n  <!-- Close button -->\n  <button\n    *ngIf=\"showCloseButton\"\n    type=\"button\"\n    class=\"close\"\n    [title]=\"closeButtonTooltip\"\n    [attr.aria-label]=\"closeButtonTooltip\"\n    (click)=\"hide()\"\n  >\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</ng-container>\n"
    })
], ModalHeaderComponent);

/**
 * LF number component.
 */
let NumberComponent = class NumberComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
        /**
         * Number of decimal digits to show.
         */
        this.scale = 0;
        /**
         * Number of digits to show on the left side of the number.
         */
        this.leadingZeroes = 1;
    }
    /**
     * Number's prefix.
     */
    get prefix() {
        return this.translate(I18N_NUMBER_PREFIX_KEY);
    }
    /**
     * Number's suffix.
     */
    get suffix() {
        return this.translate(I18N_NUMBER_SUFFIX_KEY);
    }
    /**
     * Number's decimal separator.
     */
    get decimalSeparator() {
        return this.translate(I18N_NUMBER_DECIMAL_SEPARATOR_KEY);
    }
    /**
     * Number's thousands separator.
     */
    get thousandsSeparator() {
        return this.translate(I18N_NUMBER_THOUSANDS_SEPARATOR_KEY);
    }
    get value() {
        return this.relativeStorage.has() ? this.relativeStorage.get() : undefined;
    }
    get formattedValue() {
        return (this.numericInput &&
            this.numericInput.format(this.value === undefined ? null : this.value));
    }
    get min() {
        return this.relativeStorage.has()
            ? this.relativeStorage.getStateProperty('.', 'min')
            : undefined;
    }
    get max() {
        return this.relativeStorage.has()
            ? this.relativeStorage.getStateProperty('.', 'max')
            : undefined;
    }
    /**
     * Numeric input options.
     */
    get numericInputOptions() {
        const isInt = !!this.relativeStorage.schema().isInteger;
        const min = this.min == null ? -Infinity : this.min;
        const max = this.max == null ? Infinity : this.max;
        return {
            numericRepresentation: isInt ? 'int' : 'float',
            scale: this.scale || 0,
            leadingZeroes: this.leadingZeroes || 1,
            min: isInt ? Math.max(min, Number.MIN_SAFE_INTEGER) : min,
            max: isInt ? Math.min(max, Number.MAX_SAFE_INTEGER) : max,
            prefix: this.prefix || '',
            suffix: this.suffix || '',
            decimalSeparator: this.decimalSeparator || '.',
            thousandsSeparator: this.thousandsSeparator || ''
        };
    }
    ngAfterViewInit() {
        super.ngAfterViewInit();
        // Create a new numeric input instance and recreate it whenever the
        // `<input>` element is recreated
        this.numericInput = this.newNumericInput();
        this.targetsChangeSubscription = this.targets.changes.subscribe(() => {
            this.numericInput.destroy();
            this.numericInput = this.newNumericInput();
        });
        // Update the numeric input's options whenever they change
        this.disposeObserveOptions = observe(this, 'numericInputOptions', ({ newValue }) => this.numericInput.setOptions(newValue, this.value));
        // Update the numeric input whenever the storage value changes
        this.disposeObserveValue = observe(this, 'value', ({ newValue }) => {
            if (newValue !== this.numericInput.toNumber()) {
                this.numericInput.update(newValue == null ? null : newValue);
            }
        }, true);
    }
    ngOnDestroy() {
        this.targetsChangeSubscription &&
            this.targetsChangeSubscription.unsubscribe();
        this.disposeObserveOptions && this.disposeObserveOptions();
        this.disposeObserveValue && this.disposeObserveValue();
        this.numericInput && this.numericInput.destroy();
        super.ngOnDestroy();
    }
    /**
     * Action to run on every `input` event of the text input.
     */
    _onInput() {
        this.relativeStorage.setDirty();
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isNumberSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "number" type and "nullable"');
        }
    }
    newNumericInput() {
        return new NumericInput(this.targets.first.nativeElement, Object.assign(Object.assign({}, this.numericInputOptions), { onUpdate: (_, numberValue) => this.relativeStorage.has() &&
                !this.relativeStorage.isComputed() &&
                this.relativeStorage.set('.', numberValue) }));
    }
};
NumberComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    observable,
    Input()
], NumberComponent.prototype, "scale", void 0);
__decorate([
    observable,
    Input()
], NumberComponent.prototype, "leadingZeroes", void 0);
__decorate([
    computed
], NumberComponent.prototype, "prefix", null);
__decorate([
    computed
], NumberComponent.prototype, "suffix", null);
__decorate([
    computed
], NumberComponent.prototype, "decimalSeparator", null);
__decorate([
    computed
], NumberComponent.prototype, "thousandsSeparator", null);
__decorate([
    computed
], NumberComponent.prototype, "value", null);
__decorate([
    computed
], NumberComponent.prototype, "formattedValue", null);
__decorate([
    computed
], NumberComponent.prototype, "min", null);
__decorate([
    computed
], NumberComponent.prototype, "max", null);
__decorate([
    computed
], NumberComponent.prototype, "numericInputOptions", null);
__decorate([
    action
], NumberComponent.prototype, "_onInput", null);
NumberComponent = __decorate([
    Component({
        selector: 'lf-number',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"\n        this.relativeStorage.getStateProperty('.', 'isRequired') && !isReadOnly\n      \"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <input\n        #focusTarget\n        type=\"text\"\n        class=\"form-control text-right\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [value]=\"formattedValue\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (input)=\"_onInput()\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      />\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], NumberComponent);

/**
 * Abstract class used to represent components where a single option is selected
 * from a set of options.
 */
let SingleSelectionValue = 
// tslint:disable-next-line: directive-class-suffix
class SingleSelectionValue extends SelectionValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        if (!this.relativeStorage.isNullable()) {
            return false;
        }
        const isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
        return !!isRequired;
    }
    /**
     * Index of the selected option; `-1` when none of the available options is
     * selected.
     */
    // Not `computed` since `options` cannot be accessed within a `computed` value
    get selectedOptionIndex() {
        const val = this.relativeStorage.get();
        return this.options.findIndex(opt => comparer.structural(val, opt.value));
    }
};
SingleSelectionValue.ctorParameters = () => [
    { type: PathBased },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter }
];
__decorate([
    computed
], SingleSelectionValue.prototype, "showIsRequired", null);
SingleSelectionValue = __decorate([
    Directive()
    // tslint:disable-next-line: directive-class-suffix
], SingleSelectionValue);

/**
 * Component used for selecting from a list of options by using inputs of type
 * `radio`.
 */
let RadioComponent = class RadioComponent extends SingleSelectionValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
        /**
         * Whether the list of radio inputs should be displayed inline. The component
         * will still display in "block" mode in small screens.
         */
        this.displayInline = false;
    }
    /**
     * Action to run whenever the value of the `radio` input changes.
     * @param evt `change` event.
     */
    _onRadioChange(evt) {
        this.relativeStorage.set('.', this.options[evt.target.value].value);
        this.relativeStorage.setDirty();
    }
};
RadioComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    observable,
    Input()
], RadioComponent.prototype, "displayInline", void 0);
__decorate([
    action
], RadioComponent.prototype, "_onRadioChange", null);
RadioComponent = __decorate([
    Component({
        selector: 'lf-radio',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"lf-checkable-group input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Radios -->\n      <div\n        class=\"lf-checkables form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [class.display-inline]=\"displayInline\"\n      >\n        <!-- Text for when there are no options -->\n        <div\n          *ngIf=\"optionsStatus !== 'pending' && options.length === 0\"\n          class=\"no-options\"\n        >\n          {{ noOptionsText }}\n        </div>\n\n        <!-- Pending options -->\n        <div *ngIf=\"optionsStatus === 'pending'\" class=\"pending-options\"></div>\n\n        <div\n          class=\"lf-checkable input-group input-group-sm\"\n          *ngFor=\"let option of options; let i = index\"\n        >\n          <!-- Code of each radio -->\n          <div *ngIf=\"option.code\" class=\"input-group-prepend\">\n            <div class=\"input-group-text\">{{ option.code }}</div>\n          </div>\n\n          <!-- Radio -->\n          <label\n            class=\"form-control custom-control custom-radio\"\n            [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n            [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n            [class.is-readonly]=\"isReadOnly\"\n          >\n            <!-- Actual radio -->\n            <!--\n              Note that radios don't support `readonly`, so we use the\n              `disabled` attribute\n            -->\n            <input\n              #focusTarget\n              type=\"radio\"\n              class=\"custom-control-input\"\n              [name]=\"path\"\n              [value]=\"i\"\n              [checked]=\"selectedOptionIndex === i\"\n              [disabled]=\"isReadOnly\"\n              (change)=\"_onRadioChange($event)\"\n              (focus)=\"_onFocus($event)\"\n              (blur)=\"_onBlur($event)\"\n            />\n\n            <!-- Radio label -->\n            <span class=\"custom-control-label\">\n              <span>{{ option.label }}</span>\n              <lf-help-tooltip\n                *ngIf=\"option.helpMessage\"\n                [help]=\"option.helpMessage\"\n              ></lf-help-tooltip>\n            </span>\n          </label>\n        </div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], RadioComponent);

/**
 * Component used for selecting from a list of options in a dropdown `<select>`
 * menu.
 */
let SelectComponent = class SelectComponent extends SingleSelectionValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Action to run whenever the `<select>` values changes.
     * @param evt `change` event.
     */
    _onSelectChange(evt) {
        this.relativeStorage.set('.', this.options[+evt.target.value].value);
        this.relativeStorage.setDirty();
    }
};
SelectComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    action
], SelectComponent.prototype, "_onSelectChange", null);
SelectComponent = __decorate([
    Component({
        selector: 'lf-select',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending() || optionsStatus === 'pending'\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"\n        relativeStorage.shouldShowRejected() || optionsStatus === 'rejected'\n      \"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Select element -->\n      <!--\n        Note that selects don't support `readonly`, so we use the `disabled`\n        attribute; we add an `is-readonly` class to style it differently\n      -->\n      <select\n        #focusTarget\n        class=\"form-control form-control-sm custom-select\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [disabled]=\"isReadOnly\"\n        (change)=\"_onSelectChange($event)\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      >\n        <!-- Default option -->\n        <option\n          [selected]=\"selectedOptionIndex === -1\"\n          disabled\n          hidden\n        ></option>\n\n        <!-- Disabled option for when there are no options -->\n        <option *ngIf=\"options.length === 0\" disabled>\n          {{ noOptionsText }}\n        </option>\n\n        <!-- User defined options -->\n        <option\n          *ngFor=\"let option of options; let i = index\"\n          [value]=\"i\"\n          [selected]=\"selectedOptionIndex === i\"\n          [disabled]=\"option.isDisabled\"\n        >\n          <!-- Option code -->\n          <ng-container *ngIf=\"option.code\">{{ option.code }}.</ng-container>\n\n          <!-- Option label -->\n          {{ option.label }}\n        </option>\n      </select>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], SelectComponent);

var TableComponent_1;
/**
 * Width of the selection column (in `px`).
 */
const SELECTION_COLUMN_WIDTH = 25.6;
/**
 * LF table component.
 *
 * Example usage:
 * ```html
 * <lf-table path="/path/to/table">
 *   <lf-table-header>
 *     <lf-table-column id="field1"></lf-table-column>
 *     <lf-table-column id="field2"></lf-table-column>
 *   </lf-table-header>
 *
 *   <ng-template #lfTableRowTemplate let-id="id">
 *     <tr lf-table-row [path]="id">
 *       <td lf-table-cell><lf-text path="field1"></lf-text></td>
 *       <td lf-table-cell><lf-number path="field2"></lf-number></td>
 *     </tr>
 *   </ng-template>
 * </lf-table>
 * ```
 */
let TableComponent = TableComponent_1 = class TableComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, scrollbarUtils, viewportRuler) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
        this.scrollbarUtils = scrollbarUtils;
        this.viewportRuler = viewportRuler;
        /**
         * Height (in `px`) of a single row (virtual scroll settings). All rows must
         * have the same height.
         */
        this.rowHeight = 42;
        /**
         * Maximum number of visible rows at any given time.
         */
        this.maxVisibleRows = 10;
        /**
         * Size of the virtual scroll's template cache
         * (`cdkVirtualForTemplateCacheSize` input of Angular CDK's virtual for
         * directive).
         */
        this.virtualScrollTemplateCacheSize = 20;
        /**
         * Whether to allow addition of new rows.
         */
        this.allowRowAddition = true;
        /**
         * Whether to allow removal of rows.
         */
        this.allowRowRemoval = true;
        // Selected rows
        this.selectedRows = new Map();
        // Identifier of the row that was last selected/unselected; used to implement
        // selections while pressing shift (behaviour similar to how Gmail operates)
        this.lastSelectedId = null;
        // Position of the scrollable element after the latest scroll
        this.lastScrollPosition = [0, 0];
    }
    get _addRowText() {
        return this.translate(I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY);
    }
    get _removeRowsText() {
        return this.translate(I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY);
    }
    get _noRowsText() {
        return this.translate(I18N_TABLE_NO_ROWS_TEXT_KEY);
    }
    get _columnLabels() {
        return this.translate(I18N_TABLE_COLUMN_LABELS_KEY);
    }
    /**
     * Schema of this table's value.
     */
    get _schema() {
        return this.relativeStorage.schema();
    }
    /**
     * Table's value.
     */
    get _value() {
        return this.relativeStorage.get().slice();
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get _showIsRequired() {
        const minSize = this.relativeStorage.getStateProperty('.', 'minSize');
        return minSize !== undefined && minSize > 0;
    }
    /**
     * Table actions.
     */
    get _tableActions() {
        const actions = [];
        // Remove rows action
        if (this.allowsRowRemoval && !this.noRowsSelected) {
            actions.push({
                text: this._removeRowsText,
                class: 'remove-rows',
                style: 'outline-danger',
                icon: 'trash',
                callback: () => this._onClickRemoveRows()
            });
        }
        // New row action
        const maxSize = this.relativeStorage.getStateProperty('.', 'maxSize');
        if (this.allowsRowAddition &&
            (maxSize == null || this._value.length < maxSize)) {
            actions.push({
                text: this._addRowText,
                class: 'add-row',
                style: 'outline-primary',
                icon: 'plus-circle',
                callback: () => this._onClickNewRow()
            });
        }
        return actions;
    }
    /**
     * Height (in px) that the scrollable body element should have.
     */
    get _scrollableBodyHeight() {
        return (Math.min(this._value.length, this.maxVisibleRows) * this.rowHeight +
            this.horizontalScrollbarHeight);
    }
    /**
     * Whether new rows can be added to the table (takes into consideration if the
     * table is in "read only" mode).
     */
    get allowsRowAddition() {
        return !this.isReadOnly && this.allowRowAddition;
    }
    /**
     * Whether rows can be removed from the table (takes into consideration if the
     * table is in "read only" mode).
     */
    get allowsRowRemoval() {
        return !this.isReadOnly && this.allowRowRemoval;
    }
    /**
     * Number of rows that have been selected.
     */
    get numberOfRowsSelected() {
        return this.selectedRows.size;
    }
    /**
     * Whether all rows are selected.
     */
    get allRowsSelected() {
        return this.selectedRows.size === this._value.length;
    }
    /**
     * Whether no rows are selected.
     */
    get noRowsSelected() {
        return this.selectedRows.size === 0;
    }
    /**
     * Track either by index or reference, depending on the type of value for list
     * schemas; or by row id, when dealing with table schemas.
     */
    get _trackBy() {
        if (isListSchema(this._schema)) {
            const elementsType = this._schema.elementsSchema.type;
            return ['boolean', 'number', 'string'].indexOf(elementsType) === -1
                ? (_, el) => el
                : i => i;
        }
        else {
            return (_, row) => getRowId(row);
        }
    }
    /**
     * Width (in px) of the vertical scroll bar, when existent (`0` otherwise).
     */
    get verticalScrollbarWidth() {
        return this._value.length > this.maxVisibleRows
            ? this.scrollbarUtils.verticalScrollbarWidth
            : 0;
    }
    /**
     * Height (in px) of the horizontal scroll bar, when existent (`0` otherwise).
     */
    get horizontalScrollbarHeight() {
        return this.hasHorizontalOverflow
            ? this.scrollbarUtils.horizontalScrollbarHeight
            : 0;
    }
    ngAfterViewInit() {
        var _a;
        super.ngAfterViewInit();
        // React to scrolling on the scrollable body. Adapted from:
        // https://github.com/angular/components/blob/master/src/cdk/scrolling/virtual-scroll-viewport.ts
        const scrollableBodyEl = this._scrollableBody.elementRef.nativeElement;
        const scrollableHeaderEl = (_a = this._scrollableHeader) === null || _a === void 0 ? void 0 : _a.nativeElement;
        this.scrollSubscription = this._scrollableBody
            .elementScrolled()
            .pipe(auditTime(0, typeof requestAnimationFrame !== 'undefined'
            ? animationFrameScheduler
            : asapScheduler))
            .subscribe(() => {
            // Save last scroll position to restore scroll position when needed
            this.lastScrollPosition = [
                scrollableBodyEl.scrollTop,
                scrollableBodyEl.scrollLeft
            ];
            // Sync header scroll with body scroll
            scrollableHeaderEl &&
                (scrollableHeaderEl.scrollLeft = scrollableBodyEl.scrollLeft);
        });
        // Set the table's scroll position whenever the path changes (and when the
        // component is first initialised)
        this.disposeObservePath = observe(this, 'path', ({ oldValue, newValue }) => {
            // Save old scroll value
            if (oldValue) {
                this.lfStorage.setStateProperty(oldValue, this.scrollPositionStatePropName(oldValue), this.lastScrollPosition);
            }
            // Use previous scroll values
            const savedScrollPosition = this.lfStorage.getStateProperty(newValue, this.scrollPositionStatePropName(newValue)) || [0, 0];
            if (!comparer.shallow(this.lastScrollPosition, savedScrollPosition)) {
                this.lastScrollPosition = savedScrollPosition;
                asap(() => this._scrollableBody.scrollTo({
                    top: savedScrollPosition[0],
                    left: savedScrollPosition[1]
                }));
            }
        }, true);
        // Remove "selected rows" of non-existent rows (because they were removed
        // by an outside operation, such as loading from a file)
        this.disposeObserveValue = observe(this, '_value', () => {
            for (const id of Array.from(this.selectedRows.keys())) {
                if (!this.relativeStorage.has(`${id}`)) {
                    this.selectedRows.delete(id);
                }
            }
        });
        // Refresh the virtual scroll viewport whenever its height changes
        this.disposeObserveBodyHeight = observe(this, '_scrollableBodyHeight', () => {
            this._scrollableBody.checkViewportSize();
            this.checkHasHorizontalOverflow();
        });
        // Update the status of the horizontal overflow whenever the window viewport
        // size changes
        this.viewportSubscription = this.viewportRuler.change().subscribe(() => {
            this.checkHasHorizontalOverflow();
        });
        asap(() => this.checkHasHorizontalOverflow()); // Update on start-up
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        // Save scroll value
        this.lfStorage.setStateProperty(this.path, this.scrollPositionStatePropName(this.path), this.lastScrollPosition);
        this.scrollSubscription && this.scrollSubscription.unsubscribe();
        this.disposeObservePath && this.disposeObservePath();
        this.disposeObserveValue && this.disposeObserveValue();
        this.disposeObserveBodyHeight && this.disposeObserveBodyHeight();
        this.viewportSubscription && this.viewportSubscription.unsubscribe();
    }
    _columnLabel(columnId) {
        return this._columnLabels && this._columnLabels[columnId];
    }
    /**
     * Minimum width (in px) that the table should have.
     * @param includeScrollbarColumn Whether the scrollbar column should be
     * included in the computation (should be set to `true` for the header table).
     * @returns Minimum width that the table should have.
     */
    _tableMinWidth(includeScrollbarColumn) {
        return (this._tableHeader.tableMinWidth +
            (this.allowsRowRemoval ? SELECTION_COLUMN_WIDTH : 0) +
            (includeScrollbarColumn ? this.verticalScrollbarWidth : 0));
    }
    /**
     * Maximum width (in px) that the table should have.
     * @param includeScrollbarColumn Whether the scrollbar column should be
     * included in the computation (should be set to `true` for the header table).
     * @returns Maximum width that the table should have.
     */
    _tableMaxWidth(includeScrollbarColumn) {
        return (this._tableHeader.tableMaxWidth +
            (this.allowsRowRemoval ? SELECTION_COLUMN_WIDTH : 0) +
            (includeScrollbarColumn ? this.verticalScrollbarWidth : 0));
    }
    /**
     * Widths (as strings with correct units) of each column of the table.
     * @param includeScrollbarColumn Whether the scrollbar column should be
     * included (should be set to `true` for the header table).
     * @returns Widths of each column of the table.
     */
    _columnWidths(includeScrollbarColumn) {
        return (this.allowsRowRemoval
            ? [SELECTION_COLUMN_WIDTH + 'px']
            : []).concat(this._tableHeader.columnWidths.concat(includeScrollbarColumn ? [this.verticalScrollbarWidth + 'px'] : []));
    }
    /**
     * Adds a new row to the table.
     */
    addNewRow() {
        this.relativeStorage.push('.', undefined);
        // Scroll to bottom (shows newly inserted row)
        asap(() => this.scrollToIndex(this._value.length - 1));
    }
    /**
     * Gets the selection status of the row with the provided id.
     * @param id Id of the row for which to check selection status.
     * @returns Whether the row with the provided id is selected.
     */
    getRowSelectedStatus(id) {
        return this.allowsRowRemoval && this.selectedRows.has(id);
    }
    /**
     * Sets the selection status of the row with the provided id.
     * @param id Id of the row on which to set selection status.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    setRowSelectedStatus(id, selectedStatus) {
        if (!this.relativeStorage.has(`${id}`)) {
            throw pathError(this.path, `Invalid id: ${id}`);
        }
        if (selectedStatus) {
            this.selectedRows.set(id, true);
        }
        else {
            this.selectedRows.delete(id);
        }
        this.lastSelectedId = id;
    }
    /**
     * Sets the selection status of all rows from the last row that has had its
     * selection status set to the row with the provided id.
     * @param id Id of the row until which to set selection status.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    setRowSelectedStatusFromLastSelected(id, selectedStatus) {
        if (!this.relativeStorage.has(`${id}`)) {
            throw pathError(this.path, `Invalid id: ${id}`);
        }
        const lastSelectedId = this.lastSelectedId === null ||
            !this.relativeStorage.has(`${this.lastSelectedId}`)
            ? id
            : this.lastSelectedId;
        let idx;
        let lastSelectedIdx;
        const isTable = isTableSchema(this._schema);
        if (isTable) {
            idx = this._value.findIndex(row => getRowId(row) === id);
            lastSelectedIdx =
                id === lastSelectedId
                    ? idx
                    : this._value.findIndex(row => getRowId(row) === lastSelectedId);
        }
        else {
            idx = id;
            lastSelectedIdx = lastSelectedId;
        }
        for (let i = Math.min(lastSelectedIdx, idx), l = Math.max(lastSelectedIdx, idx); i <= l; ++i) {
            const iId = isTable ? getRowId(this._value[i]) : i;
            if (selectedStatus) {
                this.selectedRows.set(iId, true);
            }
            else {
                this.selectedRows.delete(iId);
            }
        }
        this.lastSelectedId = id;
    }
    /**
     * Unselects all rows.
     */
    unselectAllRows() {
        // Doing this seems to be way faster than calling `selectedRows.clear()`
        // with, for example, 200000 rows
        this.selectedRows = new Map();
    }
    /**
     * Sets the selection status of all rows.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    setAllRowsSelectedStatus(selectedStatus) {
        if (selectedStatus) {
            const isTable = isTableSchema(this._schema);
            this._value.forEach((el, i) => {
                const id = isTable ? getRowId(el) : i;
                this.selectedRows.set(id, true);
            });
        }
        else {
            this.unselectAllRows();
        }
    }
    /**
     * Toggles the status of all rows (if they are all selected, then they all
     * become unselected, otherwise they all become selected).
     */
    toggleAllRowsSelectedStatus() {
        this.setAllRowsSelectedStatus(!this.allRowsSelected);
    }
    /**
     * Removes all selected rows.
     */
    removeSelectedRows() {
        const isTable = isTableSchema(this._schema);
        this.relativeStorage.set('.', this._value.filter((el, i) => {
            const id = isTable ? getRowId(el) : i;
            return !this.selectedRows.has(id);
        }));
        this.unselectAllRows();
        this.lastSelectedId = null;
    }
    /**
     * Scrolls to the row with the provided id.
     * @param id Identifier of the row to scroll to.
     */
    scrollToId(id) {
        if (!this.relativeStorage.has(`${id}`)) {
            throw pathError(this.path, `Invalid id: ${id}`);
        }
        const index = isListSchema(this._schema)
            ? id
            : this._value.findIndex(row => getRowId(row) === id);
        this.scrollToIndex(index);
    }
    /**
     * Scrolls to row with the provided index.
     * @param index Index of the row to scroll to.
     */
    scrollToIndex(index) {
        this._scrollableBody.scrollToIndex(index);
    }
    /**
     * Identifier of the given element with the given index.
     * @param el Element for which to get identifier.
     * @param index Index of the element in the value.
     * @returns Identifier for the given element at the given index.
     */
    _id(el, index) {
        return isListSchema(this._schema) ? index : getRowId(el);
    }
    /**
     * Action to run when the "remove rows" button is clicked.
     */
    _onClickRemoveRows() {
        this.removeSelectedRows();
        this.relativeStorage.setDirty();
    }
    /**
     * Action to run when the "new row" button is clicked.
     */
    _onClickNewRow() {
        this.addNewRow();
        this.relativeStorage.setDirty();
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if ((!isListSchema(schema) && !isTableSchema(schema)) ||
            isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "list" or "table" type and not "nullable"');
        }
    }
    // Scroll to the activated row when one is activated.
    onActivate(activatedPath) {
        const relevantPart = this.lfStorage
            .pathInfo(activatedPath)
            .find(({ path }) => path.length > this.path.length);
        const id = relevantPart && relevantPart.id;
        if (id !== undefined && this.relativeStorage.has(`${id}`)) {
            this.scrollToId(id);
        }
    }
    /**
     * State property name used to save the position of the scroll within the
     * table.
     * @param path Path of table.
     * @returns State property name.
     */
    scrollPositionStatePropName(path) {
        // Add the path to the name of the property when the value is a child of a
        // computed value (since children states are shared with the parent computed
        // value)
        return `lfTableScrollPosition${this.relativeStorage.isComputed(appendToPath(path, '..'))
            ? `[${path}]`
            : ''}`;
    }
    /**
     * Update the status of the "horizontal overflow".
     */
    checkHasHorizontalOverflow() {
        this.hasHorizontalOverflow = this.scrollbarUtils.hasHorizontalOverflow(this._scrollableBody.elementRef.nativeElement);
    }
};
TableComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
    { type: ScrollbarUtils },
    { type: ViewportRuler }
];
__decorate([
    observable,
    Input()
], TableComponent.prototype, "rowHeight", void 0);
__decorate([
    observable,
    Input()
], TableComponent.prototype, "maxVisibleRows", void 0);
__decorate([
    Input()
], TableComponent.prototype, "virtualScrollTemplateCacheSize", void 0);
__decorate([
    observable,
    Input()
], TableComponent.prototype, "allowRowAddition", void 0);
__decorate([
    observable,
    Input()
], TableComponent.prototype, "allowRowRemoval", void 0);
__decorate([
    ContentChild(TableHeaderDirective)
], TableComponent.prototype, "_tableHeader", void 0);
__decorate([
    ContentChild('lfTableRowTemplate')
], TableComponent.prototype, "_rowTemplate", void 0);
__decorate([
    ContentChild('lfTableNoRowsTemplate')
], TableComponent.prototype, "_noRowsTemplate", void 0);
__decorate([
    ViewChild('scrollableHeader')
], TableComponent.prototype, "_scrollableHeader", void 0);
__decorate([
    ViewChild('scrollableBody')
], TableComponent.prototype, "_scrollableBody", void 0);
__decorate([
    observable
], TableComponent.prototype, "hasHorizontalOverflow", void 0);
__decorate([
    observable
], TableComponent.prototype, "selectedRows", void 0);
__decorate([
    computed
], TableComponent.prototype, "_addRowText", null);
__decorate([
    computed
], TableComponent.prototype, "_removeRowsText", null);
__decorate([
    computed
], TableComponent.prototype, "_noRowsText", null);
__decorate([
    computed
], TableComponent.prototype, "_columnLabels", null);
__decorate([
    computed
], TableComponent.prototype, "_schema", null);
__decorate([
    computed
], TableComponent.prototype, "_value", null);
__decorate([
    computed
], TableComponent.prototype, "_showIsRequired", null);
__decorate([
    computed.struct
], TableComponent.prototype, "_tableActions", null);
__decorate([
    computed
], TableComponent.prototype, "_scrollableBodyHeight", null);
__decorate([
    computed
], TableComponent.prototype, "allowsRowAddition", null);
__decorate([
    computed
], TableComponent.prototype, "allowsRowRemoval", null);
__decorate([
    computed
], TableComponent.prototype, "numberOfRowsSelected", null);
__decorate([
    computed
], TableComponent.prototype, "allRowsSelected", null);
__decorate([
    computed
], TableComponent.prototype, "noRowsSelected", null);
__decorate([
    computed
], TableComponent.prototype, "_trackBy", null);
__decorate([
    computed
], TableComponent.prototype, "verticalScrollbarWidth", null);
__decorate([
    computed
], TableComponent.prototype, "horizontalScrollbarHeight", null);
__decorate([
    action
], TableComponent.prototype, "addNewRow", null);
__decorate([
    action
], TableComponent.prototype, "setRowSelectedStatus", null);
__decorate([
    action
], TableComponent.prototype, "setRowSelectedStatusFromLastSelected", null);
__decorate([
    action
], TableComponent.prototype, "unselectAllRows", null);
__decorate([
    action
], TableComponent.prototype, "setAllRowsSelectedStatus", null);
__decorate([
    action
], TableComponent.prototype, "toggleAllRowsSelectedStatus", null);
__decorate([
    action
], TableComponent.prototype, "removeSelectedRows", null);
__decorate([
    action
], TableComponent.prototype, "_onClickRemoveRows", null);
__decorate([
    action
], TableComponent.prototype, "_onClickNewRow", null);
__decorate([
    action
], TableComponent.prototype, "onActivate", null);
__decorate([
    action
], TableComponent.prototype, "checkHasHorizontalOverflow", null);
TableComponent = TableComponent_1 = __decorate([
    Component({
        selector: 'lf-table',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: TableComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <div class=\"row label\">\n      <!-- Code + label -->\n      <div class=\"code-label-container\">\n        <!-- Code -->\n        <div\n          *ngIf=\"code\"\n          class=\"input-group input-group-sm code-container mr-2\"\n          [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n          [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        >\n          <div class=\"input-group-prepend\">\n            <div class=\"input-group-text code\">{{ code }}</div>\n          </div>\n        </div>\n\n        <!-- Label -->\n        <span *ngIf=\"label\" class=\"label-text\">{{ label }}</span>\n        <lf-help-tooltip\n          *ngIf=\"helpMessage\"\n          [help]=\"helpMessage\"\n        ></lf-help-tooltip>\n      </div>\n\n      <!-- Table actions -->\n      <lf-actions-menu\n        class=\"table-actions text-right\"\n        [actions]=\"_tableActions\"\n        buttonsSize=\"sm\"\n        [alignMenusRight]=\"true\"\n      >\n      </lf-actions-menu>\n    </div>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"_showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Container of whole table -->\n    <div\n      #targetElement\n      class=\"table-container\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Header table container (scrollable horizontally) -->\n      <div #scrollableHeader class=\"scrollable-header\" *ngIf=\"_tableHeader\">\n        <table\n          class=\"table table-sm header-table\"\n          [style.minWidth]=\"_tableMinWidth(true) + 'px'\"\n          [style.maxWidth]=\"_tableMaxWidth(true) + 'px'\"\n        >\n          <!-- Table columns -->\n          <colgroup>\n            <col\n              *ngFor=\"let width of _columnWidths(true)\"\n              [attr.width]=\"width\"\n            />\n          </colgroup>\n\n          <!-- Table header -->\n          <thead>\n            <tr *ngFor=\"let row of _tableHeader.rows; let first = first\">\n              <!-- Selection column -->\n              <th\n                *ngIf=\"first && allowsRowRemoval\"\n                class=\"table-cell-select\"\n                [attr.rowSpan]=\"_tableHeader.numberOfRows\"\n              >\n                <label\n                  class=\"select-all-checkbox custom-control custom-checkbox\"\n                >\n                  <input\n                    type=\"checkbox\"\n                    class=\"custom-control-input\"\n                    [disabled]=\"_value.length === 0\"\n                    [checked]=\"allRowsSelected && _value.length > 0\"\n                    [indeterminate]=\"!allRowsSelected && !noRowsSelected\"\n                    (click)=\"toggleAllRowsSelectedStatus()\"\n                  />\n                  <span class=\"custom-control-label\"></span>\n                </label>\n              </th>\n              <!-- User defined columns -->\n              <th\n                *ngFor=\"let column of row\"\n                [attr.rowSpan]=\"column.rowSpan\"\n                [attr.colSpan]=\"column.colSpan\"\n              >\n                <!-- TODO: Allow help messages/templates? -->\n                <ng-container *ngIf=\"column.id\">{{\n                  _columnLabel(column.id)\n                }}</ng-container>\n              </th>\n              <!-- Scrollbar compensation column -->\n              <th *ngIf=\"first\" [attr.rowSpan]=\"_tableHeader.numberOfRows\"></th>\n            </tr>\n          </thead>\n        </table>\n      </div>\n\n      <!-- Body table container (scrollable content) -->\n      <cdk-virtual-scroll-viewport\n        #scrollableBody\n        class=\"scrollable-body\"\n        [itemSize]=\"rowHeight\"\n        [style.height]=\"_scrollableBodyHeight + 'px'\"\n      >\n        <table\n          class=\"table table-sm body-table\"\n          [style.minWidth]=\"_tableHeader && _tableMinWidth(false) + 'px'\"\n          [style.maxWidth]=\"_tableHeader && _tableMaxWidth(false) + 'px'\"\n        >\n          <!-- Table columns (except scrollbar column) -->\n          <colgroup *ngIf=\"_tableHeader\">\n            <col\n              *ngFor=\"let width of _columnWidths(false)\"\n              [attr.width]=\"width\"\n            />\n          </colgroup>\n\n          <!-- Table body -->\n          <tbody>\n            <!-- Row -->\n            <ng-container\n              *cdkVirtualFor=\"\n                let item of _value;\n                let index = index;\n                let count = count;\n                let first = first;\n                let last = last;\n                let even = even;\n                let odd = odd;\n                templateCacheSize: virtualScrollTemplateCacheSize;\n                trackBy: _trackBy\n              \"\n              [ngTemplateOutlet]=\"_rowTemplate\"\n              [ngTemplateOutletContext]=\"{\n                $implicit: item,\n                id: _id(item, index),\n                index: index,\n                count: count,\n                first: first,\n                last: last,\n                even: even,\n                odd: odd\n              }\"\n            ></ng-container>\n          </tbody>\n        </table>\n      </cdk-virtual-scroll-viewport>\n\n      <!-- No items -->\n      <div *ngIf=\"_value.length === 0\" class=\"no-rows\">\n        <ng-container *ngIf=\"!_noRowsTemplate\">\n          {{ _noRowsText }}\n        </ng-container>\n        <ng-container\n          *ngIf=\"_noRowsTemplate\"\n          [ngTemplateOutlet]=\"_noRowsTemplate\"\n        >\n        </ng-container>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], TableComponent);

/**
 * LF table-cell component.
 */
let TableCellComponent = class TableCellComponent {
    constructor(parentTableComponent) {
        this.parentTableComponent = parentTableComponent;
    }
    /**
     * Height of the cell.
     */
    get _hostStyleHeight() {
        return this.parentTableComponent.rowHeight + 'px';
    }
};
TableCellComponent.ctorParameters = () => [
    { type: TableComponent }
];
__decorate([
    computed,
    HostBinding('style.height')
], TableCellComponent.prototype, "_hostStyleHeight", null);
TableCellComponent = __decorate([
    Component({
        // tslint:disable-next-line:component-selector
        selector: 'td[lf-table-cell], th[lf-table-cell]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <div class=\"table-cell-container\">\n    <div class=\"table-cell-inner\"><ng-content></ng-content></div>\n  </div>\n</ng-container>\n"
    })
], TableCellComponent);

var TableRowComponent_1;
/**
 * LF table-row component.
 */
let TableRowComponent = TableRowComponent_1 = class TableRowComponent extends Value {
    constructor(parentPathBasedComponent, // Verified `OnInit`
    lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.parentPathBasedComponent = parentPathBasedComponent;
    }
    /**
     * Whether the row can be removed.
     */
    get allowsRemoval() {
        return this.parentPathBasedComponent.allowsRowRemoval;
    }
    /**
     * Whether the row is selected (adds an `is-selected` class to the row).
     */
    get isSelected() {
        return this.parentPathBasedComponent.getRowSelectedStatus(this.relativeStorage.currentId);
    }
    /**
     * Class that should be added to the row when the row should show as having an
     * error.
     */
    get _classIsInvalid() {
        return !!(this.relativeStorage.has() && this.relativeStorage.shouldShowError());
    }
    /**
     * Class that should be added to the row when the row should show as having a
     * warning.
     */
    get _classIsWarning() {
        return !!(this.relativeStorage.has() && this.relativeStorage.shouldShowWarning());
    }
    ngOnInit() {
        super.ngOnInit();
        // Table rows must be children of tables
        if (!(this.parentPathBasedComponent instanceof TableComponent)) {
            throw pathError(this.path, 'This component must be a child of a `TableComponent`');
        }
    }
    /**
     * Sets the row's selection status.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    setSelectedStatus(selectedStatus) {
        this.parentPathBasedComponent.setRowSelectedStatus(this.relativeStorage.currentId, selectedStatus);
    }
    /**
     * Sets the row selection status of all rows from the last row that has had
     * its selection status set to this row.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    setSelectedStatusFromLastSelected(selectedStatus) {
        this.parentPathBasedComponent.setRowSelectedStatusFromLastSelected(this.relativeStorage.currentId, selectedStatus);
    }
    /**
     * Action to run when the selection checkbox label is clicked: added as a fix
     * for Firefox, where `shift+click` on the label won't trigger a click on the
     * `input`; as such we manually call the event.
     * @param event Click event.
     * @param checkboxElement Element on which the even should be called instead.
     */
    _onLabelClick(event, checkboxElement) {
        this._onSelectionCheckboxClick(event);
        checkboxElement.focus();
        event.preventDefault();
    }
    /**
     * Action to run when the selection checkbox is clicked.
     * @param event Click event.
     */
    _onSelectionCheckboxClick(event) {
        if (event.shiftKey) {
            this.setSelectedStatusFromLastSelected(!this.isSelected);
        }
        else {
            this.setSelectedStatus(!this.isSelected);
        }
        event.stopPropagation(); // Don't call the label event
    }
};
TableRowComponent.ctorParameters = () => [
    { type: TableComponent, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    computed
], TableRowComponent.prototype, "allowsRemoval", null);
__decorate([
    computed,
    HostBinding('class.is-selected')
], TableRowComponent.prototype, "isSelected", null);
__decorate([
    computed,
    HostBinding('class.is-invalid')
], TableRowComponent.prototype, "_classIsInvalid", null);
__decorate([
    computed,
    HostBinding('class.is-warning')
], TableRowComponent.prototype, "_classIsWarning", null);
TableRowComponent = TableRowComponent_1 = __decorate([
    Component({
        // tslint:disable-next-line: component-selector
        selector: 'tr[lf-table-row]',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: TableRowComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"relativeStorage.has()\">\n    <!-- Cell used to hold a checkbox that marks the row as selected -->\n    <td lf-table-cell *ngIf=\"allowsRemoval\" class=\"table-cell-select\">\n      <label\n        class=\"custom-control custom-checkbox\"\n        (click)=\"_onLabelClick($event, checkboxElement)\"\n      >\n        <input\n          #checkboxElement\n          type=\"checkbox\"\n          class=\"custom-control-input\"\n          [checked]=\"isSelected\"\n          (click)=\"_onSelectionCheckboxClick($event)\"\n        />\n        <span class=\"custom-control-label\"></span>\n      </label>\n    </td>\n    <!-- User defined cells -->\n    <ng-content select=\"th[lf-table-cell], td[lf-table-cell]\"></ng-content>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], TableRowComponent);

/**
 * Component used for editing a "single line" LF string.
 */
let TextComponent = class TextComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        const minLength = this.relativeStorage.getStateProperty('.', 'minLength');
        return minLength !== undefined && minLength > 0;
    }
    /**
     * Action to run on every `input` event of the text input.
     * @param evt `input` event.
     */
    _onInput(evt) {
        this.relativeStorage.set('.', evt.target.value);
        this.relativeStorage.setDirty();
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isStringSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "string" type and not "nullable"');
        }
    }
};
TextComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    computed
], TextComponent.prototype, "showIsRequired", null);
__decorate([
    action
], TextComponent.prototype, "_onInput", null);
TextComponent = __decorate([
    Component({
        selector: 'lf-text',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <input\n        #focusTarget\n        type=\"text\"\n        class=\"form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [value]=\"relativeStorage.get()\"\n        [attr.minLength]=\"relativeStorage.getStateProperty('.', 'minLength')\"\n        [attr.maxLength]=\"relativeStorage.getStateProperty('.', 'maxLength')\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (input)=\"_onInput($event)\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      />\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], TextComponent);

/**
 * Component used for editing a "multiple lines" LF string.
 */
let TextareaComponent = class TextareaComponent extends InlineValue {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n, lfRouter);
        /**
         * Initial height of the textarea (CSS measurement string).
         */
        this.initialHeight = '6rem';
    }
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired() {
        const minLength = this.relativeStorage.getStateProperty('.', 'minLength');
        return minLength !== undefined && minLength > 0;
    }
    /**
     * Action to run on every `input` event of the textarea input.
     * @param evt `input` event.
     */
    _onInput(evt) {
        this.relativeStorage.set('.', evt.target.value);
        this.relativeStorage.setDirty();
    }
    validatePath() {
        const schema = this.relativeStorage.schema();
        if (!isStringSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "string" type and not "nullable"');
        }
    }
};
TextareaComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
];
__decorate([
    Input()
], TextareaComponent.prototype, "initialHeight", void 0);
__decorate([
    computed
], TextareaComponent.prototype, "showIsRequired", null);
__decorate([
    action
], TextareaComponent.prototype, "_onInput", null);
TextareaComponent = __decorate([
    Component({
        selector: 'lf-textarea',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Textarea -->\n      <textarea\n        #focusTarget\n        type=\"text\"\n        class=\"form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [style.height]=\"initialHeight\"\n        [name]=\"path\"\n        [value]=\"relativeStorage.get()\"\n        [attr.minLength]=\"relativeStorage.getStateProperty('.', 'minLength')\"\n        [attr.maxLength]=\"relativeStorage.getStateProperty('.', 'maxLength')\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (input)=\"_onInput($event)\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      ></textarea>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased)),
    __param(3, Optional()),
    __param(3, Inject(LfRouter))
], TextareaComponent);

/**
 * Lf tooltip component.
 */
let TooltipComponent = class TooltipComponent {
    constructor() {
        this.placement = 'top';
        this.delay = 0;
    }
};
__decorate([
    Input()
], TooltipComponent.prototype, "help", void 0);
__decorate([
    Input()
], TooltipComponent.prototype, "placement", void 0);
__decorate([
    Input()
], TooltipComponent.prototype, "delay", void 0);
TooltipComponent = __decorate([
    Component({
        selector: 'lf-tooltip',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<ng-container *mobxAutorun>\n  <span [tooltip]=\"help\" [placement]=\"placement\" [delay]=\"delay\">\n    <ng-content></ng-content>\n  </span>\n</ng-container>\n"
    })
], TooltipComponent);

var TreeEntryComponent_1;
/**
 * Entry for an item of the tree-nav.
 */
let TreeEntryComponent = TreeEntryComponent_1 = class TreeEntryComponent extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.lfRouter = lfRouter;
        /**
         * Whether this tree-entry is to be displayed as the root one (in which case
         * its label isn't shown anywhere and its children are displayed one after the
         * other). The entry can be displayed as root only when its schema is complex.
         * A button is displayed at the end of the list when there are optional values
         * to be added or to add a new element in case the schema is a list.
         */
        this.displayAsRoot = true;
    }
    /**
     * Label associated with this value.
     */
    get label() {
        const label = this.translate(I18N_VALUE_LABEL_KEY);
        return label === undefined
            ? this.relativeStorage.currentPath === '/'
                ? '/'
                : this.relativeStorage.currentId
            : label;
    }
    /**
     * Message used to ask the user to retry validating the value.
     */
    get retryValidateText() {
        return this.translate(I18N_VALUE_RETRY_VALIDATE_TEXT_KEY);
    }
    get addOptionalValueButtonText() {
        return this.translate(I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY);
    }
    get addValueToListButtonText() {
        return this.translate(I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY);
    }
    get matchingRoutes() {
        return this.lfRouter.matchingRoutes(this.path, { navigateToParent: false });
    }
    get navigateableRoute() {
        return this.lfRouter.navigateableRouteFromMatchingRoutes(this.matchingRoutes);
    }
    get url() {
        return (this.navigateableRoute &&
            this.lfRouter.createUrlFromNavigateableRoute(this.navigateableRoute));
    }
    get isActive() {
        return this.lfRouter.isActive(this.path);
    }
    get isList() {
        const schema = this.relativeStorage.schema();
        return isListSchema(schema) || isTableSchema(schema);
    }
    get childrenIds() {
        return this.lfStorage.childrenIds(this.path).filter((id) => {
            const path = appendToPath(this.path, id);
            const matchingRoutes = this.lfRouter
                .matchingRoutes(path, { navigateToParent: false })
                .filter(matchingRoute => this.matchingRouteComponentLevel(matchingRoute) ===
                this._componentLevel);
            return matchingRoutes.length > 0;
        });
    }
    get nonNullChildrenIds() {
        return this.childrenIds.filter(id => this.relativeStorage.get(id.toString()) !== null);
    }
    get nullChildrenIds() {
        return this.childrenIds.filter(id => this.relativeStorage.get(id.toString()) === null);
    }
    ngOnInit() {
        super.ngOnInit();
        // Validate the path whenever `displayAsRoot` changes
        this.disposeOnDisplayAsRootChanges = observe(this, 'displayAsRoot', () => {
            this.validatePath();
        });
        // Set `componentLevel` when not defined
        if (this._componentLevel === undefined) {
            this._componentLevel = this.matchingRouteComponentLevel(this.matchingRoutes[0]);
        }
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        this.disposeOnDisplayAsRootChanges();
    }
    childLabel(id) {
        const childPath = appendToPath(this.path, id);
        return this.lfI18n.getFromPath(childPath, I18N_VALUE_LABEL_KEY) || id;
    }
    addToList() {
        const { schema, value } = this.lfStorage
            .pathInfo(this.path, { fetchValues: true })
            .slice(-1)[0];
        this.lfStorage.push(this.path, undefined);
        this.lfRouter.navigate(appendToPath(this.path, isListSchema(schema)
            ? value.length - 1
            : getRowId(value[value.length - 1])), { queryParamsHandling: 'merge' });
    }
    initializeChild(id) {
        this.relativeStorage.initialize(id);
        this.lfRouter.navigate(appendToPath(this.path, id), {
            queryParamsHandling: 'merge'
        });
    }
    validatePath() {
        if (this.matchingRoutes.length === 0) {
            throw pathError(this.path, 'The path or one of its children must have an associated route');
        }
        const schema = this.relativeStorage.schema();
        if (this.displayAsRoot && !isComplexSchema(schema)) {
            throw pathError(this.path, 'Schema must be complex to display the entry as "root"');
        }
    }
    /**
     * The "component" level of the provided matching route (basically the number
     * of outlets used by the route).
     * @param matchingRoute Matching of a route with a provided path.
     * @returns Component level for the matching route.
     */
    matchingRouteComponentLevel(matchingRoute) {
        return matchingRoute.routes.reduce((level, route) => level + (route.component || route.redirectTo !== undefined ? 1 : 0), 0);
    }
};
TreeEntryComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter }
];
__decorate([
    observable,
    Input()
], TreeEntryComponent.prototype, "displayAsRoot", void 0);
__decorate([
    Input()
], TreeEntryComponent.prototype, "_componentLevel", void 0);
__decorate([
    computed
], TreeEntryComponent.prototype, "label", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "retryValidateText", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "addOptionalValueButtonText", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "addValueToListButtonText", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "matchingRoutes", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "navigateableRoute", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "url", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "isActive", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "isList", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "childrenIds", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "nonNullChildrenIds", null);
__decorate([
    computed
], TreeEntryComponent.prototype, "nullChildrenIds", null);
__decorate([
    action
], TreeEntryComponent.prototype, "addToList", null);
__decorate([
    action
], TreeEntryComponent.prototype, "initializeChild", null);
TreeEntryComponent = TreeEntryComponent_1 = __decorate([
    Component({
        selector: 'lf-tree-entry',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: TreeEntryComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"relativeStorage.has() && relativeStorage.get() !== null\">\n    <!-- Root entry (only show children) -->\n    <ng-container *ngIf=\"displayAsRoot\">\n      <!-- Children -->\n      <ng-container [ngTemplateOutlet]=\"childrenTemplate\"></ng-container>\n\n      <!-- Action at the bottom (with label) -->\n      <ng-container\n        [ngTemplateOutlet]=\"actionsTemplate\"\n        [ngTemplateOutletContext]=\"{\n          addOptionalValueButtonText: addOptionalValueButtonText,\n          addValueToListButtonText: addValueToListButtonText\n        }\"\n      ></ng-container>\n    </ng-container>\n\n    <!-- Non-root entry (show entry + children) -->\n    <div\n      *ngIf=\"!displayAsRoot\"\n      [ngClass]=\"{ 'nav-item': true, active: isActive }\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Item content -->\n      <div class=\"item-content\">\n        <!-- Icon + label (either in link form or not, depending on whether a\n             link is available) -->\n        <a\n          *ngIf=\"url\"\n          class=\"nav-link\"\n          [routerLink]=\"url\"\n          queryParamsHandling=\"merge\"\n        >\n          <ng-container [ngTemplateOutlet]=\"linkTemplate\"></ng-container>\n        </a>\n        <div *ngIf=\"!url\" class=\"nav-link is-disabled\">\n          <ng-container [ngTemplateOutlet]=\"linkTemplate\"></ng-container>\n        </div>\n\n        <!-- Pending validation -->\n        <div\n          class=\"status pending\"\n          *ngIf=\"relativeStorage.shouldShowPending()\"\n        ></div>\n        <!-- Rejected validation -->\n        <div\n          class=\"status rejected\"\n          *ngIf=\"relativeStorage.shouldShowRejected()\"\n          (click)=\"relativeStorage.recomputeStateProperties()\"\n        >\n          <lf-tooltip [help]=\"retryValidateText\">\n            <lf-icon icon=\"warning\"></lf-icon>\n          </lf-tooltip>\n        </div>\n\n        <!-- Actions -->\n        <ng-container\n          [ngTemplateOutlet]=\"actionsTemplate\"\n          [ngTemplateOutletContext]=\"{ alignRight: true }\"\n        ></ng-container>\n      </div>\n\n      <!-- Children -->\n      <ng-container\n        *ngIf=\"isActive\"\n        [ngTemplateOutlet]=\"childrenTemplate\"\n      ></ng-container>\n    </div>\n  </ng-container>\n</ng-container>\n\n<ng-template #linkTemplate>\n  <!-- Icon for items with sub-items, either \"v\" or \">\" or bars for lists -->\n  <span *ngIf=\"isList || nonNullChildrenIds.length > 0\" class=\"item-icon\">\n    <lf-icon\n      [icon]=\"isList ? 'bars' : isActive ? 'angle-down' : 'angle-right'\"\n      [fixedWidth]=\"true\"\n    >\n    </lf-icon>\n  </span>\n\n  <!-- Entry label -->\n  <div class=\"item-label\">{{ label }}</div>\n</ng-template>\n\n<!-- Template to show all children -->\n<ng-template #childrenTemplate>\n  <!-- Children -->\n  <ng-container *ngFor=\"let id of nonNullChildrenIds\">\n    <nav class=\"nav flex-column\">\n      <lf-tree-entry\n        [path]=\"id\"\n        [displayAsRoot]=\"false\"\n        [_componentLevel]=\"_componentLevel\"\n      ></lf-tree-entry>\n    </nav>\n  </ng-container>\n</ng-template>\n\n<!-- Template to show the item's action (if appropriate), either a button to add\n     a new element to the list, or a menu to add an optional value; possibly,\n     each action may be labelled and the menu aligned to the right -->\n<ng-template\n  #actionsTemplate\n  let-addOptionalText=\"addOptionalValueButtonText\"\n  let-addToListText=\"addValueToListButtonText\"\n  let-alignRight=\"alignRight\"\n>\n  <!-- Add optional value -->\n  <div *ngIf=\"!isList && nullChildrenIds.length > 0\" class=\"value-add\">\n    <lf-dropdown>\n      <button\n        lf-button\n        [style]=\"'outline-secondary'\"\n        size=\"sm\"\n        [dropdownToggle]=\"true\"\n        [block]=\"true\"\n      >\n        <lf-icon icon=\"plus-circle\"></lf-icon> {{ addOptionalText }}\n      </button>\n      <!-- Align to the right when not -->\n      <lf-dropdown-menu [alignRight]=\"alignRight\">\n        <button\n          lf-dropdown-item\n          *ngFor=\"let id of nullChildrenIds\"\n          (click)=\"initializeChild(id)\"\n        >\n          {{ childLabel(id) }}\n        </button>\n      </lf-dropdown-menu>\n    </lf-dropdown>\n  </div>\n\n  <!-- Add value to list -->\n  <div *ngIf=\"isList\" class=\"value-add\">\n    <button\n      lf-button\n      [style]=\"'outline-secondary'\"\n      [isDisabled]=\"\n        relativeStorage.size() >=\n        relativeStorage.getStateProperty('.', 'maxSize')\n      \"\n      size=\"sm\"\n      (click)=\"addToList()\"\n    >\n      <lf-icon icon=\"plus-circle\"></lf-icon> {{ addToListText }}\n    </button>\n  </div>\n</ng-template>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], TreeEntryComponent);

var TreeNavComponent_1;
/**
 * Component used to show a tree to navigate between values.
 */
let TreeNavComponent = TreeNavComponent_1 = class TreeNavComponent extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.lfRouter = lfRouter;
    }
    get _hasRoutes() {
        return (this.lfRouter.matchingRoutes(this.path, { navigateToParent: false })
            .length > 0);
    }
    /**
     * Hide the tree-nav.
     */
    hideTreeNav() {
        this.parentPathBasedComponent.hideTreeNav();
    }
};
TreeNavComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter }
];
__decorate([
    computed
], TreeNavComponent.prototype, "_hasRoutes", null);
TreeNavComponent = TreeNavComponent_1 = __decorate([
    Component({
        selector: 'lf-tree-nav',
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [{ provide: PathBased, useExisting: TreeNavComponent_1 }],
        template: "<ng-container *mobxAutorun>\n  <nav class=\"nav flex-column\" role=\"navigation\">\n    <!-- Small screen: hide tree-nav button -->\n    <div class=\"tree-nav-actions d-md-none\">\n      <button class=\"tree-nav-hide close\" (click)=\"hideTreeNav()\">\n        &times;\n      </button>\n    </div>\n\n    <!-- Recursively render tree entries -->\n    <lf-tree-entry *ngIf=\"_hasRoutes\" [path]=\"path\"></lf-tree-entry>\n  </nav>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, SkipSelf()),
    __param(0, Inject(PathBased))
], TreeNavComponent);

/**
 * Component used to debug information about the state of a value.
 */
let ValueStateComponent = class ValueStateComponent extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        /**
         * Whether the application is in production mode.
         */
        this.inProduction = process.env.NODE_ENV === 'production';
    }
    /**
     * State properties where each "promise" is transformed into an object for
     * easier rendering as a JSON. Also hides the `$mobx` property.
     */
    get stateProperties() {
        const schema = this.relativeStorage.schema();
        const state = this.relativeStorage.getState();
        const value = this.relativeStorage.get();
        return Array.from(Object.keys(state.props)).reduce((obj, prop) => {
            let propValue = null;
            // When the value is `null`, other validations shouldn't be executed
            if (value !== null ||
                !isReservedStateProp(schema, prop) ||
                prop === 'isRequired' ||
                prop === 'validationIssues') {
                propValue = getStateProperty(schema, state, prop);
                if (isPromiseBasedObservable(propValue)) {
                    const res = propValue.value;
                    propValue = {
                        isPromise: true,
                        state: propValue.state,
                        value: res instanceof Error ? `Error(${res.message})` : res
                    };
                }
            }
            obj[prop] = propValue;
            return obj;
        }, {});
    }
    /**
     * Whether the state properties contain at least one async property.
     */
    get hasAsyncProperties() {
        const props = this.stateProperties;
        return Object.keys(props).some(prop => {
            const val = props[prop];
            return typeof val === 'object' && val && val.isPromise;
        });
    }
};
ValueStateComponent.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n }
];
__decorate([
    computed
], ValueStateComponent.prototype, "stateProperties", null);
__decorate([
    computed
], ValueStateComponent.prototype, "hasAsyncProperties", null);
ValueStateComponent = __decorate([
    Component({
        selector: 'lf-value-state',
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: "<!-- Show state properties when not in production -->\n<ng-container *ngIf=\"!inProduction\">\n  <ng-container *mobxAutorun>\n    <ng-container *ngIf=\"relativeStorage.has()\">\n      <!-- Icon/button used to toggle the state properties modal -->\n      <lf-icon class=\"value-state-icon\" icon=\"bug\" (click)=\"stateModal.show()\">\n      </lf-icon>\n\n      <!-- Modal displayed the path's information -->\n      <lf-modal #stateModal size=\"lg\">\n        <lf-modal-header>\n          <code>{{ path }}</code>\n        </lf-modal-header>\n        <lf-modal-body>\n          <h6>Value:</h6>\n          <pre>{{ relativeStorage.get() | json }}</pre>\n          <h6>State properties:</h6>\n          <pre>{{ stateProperties | json }}</pre>\n        </lf-modal-body>\n        <lf-modal-footer *ngIf=\"hasAsyncProperties\">\n          <button\n            lf-button\n            [style]=\"'outline-secondary'\"\n            size=\"sm\"\n            (click)=\"relativeStorage.recomputeStateProperties('.', true)\"\n          >\n            Recompute promises\n          </button>\n        </lf-modal-footer>\n      </lf-modal>\n    </ng-container>\n  </ng-container>\n</ng-container>\n"
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased))
], ValueStateComponent);

/**
 * Protocol prefix used for LF links.
 */
const LF_URL_PROTOCOL = 'lf://';
/**
 * Validation message directive.
 */
let ValidationIssueDirective = class ValidationIssueDirective extends PathBased {
    constructor(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, router, markdownService) {
        super(parentPathBasedComponent, lfStorage, lfI18n);
        this.lfRouter = lfRouter;
        this.router = router;
        this.markdownService = markdownService;
    }
    /**
     * HTML string with the issue message to display.
     */
    get issueMessageHTML() {
        // Value as obtained from the i18n file
        const i18nValue = this.lfI18n.getFromPath(this.path, `${I18N_VALIDATIONS_KEY}.${this.issue.code}`, { callFunctionWithContext: false });
        // Obtain markdown message from the value
        return this.markdownService.compile(typeof i18nValue === 'function'
            ? i18nValue(this.lfStorage.relativeStorage(this.path), this.issue.data)
            : i18nValue != null
                ? i18nValue
                : this.issue.code);
    }
    ngOnInit() {
        const renderer = this.markdownService.renderer;
        const originalLink = renderer.link;
        this.markdownService.renderer.link = (href, title, text) => {
            // Replace links with the "LF protocol" with the appropriate paths
            if (href && href.startsWith(LF_URL_PROTOCOL)) {
                const path = resolvePath(this.path, href.slice(LF_URL_PROTOCOL.length));
                const route = this.lfRouter.navigateableRoute(path);
                if (href === text) {
                    text = this.labelOf(path);
                }
                href = route && this.lfRouter.createUrlFromNavigateableRoute(route);
            }
            const anchor = originalLink.call(renderer, href, title, text);
            return anchor.replace('<a', '<a class="lfPathLink"');
        };
        super.ngOnInit();
    }
    // Intercept clicks on links with class `lfPathLink` to use the router.
    // Adapted from Angular's `routerLink` implementation.
    _onClick(target, button, ctrlKey, metaKey, shiftKey) {
        if (button !== 0 ||
            ctrlKey ||
            metaKey ||
            shiftKey ||
            !target.classList.contains('lfPathLink')) {
            return true;
        }
        this.router.navigateByUrl(target.getAttribute('href'), {
            queryParamsHandling: 'merge'
        });
        return false;
    }
    /**
     * Label associated with the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    labelOf(path) {
        return this.lfI18n.getFromPath(path, I18N_VALUE_LABEL_KEY) || path;
    }
};
ValidationIssueDirective.ctorParameters = () => [
    { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
    { type: LfStorage },
    { type: LfI18n },
    { type: LfRouter },
    { type: Router },
    { type: MarkdownService }
];
__decorate([
    observable,
    Input()
], ValidationIssueDirective.prototype, "issue", void 0);
__decorate([
    computed,
    HostBinding('innerHTML')
], ValidationIssueDirective.prototype, "issueMessageHTML", null);
__decorate([
    HostListener('click', [
        '$event.target',
        '$event.button',
        '$event.ctrlKey',
        '$event.metaKey',
        '$event.shiftKey'
    ])
], ValidationIssueDirective.prototype, "_onClick", null);
ValidationIssueDirective = __decorate([
    Directive({
        selector: 'lf-validation-issue, [lfValidationIssue]',
        exportAs: 'lfValidationIssue'
    }),
    __param(0, Optional()),
    __param(0, Inject(PathBased))
], ValidationIssueDirective);

/**
 * Exported/declared components and directives.
 */
const DECLARATIONS = [
    ActionsMenuComponent,
    AlertComponent,
    AppComponent,
    ButtonComponent,
    CardComponent,
    CardContentComponent,
    CheckboxComponent,
    CheckboxGroupComponent,
    DateComponent,
    DateRangeComponent,
    DropdownComponent,
    DropdownItemComponent,
    DropdownMenuComponent,
    FileComponent,
    FormComponent,
    HelpTooltipComponent,
    IconComponent,
    ModalBodyComponent,
    ModalComponent,
    ModalFooterComponent,
    ModalHeaderComponent,
    NumberComponent,
    RadioComponent,
    SelectComponent,
    TableCellComponent,
    TableComponent,
    TableRowComponent,
    TextareaComponent,
    TextComponent,
    TooltipComponent,
    TopBarComponent,
    TreeEntryComponent,
    TreeNavComponent,
    ValidationIssueDirective,
    ValidationPanelComponent,
    ValueStateComponent
];
/**
 * LF Bootstrap theme module.
 */
let LfBootstrapThemeModule = class LfBootstrapThemeModule {
};
LfBootstrapThemeModule = __decorate([
    NgModule({
        imports: [
            BrowserAnimationsModule,
            CommonModule,
            RouterModule.forChild([]),
            BsDatepickerModule.forRoot(),
            LfCoreModule,
            LfTableHeaderModule,
            MarkdownModule.forRoot(),
            MobxAngularModule,
            ScrollingModule,
            TooltipModule.forRoot()
        ],
        declarations: DECLARATIONS,
        exports: [
            LfCoreModule,
            LfTableHeaderModule,
            MobxAngularModule,
            ...DECLARATIONS
        ]
    })
], LfBootstrapThemeModule);
/**
 * Theme services that should be provided for each provided `LF_APP_SCHEMA`.
 * Currently empty, reserved for future use.
 */
const LF_BOOTSTRAP_THEME_SERVICES = [];

/**
 * Default english translations for Bootstrap theme strings.
 */
const I18N_EN_US = {
    '*': {
        // App
        [I18N_BS_LOCALE_KEY]: 'en',
        // Unload alert service
        [I18N_UNLOAD_ALERT_MESSAGE_KEY]: 'Are you sure you want to leave? Changes that you made may not be saved.',
        // Value
        [I18N_VALUE_RETRY_VALIDATE_TEXT_KEY]: 'Retry validation',
        // Tree-nav
        [I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY]: 'Add',
        [I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY]: 'Add',
        // Closeable
        [I18N_CLOSE_BUTTON_TOOLTIP_KEY]: 'Close',
        // Actions-menu
        [I18N_ACTIONS_MENU_BUTTON_TEXT_KEY]: 'Actions',
        // Validation panel
        [I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY]: 'Errors:',
        [I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY]: 'Warnings:',
        [I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY]: 'Everything looks great!',
        [I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY]: 'Focus field',
        [I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY]: 'Next field',
        [I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY]: 'Previous field',
        // Form
        [I18N_FORM_HELP_ACTION_TEXT_KEY]: 'Help',
        [I18N_FORM_REMOVE_ACTION_TEXT_KEY]: 'Remove',
        [I18N_FORM_ENSURE_REMOVE_TEXT_KEY]: 'Please confirm that you wish to remove this form.',
        [I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY]: 'Cancel',
        [I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY]: 'Confirm',
        // Date
        [I18N_DATE_FORMAT_KEY]: 'M/D/YYYY',
        [I18N_DATE_PLACEHOLDER_KEY]: 'm/d/yyyy',
        // Date-range
        [I18N_DATE_RANGE_SEPARATOR_KEY]: ' - ',
        // File
        [I18N_FILE_CHOOSE_PLACEHOLDER_KEY]: 'Choose file',
        [I18N_FILE_BROWSE_TEXT_KEY]: 'Browse',
        [I18N_FILE_NONE_CHOSEN_KEY]: 'No file chosen',
        [I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY]: 'Clear',
        // Number
        [I18N_NUMBER_DECIMAL_SEPARATOR_KEY]: '.',
        [I18N_NUMBER_THOUSANDS_SEPARATOR_KEY]: '',
        // Table
        [I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY]: 'Add row',
        [I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY]: 'Remove rows',
        [I18N_TABLE_NO_ROWS_TEXT_KEY]: 'No rows to display.',
        // Selection
        [I18N_SELECTION_NO_OPTIONS_TEXT_KEY]: 'No options available.',
        // Validations
        [I18N_VALIDATIONS_KEY]: {
            [IS_REJECTED_CODE]: 'An error occurred validating this field.',
            [IS_REQUIRED_CODE]: 'The field is required.',
            [DISALLOWED_VALUE_CODE]: (ctx, { allowedValues }) => {
                if (isBooleanSchema(ctx.schema()) && allowedValues.length === 1) {
                    return `The field must${allowedValues[0] === true ? '' : ' not'} be ticked.`;
                }
                return `The field's value must be one of: ${allowedValues.join(', ')}.`;
            },
            [DATE_OUT_OF_BOUNDS_CODE]: (_, { minDate, maxDate }) => {
                // TODO: Format date properly
                return maxDate === undefined
                    ? `The date mustn't be before ${minDate}.`
                    : minDate === undefined
                        ? `The date mustn't be after ${maxDate}.`
                        : `The date must be between ${minDate} and ${maxDate}.`;
            },
            [SIZE_OUT_OF_BOUNDS_CODE]: (ctx, { size, minSize, maxSize }) => {
                if (size === 0 && minSize > 0) {
                    return 'The field is required.';
                }
                // Checkbox group
                if (ctx.hasStateProperty('.', `i18n(${I18N_SELECTION_OPTIONS_KEY})`)) {
                    return maxSize === undefined
                        ? `A minimum of ${+minSize} option${+minSize === 1 ? '' : 's'} must be selected.`
                        : minSize === undefined
                            ? `A maximum of ${+maxSize} option${+maxSize === 1 ? '' : 's'} must be selected.`
                            : maxSize === minSize
                                ? `${+maxSize} option${+maxSize === 1 ? '' : 's'} must be selected.`
                                : `Between ${+minSize} and ${+maxSize} options must be selected.`;
                }
                // Tables and form-lists
                return maxSize === undefined
                    ? `The collection must have at least ${+minSize} element${+minSize === 1 ? '' : 's'}.`
                    : minSize === undefined
                        ? `The collection must have no more than ${+maxSize} element${+maxSize === 1 ? '' : 's'}.`
                        : maxSize === minSize
                            ? `The collection must have ${+maxSize} element${+maxSize === 1 ? '' : 's'}.`
                            : `The collection must have between ${+minSize} and ${+maxSize} ` +
                                'elements.';
            },
            [NUMBER_OUT_OF_BOUNDS_CODE]: (_, { min, max }) => {
                return max === undefined
                    ? `The value mustn't be lesser than ${+min}.`
                    : min === undefined
                        ? `The value mustn't be greater than ${+max}.`
                        : `The value must be between ${+min} and ${+max}.`;
            },
            [LENGTH_OUT_OF_BOUNDS_CODE]: (_, { length, minLength, maxLength }) => {
                if (length === 0 && minLength > 0) {
                    return 'The field is required.';
                }
                return maxLength === undefined
                    ? `The value must have at least ${+minLength} character${+minLength === 1 ? '' : 's'}.`
                    : minLength === undefined
                        ? `The value must have at most ${+maxLength} character${+maxLength === 1 ? '' : 's'}.`
                        : maxLength === minLength
                            ? `The value must have ${+maxLength} character${+maxLength === 1 ? '' : 's'}.`
                            : `The value must have ${+minLength} to ${+maxLength} characters.`;
            }
        }
    }
};

// Define `es` locale
defineLocale('es', esLocale);
/**
 * Default spanish translations for Bootstrap theme strings.
 */
const I18N_ES_ES = {
    '*': {
        // App
        [I18N_BS_LOCALE_KEY]: 'es',
        // Unload alert service
        [I18N_UNLOAD_ALERT_MESSAGE_KEY]: 'Estás seguro que quieres irte? Es posible que los cambios realizados no se guarden.',
        // Value
        [I18N_VALUE_RETRY_VALIDATE_TEXT_KEY]: 'Reintentar la validación',
        // Tree-nav
        [I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY]: 'Añadir',
        [I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY]: 'Añadir',
        // Actions-menu
        [I18N_ACTIONS_MENU_BUTTON_TEXT_KEY]: 'Comportamiento',
        // Closeable
        [I18N_CLOSE_BUTTON_TOOLTIP_KEY]: 'Cerrar',
        // Validation panel
        [I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY]: 'Errores:',
        [I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY]: 'Advertencias:',
        [I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY]: '¡Todo parece genial!',
        [I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY]: 'Seleccionar campo',
        [I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY]: 'Siguiente campo',
        [I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY]: 'Campo anterior',
        // Form
        [I18N_FORM_HELP_ACTION_TEXT_KEY]: 'Ayuda',
        [I18N_FORM_REMOVE_ACTION_TEXT_KEY]: 'Eliminar',
        [I18N_FORM_ENSURE_REMOVE_TEXT_KEY]: 'Confirme que desea eliminar este formulario.',
        [I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY]: 'Cancelar',
        [I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY]: 'Confirmar',
        // Date
        [I18N_DATE_FORMAT_KEY]: 'DD/MM/YYYY',
        [I18N_DATE_PLACEHOLDER_KEY]: 'dd/mm/aaaa',
        // Date-range
        [I18N_DATE_RANGE_SEPARATOR_KEY]: ' - ',
        // File
        [I18N_FILE_CHOOSE_PLACEHOLDER_KEY]: 'Elija el archivo',
        [I18N_FILE_BROWSE_TEXT_KEY]: 'Buscar',
        [I18N_FILE_NONE_CHOSEN_KEY]: 'Ningún archivo elegido',
        [I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY]: 'Limpiar',
        // Number
        [I18N_NUMBER_DECIMAL_SEPARATOR_KEY]: ',',
        [I18N_NUMBER_THOUSANDS_SEPARATOR_KEY]: '',
        // Table
        [I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY]: 'Añadir fila',
        [I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY]: 'Eliminar filas',
        [I18N_TABLE_NO_ROWS_TEXT_KEY]: 'No hay filas para mostrar.',
        // Selection
        [I18N_SELECTION_NO_OPTIONS_TEXT_KEY]: 'No hay opciones disponibles.',
        // Validations
        [I18N_VALIDATIONS_KEY]: {
            [IS_REJECTED_CODE]: 'Se produjo un error al validar este campo.',
            [IS_REQUIRED_CODE]: 'El campo es obligatorio.',
            [DISALLOWED_VALUE_CODE]: (ctx, { allowedValues }) => {
                if (isBooleanSchema(ctx.schema()) && allowedValues.length === 1) {
                    return `El campo${allowedValues[0] === true ? '' : ' no'} debe estar marcado.`;
                }
                return `El valor del campo debe ser uno de: ${allowedValues.join(', ')}.`;
            },
            [DATE_OUT_OF_BOUNDS_CODE]: (_, { minDate, maxDate }) => {
                // TODO: Format date properly
                return maxDate === undefined
                    ? `La fecha no puede ser anterior al ${minDate}.`
                    : minDate === undefined
                        ? `La fecha no puede ser posterior al ${maxDate}.`
                        : `La fecha debe ser entre el ${minDate} y el ${maxDate}.`;
            },
            [SIZE_OUT_OF_BOUNDS_CODE]: (ctx, { size, minSize, maxSize }) => {
                if (size === 0 && minSize > 0) {
                    return 'El campo es obligatorio.';
                }
                // Checkbox group
                if (ctx.hasStateProperty('.', `i18n(${I18N_SELECTION_OPTIONS_KEY})`)) {
                    const numOptions = n => (n === 1 ? 'una' : n === 2 ? 'dos' : n);
                    return maxSize === undefined
                        ? `Debes seleccionar al menos ${numOptions(+minSize)} ${+minSize === 1 ? 'opción' : 'opciones'}.`
                        : minSize === undefined
                            ? `Debes seleccionar un máximo de ${numOptions(+maxSize)} ${+minSize === 1 ? 'opción' : 'opciones'}.`
                            : maxSize === minSize
                                ? `Debes seleccionar ${numOptions(+maxSize)} ${+maxSize === 1 ? 'opción' : 'opciones'}.`
                                : `Debes seleccionar entre ${numOptions(+minSize)} y ${numOptions(+maxSize)} opciones.`;
                }
                // Tables and form-lists
                return maxSize === undefined
                    ? `La colección debe tener al menos ${+minSize} elemento${+minSize === 1 ? '' : 's'}.`
                    : minSize === undefined
                        ? `La colección debe tener un máximo de ${+maxSize} elemento${+maxSize === 1 ? '' : 's'}.`
                        : maxSize === minSize
                            ? `La colección debe tener ${+maxSize} elemento${+maxSize === 1 ? '' : 's'}.`
                            : `La colección debe tener entre ${+minSize} y ${+maxSize} elementos.`;
            },
            [NUMBER_OUT_OF_BOUNDS_CODE]: (_, { min, max }) => {
                return max === undefined
                    ? `El valor no puede ser inferior a ${+min}.`
                    : min === undefined
                        ? `El valor no puede ser superior a ${+max}.`
                        : `El valor debe estar entre ${+min} y ${+max}.`;
            },
            [LENGTH_OUT_OF_BOUNDS_CODE]: (_, { length, minLength, maxLength }) => {
                if (length === 0 && minLength > 0) {
                    return 'El campo es obligatorio.';
                }
                return maxLength === undefined
                    ? `El valor debe tener al menos ${+minLength} ${+minLength === 1 ? 'carácter' : 'caracteres'}.`
                    : minLength === undefined
                        ? `El valor debe tener un máximo de ${+maxLength} ${+maxLength === 1 ? 'carácter' : 'caracteres'}.`
                        : maxLength === minLength
                            ? `El valor debe tener ${+maxLength} ${+maxLength === 1 ? 'carácter' : 'caracteres'}.`
                            : `El valor debe tener entre ${+minLength} y ${+maxLength} ` +
                                'caracteres.';
            }
        }
    }
};

// Define `pt` locale
defineLocale('pt', ptBrLocale);
/**
 * Default portuguese translations for Bootstrap theme strings.
 */
const I18N_PT_PT = {
    '*': {
        // App
        [I18N_BS_LOCALE_KEY]: 'pt',
        // Unload alert service
        [I18N_UNLOAD_ALERT_MESSAGE_KEY]: 'Tem a certeza que pretende sair? Alterações feitas podem não estar guardadas.',
        // Value
        [I18N_VALUE_RETRY_VALIDATE_TEXT_KEY]: 'Voltar a tentar validar',
        // Tree-nav
        [I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY]: 'Adicionar',
        [I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY]: 'Adicionar',
        // Actions-menu
        [I18N_ACTIONS_MENU_BUTTON_TEXT_KEY]: 'Ações',
        // Closeable
        [I18N_CLOSE_BUTTON_TOOLTIP_KEY]: 'Fechar',
        // Validation panel
        [I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY]: 'Erros:',
        [I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY]: 'Avisos:',
        [I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY]: 'Nenhum problema a reportar!',
        [I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY]: 'Selecionar campo',
        [I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY]: 'Campo seguinte',
        [I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY]: 'Campo anterior',
        // Form
        [I18N_FORM_HELP_ACTION_TEXT_KEY]: 'Ajuda',
        [I18N_FORM_REMOVE_ACTION_TEXT_KEY]: 'Remover',
        [I18N_FORM_ENSURE_REMOVE_TEXT_KEY]: 'Por favor confirme que pretende remover este formulário.',
        [I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY]: 'Cancelar',
        [I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY]: 'Confirmar',
        // Date
        [I18N_DATE_FORMAT_KEY]: 'DD/MM/YYYY',
        [I18N_DATE_PLACEHOLDER_KEY]: 'dd/mm/aaaa',
        // Date-range
        [I18N_DATE_RANGE_SEPARATOR_KEY]: ' - ',
        // File
        [I18N_FILE_CHOOSE_PLACEHOLDER_KEY]: 'Escolher ficheiro',
        [I18N_FILE_BROWSE_TEXT_KEY]: 'Procurar',
        [I18N_FILE_NONE_CHOSEN_KEY]: 'Nenhum ficheiro escolhido',
        [I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY]: 'Limpar',
        // Number
        [I18N_NUMBER_DECIMAL_SEPARATOR_KEY]: ',',
        [I18N_NUMBER_THOUSANDS_SEPARATOR_KEY]: '',
        // Table
        [I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY]: 'Adicionar linha',
        [I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY]: 'Remover linhas',
        [I18N_TABLE_NO_ROWS_TEXT_KEY]: 'Nenhuma linha a mostrar.',
        // Selection
        [I18N_SELECTION_NO_OPTIONS_TEXT_KEY]: 'Nenhuma opção disponível.',
        // Validations
        [I18N_VALIDATIONS_KEY]: {
            [IS_REJECTED_CODE]: 'Ocorreu um erro ao validar este valor.',
            [IS_REQUIRED_CODE]: 'Campo de preenchimento obrigatório.',
            [DISALLOWED_VALUE_CODE]: (ctx, { allowedValues }) => {
                if (isBooleanSchema(ctx.schema()) && allowedValues.length === 1) {
                    return `O campo ${allowedValues[0] === true ? 'tem de ser' : 'não pode ser'} marcado.`;
                }
                return `O valor do campo tem de ser um de: ${allowedValues.join(', ')}.`;
            },
            [DATE_OUT_OF_BOUNDS_CODE]: (_, { minDate, maxDate }) => {
                // TODO: Format date properly
                return maxDate === undefined
                    ? `A data não pode ser anterior a ${minDate}.`
                    : minDate === undefined
                        ? `A data não pode ser posterior a ${maxDate}.`
                        : `A data tem de estar entre ${minDate} e ${maxDate}.`;
            },
            [SIZE_OUT_OF_BOUNDS_CODE]: (ctx, { size, minSize, maxSize }) => {
                if (size === 0 && minSize > 0) {
                    return 'Campo de preenchimento obrigatório.';
                }
                // Checkbox group
                if (ctx.hasStateProperty('.', `i18n(${I18N_SELECTION_OPTIONS_KEY})`)) {
                    const numOptions = n => (n === 1 ? 'uma' : n === 2 ? 'duas' : n);
                    return maxSize === undefined
                        ? `Tem de selecionar no mínimo ${numOptions(+minSize)} ${+minSize === 1 ? 'opção' : 'opções'}.`
                        : minSize === undefined
                            ? `Tem de selecionar no máximo ${numOptions(+maxSize)} ${+minSize === 1 ? 'opção' : 'opções'}.`
                            : maxSize === minSize
                                ? `Tem de selecionar ${numOptions(+maxSize)} ${+maxSize === 1 ? 'opção' : 'opções'}.`
                                : `Entre ${numOptions(+minSize)} e ${numOptions(+maxSize)} opções têm de ser selecionadas.`;
                }
                // Tables and form-lists
                return maxSize === undefined
                    ? `A coleção tem de ter no mínimo ${+minSize} elemento${+minSize === 1 ? '' : 's'}.`
                    : minSize === undefined
                        ? `A coleção tem de ter no máximo ${+maxSize} elemento${+maxSize === 1 ? '' : 's'}.`
                        : maxSize === minSize
                            ? `A coleção tem de ter ${+maxSize} elemento${+maxSize === 1 ? '' : 's'}.`
                            : `A coleção tem de ter entre ${+minSize} e ${+maxSize} elementos.`;
            },
            [NUMBER_OUT_OF_BOUNDS_CODE]: (_, { min, max }) => {
                return max === undefined
                    ? `O valor não pode ser menor do que ${+min}.`
                    : min === undefined
                        ? `O valor não pode ser maior do que ${+max}.`
                        : `O valor tem de estar entre ${+min} e ${+max}.`;
            },
            [LENGTH_OUT_OF_BOUNDS_CODE]: (_, { length, minLength, maxLength }) => {
                if (length === 0 && minLength > 0) {
                    return 'Campo de preenchimento obrigatório.';
                }
                return maxLength === undefined
                    ? `O valor tem de ter no mínimo ${+minLength} ${+minLength === 1 ? 'carácter' : 'caracteres'}.`
                    : minLength === undefined
                        ? `O valor tem de ter no máximo ${+maxLength} ${+maxLength === 1 ? 'carácter' : 'caracteres'}.`
                        : maxLength === minLength
                            ? `O valor tem de ter ${+maxLength} ${+maxLength === 1 ? 'carácter' : 'caracteres'}.`
                            : `O valor tem de ter entre ${+minLength} e ${+maxLength} ` +
                                'caracteres.';
            }
        }
    }
};

// Module

/**
 * Generated bundle index. Do not edit.
 */

export { ActionsMenuComponent, AlertComponent, AppComponent, BsLocaleChanger, ButtonComponent, CardComponent, CardContentComponent, CheckboxComponent, CheckboxGroupComponent, DateComponent, DateRangeComponent, DropdownComponent, DropdownItemComponent, DropdownMenuComponent, FileComponent, FormComponent, HelpTooltipComponent, I18N_ACTIONS_MENU_BUTTON_TEXT_KEY, I18N_ACTIONS_MENU_KEY, I18N_ACTIONS_MENU_OPTIONS_KEY, I18N_BS_LOCALE_KEY, I18N_CLOSE_BUTTON_TOOLTIP_KEY, I18N_DATE_FORMAT_KEY, I18N_DATE_PLACEHOLDER_KEY, I18N_DATE_RANGE_SEPARATOR_KEY, I18N_EN_US, I18N_ES_ES, I18N_FILE_BROWSE_TEXT_KEY, I18N_FILE_CHOOSE_PLACEHOLDER_KEY, I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY, I18N_FILE_NONE_CHOSEN_KEY, I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY, I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY, I18N_FORM_ENSURE_REMOVE_TEXT_KEY, I18N_FORM_HELP_ACTION_TEXT_KEY, I18N_FORM_REMOVE_ACTION_TEXT_KEY, I18N_NUMBER_DECIMAL_SEPARATOR_KEY, I18N_NUMBER_PREFIX_KEY, I18N_NUMBER_SUFFIX_KEY, I18N_NUMBER_THOUSANDS_SEPARATOR_KEY, I18N_PT_PT, I18N_SELECTION_NO_OPTIONS_TEXT_KEY, I18N_SELECTION_OPTIONS_KEY, I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY, I18N_TABLE_COLUMN_LABELS_KEY, I18N_TABLE_NO_ROWS_TEXT_KEY, I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY, I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY, I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY, I18N_VALIDATIONS_KEY, I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY, I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY, I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY, I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY, I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY, I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY, I18N_VALUE_CODE_KEY, I18N_VALUE_HELP_MESSAGE_KEY, I18N_VALUE_LABEL_KEY, I18N_VALUE_LEGEND_KEY, I18N_VALUE_RETRY_VALIDATE_TEXT_KEY, IconComponent, InlineValue, LF_BOOTSTRAP_THEME_SERVICES, LF_URL_PROTOCOL, LfBootstrapThemeModule, ModalBodyComponent, ModalComponent, ModalFooterComponent, ModalHeaderComponent, NumberComponent, RadioComponent, SELECTION_COLUMN_WIDTH, SelectComponent, SelectionValue, SingleSelectionValue, TableCellComponent, TableComponent, TableRowComponent, TextComponent, TextareaComponent, Toggleable, TooltipComponent, TopBarComponent, TreeEntryComponent, TreeNavComponent, ValidationIssueDirective, ValidationPanelComponent, Value, ValueStateComponent, dateRangeSchema, isDateRangeSchema };
//# sourceMappingURL=lightweightform-bootstrap-theme.js.map
