import { __awaiter, __generator, __values, __decorate, __param, __extends, __assign, __spread } from 'tslib';
import { ViewportRuler, ScrollingModule } from '@angular/cdk/scrolling';
import { CommonModule } from '@angular/common';
import { Inject, Input, Component, ChangeDetectionStrategy, EventEmitter, Output, Directive, Optional, SkipSelf, HostBinding, ViewChild, ElementRef, ViewChildren, ɵɵdefineInjectable, ɵɵinject, Injectable, ContentChild, HostListener, NgModule } from '@angular/core';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { Router, RouterModule } from '@angular/router';
import { LfI18n, PathBased, LfStorage, LfRouter, LfFileStorage, LfFileHolder, LfCoreModule, I18N_UNLOAD_ALERT_MESSAGE_KEY } from '@lightweightform/core';
import { asap, ScrollbarUtils, TableHeaderDirective, LfTableHeaderModule } from '@lightweightform/theme-common';
import { observable, computed, action, MobxAngularModule } from 'mobx-angular';
import { BsLocaleService, BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TooltipModule } from 'ngx-bootstrap/tooltip';
import { MarkdownService, MarkdownModule } from 'ngx-markdown';
import { runInAction, observe, autorun, comparer, reaction } from 'mobx';
import { isRecordSchema, isNullableSchema, pathError, isListSchema, isBooleanSchema, tupleSchema, dateSchema, isTupleSchema, isDateSchema, isStringSchema, isNumberSchema, getRowId, isTableSchema, appendToPath, isComplexSchema, isReservedStateProp, getStateProperty, resolvePath, IS_REJECTED_CODE, IS_REQUIRED_CODE, DISALLOWED_VALUE_CODE, DATE_OUT_OF_BOUNDS_CODE, SIZE_OUT_OF_BOUNDS_CODE, NUMBER_OUT_OF_BOUNDS_CODE, LENGTH_OUT_OF_BOUNDS_CODE } from '@lightweightform/storage';
import { PENDING, isPromiseBasedObservable } from 'mobx-utils';
import 'bootstrap/js/dist/dropdown.js';
import $ from 'jquery';
import 'bootstrap/js/dist/modal.js';
import { NumericInput } from '@lightweightform/numeric-input';
import { animationFrameScheduler, asapScheduler } from 'rxjs';
import { auditTime } from 'rxjs/operators';
import { defineLocale } from 'ngx-bootstrap/chronos';
import { esLocale, ptBrLocale } from 'ngx-bootstrap/locale';

// App =========================================================================
/**
 * I18n key used to set the locale used by `ngx-bootstrap`.
 */
var I18N_BS_LOCALE_KEY = 'bsLocale';
// Value =======================================================================
/**
 * I18n key used to associate a label with a value.
 */
var I18N_VALUE_LABEL_KEY = 'label';
/**
 * I18n key used to associate a code with a value.
 */
var I18N_VALUE_CODE_KEY = 'code';
/**
 * I18n key used to associate a help message with a value.
 */
var I18N_VALUE_HELP_MESSAGE_KEY = 'helpMessage';
/**
 * I18n key used to associate a legend with a value.
 */
var I18N_VALUE_LEGEND_KEY = 'legend';
/**
 * I18n key used to associate messages with validation errors.
 */
var I18N_VALIDATIONS_KEY = 'validations';
/**
 * I18n key used to ask the user to retry validating the value.
 */
var I18N_VALUE_RETRY_VALIDATE_TEXT_KEY = 'retryValidateText';
// Tree-nav ====================================================================
/**
 * I18n key used to set the text of the dropdown button used to add optional
 * forms.
 */
var I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY = 'addOptionalValueButtonText';
/**
 * I18n key used to set the text of the button used to add forms to a list of
 * forms.
 */
var I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY = 'addValueToListButtonText';
// Closeable ===================================================================
/**
 * I18n key used to set the text of the tooltip of the "close" button in
 * components.
 */
var I18N_CLOSE_BUTTON_TOOLTIP_KEY = 'closeButtonTooltip';
// Actions-menu ================================================================
/**
 * I18n key used to set the text of the actions-menu button when it is in
 * "mobile" mode.
 */
var I18N_ACTIONS_MENU_BUTTON_TEXT_KEY = 'actionsButtonText';
/**
 * I18n key used to translate the text of the buttons.
 */
var I18N_ACTIONS_MENU_KEY = 'actionsMenu';
/**
 * I18n key used to translate the text of the options of the buttons.
 */
var I18N_ACTIONS_MENU_OPTIONS_KEY = 'actionsMenuOptions';
// Validation panel ============================================================
/**
 * I18n key used to set the "errors" title of validation panel.
 */
var I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY = 'errorsText';
/**
 * I18n key used to set the "warnings" title of validation panel.
 */
var I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY = 'warningsText';
/**
 * I18n key used to set the text that shows up in the validation panel when
 * there are no errors or warnings.
 */
var I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY = 'noIssuesText';
/**
 * I18n key used to set the text of the tooltip of the "focus" button in the
 * validation panel.
 */
var I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY = 'focusButtonTooltip';
/**
 * I18n key used to set the text of the tooltip of the "next" button in the
 * validation panel.
 */
var I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY = 'nextButtonTooltip';
/**
 * I18n key used to set the text of the tooltip of the "previous" button in the
 * validation panel.
 */
var I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY = 'prevButtonTooltip';
// Form ========================================================================
/**
 * I18n key used to set the text of a form component's help action.
 */
var I18N_FORM_HELP_ACTION_TEXT_KEY = 'helpActionText';
/**
 * I18n key used to set the text of a form component's remove action.
 */
var I18N_FORM_REMOVE_ACTION_TEXT_KEY = 'removeActionText';
/**
 * I18n key used to set the message displayed to the user in a form component to
 * confirm removal of a form.
 */
var I18N_FORM_ENSURE_REMOVE_TEXT_KEY = 'ensureRemoveText';
/**
 * I18n key used to set the text of a form component's "cancel" button in the
 * removal modal.
 */
var I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY = 'cancelRemoveButtonText';
/**
 * I18n key used to set the text of a form component's "confirm" button in the
 * removal modal.
 */
var I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY = 'confirmRemoveButtonText';
// Date ========================================================================
/**
 * I18n key used to set the format of a date component.
 */
var I18N_DATE_FORMAT_KEY = 'format';
/**
 * I18n key used to set the placeholder of a date component's input field.
 */
var I18N_DATE_PLACEHOLDER_KEY = 'placeholder';
// Date range ==================================================================
/**
 * I18n keys used to set the separator of the date range.
 */
var I18N_DATE_RANGE_SEPARATOR_KEY = 'separator';
// File ========================================================================
/**
 * I18n key used to set the "Choose file" placeholder of the file input.
 */
var I18N_FILE_CHOOSE_PLACEHOLDER_KEY = 'choosePlaceholder';
/**
 * I18n key used to set the "Browse" text of the file input.
 */
var I18N_FILE_BROWSE_TEXT_KEY = 'browseText';
/**
 * I18n key used to set the "No file chosen" text of the file input.
 */
var I18N_FILE_NONE_CHOSEN_KEY = 'noneChosenText';
/**
 * I18n key used to set the "Clear" button tooltip text.
 */
var I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY = 'clearButtonTooltip';
// Number ======================================================================
/**
 * I18n key used to set the prefix of a number component.
 */
var I18N_NUMBER_PREFIX_KEY = 'prefix';
/**
 * I18n key used to set the suffix of a number component.
 */
var I18N_NUMBER_SUFFIX_KEY = 'suffix';
/**
 * I18n key used to set the decimal separator of a number component.
 */
var I18N_NUMBER_DECIMAL_SEPARATOR_KEY = 'decimalSeparator';
/**
 * I18n key used to set the "thousands separator" of a number component.
 */
var I18N_NUMBER_THOUSANDS_SEPARATOR_KEY = 'thousandsSeparator';
// Table =======================================================================
/**
 * I18n key used to translate the "add row" text of the table component.
 */
var I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY = 'addRowActionText';
/**
 * I18n key used to translate the "remove rows" text of the table component.
 */
var I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY = 'removeRowsActionText';
/**
 * I18n key used to translate the "no rows" text of the table component.
 */
var I18N_TABLE_NO_ROWS_TEXT_KEY = 'noRowsText';
/**
 * I18n key used to set the labels of the table columns in the table component.
 */
var I18N_TABLE_COLUMN_LABELS_KEY = 'columnLabels';
// Selection ===================================================================
/**
 * I18n key used to specify the list of options.
 */
var I18N_SELECTION_OPTIONS_KEY = 'options';
/**
 * I18n key used to translate the "no options" message on components that
 * require options.
 */
var I18N_SELECTION_NO_OPTIONS_TEXT_KEY = 'noOptionsText';

/**
 * Component that responsively displays a menu of actions.
 */
var ActionsMenuComponent = /** @class */ (function () {
    function ActionsMenuComponent(lfI18n) {
        this.lfI18n = lfI18n;
        /**
         * Screen size at which the actions-menu should collapse.
         */
        this.collapseSize = 'md';
        /**
         * Screen size at which the actions-menu button should collapse.
         */
        this.actionsLabelCollapseSize = 'sm';
        /**
         * Whether the actions-menu (when collapsed) should align its menu to the
         * right.
         */
        this.alignMenusRight = false;
        /**
         * Actions currently executing.
         */
        this.runningActions = new Set();
    }
    Object.defineProperty(ActionsMenuComponent.prototype, "actionsLabel", {
        get: function () {
            return this.lfI18n.get(I18N_ACTIONS_MENU_BUTTON_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    ActionsMenuComponent.prototype.actionText = function (act) {
        return act.text != null
            ? act.text
            : act.id != null
                ? this.lfI18n.get(I18N_ACTIONS_MENU_KEY + "." + act.id)
                : '';
    };
    ActionsMenuComponent.prototype.actionOptionText = function (act, option) {
        return option.text != null
            ? option.text
            : act.id != null && option.id != null
                ? this.lfI18n.get(I18N_ACTIONS_MENU_OPTIONS_KEY + "." + act.id + "." + option.id)
                : '';
    };
    ActionsMenuComponent.prototype._runAction = function (act, value) {
        return __awaiter(this, void 0, void 0, function () {
            var res, actionId_1;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        res = act.callback && act.callback(value);
                        if (!(res && typeof res.then === 'function')) return [3 /*break*/, 4];
                        actionId_1 = this.actionId(act);
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, , 3, 4]);
                        this.runningActions.add(actionId_1);
                        return [4 /*yield*/, res];
                    case 2:
                        _a.sent();
                        return [3 /*break*/, 4];
                    case 3:
                        runInAction(function () { return _this.runningActions.delete(actionId_1); });
                        return [7 /*endfinally*/];
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    ActionsMenuComponent.prototype._runActionOption = function (act, option) {
        return __awaiter(this, void 0, void 0, function () {
            var optionId, optionRes;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        optionId = this.actionId(act, option);
                        optionRes = option.callback && option.callback();
                        this.runningActions.add(optionId);
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, , 5, 6]);
                        if (!(optionRes && typeof optionRes === 'function')) return [3 /*break*/, 3];
                        return [4 /*yield*/, optionRes];
                    case 2:
                        _a.sent();
                        _a.label = 3;
                    case 3: return [4 /*yield*/, this._runAction(act, option.value)];
                    case 4:
                        _a.sent();
                        return [3 /*break*/, 6];
                    case 5:
                        runInAction(function () { return _this.runningActions.delete(optionId); });
                        return [7 /*endfinally*/];
                    case 6: return [2 /*return*/];
                }
            });
        });
    };
    Object.defineProperty(ActionsMenuComponent.prototype, "_isAnyActionRunning", {
        get: function () {
            return this.runningActions.size > 0;
        },
        enumerable: true,
        configurable: true
    });
    ActionsMenuComponent.prototype._isActionRunning = function (act) {
        return this.runningActions.has(this.actionId(act));
    };
    ActionsMenuComponent.prototype._isChildOptionRunning = function (act) {
        var e_1, _a;
        try {
            for (var _b = __values(this.runningActions), _c = _b.next(); !_c.done; _c = _b.next()) {
                var id = _c.value;
                if (id.startsWith(this.actionId(act) + ".")) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ActionsMenuComponent.prototype._isActionOptionRunning = function (act, option) {
        return this.runningActions.has(this.actionId(act, option));
    };
    ActionsMenuComponent.prototype.actionId = function (act, option) {
        var actionId = act.id || this.actionText(act);
        var optionId = option && (option.id || this.actionOptionText(act, option));
        return optionId ? actionId + "." + optionId : "" + actionId;
    };
    ActionsMenuComponent.ctorParameters = function () { return [
        { type: LfI18n, decorators: [{ type: Inject, args: [LfI18n,] }] }
    ]; };
    __decorate([
        observable.struct,
        Input()
    ], ActionsMenuComponent.prototype, "actions", void 0);
    __decorate([
        observable,
        Input()
    ], ActionsMenuComponent.prototype, "buttonsSize", void 0);
    __decorate([
        observable,
        Input()
    ], ActionsMenuComponent.prototype, "collapseSize", void 0);
    __decorate([
        observable,
        Input()
    ], ActionsMenuComponent.prototype, "actionsLabelCollapseSize", void 0);
    __decorate([
        observable,
        Input()
    ], ActionsMenuComponent.prototype, "alignMenusRight", void 0);
    __decorate([
        observable
    ], ActionsMenuComponent.prototype, "runningActions", void 0);
    __decorate([
        computed
    ], ActionsMenuComponent.prototype, "actionsLabel", null);
    __decorate([
        action
    ], ActionsMenuComponent.prototype, "_runAction", null);
    __decorate([
        action
    ], ActionsMenuComponent.prototype, "_runActionOption", null);
    __decorate([
        computed
    ], ActionsMenuComponent.prototype, "_isAnyActionRunning", null);
    ActionsMenuComponent = __decorate([
        Component({
            selector: 'lf-actions-menu',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <!-- Large screen: inline buttons -->\n  <div\n    *ngIf=\"actions && actions.length > 0 && collapseSize !== 'every'\"\n    class=\"btn-group {{\n      collapseSize === 'none' ? '' : 'd-none d-' + collapseSize + '-block'\n    }}\"\n  >\n    <ng-template ngFor let-action [ngForOf]=\"actions\">\n      <!-- Anchor action -->\n      <a\n        lf-button\n        *ngIf=\"action.href\"\n        [class]=\"action.class || ''\"\n        [style]=\"action.style\"\n        [size]=\"buttonsSize\"\n        [href]=\"action.href\"\n      >\n        <lf-icon *ngIf=\"action.icon\" [icon]=\"action.icon\"></lf-icon>\n        {{ actionText(action) }}\n      </a>\n      <!-- Regular action (button) -->\n      <button\n        lf-button\n        *ngIf=\"!action.options && !action.href\"\n        [class]=\"action.class || ''\"\n        [style]=\"action.style\"\n        [size]=\"buttonsSize\"\n        [isActive]=\"action.isActive && action.isActive()\"\n        [isDisabled]=\"\n          _isActionRunning(action) || (action.isDisabled && action.isDisabled())\n        \"\n        (click)=\"_runAction(action)\"\n      >\n        <div *ngIf=\"_isActionRunning(action)\" class=\"action-loading\"></div>\n        <lf-icon\n          *ngIf=\"!_isActionRunning(action) && action.icon\"\n          [icon]=\"action.icon\"\n        >\n        </lf-icon>\n        {{ actionText(action) }}\n      </button>\n      <!-- Action with options (dropdown) -->\n      <lf-dropdown *ngIf=\"action.options\">\n        <button\n          lf-button\n          [class]=\"action.class || ''\"\n          [style]=\"action.style\"\n          [size]=\"buttonsSize\"\n          [isDisabled]=\"action.isDisabled && action.isDisabled()\"\n          [dropdownToggle]=\"true\"\n        >\n          <div\n            *ngIf=\"_isActionRunning(action) || _isChildOptionRunning(action)\"\n            class=\"action-loading\"\n          ></div>\n          <lf-icon\n            *ngIf=\"\n              !_isActionRunning(action) &&\n              !_isChildOptionRunning(action) &&\n              action.icon\n            \"\n            [icon]=\"action.icon\"\n          ></lf-icon>\n          {{ actionText(action) }}\n        </button>\n        <lf-dropdown-menu\n          [alignRight]=\"\n            action.alignRight == null ? alignMenusRight : action.alignRight\n          \"\n        >\n          <ng-container *ngFor=\"let option of action.options\">\n            <!-- Anchor option -->\n            <a\n              lf-dropdown-item\n              *ngIf=\"option.href\"\n              [class]=\"option.class || ''\"\n              [href]=\"option.href\"\n            >\n              <lf-icon\n                *ngIf=\"option.icon\"\n                [icon]=\"option.icon\"\n                [fixedWidth]=\"true\"\n              >\n              </lf-icon>\n              {{ actionOptionText(action, option) }}\n            </a>\n            <!-- Regular option (button) -->\n            <button\n              lf-dropdown-item\n              *ngIf=\"!option.href\"\n              type=\"button\"\n              [class]=\"option.class || ''\"\n              [isActive]=\"option.isActive && option.isActive()\"\n              [isDisabled]=\"\n                _isActionOptionRunning(action, option) ||\n                (option.isDisabled && option.isDisabled())\n              \"\n              (click)=\"_runActionOption(action, option)\"\n            >\n              <div\n                *ngIf=\"_isActionOptionRunning(action, option)\"\n                class=\"d-inline-block fa-fw\"\n              >\n                <div class=\"action-loading\"></div>\n              </div>\n              <lf-icon\n                *ngIf=\"!_isActionOptionRunning(action, option) && option.icon\"\n                [icon]=\"option.icon\"\n                [fixedWidth]=\"true\"\n              >\n              </lf-icon>\n              {{ actionOptionText(action, option) }}\n            </button>\n          </ng-container>\n        </lf-dropdown-menu>\n      </lf-dropdown>\n    </ng-template>\n  </div>\n\n  <!-- Small screen: menu buttons -->\n  <div\n    *ngIf=\"actions && actions.length > 0 && collapseSize !== 'none'\"\n    [class]=\"\n      collapseSize === 'every' ? '' : 'd-' + collapseSize + '-none d-block'\n    \"\n  >\n    <lf-dropdown>\n      <button\n        lf-button\n        [style]=\"'outline-secondary'\"\n        [size]=\"buttonsSize\"\n        [dropdownToggle]=\"true\"\n      >\n        <div *ngIf=\"_isAnyActionRunning\" class=\"action-loading\"></div>\n        <lf-icon *ngIf=\"!_isAnyActionRunning\" icon=\"gear\"></lf-icon>\n        <!-- Show a label for the actions toggle depending on screen size -->\n        <span\n          *ngIf=\"actionsLabelCollapseSize !== 'every'\"\n          [class]=\"\n            actionsLabelCollapseSize === 'none'\n              ? ''\n              : 'd-none d-' + actionsLabelCollapseSize + '-inline'\n          \"\n        >\n          {{ actionsLabel }}\n        </span>\n      </button>\n      <lf-dropdown-menu [alignRight]=\"alignMenusRight\">\n        <ng-container *ngFor=\"let action of actions; let i = index\">\n          <!-- Anchor action -->\n          <a\n            lf-dropdown-item\n            *ngIf=\"action.href\"\n            [class]=\"action.class || ''\"\n            [href]=\"action.href\"\n          >\n            <lf-icon\n              *ngIf=\"action.icon\"\n              [icon]=\"action.icon\"\n              [fixedWidth]=\"true\"\n            >\n            </lf-icon>\n            {{ actionText(action) }}\n          </a>\n          <!-- Regular action (button) -->\n          <button\n            lf-dropdown-item\n            type=\"button\"\n            *ngIf=\"!action.options && !action.href\"\n            [class]=\"action.class || ''\"\n            [isActive]=\"action.isActive && action.isActive()\"\n            [isDisabled]=\"\n              _isActionRunning(action) ||\n              (action.isDisabled && action.isDisabled())\n            \"\n            (click)=\"_runAction(action)\"\n          >\n            <div *ngIf=\"_isActionRunning(action)\" class=\"d-inline-block fa-fw\">\n              <div class=\"action-loading\"></div>\n            </div>\n            <lf-icon\n              *ngIf=\"!_isActionRunning(action) && action.icon\"\n              [icon]=\"action.icon\"\n              [fixedWidth]=\"true\"\n            >\n            </lf-icon>\n            {{ actionText(action) }}\n          </button>\n          <!-- Action with options -->\n          <ng-container *ngIf=\"action.options\">\n            <!-- Surround actions with options with dividers -->\n            <div lf-dropdown-item *ngIf=\"i > 0\" [itemType]=\"'divider'\"></div>\n            <h6\n              lf-dropdown-item\n              [class]=\"action.class || ''\"\n              [itemType]=\"'header'\"\n            >\n              <lf-icon\n                *ngIf=\"action.icon\"\n                [icon]=\"action.icon\"\n                [fixedWidth]=\"true\"\n              >\n              </lf-icon>\n              {{ actionText(action) }}\n            </h6>\n            <ng-container *ngFor=\"let option of action.options\">\n              <!-- Anchor option -->\n              <a\n                lf-dropdown-item\n                *ngIf=\"option.href\"\n                [class]=\"option.class || ''\"\n                [href]=\"option.href\"\n              >\n                {{ actionOptionText(action, option) }}\n              </a>\n              <!-- Regular option (button) -->\n              <button\n                lf-dropdown-item\n                type=\"button\"\n                *ngIf=\"!option.href\"\n                [class]=\"option.class || ''\"\n                [isActive]=\"option.isActive && option.isActive()\"\n                [isDisabled]=\"\n                  _isActionOptionRunning(action, option) ||\n                  (option.isDisabled && option.isDisabled())\n                \"\n                (click)=\"_runActionOption(action, option)\"\n              >\n                <div\n                  *ngIf=\"_isActionOptionRunning(action, option)\"\n                  class=\"d-inline-block fa-fw\"\n                >\n                  <div class=\"action-loading\"></div>\n                </div>\n                {{ actionOptionText(action, option) }}\n              </button>\n            </ng-container>\n            <div\n              lf-dropdown-item\n              *ngIf=\"i < actions.length - 1 && !actions[i + 1].options\"\n              [itemType]=\"'divider'\"\n            ></div>\n          </ng-container>\n        </ng-container>\n      </lf-dropdown-menu>\n    </lf-dropdown>\n  </div>\n</ng-container>\n"
        }),
        __param(0, Inject(LfI18n))
    ], ActionsMenuComponent);
    return ActionsMenuComponent;
}());

/**
 * Abstract class for components that are toggleable and path based.
 */
var Toggleable = /** @class */ (function (_super) {
    __extends(Toggleable, _super);
    function Toggleable(parentPathBasedComponent, lfStorage, lfI18n) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        /**
         * Whether the toggleable element should start visible.
         */
        _this.startVisible = false;
        /**
         * Event emitter which emits an event whenever the toggleable is set to be
         * shown.
         */
        // tslint:disable-next-line:no-output-rename
        _this._show = new EventEmitter();
        /**
         * Event emitter which emits an event whenever the toggleable is set to be
         * hidden.
         */
        // tslint:disable-next-line:no-output-rename
        _this._hide = new EventEmitter();
        return _this;
    }
    Object.defineProperty(Toggleable.prototype, "isVisible", {
        /**
         * Whether the toggleable is visible.
         */
        get: function () {
            return this._isVisible;
        },
        set: function (setVisible) {
            if (!this._isVisible && setVisible) {
                this._isVisible = true;
                this._show.emit();
            }
            else if (this._isVisible && !setVisible) {
                this._isVisible = false;
                this._hide.emit();
            }
        },
        enumerable: true,
        configurable: true
    });
    Toggleable.prototype.ngOnInit = function () {
        this._isVisible = this.startVisible;
    };
    /**
     * Show the toggleable element.
     */
    Toggleable.prototype.show = function () {
        this.isVisible = true;
    };
    /**
     * Hide the toggleable element.
     */
    Toggleable.prototype.hide = function () {
        this.isVisible = false;
    };
    /**
     * Toggle the visibility of the toggleable element.
     */
    Toggleable.prototype.toggle = function () {
        this.isVisible = !this.isVisible;
    };
    Toggleable.ctorParameters = function () { return [
        { type: PathBased },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        Input()
    ], Toggleable.prototype, "startVisible", void 0);
    __decorate([
        Output('show')
    ], Toggleable.prototype, "_show", void 0);
    __decorate([
        Output('hide')
    ], Toggleable.prototype, "_hide", void 0);
    __decorate([
        observable
    ], Toggleable.prototype, "_isVisible", void 0);
    __decorate([
        computed
    ], Toggleable.prototype, "isVisible", null);
    __decorate([
        action
    ], Toggleable.prototype, "show", null);
    __decorate([
        action
    ], Toggleable.prototype, "hide", null);
    __decorate([
        action
    ], Toggleable.prototype, "toggle", null);
    Toggleable = __decorate([
        Directive()
        // tslint:disable-next-line: directive-class-suffix
    ], Toggleable);
    return Toggleable;
}(PathBased));

/**
 * LF alert component.
 */
var AlertComponent = /** @class */ (function (_super) {
    __extends(AlertComponent, _super);
    function AlertComponent(parentPathBasedComponent, lfStorage, lfI18n) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
    }
    AlertComponent_1 = AlertComponent;
    Object.defineProperty(AlertComponent.prototype, "closeButtonTooltip", {
        get: function () {
            return this.translate(I18N_CLOSE_BUTTON_TOOLTIP_KEY);
        },
        enumerable: true,
        configurable: true
    });
    var AlertComponent_1;
    AlertComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        observable,
        Input()
    ], AlertComponent.prototype, "style", void 0);
    __decorate([
        observable,
        Input()
    ], AlertComponent.prototype, "showCloseButton", void 0);
    __decorate([
        computed
    ], AlertComponent.prototype, "closeButtonTooltip", null);
    AlertComponent = AlertComponent_1 = __decorate([
        Component({
            selector: 'lf-alert',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: AlertComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <div\n    class=\"alert {{ style ? 'alert-' + style : '' }}\"\n    role=\"alert\"\n    *ngIf=\"isVisible\"\n  >\n    <button\n      type=\"button\"\n      class=\"close\"\n      [title]=\"closeButtonTooltip\"\n      [attr.aria-label]=\"closeButtonTooltip\"\n      *ngIf=\"showCloseButton\"\n      (click)=\"hide()\"\n    >\n      <span aria-hidden=\"true\">&times;</span>\n    </button>\n    <ng-content></ng-content>\n  </div>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], AlertComponent);
    return AlertComponent;
}(Toggleable));

/**
 * Abstract class that all components which "encapsulate" a storage value should
 * inherit.
 */
var Value = /** @class */ (function (_super) {
    __extends(Value, _super);
    function Value(parentPathBasedComponent, lfStorage, lfI18n) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        /**
         * Whether the component should render in "read-only" mode (this has no effect
         * if this component is within an already "read-only" component).
         */
        // tslint:disable-next-line:no-input-rename
        _this._isReadOnly = false;
        /**
         * Add an `lf-value` class to all value components.
         */
        _this._classLfValue = true;
        return _this;
    }
    Object.defineProperty(Value.prototype, "label", {
        /**
         * Label associated with this value.
         */
        get: function () {
            return this.translate(I18N_VALUE_LABEL_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Value.prototype, "code", {
        /**
         * Code associated with this value.
         */
        get: function () {
            return this.translate(I18N_VALUE_CODE_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Value.prototype, "helpMessage", {
        /**
         * Help message associated with this value.
         */
        get: function () {
            return this.translate(I18N_VALUE_HELP_MESSAGE_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Value.prototype, "legend", {
        /**
         * Legend associated with this value.
         */
        get: function () {
            return this.translate(I18N_VALUE_LEGEND_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Value.prototype, "retryValidateText", {
        /**
         * Message used to ask the user to retry validating the value.
         */
        get: function () {
            return this.translate(I18N_VALUE_RETRY_VALIDATE_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Value.prototype, "isReadOnly", {
        /**
         * Whether the component should render in "read-only" mode. Inherits the
         * "read-only" state of parent components (meaning that it's not possible to
         * have an "editable" component within a "read-only" one). Furthermore, if the
         * component's value is computed, the component will always be in "read-only"
         * mode.
         */
        get: function () {
            return ((this.parentPathBasedComponent !== null &&
                this.parentPathBasedComponent.isReadOnly) ||
                this.relativeStorage.isComputed() ||
                this._isReadOnly);
        },
        enumerable: true,
        configurable: true
    });
    Value.ctorParameters = function () { return [
        { type: PathBased },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        observable,
        Input('isReadOnly')
    ], Value.prototype, "_isReadOnly", void 0);
    __decorate([
        HostBinding('class.lf-value')
    ], Value.prototype, "_classLfValue", void 0);
    __decorate([
        computed
    ], Value.prototype, "label", null);
    __decorate([
        computed
    ], Value.prototype, "code", null);
    __decorate([
        computed
    ], Value.prototype, "helpMessage", null);
    __decorate([
        computed
    ], Value.prototype, "legend", null);
    __decorate([
        computed
    ], Value.prototype, "retryValidateText", null);
    __decorate([
        computed
    ], Value.prototype, "isReadOnly", null);
    Value = __decorate([
        Directive()
        // tslint:disable-next-line: directive-class-suffix
    ], Value);
    return Value;
}(PathBased));

/**
 * Validation panel component.
 */
var ValidationPanelComponent = /** @class */ (function (_super) {
    __extends(ValidationPanelComponent, _super);
    function ValidationPanelComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.lfRouter = lfRouter;
        return _this;
    }
    Object.defineProperty(ValidationPanelComponent.prototype, "errorsText", {
        get: function () {
            return this.translate(I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "warningsText", {
        get: function () {
            return this.translate(I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "noIssuesText", {
        get: function () {
            return this.translate(I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "focusButtonTooltip", {
        get: function () {
            return this.translate(I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "nextButtonTooltip", {
        get: function () {
            return this.translate(I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "prevButtonTooltip", {
        get: function () {
            return this.translate(I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "closeButtonTooltip", {
        get: function () {
            return this.translate(I18N_CLOSE_BUTTON_TOOLTIP_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "isPending", {
        get: function () {
            return this.relativeStorage.validationStatus() === PENDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "currentPath", {
        get: function () {
            return this._currentPath && this._validationIssues[this._currentPath]
                ? this._currentPath
                : this._pages[0];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "currentLabel", {
        get: function () {
            return this.currentPath && this.labelOf(this.currentPath);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "hasNext", {
        get: function () {
            return this._pages.length - 1 > this._pages.indexOf(this.currentPath);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "hasPrevious", {
        get: function () {
            return this._pages.indexOf(this.currentPath) > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "errors", {
        get: function () {
            return ((this._validationIssues[this.currentPath] || []).filter(function (issue) { return !issue.isWarning; }) || []);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "warnings", {
        get: function () {
            return ((this._validationIssues[this.currentPath] || []).filter(function (issue) { return issue.isWarning; }) || []);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "hasNoIssues", {
        get: function () {
            return this._pages.length === 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "panelType", {
        get: function () {
            return this.isPending
                ? 'secondary'
                : this.errors.length > 0
                    ? 'danger'
                    : this.warnings.length > 0
                        ? 'warning'
                        : 'success';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "_pages", {
        get: function () {
            return Object.keys(this._validationIssues);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValidationPanelComponent.prototype, "_validationIssues", {
        get: function () {
            return this.relativeStorage.validationIssues() || {};
        },
        enumerable: true,
        configurable: true
    });
    ValidationPanelComponent.prototype.show = function () {
        _super.prototype.show.call(this);
        this.navigateToCurrentPath();
    };
    ValidationPanelComponent.prototype.triggerFocus = function () {
        this.navigateToCurrentPath();
    };
    ValidationPanelComponent.prototype.next = function () {
        if (this.hasNext) {
            this._currentPath = this._pages[this._pages.indexOf(this.currentPath) + 1];
            this.navigateToCurrentPath();
        }
    };
    ValidationPanelComponent.prototype.previous = function () {
        if (this.hasPrevious) {
            this._currentPath = this._pages[this._pages.indexOf(this.currentPath) - 1];
            this.navigateToCurrentPath();
        }
    };
    /**
     * Label associated with the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    ValidationPanelComponent.prototype.labelOf = function (path) {
        return this.lfI18n.getFromPath(path, I18N_VALUE_LABEL_KEY) || path;
    };
    ValidationPanelComponent.prototype.navigateToCurrentPath = function () {
        if (this.currentPath) {
            // Check if the first route that matches the path is navigateable, if not
            // don't navigate
            var firstMatching = this.lfRouter.matchingRoutes(this.currentPath, {
                navigateToParent: true
            })[0];
            var navigateable = firstMatching &&
                this.lfRouter.navigateableRouteFromMatchingRoutes([firstMatching]);
            if (navigateable) {
                this.lfRouter.navigateFromNavigateableRoute(navigateable, {
                    queryParamsHandling: 'merge'
                });
            }
            else {
                // Remove fragment TODO: Find a better way of doing it
                this.lfRouter.navigate('.', { queryParamsHandling: 'merge' });
            }
        }
    };
    ValidationPanelComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter }
    ]; };
    __decorate([
        observable
    ], ValidationPanelComponent.prototype, "_currentPath", void 0);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "errorsText", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "warningsText", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "noIssuesText", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "focusButtonTooltip", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "nextButtonTooltip", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "prevButtonTooltip", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "closeButtonTooltip", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "isPending", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "currentPath", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "currentLabel", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "hasNext", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "hasPrevious", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "errors", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "warnings", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "hasNoIssues", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "panelType", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "_pages", null);
    __decorate([
        computed
    ], ValidationPanelComponent.prototype, "_validationIssues", null);
    __decorate([
        action
    ], ValidationPanelComponent.prototype, "show", null);
    __decorate([
        action
    ], ValidationPanelComponent.prototype, "triggerFocus", null);
    __decorate([
        action
    ], ValidationPanelComponent.prototype, "next", null);
    __decorate([
        action
    ], ValidationPanelComponent.prototype, "previous", null);
    ValidationPanelComponent = __decorate([
        Component({
            selector: 'lf-validation-panel',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <div class=\"validation-panel-container\" *ngIf=\"isVisible\">\n    <div class=\"card border-{{ panelType }}\">\n      <div\n        class=\"card-header bg-{{ panelType }} text-white d-inline-flex\n               justify-content-between\"\n      >\n        <span class=\"header-title\">{{ currentLabel }}</span>\n        <div class=\"actions-bar d-inline-flex justify-content-between\">\n          <button\n            lf-button\n            class=\"panel-focus\"\n            size=\"sm\"\n            [title]=\"focusButtonTooltip\"\n            [attr.aria-label]=\"focusButtonTooltip\"\n            [style]=\"'outline-light'\"\n            (click)=\"triggerFocus()\"\n          >\n            <lf-icon icon=\"crosshairs\"></lf-icon>\n          </button>\n          <div class=\"btn-group mx-4\">\n            <button\n              lf-button\n              class=\"panel-prev\"\n              size=\"sm\"\n              [title]=\"prevButtonTooltip\"\n              [attr.aria-label]=\"prevButtonTooltip\"\n              [style]=\"'outline-light'\"\n              [isDisabled]=\"!hasPrevious\"\n              (click)=\"previous()\"\n            >\n              <lf-icon icon=\"chevron-left\"></lf-icon>\n            </button>\n            <button\n              lf-button\n              class=\"panel-next\"\n              size=\"sm\"\n              [title]=\"nextButtonTooltip\"\n              [attr.aria-label]=\"nextButtonTooltip\"\n              [style]=\"'outline-light'\"\n              [isDisabled]=\"!hasNext\"\n              (click)=\"next()\"\n            >\n              <lf-icon icon=\"chevron-right\"></lf-icon>\n            </button>\n          </div>\n          <button\n            lf-button\n            class=\"panel-close\"\n            size=\"sm\"\n            [title]=\"closeButtonTooltip\"\n            [attr.aria-label]=\"closeButtonTooltip\"\n            [style]=\"'outline-light'\"\n            (click)=\"hide()\"\n          >\n            <lf-icon icon=\"times\"></lf-icon>\n          </button>\n        </div>\n      </div>\n      <div class=\"card-body bg-{{ panelType }}\">\n        <div *ngIf=\"isPending\" class=\"pending\"></div>\n        <ng-container *ngIf=\"!isPending && errors.length > 0\">\n          <strong>\n            <lf-icon icon=\"exclamation-circle\"></lf-icon> {{ errorsText }}\n          </strong>\n          <ul>\n            <li\n              *ngFor=\"let error of errors\"\n              class=\"validation-issue\"\n              lfValidationIssue\n              [path]=\"currentPath\"\n              [issue]=\"error\"\n            ></li>\n          </ul>\n        </ng-container>\n        <ng-container *ngIf=\"!isPending && warnings.length > 0\">\n          <strong>\n            <lf-icon icon=\"exclamation-triangle\"></lf-icon> {{ warningsText }}\n          </strong>\n          <ul>\n            <li\n              *ngFor=\"let warning of warnings\"\n              class=\"validation-issue\"\n              lfValidationIssue\n              [path]=\"currentPath\"\n              [issue]=\"warning\"\n            ></li>\n          </ul>\n        </ng-container>\n        <ng-container *ngIf=\"!isPending && hasNoIssues\">\n          {{ noIssuesText }}\n        </ng-container>\n      </div>\n    </div>\n  </div>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased))
    ], ValidationPanelComponent);
    return ValidationPanelComponent;
}(Toggleable));

/**
 * Lf app component.
 */
var AppComponent = /** @class */ (function (_super) {
    __extends(AppComponent, _super);
    function AppComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.lfRouter = lfRouter;
        // State of the tree nav visibility
        _this._isTreeNavVisible = false;
        // Whether the backdrop element should be in visible or invisible state
        _this._isBackdropVisible = false;
        // Whether the backdrop element should exist
        _this._shouldBackdropExist = false;
        return _this;
    }
    AppComponent_1 = AppComponent;
    Object.defineProperty(AppComponent.prototype, "isTreeNavVisible", {
        get: function () {
            return this._isTreeNavVisible;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AppComponent.prototype, "treeNavTranslateX", {
        // Current `translateX` value of the tree nav
        get: function () {
            // Obtain `tx` from `'matrix(a, b, c, d, tx, ty)'`
            return +window
                .getComputedStyle(this._treeNavContainer.nativeElement)
                .getPropertyValue('transform')
                .split(',')[4];
        },
        enumerable: true,
        configurable: true
    });
    AppComponent.prototype.ngOnInit = function () {
        if (this._path === undefined) {
            this._path = '/';
        }
        _super.prototype.ngOnInit.call(this);
    };
    AppComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        // Hide tree nav when `Escape` is pressed
        this.onPressEsc = function (evt) {
            if (_this.isTreeNavVisible && evt.key === 'Escape') {
                _this.hideTreeNav();
            }
        };
        window.addEventListener('keyup', this.onPressEsc);
        // Scroll viewport to the top whenever the router path changes
        if (this.lfRouter !== null) {
            this.disposeOnRouterPathChange = observe(this.lfRouter, 'path', function () {
                _this.scrollTo({ top: 0, left: 0 });
            });
        }
    };
    AppComponent.prototype.ngOnDestroy = function () {
        this.onPressEsc && window.removeEventListener('keyup', this.onPressEsc);
        this.disposeOnRouterPathChange && this.disposeOnRouterPathChange();
    };
    AppComponent.prototype.showTreeNav = function () {
        if (!this._isTreeNavVisible) {
            this._isTreeNavVisible = true;
            this._isBackdropVisible = true;
            this._shouldBackdropExist = true;
            this.lastTreeNavTranslateX = this.treeNavTranslateX;
        }
    };
    AppComponent.prototype.hideTreeNav = function () {
        if (this._isTreeNavVisible) {
            this._isTreeNavVisible = false;
            // When there was no time for an animation and `transitionend` isn't called
            if (this.lastTreeNavTranslateX === this.treeNavTranslateX) {
                this._onTreeNavTransitionEnd();
            }
        }
    };
    AppComponent.prototype.validate = function () {
        this.relativeStorage.setTouched('.', true);
        this._validationPanel.show();
    };
    /**
     * Scroll the main content area.
     * @param options Options for the scrolling.
     */
    AppComponent.prototype.scrollTo = function (options) {
        // Depending on whether we're in mobile or desktop mode, the scrollable
        // element differs
        this._mainContainer.nativeElement.scrollTo(options);
        this._mainContent.nativeElement.scrollTo(options);
    };
    // Action to run after the tree nav finishes hiding (hide backdrop)
    AppComponent.prototype._onTreeNavTransitionEnd = function () {
        var _this = this;
        if (!this.isTreeNavVisible && this._isBackdropVisible) {
            runInAction('hideTreeNavBackdrop', function () { return (_this._isBackdropVisible = false); });
        }
    };
    // Action to run after the backdrop finishes hiding (delete backdrop)
    AppComponent.prototype._onBackdropTransitionEnd = function () {
        var _this = this;
        runInAction('removeTreeNavBackdrop', function () { return (_this._shouldBackdropExist = false); });
    };
    AppComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isRecordSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "record" type and not "nullable"');
        }
    };
    var AppComponent_1;
    AppComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        ViewChild(ValidationPanelComponent)
    ], AppComponent.prototype, "_validationPanel", void 0);
    __decorate([
        ViewChild('treeNavContainer')
    ], AppComponent.prototype, "_treeNavContainer", void 0);
    __decorate([
        ViewChild('mainContainer')
    ], AppComponent.prototype, "_mainContainer", void 0);
    __decorate([
        ViewChild('mainContent')
    ], AppComponent.prototype, "_mainContent", void 0);
    __decorate([
        observable
    ], AppComponent.prototype, "_isTreeNavVisible", void 0);
    __decorate([
        observable
    ], AppComponent.prototype, "_isBackdropVisible", void 0);
    __decorate([
        observable
    ], AppComponent.prototype, "_shouldBackdropExist", void 0);
    __decorate([
        computed
    ], AppComponent.prototype, "isTreeNavVisible", null);
    __decorate([
        action
    ], AppComponent.prototype, "showTreeNav", null);
    __decorate([
        action
    ], AppComponent.prototype, "hideTreeNav", null);
    __decorate([
        action
    ], AppComponent.prototype, "validate", null);
    AppComponent = AppComponent_1 = __decorate([
        Component({
            selector: 'lf-app',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: AppComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <div class=\"d-flex flex-column h-100\">\n    <!-- Application header -->\n    <header id=\"lf-header\">\n      <ng-content select=\"lf-top-bar\"></ng-content>\n    </header>\n\n    <!-- Content -->\n    <div #mainContainer id=\"lf-main-container\" class=\"container-fluid\">\n      <div id=\"lf-main-row\" class=\"row\">\n        <!-- Container of the tree nav (collapsible from the `top-bar`) -->\n        <div\n          #treeNavContainer\n          id=\"lf-tree-nav-container\"\n          class=\"col-xl-2 col-md-3 col-sm-12\"\n          [class.show]=\"isTreeNavVisible\"\n          [class.animate]=\"_shouldBackdropExist\"\n          (transitionend)=\"_onTreeNavTransitionEnd()\"\n        >\n          <ng-content select=\"lf-tree-nav\"></ng-content>\n        </div>\n\n        <!-- Main content -->\n        <div\n          #mainContent\n          id=\"lf-main-content\"\n          class=\"col-xl-10 col-md-9 col-sm-12\"\n        >\n          <ng-content></ng-content>\n\n          <!-- Validation panel -->\n          <lf-validation-panel></lf-validation-panel>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div\n    *ngIf=\"_shouldBackdropExist\"\n    class=\"modal-backdrop fade d-md-none\"\n    [class.show]=\"_isBackdropVisible\"\n    (click)=\"hideTreeNav()\"\n    (transitionend)=\"_onBackdropTransitionEnd()\"\n  ></div>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], AppComponent);
    return AppComponent;
}(Value));

/**
 * LF component used to display the "top-bar" of an application.
 */
var TopBarComponent = /** @class */ (function () {
    function TopBarComponent(lfStorage, lfRouter, lfI18n, lfFileStorage, _appComponent) {
        this.lfStorage = lfStorage;
        this.lfRouter = lfRouter;
        this.lfI18n = lfI18n;
        this.lfFileStorage = lfFileStorage;
        this._appComponent = _appComponent;
    }
    Object.defineProperty(TopBarComponent.prototype, "retryValidationText", {
        get: function () {
            return this.lfI18n.get(I18N_VALUE_RETRY_VALIDATE_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TopBarComponent.prototype, "rootUrl", {
        get: function () {
            try {
                return this.lfRouter.createUrl('/');
            }
            catch (err) {
                return '/';
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TopBarComponent.prototype, "appIsPending", {
        get: function () {
            return (this.lfStorage.shouldShowPending() ||
                (this.lfFileStorage && this.lfFileStorage.isLoading));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TopBarComponent.prototype, "shouldShowAppRecompute", {
        get: function () {
            return !!this.lfStorage.shouldShowRejected();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TopBarComponent.prototype, "isTreeNavVisible", {
        get: function () {
            return this._appComponent.isTreeNavVisible;
        },
        enumerable: true,
        configurable: true
    });
    TopBarComponent.prototype.recomputeAppStateProperties = function () {
        this.lfStorage.recomputeStateProperties();
    };
    TopBarComponent.prototype.showTreeNav = function () {
        this._appComponent.showTreeNav();
    };
    TopBarComponent.ctorParameters = function () { return [
        { type: LfStorage },
        { type: LfRouter },
        { type: LfI18n, decorators: [{ type: Inject, args: [LfI18n,] }] },
        { type: LfFileStorage, decorators: [{ type: Optional }, { type: Inject, args: [LfFileStorage,] }] },
        { type: AppComponent, decorators: [{ type: Inject, args: [AppComponent,] }] }
    ]; };
    __decorate([
        observable.struct,
        Input()
    ], TopBarComponent.prototype, "actions", void 0);
    __decorate([
        computed
    ], TopBarComponent.prototype, "retryValidationText", null);
    __decorate([
        computed
    ], TopBarComponent.prototype, "rootUrl", null);
    __decorate([
        computed
    ], TopBarComponent.prototype, "appIsPending", null);
    __decorate([
        computed
    ], TopBarComponent.prototype, "shouldShowAppRecompute", null);
    __decorate([
        computed
    ], TopBarComponent.prototype, "isTreeNavVisible", null);
    __decorate([
        action
    ], TopBarComponent.prototype, "recomputeAppStateProperties", null);
    __decorate([
        action
    ], TopBarComponent.prototype, "showTreeNav", null);
    TopBarComponent = __decorate([
        Component({
            selector: 'lf-top-bar',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <nav class=\"navbar navbar-expand-lg justify-content-between\">\n    <!-- Tree toggle + title + pending icon -->\n    <div class=\"navbar-brand\">\n      <!-- Small screen: show tree-nav button -->\n      <button\n        lf-button\n        class=\"tree-nav-show d-md-none\"\n        [style]=\"'outline-secondary'\"\n        (click)=\"showTreeNav()\"\n      >\n        <lf-icon icon=\"bars\"></lf-icon>\n      </button>\n\n      <!-- Title -->\n      <a\n        class=\"navbar-title\"\n        [routerLink]=\"rootUrl\"\n        queryParamsHandling=\"merge\"\n      >\n        <ng-content></ng-content>\n      </a>\n\n      <!-- Pending app validation -->\n      <div class=\"pending-app\" *ngIf=\"appIsPending\"></div>\n\n      <!-- Rejected app validation -->\n      <div\n        class=\"rejected-app\"\n        *ngIf=\"shouldShowAppRecompute\"\n        (click)=\"recomputeAppStateProperties()\"\n      >\n        <lf-tooltip [help]=\"retryValidationText\" placement=\"right\">\n          <lf-icon icon=\"warning\"></lf-icon>\n        </lf-tooltip>\n      </div>\n    </div>\n\n    <!-- Application actions -->\n    <lf-actions-menu [actions]=\"actions\" [alignMenusRight]=\"true\">\n    </lf-actions-menu>\n  </nav>\n</ng-container>\n"
        }),
        __param(2, Inject(LfI18n)),
        __param(3, Optional()), __param(3, Inject(LfFileStorage)),
        __param(4, Inject(AppComponent))
    ], TopBarComponent);
    return TopBarComponent;
}());

/**
 * Bootstrap button component.
 */
var ButtonComponent = /** @class */ (function () {
    function ButtonComponent(_host) {
        /**
         * HTML button type.
         */
        this.type = 'button';
        /**
         * Match the width of parent if `true`.
         */
        this.block = false;
        /**
         * Display a dropdown icon (this is automatic if `dropdownToggleSplit` is
         * set).
         */
        this.dropdownToggle = false;
        /**
         * Reduces the padding of the button so it can be used as the dropdown part of
         * a split dropdown.
         */
        this.dropdownToggleSplit = false;
        /**
         * Set the button as disabled.
         */
        this.isDisabled = false;
        /**
         * Set the button as active.
         */
        this.isActive = false;
        /**
         * Always add the class `btn` to LF buttons.
         */
        this._hostClassBtn = true;
        this._tagName = _host.nativeElement.tagName.toLowerCase();
    }
    Object.defineProperty(ButtonComponent.prototype, "_role", {
        // Set the role as `'button'` when the element is an `a`.
        get: function () {
            return this._tagName === 'a' ? 'button' : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnPrimary", {
        // Set the corresponding style class depending on the button style (setting
        // individual classes instead of `class` itself makes it possible for the user
        // to still set `class` on the component without it being overridden)
        get: function () {
            return this.style === 'primary';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnSecondary", {
        get: function () {
            return this.style === 'secondary';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnSuccess", {
        get: function () {
            return this.style === 'success';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnDanger", {
        get: function () {
            return this.style === 'danger';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnWarning", {
        get: function () {
            return this.style === 'warning';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnInfo", {
        get: function () {
            return this.style === 'info';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnLight", {
        get: function () {
            return this.style === 'light';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnDark", {
        get: function () {
            return this.style === 'dark';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnLink", {
        get: function () {
            return this.style === 'link';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlinePrimary", {
        get: function () {
            return this.style === 'outline-primary';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineSecondary", {
        get: function () {
            return this.style === 'outline-secondary';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineSuccess", {
        get: function () {
            return this.style === 'outline-success';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineDanger", {
        get: function () {
            return this.style === 'outline-danger';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineWarning", {
        get: function () {
            return this.style === 'outline-warning';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineInfo", {
        get: function () {
            return this.style === 'outline-info';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineLight", {
        get: function () {
            return this.style === 'outline-light';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnOutlineDark", {
        get: function () {
            return this.style === 'outline-dark';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnSm", {
        // Set the corresponding style class
        get: function () {
            return this.size === 'sm';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassBtnLg", {
        get: function () {
            return this.size === 'lg';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostClassDropdownToggle", {
        // Set the dropdown toggle class when possible
        get: function () {
            return (this._tagName !== 'input' &&
                (this.dropdownToggle || this.dropdownToggleSplit));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostType", {
        // Set type to `'button'` by default (on `button`s and `input`s)
        get: function () {
            return this._tagName !== 'a' ? this.type || 'button' : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostDisabled", {
        get: function () {
            return this._tagName !== 'a' && this.isDisabled ? '' : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostAriaDisabled", {
        get: function () {
            return this._tagName !== 'a' && this.isDisabled ? 'true' : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ButtonComponent.prototype, "_hostAriaPressed", {
        get: function () {
            return this.isActive ? 'true' : undefined;
        },
        enumerable: true,
        configurable: true
    });
    ButtonComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        observable,
        Input()
    ], ButtonComponent.prototype, "style", void 0);
    __decorate([
        observable,
        Input()
    ], ButtonComponent.prototype, "size", void 0);
    __decorate([
        observable,
        Input()
    ], ButtonComponent.prototype, "type", void 0);
    __decorate([
        observable,
        Input(),
        HostBinding('class.btn-block')
    ], ButtonComponent.prototype, "block", void 0);
    __decorate([
        observable,
        Input()
    ], ButtonComponent.prototype, "dropdownToggle", void 0);
    __decorate([
        observable,
        Input(),
        HostBinding('class.dropdown-toggle-split')
    ], ButtonComponent.prototype, "dropdownToggleSplit", void 0);
    __decorate([
        observable,
        Input()
    ], ButtonComponent.prototype, "isDisabled", void 0);
    __decorate([
        observable,
        Input(),
        HostBinding('class.active')
    ], ButtonComponent.prototype, "isActive", void 0);
    __decorate([
        HostBinding('class.btn')
    ], ButtonComponent.prototype, "_hostClassBtn", void 0);
    __decorate([
        HostBinding('attr.role')
    ], ButtonComponent.prototype, "_role", null);
    __decorate([
        computed,
        HostBinding('class.btn-primary')
    ], ButtonComponent.prototype, "_hostClassBtnPrimary", null);
    __decorate([
        computed,
        HostBinding('class.btn-secondary')
    ], ButtonComponent.prototype, "_hostClassBtnSecondary", null);
    __decorate([
        computed,
        HostBinding('class.btn-success')
    ], ButtonComponent.prototype, "_hostClassBtnSuccess", null);
    __decorate([
        computed,
        HostBinding('class.btn-danger')
    ], ButtonComponent.prototype, "_hostClassBtnDanger", null);
    __decorate([
        computed,
        HostBinding('class.btn-warning')
    ], ButtonComponent.prototype, "_hostClassBtnWarning", null);
    __decorate([
        computed,
        HostBinding('class.btn-info')
    ], ButtonComponent.prototype, "_hostClassBtnInfo", null);
    __decorate([
        computed,
        HostBinding('class.btn-light')
    ], ButtonComponent.prototype, "_hostClassBtnLight", null);
    __decorate([
        computed,
        HostBinding('class.btn-dark')
    ], ButtonComponent.prototype, "_hostClassBtnDark", null);
    __decorate([
        computed,
        HostBinding('class.btn-link')
    ], ButtonComponent.prototype, "_hostClassBtnLink", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-primary')
    ], ButtonComponent.prototype, "_hostClassBtnOutlinePrimary", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-secondary')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineSecondary", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-success')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineSuccess", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-danger')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineDanger", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-warning')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineWarning", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-info')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineInfo", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-light')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineLight", null);
    __decorate([
        computed,
        HostBinding('class.btn-outline-dark')
    ], ButtonComponent.prototype, "_hostClassBtnOutlineDark", null);
    __decorate([
        computed,
        HostBinding('class.btn-sm')
    ], ButtonComponent.prototype, "_hostClassBtnSm", null);
    __decorate([
        computed,
        HostBinding('class.btn-lg')
    ], ButtonComponent.prototype, "_hostClassBtnLg", null);
    __decorate([
        computed,
        HostBinding('class.dropdown-toggle')
    ], ButtonComponent.prototype, "_hostClassDropdownToggle", null);
    __decorate([
        computed,
        HostBinding('attr.type')
    ], ButtonComponent.prototype, "_hostType", null);
    __decorate([
        computed,
        HostBinding('attr.disabled')
    ], ButtonComponent.prototype, "_hostDisabled", null);
    __decorate([
        computed,
        HostBinding('attr.aria-disabled')
    ], ButtonComponent.prototype, "_hostAriaDisabled", null);
    __decorate([
        computed,
        HostBinding('attr.aria-pressed')
    ], ButtonComponent.prototype, "_hostAriaPressed", null);
    ButtonComponent = __decorate([
        Component({
            // tslint:disable-next-line:component-selector
            selector: 'button[lf-button], input[lf-button], a[lf-button]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
        })
    ], ButtonComponent);
    return ButtonComponent;
}());

/**
 * Content of an `lf-card`.
 */
var CardContentComponent = /** @class */ (function (_super) {
    __extends(CardContentComponent, _super);
    function CardContentComponent(parentPathBasedComponent, lfStorage, lfI18n) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
    }
    CardContentComponent_1 = CardContentComponent;
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardHeader", {
        // Classes for each type of card content
        get: function () {
            return this.contentType === 'header';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardBody", {
        get: function () {
            return this.contentType === 'body';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardFooter", {
        get: function () {
            return this.contentType === 'footer';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardTitle", {
        get: function () {
            return this.contentType === 'title';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardSubtitle", {
        get: function () {
            return this.contentType === 'subtitle';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardText", {
        get: function () {
            return this.contentType === 'text';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardLink", {
        get: function () {
            return this.contentType === 'link';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardImg", {
        get: function () {
            return this.contentType === 'img';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardImgOverlay", {
        get: function () {
            return this.contentType === 'img-overlay';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardImgTop", {
        get: function () {
            return this.contentType === 'img-top';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardContentComponent.prototype, "_hostClassCardImgBottom", {
        get: function () {
            return this.contentType === 'img-bottom';
        },
        enumerable: true,
        configurable: true
    });
    var CardContentComponent_1;
    CardContentComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        observable,
        Input()
    ], CardContentComponent.prototype, "contentType", void 0);
    __decorate([
        computed,
        HostBinding('class.card-header')
    ], CardContentComponent.prototype, "_hostClassCardHeader", null);
    __decorate([
        computed,
        HostBinding('class.card-body')
    ], CardContentComponent.prototype, "_hostClassCardBody", null);
    __decorate([
        computed,
        HostBinding('class.card-footer')
    ], CardContentComponent.prototype, "_hostClassCardFooter", null);
    __decorate([
        computed,
        HostBinding('class.card-title')
    ], CardContentComponent.prototype, "_hostClassCardTitle", null);
    __decorate([
        computed,
        HostBinding('class.card-subtitle')
    ], CardContentComponent.prototype, "_hostClassCardSubtitle", null);
    __decorate([
        computed,
        HostBinding('class.card-text')
    ], CardContentComponent.prototype, "_hostClassCardText", null);
    __decorate([
        computed,
        HostBinding('class.card-link')
    ], CardContentComponent.prototype, "_hostClassCardLink", null);
    __decorate([
        computed,
        HostBinding('class.card-img')
    ], CardContentComponent.prototype, "_hostClassCardImg", null);
    __decorate([
        computed,
        HostBinding('class.card-img-overlay')
    ], CardContentComponent.prototype, "_hostClassCardImgOverlay", null);
    __decorate([
        computed,
        HostBinding('class.card-img-top')
    ], CardContentComponent.prototype, "_hostClassCardImgTop", null);
    __decorate([
        computed,
        HostBinding('class.card-img-bottom')
    ], CardContentComponent.prototype, "_hostClassCardImgBottom", null);
    CardContentComponent = CardContentComponent_1 = __decorate([
        Component({
            selector: 'lf-card-content, [lf-card-content]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: CardContentComponent_1 }],
            template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], CardContentComponent);
    return CardContentComponent;
}(PathBased));

/**
 * Bootstrap card component, see options on how to further customise the card
 * with background and border utilities at [Bootstrap documentation](
 * https://getbootstrap.com/docs/4.1/components/card/#card-styles).
 */
var CardComponent = /** @class */ (function (_super) {
    __extends(CardComponent, _super);
    function CardComponent(parentPathBasedComponent, lfStorage, lfI18n) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        /**
         * Always add the class `card` to LF cards.
         */
        _this._hostClassCard = true;
        return _this;
    }
    CardComponent_1 = CardComponent;
    var CardComponent_1;
    CardComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        HostBinding('class.card')
    ], CardComponent.prototype, "_hostClassCard", void 0);
    CardComponent = CardComponent_1 = __decorate([
        Component({
            selector: 'lf-card, [lf-card]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: CardComponent_1 }],
            template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], CardComponent);
    return CardComponent;
}(PathBased));

/**
 * Abstract class used to represent typical "inline-able" values.
 */
var InlineValue = /** @class */ (function (_super) {
    __extends(InlineValue, _super);
    function InlineValue(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.lfRouter = lfRouter;
        /**
         * Whether the component should be hidden when its value isn't required.
         * **NOT READY FOR USE**
         */
        // TODO: What about components that aren't nullable? Example: tables, text, we
        // should use minSize/minLength instead. Allow each component to implement its
        // own "isRequired" functionality?
        _this._hideWhenNotRequired = false;
        /**
         * Event emitter which emits an event whenever the component's DOM input is
         * focused.
         */
        _this.focus = new EventEmitter();
        /**
         * Event emitter which emits an event whenever the component's DOM input is
         * blurred.
         */
        _this.blur = new EventEmitter();
        /**
         * Add an `lf-inline-value` class to components.
         */
        _this._classLfInlineValue = true;
        return _this;
    }
    Object.defineProperty(InlineValue.prototype, "shouldDisplay", {
        /**
         * Whether this component should be displayed.
         */
        get: function () {
            return (this.relativeStorage.has() &&
                (!this._hideWhenNotRequired ||
                    this.relativeStorage.getStateProperty('.', 'isRequired')));
        },
        enumerable: true,
        configurable: true
    });
    InlineValue.prototype.ngOnInit = function () {
        _super.prototype.ngOnInit.call(this);
    };
    InlineValue.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.lfRouter !== null) {
            // Auto-focus the field when this component's path is activated
            this.disposeOnActive = autorun(function () {
                if (_this.lfRouter.isActiveWithFragment(_this.path)) {
                    var res = _this.onActivate &&
                        _this.onActivate(_this.lfRouter.pathWithFragment);
                    // Trigger the `focus` only when path matches exactly
                    if (res !== false &&
                        _this.lfRouter.isActiveWithFragment(_this.path, true)) {
                        asap(function () { return _this.triggerFocus(); });
                    }
                }
            }, { name: 'fieldAutorunFocusOnActive' });
        }
    };
    InlineValue.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
        this.disposeOnActive && this.disposeOnActive();
    };
    /**
     * Scrolls this component into the center of the viewport and focuses it.
     */
    InlineValue.prototype.triggerFocus = function () {
        if (this.targets && this.targets.length > 0) {
            var target = this.targets.first.nativeElement;
            target.scrollIntoView({ block: 'center' });
            target.focus();
        }
    };
    /**
     * Action to run whenever a focusable part of the field is focused.
     * @param evt `focus` event.
     */
    InlineValue.prototype._onFocus = function (evt) {
        this.focus.emit(evt);
    };
    /**
     * Action to run whenever a focusable part of the field is blurred.
     * @param evt `blur` event.
     * @param setTouched Whether to try and set the value as "touched". Defaults
     * to `true`.
     */
    InlineValue.prototype._onBlur = function (evt, setTouched) {
        if (setTouched === void 0) { setTouched = true; }
        var _a;
        if (setTouched && !this.relativeStorage.isComputed()) {
            this.relativeStorage.setTouched();
        }
        // Remove the fragment when the path exactly matches the URL
        if ((_a = this.lfRouter) === null || _a === void 0 ? void 0 : _a.isActiveWithFragment(this.path, true)) {
            this.lfRouter.navigate('.', { queryParamsHandling: 'merge' });
        }
        this.blur.emit(evt);
    };
    InlineValue.ctorParameters = function () { return [
        { type: PathBased },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter }
    ]; };
    __decorate([
        observable,
        Input()
    ], InlineValue.prototype, "_hideWhenNotRequired", void 0);
    __decorate([
        Output()
    ], InlineValue.prototype, "focus", void 0);
    __decorate([
        Output()
    ], InlineValue.prototype, "blur", void 0);
    __decorate([
        HostBinding('class.lf-inline-value')
    ], InlineValue.prototype, "_classLfInlineValue", void 0);
    __decorate([
        ViewChildren('focusTarget')
    ], InlineValue.prototype, "targets", void 0);
    __decorate([
        computed
    ], InlineValue.prototype, "shouldDisplay", null);
    InlineValue = __decorate([
        Directive()
        // tslint:disable-next-line: directive-class-suffix
    ], InlineValue);
    return InlineValue;
}(Value));

/**
 * Class which represents a component whose value may be restricted by a set of
 * options.
 */
var SelectionValue = /** @class */ (function (_super) {
    __extends(SelectionValue, _super);
    function SelectionValue(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    Object.defineProperty(SelectionValue.prototype, "options", {
        /**
         * Selectable options (possibly fetched asynchronously).
         */
        // Not `computed` due to `useState` (cannot be used within a `computed`)
        get: function () {
            return this.translate(I18N_SELECTION_OPTIONS_KEY, { useState: true }) || [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SelectionValue.prototype, "noOptionsText", {
        /**
         * Text to be shown when there are no options available.
         */
        get: function () {
            return this.translate(I18N_SELECTION_NO_OPTIONS_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SelectionValue.prototype, "optionsStatus", {
        /**
         * Promise-status of the options.
         */
        get: function () {
            return this.translationStatus(I18N_SELECTION_OPTIONS_KEY);
        },
        enumerable: true,
        configurable: true
    });
    SelectionValue.ctorParameters = function () { return [
        { type: PathBased },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter }
    ]; };
    __decorate([
        computed
    ], SelectionValue.prototype, "noOptionsText", null);
    __decorate([
        computed
    ], SelectionValue.prototype, "optionsStatus", null);
    SelectionValue = __decorate([
        Directive()
        // tslint:disable-next-line: directive-class-suffix
    ], SelectionValue);
    return SelectionValue;
}(InlineValue));

/**
 * Component used for selecting a list of options by using inputs of type
 * `checkbox`.
 */
var CheckboxGroupComponent = /** @class */ (function (_super) {
    __extends(CheckboxGroupComponent, _super);
    function CheckboxGroupComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
        /**
         * Whether the list of checkbox inputs should be displayed inline. The
         * component will still display in "block" mode in small screens.
         */
        _this.displayInline = false;
        return _this;
    }
    Object.defineProperty(CheckboxGroupComponent.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            var minSize = this.relativeStorage.getStateProperty('.', 'minSize');
            return minSize !== undefined && minSize > 0;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Whether a given option is selected.
     * @param option Option to check if it is selected.
     */
    CheckboxGroupComponent.prototype.isSelected = function (option) {
        return this.relativeStorage
            .get()
            .some(function (el) { return comparer.structural(el, option.value); });
    };
    /**
     * Action to run whenever a checkbox `input` changes.
     * @param option Option that changed.
     */
    CheckboxGroupComponent.prototype._onOptionChange = function (option, evt) {
        var checked = !!evt.target.checked;
        var isSelected = this.isSelected(option);
        if (isSelected && !checked) {
            this.relativeStorage.filter('.', function (el) { return !comparer.structural(el, option.value); });
        }
        else if (!isSelected && checked) {
            this.relativeStorage.push('.', option.value);
        }
        this.relativeStorage.setDirty();
    };
    CheckboxGroupComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isListSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "list" type and not "nullable"');
        }
    };
    CheckboxGroupComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        observable,
        Input()
    ], CheckboxGroupComponent.prototype, "displayInline", void 0);
    __decorate([
        computed
    ], CheckboxGroupComponent.prototype, "showIsRequired", null);
    __decorate([
        action
    ], CheckboxGroupComponent.prototype, "_onOptionChange", null);
    CheckboxGroupComponent = __decorate([
        Component({
            selector: 'lf-checkbox-group',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"lf-checkable-group input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Checkboxes -->\n      <div\n        class=\"lf-checkables form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [class.display-inline]=\"displayInline\"\n      >\n        <!-- Text for when there are no options -->\n        <div\n          *ngIf=\"optionsStatus !== 'pending' && options.length === 0\"\n          class=\"no-options\"\n        >\n          {{ noOptionsText }}\n        </div>\n\n        <!-- Pending options -->\n        <div *ngIf=\"optionsStatus === 'pending'\" class=\"pending-options\"></div>\n\n        <div\n          class=\"lf-checkable input-group input-group-sm\"\n          *ngFor=\"let option of options; let i = index\"\n        >\n          <!-- Code of each checkbox -->\n          <div *ngIf=\"option.code\" class=\"input-group-prepend\">\n            <div class=\"input-group-text\">{{ option.code }}</div>\n          </div>\n\n          <!-- Checkbox -->\n          <label\n            class=\"form-control custom-control custom-checkbox\"\n            [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n            [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n            [class.is-readonly]=\"isReadOnly\"\n          >\n            <!-- Actual checkbox -->\n            <!--\n              Note that checkboxes don't support `readonly`, so we use\n              the `disabled` attribute\n            -->\n            <input\n              #focusTarget\n              type=\"checkbox\"\n              class=\"custom-control-input\"\n              [name]=\"path + '[' + i + ']'\"\n              [value]=\"i\"\n              [checked]=\"isSelected(option)\"\n              [disabled]=\"isReadOnly\"\n              (change)=\"_onOptionChange(option, $event)\"\n              (focus)=\"_onFocus($event)\"\n              (blur)=\"_onBlur($event)\"\n            />\n\n            <!-- Checkbox label -->\n            <span class=\"custom-control-label\">\n              {{ option.label }}\n              <lf-help-tooltip\n                *ngIf=\"option.helpMessage\"\n                [help]=\"option.helpMessage\"\n              ></lf-help-tooltip>\n            </span>\n          </label>\n        </div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], CheckboxGroupComponent);
    return CheckboxGroupComponent;
}(SelectionValue));

/**
 * LF checkbox component.
 */
var CheckboxComponent = /** @class */ (function (_super) {
    __extends(CheckboxComponent, _super);
    function CheckboxComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    Object.defineProperty(CheckboxComponent.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            if (!this.relativeStorage.isNullable()) {
                var allowedValues = this.relativeStorage.getStateProperty('.', 'allowedValues');
                return (allowedValues && allowedValues.length === 1 && allowedValues[0] === true);
            }
            var isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
            return !!isRequired;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Action to run whenever the value of the checkbox changes.
     * @param evt `change` event.
     */
    CheckboxComponent.prototype._onCheckboxChange = function (evt) {
        this.relativeStorage.set('.', !!evt.target.checked);
        this.relativeStorage.setDirty();
    };
    CheckboxComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isBooleanSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "boolean" type');
        }
    };
    CheckboxComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        computed
    ], CheckboxComponent.prototype, "showIsRequired", null);
    __decorate([
        action
    ], CheckboxComponent.prototype, "_onCheckboxChange", null);
    CheckboxComponent = __decorate([
        Component({
            selector: 'lf-checkbox',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"lf-checkable input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Checkbox -->\n      <label\n        class=\"form-control custom-control custom-checkbox\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n      >\n        <!-- Actual checkbox -->\n        <!--\n          Note that checkboxes don't support `readonly`, so we use the\n          `disabled` attribute\n        -->\n        <input\n          #focusTarget\n          type=\"checkbox\"\n          class=\"custom-control-input\"\n          [name]=\"path\"\n          [checked]=\"relativeStorage.get()\"\n          [indeterminate]=\"relativeStorage.get() === null\"\n          (change)=\"_onCheckboxChange($event)\"\n          [disabled]=\"isReadOnly\"\n          (focus)=\"_onFocus($event)\"\n          (blur)=\"_onBlur($event)\"\n        />\n\n        <!-- Label -->\n        <span class=\"custom-control-label\">\n          <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n          <lf-help-tooltip\n            *ngIf=\"helpMessage\"\n            [help]=\"helpMessage\"\n          ></lf-help-tooltip>\n        </span>\n      </label>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], CheckboxComponent);
    return CheckboxComponent;
}(InlineValue));

/**
 * Automatically change `ngx-bootstrap` locale based on current language.
 */
var BsLocaleChanger = /** @class */ (function () {
    function BsLocaleChanger(bsLocaleService, lfI18n) {
        var _this = this;
        this.bsLocaleService = bsLocaleService;
        this.lfI18n = lfI18n;
        observe(this.lfI18n, 'currentLanguage', function () {
            _this.bsLocaleService.use(_this.lfI18n.get(I18N_BS_LOCALE_KEY) || 'en');
        }, true);
    }
    BsLocaleChanger.ctorParameters = function () { return [
        { type: BsLocaleService },
        { type: LfI18n }
    ]; };
    BsLocaleChanger.ɵprov = ɵɵdefineInjectable({ factory: function BsLocaleChanger_Factory() { return new BsLocaleChanger(ɵɵinject(BsLocaleService), ɵɵinject(LfI18n)); }, token: BsLocaleChanger, providedIn: "root" });
    BsLocaleChanger = __decorate([
        Injectable({ providedIn: 'root' })
    ], BsLocaleChanger);
    return BsLocaleChanger;
}());

/**
 * Creates a new date-range schema object.
 * @param options Options used to create the schema.
 * @returns Date-range schema.
 */
function dateRangeSchema(options) {
    if (options === void 0) { options = {}; }
    var initialState = options.initialState || {};
    var startDateOptions = options.startDateOptions || {};
    var endDateOptions = options.endDateOptions || {};
    // When the date-range isn't computed, we apply `minDate` and `maxDate` to the
    // inner tuple elements for automatic validation
    if (options.computedValue === undefined) {
        if (options.minDate) {
            initialState.minDate =
                typeof options.minDate === 'function'
                    ? function (ctx) {
                        return options.minDate(ctx.relativeStorage('..'));
                    }
                    : options.minDate;
        }
        if (options.maxDate) {
            initialState.maxDate =
                typeof options.maxDate === 'function'
                    ? function (ctx) {
                        return options.maxDate(ctx.relativeStorage('..'));
                    }
                    : options.maxDate;
        }
        var minDate = typeof options.minDate === 'function'
            ? function (ctx) { return ctx.getStateProperty('.', 'minDate'); }
            : options.minDate;
        var maxDate = typeof options.maxDate === 'function'
            ? function (ctx) { return ctx.getStateProperty('.', 'maxDate'); }
            : options.maxDate;
        startDateOptions.minDate = minDate;
        // Disallow an end date that comes before the start date
        endDateOptions.minDate = function (ctx) { return ctx.get('0'); };
        endDateOptions.maxDate = maxDate;
    }
    return tupleSchema([dateSchema(startDateOptions), dateSchema(endDateOptions)], __assign(__assign({}, options), { initialState: initialState }));
}
/**
 * Returns whether a given schema is a date-range schema.
 * @param schema Schema to check.
 * @returns `true` when the provided schema is a date-range schema.
 */
function isDateRangeSchema(schema) {
    return (isTupleSchema(schema) &&
        schema.elementsSchemas.length === 2 &&
        isDateSchema(schema.elementsSchemas[0]) &&
        isDateSchema(schema.elementsSchemas[1]));
}

/**
 * Converts a date representing a certain day in local time to a date that
 * represents that same day in UTC. Used to fix:
 * https://github.com/valor-software/ngx-bootstrap/issues/3609
 * @param date Date to convert.
 * @returns Date in UTC.
 */
function localDateToUTC(date) {
    return new Date(Date.UTC(date.getFullYear(), date.getMonth(), date.getDate()));
}

/**
 * LF date-range component.
 */
var DateRangeComponent = /** @class */ (function (_super) {
    __extends(DateRangeComponent, _super);
    function DateRangeComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, _bsLocaleChanger) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    Object.defineProperty(DateRangeComponent.prototype, "dateFormat", {
        /**
         * Format for a single date.
         */
        get: function () {
            return this.translate(I18N_DATE_FORMAT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateRangeComponent.prototype, "separator", {
        /**
         * Separator used between the dates in the date-range.
         */
        get: function () {
            return this.translate(I18N_DATE_RANGE_SEPARATOR_KEY) || '-';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateRangeComponent.prototype, "placeholder", {
        /**
         * Placeholder of the `input` field.
         */
        get: function () {
            var datePlaceholder = this.translate(I18N_DATE_PLACEHOLDER_KEY);
            return datePlaceholder
                ? "" + datePlaceholder + this.separator + datePlaceholder
                : '';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateRangeComponent.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            var isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
            return !!isRequired;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateRangeComponent.prototype, "bsConfig", {
        /**
         * Configuration to use by Bootstrap datepicker.
         */
        get: function () {
            return {
                containerClass: 'theme-default',
                rangeInputFormat: this.dateFormat,
                rangeSeparator: this.separator
            };
        },
        enumerable: true,
        configurable: true
    });
    DateRangeComponent.prototype.ngOnInit = function () {
        var _this = this;
        _super.prototype.ngOnInit.call(this);
        this.disposeBsConfigObserve = observe(this, 'bsConfig', function () {
            asap(function () {
                _this._bsDateRangePicker.setConfig();
                _this._bsDateRangePicker.bsValueChange.emit(_this.relativeStorage.has() ? _this.relativeStorage.get() : null);
            });
        }, true);
    };
    DateRangeComponent.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
        this.disposeBsConfigObserve && this.disposeBsConfigObserve();
    };
    /**
     * Action to run whenever the date range is modified via the Bootstrap
     * datepicker UI.
     * @param dateRange Tuple representing the range.
     */
    DateRangeComponent.prototype._onDateRangePickerChange = function (dateRange) {
        if (dateRange) {
            // XXX: When the `rangeInputFormat` is not the default one, manually
            // setting the input causes `dateRange` to contain `[null, null]`; this
            // should probably be fixed from ngx-bootstrap's side
            if (!dateRange[0] || !dateRange[1]) {
                dateRange = null;
            }
            else {
                // XXX: We convert the dates to UTC due to:
                // https://github.com/valor-software/ngx-bootstrap/issues/3609
                dateRange[0] = localDateToUTC(dateRange[0]);
                dateRange[1] = localDateToUTC(dateRange[1]);
            }
        }
        // FIXME: This function is being called as soon as the component loads, thus
        // the comparison against the current date range (which shouldn't be
        // needed).
        var currentDateRange = this.relativeStorage.get();
        if (!comparer.structural(currentDateRange, dateRange)) {
            this.relativeStorage.set('.', dateRange);
            this.relativeStorage.setDirty('.', true);
        }
    };
    DateRangeComponent.prototype._onFocus = function (evt) {
        _super.prototype._onFocus.call(this, evt);
        this._bsDateRangePicker.show();
    };
    /**
     * Set touched when the date picker is hidden rather than on blur (it is
     * possible to change the value via the popup without actually focusing the
     * input; besides, otherwise the input may go invalid when the user selects
     * the first date of the range, but before the second).
     */
    DateRangeComponent.prototype._onDateRangePickerHidden = function () {
        if (!this.relativeStorage.isComputed()) {
            this.relativeStorage.setTouched('.', true);
        }
    };
    DateRangeComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isDateRangeSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "date-range" type and "nullable"');
        }
    };
    DateRangeComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
        { type: BsLocaleChanger }
    ]; };
    __decorate([
        ViewChild('drp')
    ], DateRangeComponent.prototype, "_bsDateRangePicker", void 0);
    __decorate([
        computed
    ], DateRangeComponent.prototype, "dateFormat", null);
    __decorate([
        computed
    ], DateRangeComponent.prototype, "separator", null);
    __decorate([
        computed
    ], DateRangeComponent.prototype, "placeholder", null);
    __decorate([
        computed
    ], DateRangeComponent.prototype, "showIsRequired", null);
    __decorate([
        computed
    ], DateRangeComponent.prototype, "bsConfig", null);
    __decorate([
        action
    ], DateRangeComponent.prototype, "_onDateRangePickerChange", null);
    __decorate([
        action
    ], DateRangeComponent.prototype, "_onDateRangePickerHidden", null);
    DateRangeComponent = __decorate([
        Component({
            selector: 'lf-date-range',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <!--\n        We disable the directive's `triggers` since it doesn't work well on\n        focus (using \"focus\" as a trigger will cause the menu to disappear if it\n        was already shown since the trigger calls `toggle`). Instead we manually\n        call `show` on focus.\n      -->\n      <input\n        #focusTarget\n        bsDaterangepicker\n        #drp=\"bsDaterangepicker\"\n        triggers=\"\"\n        [bsConfig]=\"bsConfig\"\n        [bsValue]=\"relativeStorage.get()\"\n        [isDisabled]=\"isReadOnly\"\n        (bsValueChange)=\"_onDateRangePickerChange($event)\"\n        (onHidden)=\"_onDateRangePickerHidden()\"\n        type=\"text\"\n        class=\"form-control date-input text-right\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [minDate]=\"relativeStorage.getStateProperty('.', 'minDate')\"\n        [maxDate]=\"relativeStorage.getStateProperty('.', 'maxDate')\"\n        [placeholder]=\"placeholder\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event, false)\"\n      />\n\n      <!-- Date icon -->\n      <div class=\"input-group-append\" (click)=\"drp.toggle()\">\n        <div class=\"input-group-text\"><lf-icon icon=\"calendar\"></lf-icon></div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], DateRangeComponent);
    return DateRangeComponent;
}(InlineValue));

/**
 * LF date component.
 */
var DateComponent = /** @class */ (function (_super) {
    __extends(DateComponent, _super);
    function DateComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, _bsLocaleChanger) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    Object.defineProperty(DateComponent.prototype, "dateFormat", {
        /**
         * Format of the date.
         */
        get: function () {
            return this.translate(I18N_DATE_FORMAT_KEY) || 'YYYY-MM-DD';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateComponent.prototype, "placeholder", {
        /**
         * Placeholder of the `input` field.
         */
        get: function () {
            return this.translate(I18N_DATE_PLACEHOLDER_KEY) || '';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateComponent.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            var isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
            return !!isRequired;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateComponent.prototype, "bsConfig", {
        /**
         * Config for the `BsDatepicker`.
         */
        get: function () {
            return {
                containerClass: 'theme-default',
                dateInputFormat: this.dateFormat
            };
        },
        enumerable: true,
        configurable: true
    });
    DateComponent.prototype.ngOnInit = function () {
        var _this = this;
        _super.prototype.ngOnInit.call(this);
        this.disposeBsConfigObserve = observe(this, 'bsConfig', function () {
            asap(function () {
                _this._bsDatePicker.setConfig();
                _this._bsDatePicker.bsValueChange.emit(_this.relativeStorage.has() ? _this.relativeStorage.get() : null);
            });
        }, true);
    };
    DateComponent.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
        this.disposeBsConfigObserve && this.disposeBsConfigObserve();
    };
    /**
     * Action to run whenever the date `input` changes.
     * @param date Date to set.
     */
    DateComponent.prototype._onDatePickerChange = function (date) {
        // XXX: We convert the date to UTC due to:
        // https://github.com/valor-software/ngx-bootstrap/issues/3609
        date = !date || isNaN(+date) ? null : localDateToUTC(date);
        // FIXME: This function is being called as soon as the component loads, thus
        // the comparison against the current date (which shouldn't be needed).
        var currentDate = this.relativeStorage.get();
        if (!comparer.structural(currentDate, date)) {
            this.relativeStorage.set('.', date);
            this.relativeStorage.setDirty();
        }
    };
    DateComponent.prototype._onFocus = function (evt) {
        _super.prototype._onFocus.call(this, evt);
        this._bsDatePicker.show();
    };
    /**
     * Set touched when the date picker is hidden rather than on blur (it is
     * possible to change the value via the popup without actually focusing the
     * input).
     */
    DateComponent.prototype._onDatePickerHidden = function () {
        if (!this.relativeStorage.isComputed()) {
            this.relativeStorage.setTouched();
        }
    };
    DateComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isDateSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "date" type and "nullable"');
        }
    };
    DateComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
        { type: BsLocaleChanger }
    ]; };
    __decorate([
        ViewChild('dp')
    ], DateComponent.prototype, "_bsDatePicker", void 0);
    __decorate([
        computed
    ], DateComponent.prototype, "dateFormat", null);
    __decorate([
        computed
    ], DateComponent.prototype, "placeholder", null);
    __decorate([
        computed
    ], DateComponent.prototype, "showIsRequired", null);
    __decorate([
        computed
    ], DateComponent.prototype, "bsConfig", null);
    __decorate([
        action
    ], DateComponent.prototype, "_onDatePickerChange", null);
    __decorate([
        action
    ], DateComponent.prototype, "_onDatePickerHidden", null);
    DateComponent = __decorate([
        Component({
            selector: 'lf-date',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <!--\n        We disable the directive's `triggers` since it doesn't work well on\n        focus (using \"focus\" as a trigger will cause the menu to disappear if it\n        was already shown since the trigger calls `toggle`). Instead we manually\n        call `show` on focus.\n      -->\n      <input\n        #focusTarget\n        bsDatepicker\n        #dp=\"bsDatepicker\"\n        triggers=\"\"\n        [bsConfig]=\"bsConfig\"\n        [bsValue]=\"relativeStorage.get()\"\n        [isDisabled]=\"isReadOnly\"\n        (bsValueChange)=\"_onDatePickerChange($event)\"\n        (onHidden)=\"_onDatePickerHidden()\"\n        type=\"text\"\n        class=\"form-control date-input text-right\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [minDate]=\"relativeStorage.getStateProperty('.', 'minDate')\"\n        [maxDate]=\"relativeStorage.getStateProperty('.', 'maxDate')\"\n        [placeholder]=\"placeholder\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event, false)\"\n      />\n\n      <!-- Date icon -->\n      <div class=\"input-group-append\" (click)=\"dp.toggle()\">\n        <div class=\"input-group-text\"><lf-icon icon=\"calendar\"></lf-icon></div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], DateComponent);
    return DateComponent;
}(InlineValue));

var DropdownItemComponent = /** @class */ (function () {
    function DropdownItemComponent(_host) {
        this.itemType = 'item';
        this.isActive = false;
        this.isDisabled = false;
        this._tagName = _host.nativeElement.tagName.toLowerCase();
    }
    Object.defineProperty(DropdownItemComponent.prototype, "_hostClassDropdownItem", {
        // Classes for each type of dropdown item
        get: function () {
            return this.itemType === 'item';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownItemComponent.prototype, "_hostClassDropdownDivider", {
        get: function () {
            return this.itemType === 'divider';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownItemComponent.prototype, "_hostClassDropdownItemText", {
        get: function () {
            return this.itemType === 'text';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownItemComponent.prototype, "_hostClassDropdownHeader", {
        get: function () {
            return this.itemType === 'header';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownItemComponent.prototype, "_hostClassDisabled", {
        // Set disable (attribute for buttons, class for others)
        get: function () {
            return (this.itemType === 'item' && this._tagName !== 'button' && this.isDisabled);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownItemComponent.prototype, "_hostDisabled", {
        get: function () {
            return this.itemType === 'item' &&
                this._tagName === 'button' &&
                this.isDisabled
                ? ''
                : undefined;
        },
        enumerable: true,
        configurable: true
    });
    DropdownItemComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        observable,
        Input()
    ], DropdownItemComponent.prototype, "itemType", void 0);
    __decorate([
        observable,
        Input(),
        HostBinding('class.active')
    ], DropdownItemComponent.prototype, "isActive", void 0);
    __decorate([
        observable,
        Input()
    ], DropdownItemComponent.prototype, "isDisabled", void 0);
    __decorate([
        computed,
        HostBinding('class.dropdown-item')
    ], DropdownItemComponent.prototype, "_hostClassDropdownItem", null);
    __decorate([
        computed,
        HostBinding('class.dropdown-divider')
    ], DropdownItemComponent.prototype, "_hostClassDropdownDivider", null);
    __decorate([
        computed,
        HostBinding('class.dropdown-item-text')
    ], DropdownItemComponent.prototype, "_hostClassDropdownItemText", null);
    __decorate([
        computed,
        HostBinding('class.dropdown-header')
    ], DropdownItemComponent.prototype, "_hostClassDropdownHeader", null);
    __decorate([
        computed,
        HostBinding('class.disabled')
    ], DropdownItemComponent.prototype, "_hostClassDisabled", null);
    __decorate([
        computed,
        HostBinding('attr.disabled')
    ], DropdownItemComponent.prototype, "_hostDisabled", null);
    DropdownItemComponent = __decorate([
        Component({
            selector: 'lf-dropdown-item, [lf-dropdown-item]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
        })
    ], DropdownItemComponent);
    return DropdownItemComponent;
}());

var DropdownMenuComponent = /** @class */ (function () {
    function DropdownMenuComponent() {
        this.alignRight = false;
        this._hostClassDropdownMenu = true;
    }
    __decorate([
        observable,
        Input(),
        HostBinding('class.dropdown-menu-right')
    ], DropdownMenuComponent.prototype, "alignRight", void 0);
    __decorate([
        HostBinding('class.dropdown-menu')
    ], DropdownMenuComponent.prototype, "_hostClassDropdownMenu", void 0);
    DropdownMenuComponent = __decorate([
        Component({
            selector: 'lf-dropdown-menu, [lf-dropdown-menu]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
        })
    ], DropdownMenuComponent);
    return DropdownMenuComponent;
}());

/**
 * LF dropdown component.
 */
var DropdownComponent = /** @class */ (function (_super) {
    __extends(DropdownComponent, _super);
    function DropdownComponent(parentPathBasedComponent, lfStorage, lfI18n, host) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.host = host;
        _this.position = 'down';
        _this.offset = 0;
        _this.flip = true;
        _this.boundary = 'scrollParent';
        _this.reference = 'toggle';
        _this.display = 'dynamic';
        _this.shown = new EventEmitter();
        _this.hidden = new EventEmitter();
        _this._hostClassBtnGroup = true;
        return _this;
    }
    DropdownComponent_1 = DropdownComponent;
    Object.defineProperty(DropdownComponent.prototype, "_hostClassDropleft", {
        get: function () {
            return this.position === 'left';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownComponent.prototype, "_hostClassDropright", {
        get: function () {
            return this.position === 'right';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DropdownComponent.prototype, "_hostClassDropup", {
        get: function () {
            return this.position === 'up';
        },
        enumerable: true,
        configurable: true
    });
    DropdownComponent.prototype.ngAfterViewInit = function () {
        this.createDropdown();
    };
    DropdownComponent.prototype.ngOnDestroy = function () {
        this.destroyDropdown();
        _super.prototype.ngOnDestroy.call(this);
    };
    /**
     * Creates a new dropdown and starts listening to events.
     */
    DropdownComponent.prototype.createDropdown = function () {
        var _this = this;
        var target = this._toggle
            ? this._toggle.nativeElement
            : this.host.nativeElement.children[0];
        this.$toggle = $(target)
            .attr('data-toggle', 'dropdown')
            .attr('aria-haspopup', 'true')
            .attr('aria-expanded', 'false')
            .dropdown({
            offset: this.offset,
            flip: this.flip,
            boundary: this.boundary instanceof ElementRef
                ? this.boundary.nativeElement
                : this.boundary,
            reference: this.reference instanceof ElementRef
                ? this.reference.nativeElement
                : this.reference,
            display: this.display
        });
        this.$host = $(this.host.nativeElement);
        // Make UI match state at startup
        if (this.isVisible) {
            this.$toggle.dropdown('toggle');
        }
        // There seems to be no way of updating these settings, so the most we can
        // do is destroy and reconstruct the modal whenever they change. TODO:
        // Figure out a better approach for this
        this.disposeOnOptionsChange = reaction(function () { return [
            _this.offset,
            _this.flip,
            _this.boundary,
            _this.reference,
            _this.display
        ]; }, function () {
            _this.destroyDropdown();
            _this.createDropdown();
        }, { name: 'dropdownReactionOnOptionsChange' });
        // Set the component's state if the dropdown is shown without calling
        // `show()`
        this.$host.on('show.bs.dropdown', function () {
            _this.isAnimating = true;
            if (!_this.isVisible) {
                _this.show();
            }
        });
        // Set the component's state if the dropdown is hidden without calling
        // `hide()`
        this.$host.on('hide.bs.dropdown', function () {
            _this.isAnimating = true;
            if (_this.isVisible) {
                _this.hide();
            }
        });
        // Runs when the showing animation ends
        this.$host.on('shown.bs.dropdown', function () {
            _this.isAnimating = false;
            _this.shown.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (!_this.isVisible) {
                _this.hide();
            }
        });
        // Runs when the hiding animation ends
        this.$host.on('hidden.bs.dropdown', function () {
            _this.isAnimating = false;
            _this.hidden.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (_this.isVisible) {
                _this.show();
            }
        });
        // Open the dropdown when `show` is called
        this.showSubscription = this._show.subscribe(function () {
            if (!_this.isAnimating && !_this.$host.hasClass('show')) {
                _this.$toggle.dropdown('toggle');
            }
        });
        // Close the dropdown when `hide` is called
        this.hideSubscription = this._hide.subscribe(function () {
            if (!_this.isAnimating && _this.$host.hasClass('show')) {
                _this.$toggle.dropdown('toggle');
            }
        });
    };
    /**
     * Unsubscribes from all events and destroys the dropdown.
     */
    DropdownComponent.prototype.destroyDropdown = function () {
        this.disposeOnOptionsChange && this.disposeOnOptionsChange();
        if (this.$host) {
            this.$host.off('show.bs.dropdown');
            this.$host.off('hide.bs.dropdown');
            this.$host.off('shown.bs.dropdown');
            this.$host.off('hidden.bs.dropdown');
        }
        this.showSubscription && this.showSubscription.unsubscribe();
        this.hideSubscription && this.hideSubscription.unsubscribe();
        this.$toggle &&
            this.$toggle
                .removeAttr('data-toggle')
                .removeAttr('aria-haspopup')
                .removeAttr('aria-expanded')
                .dropdown('dispose');
    };
    var DropdownComponent_1;
    DropdownComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: ElementRef }
    ]; };
    __decorate([
        observable,
        Input()
    ], DropdownComponent.prototype, "position", void 0);
    __decorate([
        observable,
        Input()
    ], DropdownComponent.prototype, "offset", void 0);
    __decorate([
        observable,
        Input()
    ], DropdownComponent.prototype, "flip", void 0);
    __decorate([
        observable,
        Input()
    ], DropdownComponent.prototype, "boundary", void 0);
    __decorate([
        observable,
        Input()
    ], DropdownComponent.prototype, "reference", void 0);
    __decorate([
        observable,
        Input()
    ], DropdownComponent.prototype, "display", void 0);
    __decorate([
        Output()
    ], DropdownComponent.prototype, "shown", void 0);
    __decorate([
        Output()
    ], DropdownComponent.prototype, "hidden", void 0);
    __decorate([
        HostBinding('class.btn-group')
    ], DropdownComponent.prototype, "_hostClassBtnGroup", void 0);
    __decorate([
        ContentChild('dropdownToggle', { read: ElementRef })
    ], DropdownComponent.prototype, "_toggle", void 0);
    __decorate([
        computed,
        HostBinding('class.dropleft')
    ], DropdownComponent.prototype, "_hostClassDropleft", null);
    __decorate([
        computed,
        HostBinding('class.dropright')
    ], DropdownComponent.prototype, "_hostClassDropright", null);
    __decorate([
        computed,
        HostBinding('class.dropup')
    ], DropdownComponent.prototype, "_hostClassDropup", null);
    DropdownComponent = DropdownComponent_1 = __decorate([
        Component({
            selector: 'lf-dropdown, [lf-dropdown]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: DropdownComponent_1 }],
            template: '<ng-container *mobxAutorun><ng-content></ng-content></ng-container>'
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], DropdownComponent);
    return DropdownComponent;
}(Toggleable));

/**
 * Component used for selecting files.
 */
var FileComponent = /** @class */ (function (_super) {
    __extends(FileComponent, _super);
    function FileComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, lfFileHolder) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
        _this.lfFileHolder = lfFileHolder;
        /**
         * One or more unique file type specifiers describing file types to allow.
         */
        _this.accept = '';
        // Unique id per component, used for the label to target the file input
        _this._id = "lf-file-input-" + FileComponent_1.idCounter++;
        _this._selectedFile = null;
        return _this;
    }
    FileComponent_1 = FileComponent;
    Object.defineProperty(FileComponent.prototype, "choosePlaceholder", {
        /**
         * "Choose file" placeholder text.
         */
        get: function () {
            return this.translate(I18N_FILE_CHOOSE_PLACEHOLDER_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FileComponent.prototype, "browseText", {
        /**
         * "Browse" text.
         */
        get: function () {
            return this.translate(I18N_FILE_BROWSE_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FileComponent.prototype, "noneChosenText", {
        /**
         * "No file chosen" text.
         */
        get: function () {
            return this.translate(I18N_FILE_NONE_CHOSEN_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FileComponent.prototype, "clearButtonTooltip", {
        /**
         * "Clear" button tooltip.
         */
        get: function () {
            return this.translate(I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FileComponent.prototype, "value", {
        get: function () {
            return this.relativeStorage.has() ? this.relativeStorage.get() : undefined;
        },
        enumerable: true,
        configurable: true
    });
    FileComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        _super.prototype.ngAfterViewInit.call(this);
        // Update the selected file when the value changes. If the file is in the
        // file holder then we switch to it, otherwise we set the file as `null`,
        // since it doesn't exist
        this.disposeObserveValue = observe(this, 'value', function (_a) {
            var newValue = _a.newValue;
            var file = _this.lfFileHolder.get(_this.relativeStorage.currentPath);
            if (file && newValue === file.name) {
                _this._selectedFile = file;
            }
            else {
                _this.setFile(null);
            }
        }, true);
        // Remove selected file when a file was selected but the `minSize`/`maxSize`
        // changed and made the selected file invalid
        this.disposeOnMinMaxSizeChange = reaction(function () { return [_this.value, _this.minSize, _this.maxSize]; }, function () {
            var file = _this.lfFileHolder.get(_this.relativeStorage.currentPath);
            if (file && !_this.hasValidSize(file)) {
                _this.setFile(null);
            }
        }, { name: 'fileReactionOnMinMaxSizeChange' });
    };
    FileComponent.prototype.ngOnDestroy = function () {
        this.disposeObserveValue && this.disposeObserveValue();
        this.disposeOnMinMaxSizeChange && this.disposeOnMinMaxSizeChange();
        _super.prototype.ngOnDestroy.call(this);
    };
    /**
     * Action to run on every `input` event of the file input.
     * @param evt `input` event.
     */
    FileComponent.prototype._onInput = function (evt) {
        this.setFile(evt.target.files[0] || null);
        this.relativeStorage.setDirty();
    };
    FileComponent.prototype._onClickClear = function (evt) {
        evt.preventDefault();
        this.setFile(null);
    };
    FileComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isStringSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "string" type and "nullable"');
        }
    };
    FileComponent.prototype.setFile = function (file) {
        var _a;
        var fileInput = this.targets.first.nativeElement;
        // Disallow files with wrong sizes
        if (!this.hasValidSize(file)) {
            // Access file input via `#focusTarget`
            fileInput.value = '';
            file = null;
        }
        this._selectedFile = file;
        // Set file in file holder service
        if (file != null) {
            this.lfFileHolder.set(this.relativeStorage.currentPath, file);
        }
        else {
            this.lfFileHolder.delete(this.relativeStorage.currentPath);
            fileInput.value = '';
        }
        this.relativeStorage.set('.', ((_a = file) === null || _a === void 0 ? void 0 : _a.name) || null);
    };
    FileComponent.prototype.hasValidSize = function (file) {
        var _a, _b;
        return (!file ||
            (file.size >= (_a = this.minSize, (_a !== null && _a !== void 0 ? _a : 0)) &&
                file.size <= (_b = this.maxSize, (_b !== null && _b !== void 0 ? _b : Infinity))));
    };
    var FileComponent_1;
    FileComponent.idCounter = 0;
    FileComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
        { type: LfFileHolder }
    ]; };
    __decorate([
        observable,
        Input()
    ], FileComponent.prototype, "accept", void 0);
    __decorate([
        observable,
        Input()
    ], FileComponent.prototype, "minSize", void 0);
    __decorate([
        observable,
        Input()
    ], FileComponent.prototype, "maxSize", void 0);
    __decorate([
        observable
    ], FileComponent.prototype, "_selectedFile", void 0);
    __decorate([
        computed
    ], FileComponent.prototype, "choosePlaceholder", null);
    __decorate([
        computed
    ], FileComponent.prototype, "browseText", null);
    __decorate([
        computed
    ], FileComponent.prototype, "noneChosenText", null);
    __decorate([
        computed
    ], FileComponent.prototype, "clearButtonTooltip", null);
    __decorate([
        computed
    ], FileComponent.prototype, "value", null);
    __decorate([
        action
    ], FileComponent.prototype, "_onInput", null);
    __decorate([
        action
    ], FileComponent.prototype, "setFile", null);
    FileComponent = FileComponent_1 = __decorate([
        Component({
            selector: 'lf-file',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"\n        this.relativeStorage.getStateProperty('.', 'isRequired') && !isReadOnly\n      \"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- File input -->\n      <div class=\"custom-file\" [title]=\"_selectedFile?.name || noneChosenText\">\n        <input\n          #focusTarget\n          type=\"file\"\n          [accept]=\"accept\"\n          [id]=\"_id\"\n          class=\"custom-file-input\"\n          [attr.aria-describedby]=\"_id\"\n          [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n          [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n          [class.is-readonly]=\"isReadOnly\"\n          [name]=\"path\"\n          [disabled]=\"isReadOnly\"\n          (input)=\"_onInput($event)\"\n          (focus)=\"_onFocus($event)\"\n          (blur)=\"_onBlur($event)\"\n        />\n        <label\n          class=\"custom-file-label\"\n          [attr.for]=\"_id\"\n          [attr.data-browse]=\"browseText\"\n        >\n          <span\n            class=\"custom-file-label-content\"\n            [class.placeholder]=\"!_selectedFile\"\n            >{{ _selectedFile?.name || choosePlaceholder }}</span\n          >\n\n          <!-- Clear button -->\n          <button\n            *ngIf=\"_selectedFile && !isReadOnly\"\n            type=\"button\"\n            class=\"close\"\n            [title]=\"clearButtonTooltip\"\n            [attr.aria-label]=\"clearButtonTooltip\"\n            (click)=\"_onClickClear($event)\"\n          >\n            <span aria-hidden=\"true\">\u00D7</span>\n          </button>\n\n          <!-- Browse text -->\n          <div class=\"browse-text\">{{ browseText }}</div>\n        </label>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], FileComponent);
    return FileComponent;
}(InlineValue));

/**
 * LF form component.
 */
var FormComponent = /** @class */ (function (_super) {
    __extends(FormComponent, _super);
    function FormComponent(parentPathBasedComponent, lfStorage, lfI18n) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
    }
    FormComponent_1 = FormComponent;
    Object.defineProperty(FormComponent.prototype, "helpActionText", {
        /**
         * Text used for the "help" action.
         */
        get: function () {
            return this.translate(I18N_FORM_HELP_ACTION_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormComponent.prototype, "removeActionText", {
        /**
         * Text used for the "remove" action.
         */
        get: function () {
            return this.translate(I18N_FORM_REMOVE_ACTION_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormComponent.prototype, "ensureRemoveText", {
        /**
         * Message displayed to the user to confirm removal of the form.
         */
        get: function () {
            return this.translate(I18N_FORM_ENSURE_REMOVE_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormComponent.prototype, "cancelRemoveButtonText", {
        /**
         * Text for the "cancel" button in the removal modal.
         */
        get: function () {
            return this.translate(I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormComponent.prototype, "confirmRemoveButtonText", {
        /**
         * Text for the "confirm" button in the removal modal.
         */
        get: function () {
            return this.translate(I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormComponent.prototype, "isRemovable", {
        /**
         * Whether this form can be removed (if it is `nullable` or its parent is a
         * list or map).
         */
        get: function () {
            return (this.relativeStorage.isNullable() || this.relativeStorage.isRemovable());
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormComponent.prototype, "_formActions", {
        /**
         * Form-related actions shown on the top of the form.
         */
        get: function () {
            var _this = this;
            var actions = [];
            // Help action
            if (this.helpMessage !== undefined) {
                actions.push({
                    text: this.helpActionText,
                    class: 'help',
                    style: 'outline-primary',
                    icon: 'question-circle',
                    callback: function () { return _this.showHelpModal(); }
                });
            }
            // Remove form action
            if (this.isRemovable) {
                actions.push({
                    text: this.removeActionText,
                    class: 'remove-form',
                    style: 'outline-danger',
                    icon: 'trash',
                    callback: function () { return _this.showRemoveModal(); }
                });
            }
            return actions;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Removes this form by either setting it to `null` (when it is `nullable` or
     * removing it from its parent list or map).
     */
    FormComponent.prototype.remove = function () {
        if (this.relativeStorage.isNullable()) {
            this.relativeStorage.set('.', null);
        }
        else {
            this.relativeStorage.remove();
        }
    };
    FormComponent.prototype._cancelRemove = function () {
        this._removeModal.hide();
    };
    FormComponent.prototype._confirmRemove = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this._removeModal.hide()];
                    case 1:
                        _a.sent();
                        this.remove();
                        return [2 /*return*/];
                }
            });
        });
    };
    FormComponent.prototype.showHelpModal = function () {
        this._helpModal.show();
    };
    FormComponent.prototype.showRemoveModal = function () {
        this._removeModal.show();
    };
    var FormComponent_1;
    FormComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        ViewChild('helpModal')
    ], FormComponent.prototype, "_helpModal", void 0);
    __decorate([
        ViewChild('removeModal')
    ], FormComponent.prototype, "_removeModal", void 0);
    __decorate([
        computed
    ], FormComponent.prototype, "helpActionText", null);
    __decorate([
        computed
    ], FormComponent.prototype, "removeActionText", null);
    __decorate([
        computed
    ], FormComponent.prototype, "ensureRemoveText", null);
    __decorate([
        computed
    ], FormComponent.prototype, "cancelRemoveButtonText", null);
    __decorate([
        computed
    ], FormComponent.prototype, "confirmRemoveButtonText", null);
    __decorate([
        computed
    ], FormComponent.prototype, "isRemovable", null);
    __decorate([
        computed
    ], FormComponent.prototype, "_formActions", null);
    __decorate([
        action
    ], FormComponent.prototype, "remove", null);
    FormComponent = FormComponent_1 = __decorate([
        Component({
            selector: 'lf-form',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: FormComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <form\n    *ngIf=\"relativeStorage.has() && relativeStorage.get() !== null\"\n    class=\"container\"\n    [name]=\"path\"\n    (submit)=\"$event.preventDefault()\"\n  >\n    <!-- Form title -->\n    <div class=\"form-title-container\">\n      <h1 class=\"form-title\">{{ label }}</h1>\n      <!-- Form actions -->\n      <lf-actions-menu\n        class=\"form-actions\"\n        [actions]=\"_formActions\"\n        buttonsSize=\"sm\"\n        [alignMenusRight]=\"true\"\n      >\n      </lf-actions-menu>\n    </div>\n\n    <!-- Form content -->\n    <ng-content></ng-content>\n  </form>\n\n  <!-- Help modal -->\n  <lf-modal #helpModal class=\"help-modal\" size=\"lg\" *ngIf=\"helpMessage\">\n    <lf-modal-header>{{ helpActionText }}</lf-modal-header>\n    <lf-modal-body [innerHTML]=\"helpMessage\"></lf-modal-body>\n  </lf-modal>\n\n  <!-- Modal to confirm form deletion -->\n  <lf-modal *ngIf=\"isRemovable\" #removeModal class=\"remove-modal\">\n    <lf-modal-header>{{ removeActionText }}</lf-modal-header>\n    <lf-modal-body>\n      <p>{{ ensureRemoveText }}</p>\n    </lf-modal-body>\n    <lf-modal-footer>\n      <button\n        lf-button\n        class=\"cancel-remove\"\n        [style]=\"'outline-secondary'\"\n        size=\"sm\"\n        (click)=\"_cancelRemove()\"\n      >\n        {{ cancelRemoveButtonText }}\n      </button>\n      <button\n        lf-button\n        class=\"confirm-remove\"\n        [style]=\"'outline-danger'\"\n        size=\"sm\"\n        (click)=\"_confirmRemove()\"\n      >\n        {{ confirmRemoveButtonText }}\n      </button>\n    </lf-modal-footer>\n  </lf-modal>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], FormComponent);
    return FormComponent;
}(Value));

var HelpTooltipComponent = /** @class */ (function () {
    function HelpTooltipComponent() {
    }
    __decorate([
        Input()
    ], HelpTooltipComponent.prototype, "help", void 0);
    HelpTooltipComponent = __decorate([
        Component({
            selector: 'lf-help-tooltip',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<lf-tooltip [help]=\"help\" boundary=\"window\">\n  <lf-icon icon=\"question-circle\"></lf-icon>\n</lf-tooltip>\n"
        })
    ], HelpTooltipComponent);
    return HelpTooltipComponent;
}());

/**
 * LF icon component.
 */
var IconComponent = /** @class */ (function () {
    function IconComponent() {
        this.fixedWidth = false;
        this.spin = false;
        this.pulse = false;
        this.ariaHidden = true;
    }
    Object.defineProperty(IconComponent.prototype, "classes", {
        get: function () {
            var _a;
            var classes = (_a = {
                    fa: true
                },
                _a['fa-' + this.icon] = true,
                _a['fa-fw'] = this.fixedWidth,
                _a['fa-spin'] = this.spin,
                _a['fa-pulse'] = this.pulse,
                _a);
            if (this.size) {
                classes['fa-' + this.size] = true;
            }
            return classes;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        observable,
        Input()
    ], IconComponent.prototype, "icon", void 0);
    __decorate([
        observable,
        Input()
    ], IconComponent.prototype, "size", void 0);
    __decorate([
        observable,
        Input()
    ], IconComponent.prototype, "fixedWidth", void 0);
    __decorate([
        observable,
        Input()
    ], IconComponent.prototype, "spin", void 0);
    __decorate([
        observable,
        Input()
    ], IconComponent.prototype, "pulse", void 0);
    __decorate([
        observable,
        Input()
    ], IconComponent.prototype, "ariaHidden", void 0);
    __decorate([
        computed
    ], IconComponent.prototype, "classes", null);
    IconComponent = __decorate([
        Component({
            selector: 'lf-icon',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <i\n    *ngIf=\"icon\"\n    [ngClass]=\"classes\"\n    [attr.aria-hidden]=\"ariaHidden ? 'true' : 'false'\"\n  >\n  </i>\n</ng-container>\n"
        })
    ], IconComponent);
    return IconComponent;
}());

/**
 * Component that represents the body of a Bootstrap modal.
 */
var ModalBodyComponent = /** @class */ (function () {
    function ModalBodyComponent() {
        this._hostClassModalBody = true;
    }
    __decorate([
        HostBinding('class.modal-body')
    ], ModalBodyComponent.prototype, "_hostClassModalBody", void 0);
    ModalBodyComponent = __decorate([
        Component({
            selector: 'lf-modal-body, [lf-modal-body]',
            template: '<ng-content></ng-content>'
        })
    ], ModalBodyComponent);
    return ModalBodyComponent;
}());

/**
 * Component that represents the footer of a Bootstrap modal.
 */
var ModalFooterComponent = /** @class */ (function () {
    function ModalFooterComponent() {
        this._hostClassModalFooter = true;
    }
    __decorate([
        HostBinding('class.modal-footer')
    ], ModalFooterComponent.prototype, "_hostClassModalFooter", void 0);
    ModalFooterComponent = __decorate([
        Component({
            selector: 'lf-modal-footer, [lf-modal-footer]',
            template: '<ng-content></ng-content>'
        })
    ], ModalFooterComponent);
    return ModalFooterComponent;
}());

/**
 * LF modal component.
 */
var ModalComponent = /** @class */ (function (_super) {
    __extends(ModalComponent, _super);
    function ModalComponent(parentPathBasedComponent, lfStorage, lfI18n) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        /**
         * Whether to center the modal vertically on screen.
         */
        _this.isCentered = false;
        /**
         * Whether to animate the modal component.
         */
        _this.animate = true;
        /**
         * Whether to enable closing the modal by pressing the `Esc` key.
         */
        _this.closeWithEsc = true;
        /**
         * Whether to show a dark background underneath the modal when it appears.
         */
        _this.showBackdrop = true;
        /**
         * Whether to disable closing the modal by clicking on the backdrop.
         */
        _this.ignoreBackdropClick = false;
        /**
         * If the modal contains `<input>`, `<select>`, or `<textarea>` elements
         * within, focus the first found element after the modal opens.
         */
        _this.autoFocus = false;
        /**
         * Event emitter which emits an event whenever the modal finishes showing.
         */
        _this.shown = new EventEmitter();
        /**
         * Event emitter which emits an event whenever the modal finishes hiding.
         */
        _this.hidden = new EventEmitter();
        return _this;
    }
    ModalComponent_1 = ModalComponent;
    ModalComponent.prototype.ngAfterViewInit = function () {
        this.createModal();
    };
    ModalComponent.prototype.ngOnDestroy = function () {
        this.destroyModal();
        _super.prototype.ngOnDestroy.call(this);
    };
    /**
     * Method to call on long modals when their content changes, which forces
     * their height to also change.
     */
    ModalComponent.prototype.refresh = function () {
        this.$modal.modal('handleUpdate');
    };
    ModalComponent.prototype.show = function () {
        var _this = this;
        return new Promise(function (resolve) {
            _super.prototype.show.call(_this);
            if (_this.isAnimating) {
                _this.$modal.one('shown.bs.modal', resolve);
            }
            else {
                resolve();
            }
        });
    };
    ModalComponent.prototype.hide = function () {
        var _this = this;
        return new Promise(function (resolve) {
            _super.prototype.hide.call(_this);
            if (_this.isAnimating) {
                _this.$modal.one('hidden.bs.modal', resolve);
            }
            else {
                resolve();
            }
        });
    };
    ModalComponent.prototype.toggle = function () {
        return this.isVisible ? this.hide() : this.show();
    };
    /**
     * Creates a new modal and starts listening to events.
     */
    ModalComponent.prototype.createModal = function () {
        var _this = this;
        this.$modal = $(this._modal.nativeElement).modal({
            backdrop: this.showBackdrop && this.ignoreBackdropClick
                ? 'static'
                : this.showBackdrop,
            keyboard: this.closeWithEsc,
            show: this.isVisible
        });
        // There seems to be no way of updating these settings, so the most we can
        // do is destroy and reconstruct the modal whenever they change. TODO:
        // Figure out a better approach for this, perhaps implement this
        // functionality ourselves
        this.disposeOnOptionsChange = reaction(function () { return [_this.closeWithEsc, _this.showBackdrop, _this.ignoreBackdropClick]; }, function () { return _this.destroyModal().then(function () { return _this.createModal(); }); }, { name: 'modalReactionOnOptionsChange' });
        // Set the component's state if the modal is shown unconventionally
        // (i.e. without calling `show()`)
        this.$modal.on('show.bs.modal', function () {
            _this.isAnimating = true;
            if (!_this.isVisible) {
                _this.show();
            }
        });
        // Set the component's state if the modal is hidden unconventionally
        // (i.e. without calling `hide()`), this happens, for instance, when
        // pressing `Esc` or when pressing the area outside the modal
        this.$modal.on('hide.bs.modal', function () {
            _this.isAnimating = true;
            if (_this.isVisible) {
                _this.hide();
            }
        });
        // Runs when the showing animation ends
        this.$modal.on('shown.bs.modal', function () {
            _this.isAnimating = false;
            _this.shown.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (!_this.isVisible) {
                _this.hide();
            }
            // Focus the first input of the modal's body once it opens
            if (_this.autoFocus) {
                var firstInput = $('.modal-body input, .modal-body select, .modal-body textarea', _this.$modal).get(0);
                if (firstInput) {
                    firstInput.focus();
                }
            }
        });
        // Runs when the hiding animation ends
        this.$modal.on('hidden.bs.modal', function () {
            _this.isAnimating = false;
            _this.hidden.emit();
            // `isVisible` may change faster than the animations occur, force the UI
            // state to match `isVisible`
            if (_this.isVisible) {
                _this.show();
            }
        });
        // Open the modal when `show` is called
        this.onShowSubscription = this._show.subscribe(function () {
            if (!_this.isAnimating) {
                _this.$modal.modal('show');
            }
        });
        // Close the modal when `hide` is called
        this.onHideSubscription = this._hide.subscribe(function () {
            if (!_this.isAnimating) {
                _this.$modal.modal('hide');
            }
        });
    };
    /**
     * Unsubscribes from all events and destroys the modal (returns a promise that
     * resolves after the modal has been destroyed).
     * @returns Promise that resolves when the modal has been destroyed.
     */
    // FIXME: This returns a promise because we are forced to hide the modal prior
    // to removing it; otherwise a leftover backdrop will stay within the document
    // (this is probably an upstream Bootstrap bug)
    ModalComponent.prototype.destroyModal = function () {
        var _this = this;
        this.disposeOnOptionsChange && this.disposeOnOptionsChange();
        if (this.$modal) {
            this.$modal.off('show.bs.modal');
            this.$modal.off('hide.bs.modal');
            this.$modal.off('shown.bs.modal');
            this.$modal.off('hidden.bs.modal');
        }
        this.onShowSubscription && this.onShowSubscription.unsubscribe();
        this.onHideSubscription && this.onHideSubscription.unsubscribe();
        if (this.isVisible) {
            return new Promise(function (resolve) {
                // If we don't hide the modal prior to disposing of it, then a leftover
                // backdrop will stay in the document
                _this.hide();
                _this.$modal.one('hidden.bs.modal', function () {
                    $(_this).modal('dispose');
                    resolve();
                });
            });
        }
        else {
            this.$modal.modal('dispose');
            return Promise.resolve();
        }
    };
    var ModalComponent_1;
    ModalComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "size", void 0);
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "isCentered", void 0);
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "animate", void 0);
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "closeWithEsc", void 0);
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "showBackdrop", void 0);
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "ignoreBackdropClick", void 0);
    __decorate([
        observable,
        Input()
    ], ModalComponent.prototype, "autoFocus", void 0);
    __decorate([
        Output()
    ], ModalComponent.prototype, "shown", void 0);
    __decorate([
        Output()
    ], ModalComponent.prototype, "hidden", void 0);
    __decorate([
        ViewChild('modal')
    ], ModalComponent.prototype, "_modal", void 0);
    ModalComponent = ModalComponent_1 = __decorate([
        Component({
            selector: 'lf-modal',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: ModalComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <div\n    #modal\n    class=\"modal\"\n    [class.fade]=\"animate\"\n    tabindex=\"-1\"\n    role=\"dialog\"\n    aria-hidden=\"true\"\n  >\n    <div\n      class=\"modal-dialog {{ size ? 'modal-' + size : '' }}\"\n      [class.modal-dialog-centered]=\"isCentered\"\n    >\n      <div class=\"modal-content\" role=\"document\"><ng-content></ng-content></div>\n    </div>\n  </div>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], ModalComponent);
    return ModalComponent;
}(Toggleable));

/**
 * Component that represents the header of a Bootstrap modal.
 */
var ModalHeaderComponent = /** @class */ (function () {
    function ModalHeaderComponent(modalComponent) {
        this.modalComponent = modalComponent;
        /**
         * Whether to display a button to close the modal.
         */
        this.showCloseButton = true;
        // The modal header must always have the `modal-header` class.
        this._hostClassModalHeader = true;
    }
    Object.defineProperty(ModalHeaderComponent.prototype, "closeButtonTooltip", {
        /**
         * Tooltip text used by the modal's close button.
         */
        get: function () {
            return this.modalComponent.translate(I18N_CLOSE_BUTTON_TOOLTIP_KEY);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Hides the modal.
     */
    ModalHeaderComponent.prototype.hide = function () {
        this.modalComponent.hide();
    };
    ModalHeaderComponent.ctorParameters = function () { return [
        { type: ModalComponent }
    ]; };
    __decorate([
        observable,
        Input()
    ], ModalHeaderComponent.prototype, "showCloseButton", void 0);
    __decorate([
        HostBinding('class.modal-header')
    ], ModalHeaderComponent.prototype, "_hostClassModalHeader", void 0);
    __decorate([
        computed
    ], ModalHeaderComponent.prototype, "closeButtonTooltip", null);
    ModalHeaderComponent = __decorate([
        Component({
            selector: 'lf-modal-header, [lf-modal-header]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <!-- Title -->\n  <h5 class=\"modal-title\"><ng-content></ng-content></h5>\n\n  <!-- Close button -->\n  <button\n    *ngIf=\"showCloseButton\"\n    type=\"button\"\n    class=\"close\"\n    [title]=\"closeButtonTooltip\"\n    [attr.aria-label]=\"closeButtonTooltip\"\n    (click)=\"hide()\"\n  >\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</ng-container>\n"
        })
    ], ModalHeaderComponent);
    return ModalHeaderComponent;
}());

/**
 * LF number component.
 */
var NumberComponent = /** @class */ (function (_super) {
    __extends(NumberComponent, _super);
    function NumberComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
        /**
         * Number of decimal digits to show.
         */
        _this.scale = 0;
        /**
         * Number of digits to show on the left side of the number.
         */
        _this.leadingZeroes = 1;
        return _this;
    }
    Object.defineProperty(NumberComponent.prototype, "prefix", {
        /**
         * Number's prefix.
         */
        get: function () {
            return this.translate(I18N_NUMBER_PREFIX_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "suffix", {
        /**
         * Number's suffix.
         */
        get: function () {
            return this.translate(I18N_NUMBER_SUFFIX_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "decimalSeparator", {
        /**
         * Number's decimal separator.
         */
        get: function () {
            return this.translate(I18N_NUMBER_DECIMAL_SEPARATOR_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "thousandsSeparator", {
        /**
         * Number's thousands separator.
         */
        get: function () {
            return this.translate(I18N_NUMBER_THOUSANDS_SEPARATOR_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "value", {
        get: function () {
            return this.relativeStorage.has() ? this.relativeStorage.get() : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "formattedValue", {
        get: function () {
            return (this.numericInput &&
                this.numericInput.format(this.value === undefined ? null : this.value));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "min", {
        get: function () {
            return this.relativeStorage.has()
                ? this.relativeStorage.getStateProperty('.', 'min')
                : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "max", {
        get: function () {
            return this.relativeStorage.has()
                ? this.relativeStorage.getStateProperty('.', 'max')
                : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberComponent.prototype, "numericInputOptions", {
        /**
         * Numeric input options.
         */
        get: function () {
            var isInt = !!this.relativeStorage.schema().isInteger;
            var min = this.min == null ? -Infinity : this.min;
            var max = this.max == null ? Infinity : this.max;
            return {
                numericRepresentation: isInt ? 'int' : 'float',
                scale: this.scale || 0,
                leadingZeroes: this.leadingZeroes || 1,
                min: isInt ? Math.max(min, Number.MIN_SAFE_INTEGER) : min,
                max: isInt ? Math.min(max, Number.MAX_SAFE_INTEGER) : max,
                prefix: this.prefix || '',
                suffix: this.suffix || '',
                decimalSeparator: this.decimalSeparator || '.',
                thousandsSeparator: this.thousandsSeparator || ''
            };
        },
        enumerable: true,
        configurable: true
    });
    NumberComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        _super.prototype.ngAfterViewInit.call(this);
        // Create a new numeric input instance and recreate it whenever the
        // `<input>` element is recreated
        this.numericInput = this.newNumericInput();
        this.targetsChangeSubscription = this.targets.changes.subscribe(function () {
            _this.numericInput.destroy();
            _this.numericInput = _this.newNumericInput();
        });
        // Update the numeric input's options whenever they change
        this.disposeObserveOptions = observe(this, 'numericInputOptions', function (_a) {
            var newValue = _a.newValue;
            return _this.numericInput.setOptions(newValue, _this.value);
        });
        // Update the numeric input whenever the storage value changes
        this.disposeObserveValue = observe(this, 'value', function (_a) {
            var newValue = _a.newValue;
            if (newValue !== _this.numericInput.toNumber()) {
                _this.numericInput.update(newValue == null ? null : newValue);
            }
        }, true);
    };
    NumberComponent.prototype.ngOnDestroy = function () {
        this.targetsChangeSubscription &&
            this.targetsChangeSubscription.unsubscribe();
        this.disposeObserveOptions && this.disposeObserveOptions();
        this.disposeObserveValue && this.disposeObserveValue();
        this.numericInput && this.numericInput.destroy();
        _super.prototype.ngOnDestroy.call(this);
    };
    /**
     * Action to run on every `input` event of the text input.
     */
    NumberComponent.prototype._onInput = function () {
        this.relativeStorage.setDirty();
    };
    NumberComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isNumberSchema(schema) || !isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "number" type and "nullable"');
        }
    };
    NumberComponent.prototype.newNumericInput = function () {
        var _this = this;
        return new NumericInput(this.targets.first.nativeElement, __assign(__assign({}, this.numericInputOptions), { onUpdate: function (_, numberValue) {
                return _this.relativeStorage.has() &&
                    !_this.relativeStorage.isComputed() &&
                    _this.relativeStorage.set('.', numberValue);
            } }));
    };
    NumberComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        observable,
        Input()
    ], NumberComponent.prototype, "scale", void 0);
    __decorate([
        observable,
        Input()
    ], NumberComponent.prototype, "leadingZeroes", void 0);
    __decorate([
        computed
    ], NumberComponent.prototype, "prefix", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "suffix", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "decimalSeparator", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "thousandsSeparator", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "value", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "formattedValue", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "min", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "max", null);
    __decorate([
        computed
    ], NumberComponent.prototype, "numericInputOptions", null);
    __decorate([
        action
    ], NumberComponent.prototype, "_onInput", null);
    NumberComponent = __decorate([
        Component({
            selector: 'lf-number',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"\n        this.relativeStorage.getStateProperty('.', 'isRequired') && !isReadOnly\n      \"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <input\n        #focusTarget\n        type=\"text\"\n        class=\"form-control text-right\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [value]=\"formattedValue\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (input)=\"_onInput()\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      />\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], NumberComponent);
    return NumberComponent;
}(InlineValue));

/**
 * Abstract class used to represent components where a single option is selected
 * from a set of options.
 */
var SingleSelectionValue = /** @class */ (function (_super) {
    __extends(SingleSelectionValue, _super);
    function SingleSelectionValue(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    Object.defineProperty(SingleSelectionValue.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            if (!this.relativeStorage.isNullable()) {
                return false;
            }
            var isRequired = this.relativeStorage.getStateProperty('.', 'isRequired');
            return !!isRequired;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SingleSelectionValue.prototype, "selectedOptionIndex", {
        /**
         * Index of the selected option; `-1` when none of the available options is
         * selected.
         */
        // Not `computed` since `options` cannot be accessed within a `computed` value
        get: function () {
            var val = this.relativeStorage.get();
            return this.options.findIndex(function (opt) { return comparer.structural(val, opt.value); });
        },
        enumerable: true,
        configurable: true
    });
    SingleSelectionValue.ctorParameters = function () { return [
        { type: PathBased },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter }
    ]; };
    __decorate([
        computed
    ], SingleSelectionValue.prototype, "showIsRequired", null);
    SingleSelectionValue = __decorate([
        Directive()
        // tslint:disable-next-line: directive-class-suffix
    ], SingleSelectionValue);
    return SingleSelectionValue;
}(SelectionValue));

/**
 * Component used for selecting from a list of options by using inputs of type
 * `radio`.
 */
var RadioComponent = /** @class */ (function (_super) {
    __extends(RadioComponent, _super);
    function RadioComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
        /**
         * Whether the list of radio inputs should be displayed inline. The component
         * will still display in "block" mode in small screens.
         */
        _this.displayInline = false;
        return _this;
    }
    /**
     * Action to run whenever the value of the `radio` input changes.
     * @param evt `change` event.
     */
    RadioComponent.prototype._onRadioChange = function (evt) {
        this.relativeStorage.set('.', this.options[evt.target.value].value);
        this.relativeStorage.setDirty();
    };
    RadioComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        observable,
        Input()
    ], RadioComponent.prototype, "displayInline", void 0);
    __decorate([
        action
    ], RadioComponent.prototype, "_onRadioChange", null);
    RadioComponent = __decorate([
        Component({
            selector: 'lf-radio',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"lf-checkable-group input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Radios -->\n      <div\n        class=\"lf-checkables form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [class.display-inline]=\"displayInline\"\n      >\n        <!-- Text for when there are no options -->\n        <div\n          *ngIf=\"optionsStatus !== 'pending' && options.length === 0\"\n          class=\"no-options\"\n        >\n          {{ noOptionsText }}\n        </div>\n\n        <!-- Pending options -->\n        <div *ngIf=\"optionsStatus === 'pending'\" class=\"pending-options\"></div>\n\n        <div\n          class=\"lf-checkable input-group input-group-sm\"\n          *ngFor=\"let option of options; let i = index\"\n        >\n          <!-- Code of each radio -->\n          <div *ngIf=\"option.code\" class=\"input-group-prepend\">\n            <div class=\"input-group-text\">{{ option.code }}</div>\n          </div>\n\n          <!-- Radio -->\n          <label\n            class=\"form-control custom-control custom-radio\"\n            [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n            [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n            [class.is-readonly]=\"isReadOnly\"\n          >\n            <!-- Actual radio -->\n            <!--\n              Note that radios don't support `readonly`, so we use the\n              `disabled` attribute\n            -->\n            <input\n              #focusTarget\n              type=\"radio\"\n              class=\"custom-control-input\"\n              [name]=\"path\"\n              [value]=\"i\"\n              [checked]=\"selectedOptionIndex === i\"\n              [disabled]=\"isReadOnly\"\n              (change)=\"_onRadioChange($event)\"\n              (focus)=\"_onFocus($event)\"\n              (blur)=\"_onBlur($event)\"\n            />\n\n            <!-- Radio label -->\n            <span class=\"custom-control-label\">\n              <span>{{ option.label }}</span>\n              <lf-help-tooltip\n                *ngIf=\"option.helpMessage\"\n                [help]=\"option.helpMessage\"\n              ></lf-help-tooltip>\n            </span>\n          </label>\n        </div>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], RadioComponent);
    return RadioComponent;
}(SingleSelectionValue));

/**
 * Component used for selecting from a list of options in a dropdown `<select>`
 * menu.
 */
var SelectComponent = /** @class */ (function (_super) {
    __extends(SelectComponent, _super);
    function SelectComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    /**
     * Action to run whenever the `<select>` values changes.
     * @param evt `change` event.
     */
    SelectComponent.prototype._onSelectChange = function (evt) {
        this.relativeStorage.set('.', this.options[+evt.target.value].value);
        this.relativeStorage.setDirty();
    };
    SelectComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        action
    ], SelectComponent.prototype, "_onSelectChange", null);
    SelectComponent = __decorate([
        Component({
            selector: 'lf-select',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending() || optionsStatus === 'pending'\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"\n        relativeStorage.shouldShowRejected() || optionsStatus === 'rejected'\n      \"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Select element -->\n      <!--\n        Note that selects don't support `readonly`, so we use the `disabled`\n        attribute; we add an `is-readonly` class to style it differently\n      -->\n      <select\n        #focusTarget\n        class=\"form-control form-control-sm custom-select\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [disabled]=\"isReadOnly\"\n        (change)=\"_onSelectChange($event)\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      >\n        <!-- Default option -->\n        <option\n          [selected]=\"selectedOptionIndex === -1\"\n          disabled\n          hidden\n        ></option>\n\n        <!-- Disabled option for when there are no options -->\n        <option *ngIf=\"options.length === 0\" disabled>\n          {{ noOptionsText }}\n        </option>\n\n        <!-- User defined options -->\n        <option\n          *ngFor=\"let option of options; let i = index\"\n          [value]=\"i\"\n          [selected]=\"selectedOptionIndex === i\"\n          [disabled]=\"option.isDisabled\"\n        >\n          <!-- Option code -->\n          <ng-container *ngIf=\"option.code\">{{ option.code }}.</ng-container>\n\n          <!-- Option label -->\n          {{ option.label }}\n        </option>\n      </select>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], SelectComponent);
    return SelectComponent;
}(SingleSelectionValue));

/**
 * Width of the selection column (in `px`).
 */
var SELECTION_COLUMN_WIDTH = 25.6;
/**
 * LF table component.
 *
 * Example usage:
 * ```html
 * <lf-table path="/path/to/table">
 *   <lf-table-header>
 *     <lf-table-column id="field1"></lf-table-column>
 *     <lf-table-column id="field2"></lf-table-column>
 *   </lf-table-header>
 *
 *   <ng-template #lfTableRowTemplate let-id="id">
 *     <tr lf-table-row [path]="id">
 *       <td lf-table-cell><lf-text path="field1"></lf-text></td>
 *       <td lf-table-cell><lf-number path="field2"></lf-number></td>
 *     </tr>
 *   </ng-template>
 * </lf-table>
 * ```
 */
var TableComponent = /** @class */ (function (_super) {
    __extends(TableComponent, _super);
    function TableComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, scrollbarUtils, viewportRuler) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
        _this.scrollbarUtils = scrollbarUtils;
        _this.viewportRuler = viewportRuler;
        /**
         * Height (in `px`) of a single row (virtual scroll settings). All rows must
         * have the same height.
         */
        _this.rowHeight = 42;
        /**
         * Maximum number of visible rows at any given time.
         */
        _this.maxVisibleRows = 10;
        /**
         * Size of the virtual scroll's template cache
         * (`cdkVirtualForTemplateCacheSize` input of Angular CDK's virtual for
         * directive).
         */
        _this.virtualScrollTemplateCacheSize = 20;
        /**
         * Whether to allow addition of new rows.
         */
        _this.allowRowAddition = true;
        /**
         * Whether to allow removal of rows.
         */
        _this.allowRowRemoval = true;
        // Selected rows
        _this.selectedRows = new Map();
        // Identifier of the row that was last selected/unselected; used to implement
        // selections while pressing shift (behaviour similar to how Gmail operates)
        _this.lastSelectedId = null;
        // Position of the scrollable element after the latest scroll
        _this.lastScrollPosition = [0, 0];
        return _this;
    }
    TableComponent_1 = TableComponent;
    Object.defineProperty(TableComponent.prototype, "_addRowText", {
        get: function () {
            return this.translate(I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_removeRowsText", {
        get: function () {
            return this.translate(I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_noRowsText", {
        get: function () {
            return this.translate(I18N_TABLE_NO_ROWS_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_columnLabels", {
        get: function () {
            return this.translate(I18N_TABLE_COLUMN_LABELS_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_schema", {
        /**
         * Schema of this table's value.
         */
        get: function () {
            return this.relativeStorage.schema();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_value", {
        /**
         * Table's value.
         */
        get: function () {
            return this.relativeStorage.get().slice();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            var minSize = this.relativeStorage.getStateProperty('.', 'minSize');
            return minSize !== undefined && minSize > 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_tableActions", {
        /**
         * Table actions.
         */
        get: function () {
            var _this = this;
            var actions = [];
            // Remove rows action
            if (this.allowsRowRemoval && !this.noRowsSelected) {
                actions.push({
                    text: this._removeRowsText,
                    class: 'remove-rows',
                    style: 'outline-danger',
                    icon: 'trash',
                    callback: function () { return _this._onClickRemoveRows(); }
                });
            }
            // New row action
            var maxSize = this.relativeStorage.getStateProperty('.', 'maxSize');
            if (this.allowsRowAddition &&
                (maxSize == null || this._value.length < maxSize)) {
                actions.push({
                    text: this._addRowText,
                    class: 'add-row',
                    style: 'outline-primary',
                    icon: 'plus-circle',
                    callback: function () { return _this._onClickNewRow(); }
                });
            }
            return actions;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_scrollableBodyHeight", {
        /**
         * Height (in px) that the scrollable body element should have.
         */
        get: function () {
            return (Math.min(this._value.length, this.maxVisibleRows) * this.rowHeight +
                this.horizontalScrollbarHeight);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "allowsRowAddition", {
        /**
         * Whether new rows can be added to the table (takes into consideration if the
         * table is in "read only" mode).
         */
        get: function () {
            return !this.isReadOnly && this.allowRowAddition;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "allowsRowRemoval", {
        /**
         * Whether rows can be removed from the table (takes into consideration if the
         * table is in "read only" mode).
         */
        get: function () {
            return !this.isReadOnly && this.allowRowRemoval;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "numberOfRowsSelected", {
        /**
         * Number of rows that have been selected.
         */
        get: function () {
            return this.selectedRows.size;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "allRowsSelected", {
        /**
         * Whether all rows are selected.
         */
        get: function () {
            return this.selectedRows.size === this._value.length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "noRowsSelected", {
        /**
         * Whether no rows are selected.
         */
        get: function () {
            return this.selectedRows.size === 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "_trackBy", {
        /**
         * Track either by index or reference, depending on the type of value for list
         * schemas; or by row id, when dealing with table schemas.
         */
        get: function () {
            if (isListSchema(this._schema)) {
                var elementsType = this._schema.elementsSchema.type;
                return ['boolean', 'number', 'string'].indexOf(elementsType) === -1
                    ? function (_, el) { return el; }
                    : function (i) { return i; };
            }
            else {
                return function (_, row) { return getRowId(row); };
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "verticalScrollbarWidth", {
        /**
         * Width (in px) of the vertical scroll bar, when existent (`0` otherwise).
         */
        get: function () {
            return this._value.length > this.maxVisibleRows
                ? this.scrollbarUtils.verticalScrollbarWidth
                : 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "horizontalScrollbarHeight", {
        /**
         * Height (in px) of the horizontal scroll bar, when existent (`0` otherwise).
         */
        get: function () {
            return this.hasHorizontalOverflow
                ? this.scrollbarUtils.horizontalScrollbarHeight
                : 0;
        },
        enumerable: true,
        configurable: true
    });
    TableComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        var _a;
        _super.prototype.ngAfterViewInit.call(this);
        // React to scrolling on the scrollable body. Adapted from:
        // https://github.com/angular/components/blob/master/src/cdk/scrolling/virtual-scroll-viewport.ts
        var scrollableBodyEl = this._scrollableBody.elementRef.nativeElement;
        var scrollableHeaderEl = (_a = this._scrollableHeader) === null || _a === void 0 ? void 0 : _a.nativeElement;
        this.scrollSubscription = this._scrollableBody
            .elementScrolled()
            .pipe(auditTime(0, typeof requestAnimationFrame !== 'undefined'
            ? animationFrameScheduler
            : asapScheduler))
            .subscribe(function () {
            // Save last scroll position to restore scroll position when needed
            _this.lastScrollPosition = [
                scrollableBodyEl.scrollTop,
                scrollableBodyEl.scrollLeft
            ];
            // Sync header scroll with body scroll
            scrollableHeaderEl &&
                (scrollableHeaderEl.scrollLeft = scrollableBodyEl.scrollLeft);
        });
        // Set the table's scroll position whenever the path changes (and when the
        // component is first initialised)
        this.disposeObservePath = observe(this, 'path', function (_a) {
            var oldValue = _a.oldValue, newValue = _a.newValue;
            // Save old scroll value
            if (oldValue) {
                _this.lfStorage.setStateProperty(oldValue, _this.scrollPositionStatePropName(oldValue), _this.lastScrollPosition);
            }
            // Use previous scroll values
            var savedScrollPosition = _this.lfStorage.getStateProperty(newValue, _this.scrollPositionStatePropName(newValue)) || [0, 0];
            if (!comparer.shallow(_this.lastScrollPosition, savedScrollPosition)) {
                _this.lastScrollPosition = savedScrollPosition;
                asap(function () {
                    return _this._scrollableBody.scrollTo({
                        top: savedScrollPosition[0],
                        left: savedScrollPosition[1]
                    });
                });
            }
        }, true);
        // Remove "selected rows" of non-existent rows (because they were removed
        // by an outside operation, such as loading from a file)
        this.disposeObserveValue = observe(this, '_value', function () {
            var e_1, _a;
            try {
                for (var _b = __values(Array.from(_this.selectedRows.keys())), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var id = _c.value;
                    if (!_this.relativeStorage.has("" + id)) {
                        _this.selectedRows.delete(id);
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_1) throw e_1.error; }
            }
        });
        // Refresh the virtual scroll viewport whenever its height changes
        this.disposeObserveBodyHeight = observe(this, '_scrollableBodyHeight', function () {
            _this._scrollableBody.checkViewportSize();
            _this.checkHasHorizontalOverflow();
        });
        // Update the status of the horizontal overflow whenever the window viewport
        // size changes
        this.viewportSubscription = this.viewportRuler.change().subscribe(function () {
            _this.checkHasHorizontalOverflow();
        });
        asap(function () { return _this.checkHasHorizontalOverflow(); }); // Update on start-up
    };
    TableComponent.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
        // Save scroll value
        this.lfStorage.setStateProperty(this.path, this.scrollPositionStatePropName(this.path), this.lastScrollPosition);
        this.scrollSubscription && this.scrollSubscription.unsubscribe();
        this.disposeObservePath && this.disposeObservePath();
        this.disposeObserveValue && this.disposeObserveValue();
        this.disposeObserveBodyHeight && this.disposeObserveBodyHeight();
        this.viewportSubscription && this.viewportSubscription.unsubscribe();
    };
    TableComponent.prototype._columnLabel = function (columnId) {
        return this._columnLabels && this._columnLabels[columnId];
    };
    /**
     * Minimum width (in px) that the table should have.
     * @param includeScrollbarColumn Whether the scrollbar column should be
     * included in the computation (should be set to `true` for the header table).
     * @returns Minimum width that the table should have.
     */
    TableComponent.prototype._tableMinWidth = function (includeScrollbarColumn) {
        return (this._tableHeader.tableMinWidth +
            (this.allowsRowRemoval ? SELECTION_COLUMN_WIDTH : 0) +
            (includeScrollbarColumn ? this.verticalScrollbarWidth : 0));
    };
    /**
     * Maximum width (in px) that the table should have.
     * @param includeScrollbarColumn Whether the scrollbar column should be
     * included in the computation (should be set to `true` for the header table).
     * @returns Maximum width that the table should have.
     */
    TableComponent.prototype._tableMaxWidth = function (includeScrollbarColumn) {
        return (this._tableHeader.tableMaxWidth +
            (this.allowsRowRemoval ? SELECTION_COLUMN_WIDTH : 0) +
            (includeScrollbarColumn ? this.verticalScrollbarWidth : 0));
    };
    /**
     * Widths (as strings with correct units) of each column of the table.
     * @param includeScrollbarColumn Whether the scrollbar column should be
     * included (should be set to `true` for the header table).
     * @returns Widths of each column of the table.
     */
    TableComponent.prototype._columnWidths = function (includeScrollbarColumn) {
        return (this.allowsRowRemoval
            ? [SELECTION_COLUMN_WIDTH + 'px']
            : []).concat(this._tableHeader.columnWidths.concat(includeScrollbarColumn ? [this.verticalScrollbarWidth + 'px'] : []));
    };
    /**
     * Adds a new row to the table.
     */
    TableComponent.prototype.addNewRow = function () {
        var _this = this;
        this.relativeStorage.push('.', undefined);
        // Scroll to bottom (shows newly inserted row)
        asap(function () { return _this.scrollToIndex(_this._value.length - 1); });
    };
    /**
     * Gets the selection status of the row with the provided id.
     * @param id Id of the row for which to check selection status.
     * @returns Whether the row with the provided id is selected.
     */
    TableComponent.prototype.getRowSelectedStatus = function (id) {
        return this.allowsRowRemoval && this.selectedRows.has(id);
    };
    /**
     * Sets the selection status of the row with the provided id.
     * @param id Id of the row on which to set selection status.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    TableComponent.prototype.setRowSelectedStatus = function (id, selectedStatus) {
        if (!this.relativeStorage.has("" + id)) {
            throw pathError(this.path, "Invalid id: " + id);
        }
        if (selectedStatus) {
            this.selectedRows.set(id, true);
        }
        else {
            this.selectedRows.delete(id);
        }
        this.lastSelectedId = id;
    };
    /**
     * Sets the selection status of all rows from the last row that has had its
     * selection status set to the row with the provided id.
     * @param id Id of the row until which to set selection status.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    TableComponent.prototype.setRowSelectedStatusFromLastSelected = function (id, selectedStatus) {
        if (!this.relativeStorage.has("" + id)) {
            throw pathError(this.path, "Invalid id: " + id);
        }
        var lastSelectedId = this.lastSelectedId === null ||
            !this.relativeStorage.has("" + this.lastSelectedId)
            ? id
            : this.lastSelectedId;
        var idx;
        var lastSelectedIdx;
        var isTable = isTableSchema(this._schema);
        if (isTable) {
            idx = this._value.findIndex(function (row) { return getRowId(row) === id; });
            lastSelectedIdx =
                id === lastSelectedId
                    ? idx
                    : this._value.findIndex(function (row) { return getRowId(row) === lastSelectedId; });
        }
        else {
            idx = id;
            lastSelectedIdx = lastSelectedId;
        }
        for (var i = Math.min(lastSelectedIdx, idx), l = Math.max(lastSelectedIdx, idx); i <= l; ++i) {
            var iId = isTable ? getRowId(this._value[i]) : i;
            if (selectedStatus) {
                this.selectedRows.set(iId, true);
            }
            else {
                this.selectedRows.delete(iId);
            }
        }
        this.lastSelectedId = id;
    };
    /**
     * Unselects all rows.
     */
    TableComponent.prototype.unselectAllRows = function () {
        // Doing this seems to be way faster than calling `selectedRows.clear()`
        // with, for example, 200000 rows
        this.selectedRows = new Map();
    };
    /**
     * Sets the selection status of all rows.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    TableComponent.prototype.setAllRowsSelectedStatus = function (selectedStatus) {
        var _this = this;
        if (selectedStatus) {
            var isTable_1 = isTableSchema(this._schema);
            this._value.forEach(function (el, i) {
                var id = isTable_1 ? getRowId(el) : i;
                _this.selectedRows.set(id, true);
            });
        }
        else {
            this.unselectAllRows();
        }
    };
    /**
     * Toggles the status of all rows (if they are all selected, then they all
     * become unselected, otherwise they all become selected).
     */
    TableComponent.prototype.toggleAllRowsSelectedStatus = function () {
        this.setAllRowsSelectedStatus(!this.allRowsSelected);
    };
    /**
     * Removes all selected rows.
     */
    TableComponent.prototype.removeSelectedRows = function () {
        var _this = this;
        var isTable = isTableSchema(this._schema);
        this.relativeStorage.set('.', this._value.filter(function (el, i) {
            var id = isTable ? getRowId(el) : i;
            return !_this.selectedRows.has(id);
        }));
        this.unselectAllRows();
        this.lastSelectedId = null;
    };
    /**
     * Scrolls to the row with the provided id.
     * @param id Identifier of the row to scroll to.
     */
    TableComponent.prototype.scrollToId = function (id) {
        if (!this.relativeStorage.has("" + id)) {
            throw pathError(this.path, "Invalid id: " + id);
        }
        var index = isListSchema(this._schema)
            ? id
            : this._value.findIndex(function (row) { return getRowId(row) === id; });
        this.scrollToIndex(index);
    };
    /**
     * Scrolls to row with the provided index.
     * @param index Index of the row to scroll to.
     */
    TableComponent.prototype.scrollToIndex = function (index) {
        this._scrollableBody.scrollToIndex(index);
    };
    /**
     * Identifier of the given element with the given index.
     * @param el Element for which to get identifier.
     * @param index Index of the element in the value.
     * @returns Identifier for the given element at the given index.
     */
    TableComponent.prototype._id = function (el, index) {
        return isListSchema(this._schema) ? index : getRowId(el);
    };
    /**
     * Action to run when the "remove rows" button is clicked.
     */
    TableComponent.prototype._onClickRemoveRows = function () {
        this.removeSelectedRows();
        this.relativeStorage.setDirty();
    };
    /**
     * Action to run when the "new row" button is clicked.
     */
    TableComponent.prototype._onClickNewRow = function () {
        this.addNewRow();
        this.relativeStorage.setDirty();
    };
    TableComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if ((!isListSchema(schema) && !isTableSchema(schema)) ||
            isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "list" or "table" type and not "nullable"');
        }
    };
    // Scroll to the activated row when one is activated.
    TableComponent.prototype.onActivate = function (activatedPath) {
        var _this = this;
        var relevantPart = this.lfStorage
            .pathInfo(activatedPath)
            .find(function (_a) {
            var path = _a.path;
            return path.length > _this.path.length;
        });
        var id = relevantPart && relevantPart.id;
        if (id !== undefined && this.relativeStorage.has("" + id)) {
            this.scrollToId(id);
        }
    };
    /**
     * State property name used to save the position of the scroll within the
     * table.
     * @param path Path of table.
     * @returns State property name.
     */
    TableComponent.prototype.scrollPositionStatePropName = function (path) {
        // Add the path to the name of the property when the value is a child of a
        // computed value (since children states are shared with the parent computed
        // value)
        return "lfTableScrollPosition" + (this.relativeStorage.isComputed(appendToPath(path, '..'))
            ? "[" + path + "]"
            : '');
    };
    /**
     * Update the status of the "horizontal overflow".
     */
    TableComponent.prototype.checkHasHorizontalOverflow = function () {
        this.hasHorizontalOverflow = this.scrollbarUtils.hasHorizontalOverflow(this._scrollableBody.elementRef.nativeElement);
    };
    var TableComponent_1;
    TableComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] },
        { type: ScrollbarUtils },
        { type: ViewportRuler }
    ]; };
    __decorate([
        observable,
        Input()
    ], TableComponent.prototype, "rowHeight", void 0);
    __decorate([
        observable,
        Input()
    ], TableComponent.prototype, "maxVisibleRows", void 0);
    __decorate([
        Input()
    ], TableComponent.prototype, "virtualScrollTemplateCacheSize", void 0);
    __decorate([
        observable,
        Input()
    ], TableComponent.prototype, "allowRowAddition", void 0);
    __decorate([
        observable,
        Input()
    ], TableComponent.prototype, "allowRowRemoval", void 0);
    __decorate([
        ContentChild(TableHeaderDirective)
    ], TableComponent.prototype, "_tableHeader", void 0);
    __decorate([
        ContentChild('lfTableRowTemplate')
    ], TableComponent.prototype, "_rowTemplate", void 0);
    __decorate([
        ContentChild('lfTableNoRowsTemplate')
    ], TableComponent.prototype, "_noRowsTemplate", void 0);
    __decorate([
        ViewChild('scrollableHeader')
    ], TableComponent.prototype, "_scrollableHeader", void 0);
    __decorate([
        ViewChild('scrollableBody')
    ], TableComponent.prototype, "_scrollableBody", void 0);
    __decorate([
        observable
    ], TableComponent.prototype, "hasHorizontalOverflow", void 0);
    __decorate([
        observable
    ], TableComponent.prototype, "selectedRows", void 0);
    __decorate([
        computed
    ], TableComponent.prototype, "_addRowText", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_removeRowsText", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_noRowsText", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_columnLabels", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_schema", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_value", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_showIsRequired", null);
    __decorate([
        computed.struct
    ], TableComponent.prototype, "_tableActions", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_scrollableBodyHeight", null);
    __decorate([
        computed
    ], TableComponent.prototype, "allowsRowAddition", null);
    __decorate([
        computed
    ], TableComponent.prototype, "allowsRowRemoval", null);
    __decorate([
        computed
    ], TableComponent.prototype, "numberOfRowsSelected", null);
    __decorate([
        computed
    ], TableComponent.prototype, "allRowsSelected", null);
    __decorate([
        computed
    ], TableComponent.prototype, "noRowsSelected", null);
    __decorate([
        computed
    ], TableComponent.prototype, "_trackBy", null);
    __decorate([
        computed
    ], TableComponent.prototype, "verticalScrollbarWidth", null);
    __decorate([
        computed
    ], TableComponent.prototype, "horizontalScrollbarHeight", null);
    __decorate([
        action
    ], TableComponent.prototype, "addNewRow", null);
    __decorate([
        action
    ], TableComponent.prototype, "setRowSelectedStatus", null);
    __decorate([
        action
    ], TableComponent.prototype, "setRowSelectedStatusFromLastSelected", null);
    __decorate([
        action
    ], TableComponent.prototype, "unselectAllRows", null);
    __decorate([
        action
    ], TableComponent.prototype, "setAllRowsSelectedStatus", null);
    __decorate([
        action
    ], TableComponent.prototype, "toggleAllRowsSelectedStatus", null);
    __decorate([
        action
    ], TableComponent.prototype, "removeSelectedRows", null);
    __decorate([
        action
    ], TableComponent.prototype, "_onClickRemoveRows", null);
    __decorate([
        action
    ], TableComponent.prototype, "_onClickNewRow", null);
    __decorate([
        action
    ], TableComponent.prototype, "onActivate", null);
    __decorate([
        action
    ], TableComponent.prototype, "checkHasHorizontalOverflow", null);
    TableComponent = TableComponent_1 = __decorate([
        Component({
            selector: 'lf-table',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: TableComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <div class=\"row label\">\n      <!-- Code + label -->\n      <div class=\"code-label-container\">\n        <!-- Code -->\n        <div\n          *ngIf=\"code\"\n          class=\"input-group input-group-sm code-container mr-2\"\n          [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n          [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        >\n          <div class=\"input-group-prepend\">\n            <div class=\"input-group-text code\">{{ code }}</div>\n          </div>\n        </div>\n\n        <!-- Label -->\n        <span *ngIf=\"label\" class=\"label-text\">{{ label }}</span>\n        <lf-help-tooltip\n          *ngIf=\"helpMessage\"\n          [help]=\"helpMessage\"\n        ></lf-help-tooltip>\n      </div>\n\n      <!-- Table actions -->\n      <lf-actions-menu\n        class=\"table-actions text-right\"\n        [actions]=\"_tableActions\"\n        buttonsSize=\"sm\"\n        [alignMenusRight]=\"true\"\n      >\n      </lf-actions-menu>\n    </div>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"_showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Container of whole table -->\n    <div\n      #targetElement\n      class=\"table-container\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Header table container (scrollable horizontally) -->\n      <div #scrollableHeader class=\"scrollable-header\" *ngIf=\"_tableHeader\">\n        <table\n          class=\"table table-sm header-table\"\n          [style.minWidth]=\"_tableMinWidth(true) + 'px'\"\n          [style.maxWidth]=\"_tableMaxWidth(true) + 'px'\"\n        >\n          <!-- Table columns -->\n          <colgroup>\n            <col\n              *ngFor=\"let width of _columnWidths(true)\"\n              [attr.width]=\"width\"\n            />\n          </colgroup>\n\n          <!-- Table header -->\n          <thead>\n            <tr *ngFor=\"let row of _tableHeader.rows; let first = first\">\n              <!-- Selection column -->\n              <th\n                *ngIf=\"first && allowsRowRemoval\"\n                class=\"table-cell-select\"\n                [attr.rowSpan]=\"_tableHeader.numberOfRows\"\n              >\n                <label\n                  class=\"select-all-checkbox custom-control custom-checkbox\"\n                >\n                  <input\n                    type=\"checkbox\"\n                    class=\"custom-control-input\"\n                    [disabled]=\"_value.length === 0\"\n                    [checked]=\"allRowsSelected && _value.length > 0\"\n                    [indeterminate]=\"!allRowsSelected && !noRowsSelected\"\n                    (click)=\"toggleAllRowsSelectedStatus()\"\n                  />\n                  <span class=\"custom-control-label\"></span>\n                </label>\n              </th>\n              <!-- User defined columns -->\n              <th\n                *ngFor=\"let column of row\"\n                [attr.rowSpan]=\"column.rowSpan\"\n                [attr.colSpan]=\"column.colSpan\"\n              >\n                <!-- TODO: Allow help messages/templates? -->\n                <ng-container *ngIf=\"column.id\">{{\n                  _columnLabel(column.id)\n                }}</ng-container>\n              </th>\n              <!-- Scrollbar compensation column -->\n              <th *ngIf=\"first\" [attr.rowSpan]=\"_tableHeader.numberOfRows\"></th>\n            </tr>\n          </thead>\n        </table>\n      </div>\n\n      <!-- Body table container (scrollable content) -->\n      <cdk-virtual-scroll-viewport\n        #scrollableBody\n        class=\"scrollable-body\"\n        [itemSize]=\"rowHeight\"\n        [style.height]=\"_scrollableBodyHeight + 'px'\"\n      >\n        <table\n          class=\"table table-sm body-table\"\n          [style.minWidth]=\"_tableHeader && _tableMinWidth(false) + 'px'\"\n          [style.maxWidth]=\"_tableHeader && _tableMaxWidth(false) + 'px'\"\n        >\n          <!-- Table columns (except scrollbar column) -->\n          <colgroup *ngIf=\"_tableHeader\">\n            <col\n              *ngFor=\"let width of _columnWidths(false)\"\n              [attr.width]=\"width\"\n            />\n          </colgroup>\n\n          <!-- Table body -->\n          <tbody>\n            <!-- Row -->\n            <ng-container\n              *cdkVirtualFor=\"\n                let item of _value;\n                let index = index;\n                let count = count;\n                let first = first;\n                let last = last;\n                let even = even;\n                let odd = odd;\n                templateCacheSize: virtualScrollTemplateCacheSize;\n                trackBy: _trackBy\n              \"\n              [ngTemplateOutlet]=\"_rowTemplate\"\n              [ngTemplateOutletContext]=\"{\n                $implicit: item,\n                id: _id(item, index),\n                index: index,\n                count: count,\n                first: first,\n                last: last,\n                even: even,\n                odd: odd\n              }\"\n            ></ng-container>\n          </tbody>\n        </table>\n      </cdk-virtual-scroll-viewport>\n\n      <!-- No items -->\n      <div *ngIf=\"_value.length === 0\" class=\"no-rows\">\n        <ng-container *ngIf=\"!_noRowsTemplate\">\n          {{ _noRowsText }}\n        </ng-container>\n        <ng-container\n          *ngIf=\"_noRowsTemplate\"\n          [ngTemplateOutlet]=\"_noRowsTemplate\"\n        >\n        </ng-container>\n      </div>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], TableComponent);
    return TableComponent;
}(InlineValue));

/**
 * LF table-cell component.
 */
var TableCellComponent = /** @class */ (function () {
    function TableCellComponent(parentTableComponent) {
        this.parentTableComponent = parentTableComponent;
    }
    Object.defineProperty(TableCellComponent.prototype, "_hostStyleHeight", {
        /**
         * Height of the cell.
         */
        get: function () {
            return this.parentTableComponent.rowHeight + 'px';
        },
        enumerable: true,
        configurable: true
    });
    TableCellComponent.ctorParameters = function () { return [
        { type: TableComponent }
    ]; };
    __decorate([
        computed,
        HostBinding('style.height')
    ], TableCellComponent.prototype, "_hostStyleHeight", null);
    TableCellComponent = __decorate([
        Component({
            // tslint:disable-next-line:component-selector
            selector: 'td[lf-table-cell], th[lf-table-cell]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <div class=\"table-cell-container\">\n    <div class=\"table-cell-inner\"><ng-content></ng-content></div>\n  </div>\n</ng-container>\n"
        })
    ], TableCellComponent);
    return TableCellComponent;
}());

/**
 * LF table-row component.
 */
var TableRowComponent = /** @class */ (function (_super) {
    __extends(TableRowComponent, _super);
    function TableRowComponent(parentPathBasedComponent, // Verified `OnInit`
    lfStorage, lfI18n) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.parentPathBasedComponent = parentPathBasedComponent;
        return _this;
    }
    TableRowComponent_1 = TableRowComponent;
    Object.defineProperty(TableRowComponent.prototype, "allowsRemoval", {
        /**
         * Whether the row can be removed.
         */
        get: function () {
            return this.parentPathBasedComponent.allowsRowRemoval;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableRowComponent.prototype, "isSelected", {
        /**
         * Whether the row is selected (adds an `is-selected` class to the row).
         */
        get: function () {
            return this.parentPathBasedComponent.getRowSelectedStatus(this.relativeStorage.currentId);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableRowComponent.prototype, "_classIsInvalid", {
        /**
         * Class that should be added to the row when the row should show as having an
         * error.
         */
        get: function () {
            return !!(this.relativeStorage.has() && this.relativeStorage.shouldShowError());
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableRowComponent.prototype, "_classIsWarning", {
        /**
         * Class that should be added to the row when the row should show as having a
         * warning.
         */
        get: function () {
            return !!(this.relativeStorage.has() && this.relativeStorage.shouldShowWarning());
        },
        enumerable: true,
        configurable: true
    });
    TableRowComponent.prototype.ngOnInit = function () {
        _super.prototype.ngOnInit.call(this);
        // Table rows must be children of tables
        if (!(this.parentPathBasedComponent instanceof TableComponent)) {
            throw pathError(this.path, 'This component must be a child of a `TableComponent`');
        }
    };
    /**
     * Sets the row's selection status.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    TableRowComponent.prototype.setSelectedStatus = function (selectedStatus) {
        this.parentPathBasedComponent.setRowSelectedStatus(this.relativeStorage.currentId, selectedStatus);
    };
    /**
     * Sets the row selection status of all rows from the last row that has had
     * its selection status set to this row.
     * @param selectedStatus `true` to set selected, `false` to set unselected.
     */
    TableRowComponent.prototype.setSelectedStatusFromLastSelected = function (selectedStatus) {
        this.parentPathBasedComponent.setRowSelectedStatusFromLastSelected(this.relativeStorage.currentId, selectedStatus);
    };
    /**
     * Action to run when the selection checkbox label is clicked: added as a fix
     * for Firefox, where `shift+click` on the label won't trigger a click on the
     * `input`; as such we manually call the event.
     * @param event Click event.
     * @param checkboxElement Element on which the even should be called instead.
     */
    TableRowComponent.prototype._onLabelClick = function (event, checkboxElement) {
        this._onSelectionCheckboxClick(event);
        checkboxElement.focus();
        event.preventDefault();
    };
    /**
     * Action to run when the selection checkbox is clicked.
     * @param event Click event.
     */
    TableRowComponent.prototype._onSelectionCheckboxClick = function (event) {
        if (event.shiftKey) {
            this.setSelectedStatusFromLastSelected(!this.isSelected);
        }
        else {
            this.setSelectedStatus(!this.isSelected);
        }
        event.stopPropagation(); // Don't call the label event
    };
    var TableRowComponent_1;
    TableRowComponent.ctorParameters = function () { return [
        { type: TableComponent, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        computed
    ], TableRowComponent.prototype, "allowsRemoval", null);
    __decorate([
        computed,
        HostBinding('class.is-selected')
    ], TableRowComponent.prototype, "isSelected", null);
    __decorate([
        computed,
        HostBinding('class.is-invalid')
    ], TableRowComponent.prototype, "_classIsInvalid", null);
    __decorate([
        computed,
        HostBinding('class.is-warning')
    ], TableRowComponent.prototype, "_classIsWarning", null);
    TableRowComponent = TableRowComponent_1 = __decorate([
        Component({
            // tslint:disable-next-line: component-selector
            selector: 'tr[lf-table-row]',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: TableRowComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"relativeStorage.has()\">\n    <!-- Cell used to hold a checkbox that marks the row as selected -->\n    <td lf-table-cell *ngIf=\"allowsRemoval\" class=\"table-cell-select\">\n      <label\n        class=\"custom-control custom-checkbox\"\n        (click)=\"_onLabelClick($event, checkboxElement)\"\n      >\n        <input\n          #checkboxElement\n          type=\"checkbox\"\n          class=\"custom-control-input\"\n          [checked]=\"isSelected\"\n          (click)=\"_onSelectionCheckboxClick($event)\"\n        />\n        <span class=\"custom-control-label\"></span>\n      </label>\n    </td>\n    <!-- User defined cells -->\n    <ng-content select=\"th[lf-table-cell], td[lf-table-cell]\"></ng-content>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], TableRowComponent);
    return TableRowComponent;
}(Value));

/**
 * Component used for editing a "single line" LF string.
 */
var TextComponent = /** @class */ (function (_super) {
    __extends(TextComponent, _super);
    function TextComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        return _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
    }
    Object.defineProperty(TextComponent.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            var minLength = this.relativeStorage.getStateProperty('.', 'minLength');
            return minLength !== undefined && minLength > 0;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Action to run on every `input` event of the text input.
     * @param evt `input` event.
     */
    TextComponent.prototype._onInput = function (evt) {
        this.relativeStorage.set('.', evt.target.value);
        this.relativeStorage.setDirty();
    };
    TextComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isStringSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "string" type and not "nullable"');
        }
    };
    TextComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        computed
    ], TextComponent.prototype, "showIsRequired", null);
    __decorate([
        action
    ], TextComponent.prototype, "_onInput", null);
    TextComponent = __decorate([
        Component({
            selector: 'lf-text',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Input -->\n      <input\n        #focusTarget\n        type=\"text\"\n        class=\"form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [name]=\"path\"\n        [value]=\"relativeStorage.get()\"\n        [attr.minLength]=\"relativeStorage.getStateProperty('.', 'minLength')\"\n        [attr.maxLength]=\"relativeStorage.getStateProperty('.', 'maxLength')\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (input)=\"_onInput($event)\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      />\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], TextComponent);
    return TextComponent;
}(InlineValue));

/**
 * Component used for editing a "multiple lines" LF string.
 */
var TextareaComponent = /** @class */ (function (_super) {
    __extends(TextareaComponent, _super);
    function TextareaComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n, lfRouter) || this;
        /**
         * Initial height of the textarea (CSS measurement string).
         */
        _this.initialHeight = '6rem';
        return _this;
    }
    Object.defineProperty(TextareaComponent.prototype, "showIsRequired", {
        /**
         * Whether to show the "is required" icon on the component.
         */
        get: function () {
            var minLength = this.relativeStorage.getStateProperty('.', 'minLength');
            return minLength !== undefined && minLength > 0;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Action to run on every `input` event of the textarea input.
     * @param evt `input` event.
     */
    TextareaComponent.prototype._onInput = function (evt) {
        this.relativeStorage.set('.', evt.target.value);
        this.relativeStorage.setDirty();
    };
    TextareaComponent.prototype.validatePath = function () {
        var schema = this.relativeStorage.schema();
        if (!isStringSchema(schema) || isNullableSchema(schema)) {
            throw pathError(this.path, 'Schema must be of the "string" type and not "nullable"');
        }
    };
    TextareaComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter, decorators: [{ type: Optional }, { type: Inject, args: [LfRouter,] }] }
    ]; };
    __decorate([
        Input()
    ], TextareaComponent.prototype, "initialHeight", void 0);
    __decorate([
        computed
    ], TextareaComponent.prototype, "showIsRequired", null);
    __decorate([
        action
    ], TextareaComponent.prototype, "_onInput", null);
    TextareaComponent = __decorate([
        Component({
            selector: 'lf-textarea',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"shouldDisplay\">\n    <!-- Label -->\n    <span *ngIf=\"label\" class=\"label\">{{ label }}</span>\n    <lf-help-tooltip *ngIf=\"helpMessage\" [help]=\"helpMessage\"></lf-help-tooltip>\n\n    <!-- Required icon -->\n    <lf-icon\n      class=\"is-required\"\n      icon=\"asterisk\"\n      *ngIf=\"showIsRequired && !isReadOnly\"\n    ></lf-icon>\n\n    <!-- Pending validation -->\n    <div\n      class=\"status pending\"\n      *ngIf=\"relativeStorage.shouldShowPending()\"\n    ></div>\n    <!-- Rejected validation -->\n    <div\n      class=\"status rejected\"\n      *ngIf=\"relativeStorage.shouldShowRejected()\"\n      (click)=\"relativeStorage.recomputeStateProperties()\"\n    >\n      <lf-tooltip [help]=\"retryValidateText\">\n        <lf-icon icon=\"warning\"></lf-icon>\n      </lf-tooltip>\n    </div>\n\n    <!-- (Debug) value state -->\n    <lf-value-state [path]=\"path\"></lf-value-state>\n\n    <!-- Input group -->\n    <div\n      class=\"input-group input-group-sm\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Code -->\n      <div *ngIf=\"code\" class=\"input-group-prepend\">\n        <div class=\"input-group-text\">{{ code }}</div>\n      </div>\n\n      <!-- Textarea -->\n      <textarea\n        #focusTarget\n        type=\"text\"\n        class=\"form-control\"\n        [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n        [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n        [class.is-readonly]=\"isReadOnly\"\n        [style.height]=\"initialHeight\"\n        [name]=\"path\"\n        [value]=\"relativeStorage.get()\"\n        [attr.minLength]=\"relativeStorage.getStateProperty('.', 'minLength')\"\n        [attr.maxLength]=\"relativeStorage.getStateProperty('.', 'maxLength')\"\n        [readonly]=\"isReadOnly\"\n        autocomplete=\"off\"\n        (input)=\"_onInput($event)\"\n        (focus)=\"_onFocus($event)\"\n        (blur)=\"_onBlur($event)\"\n      ></textarea>\n    </div>\n\n    <!-- Legend -->\n    <div *ngIf=\"legend\" class=\"legend\">{{ legend }}</div>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased)),
        __param(3, Optional()),
        __param(3, Inject(LfRouter))
    ], TextareaComponent);
    return TextareaComponent;
}(InlineValue));

/**
 * Lf tooltip component.
 */
var TooltipComponent = /** @class */ (function () {
    function TooltipComponent() {
        this.placement = 'top';
        this.delay = 0;
    }
    __decorate([
        Input()
    ], TooltipComponent.prototype, "help", void 0);
    __decorate([
        Input()
    ], TooltipComponent.prototype, "placement", void 0);
    __decorate([
        Input()
    ], TooltipComponent.prototype, "delay", void 0);
    TooltipComponent = __decorate([
        Component({
            selector: 'lf-tooltip',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<ng-container *mobxAutorun>\n  <span [tooltip]=\"help\" [placement]=\"placement\" [delay]=\"delay\">\n    <ng-content></ng-content>\n  </span>\n</ng-container>\n"
        })
    ], TooltipComponent);
    return TooltipComponent;
}());

/**
 * Entry for an item of the tree-nav.
 */
var TreeEntryComponent = /** @class */ (function (_super) {
    __extends(TreeEntryComponent, _super);
    function TreeEntryComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.lfRouter = lfRouter;
        /**
         * Whether this tree-entry is to be displayed as the root one (in which case
         * its label isn't shown anywhere and its children are displayed one after the
         * other). The entry can be displayed as root only when its schema is complex.
         * A button is displayed at the end of the list when there are optional values
         * to be added or to add a new element in case the schema is a list.
         */
        _this.displayAsRoot = true;
        return _this;
    }
    TreeEntryComponent_1 = TreeEntryComponent;
    Object.defineProperty(TreeEntryComponent.prototype, "label", {
        /**
         * Label associated with this value.
         */
        get: function () {
            var label = this.translate(I18N_VALUE_LABEL_KEY);
            return label === undefined
                ? this.relativeStorage.currentPath === '/'
                    ? '/'
                    : this.relativeStorage.currentId
                : label;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "retryValidateText", {
        /**
         * Message used to ask the user to retry validating the value.
         */
        get: function () {
            return this.translate(I18N_VALUE_RETRY_VALIDATE_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "addOptionalValueButtonText", {
        get: function () {
            return this.translate(I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "addValueToListButtonText", {
        get: function () {
            return this.translate(I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "matchingRoutes", {
        get: function () {
            return this.lfRouter.matchingRoutes(this.path, { navigateToParent: false });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "navigateableRoute", {
        get: function () {
            return this.lfRouter.navigateableRouteFromMatchingRoutes(this.matchingRoutes);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "url", {
        get: function () {
            return (this.navigateableRoute &&
                this.lfRouter.createUrlFromNavigateableRoute(this.navigateableRoute));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "isActive", {
        get: function () {
            return this.lfRouter.isActive(this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "isList", {
        get: function () {
            var schema = this.relativeStorage.schema();
            return isListSchema(schema) || isTableSchema(schema);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "childrenIds", {
        get: function () {
            var _this = this;
            return this.lfStorage.childrenIds(this.path).filter(function (id) {
                var path = appendToPath(_this.path, id);
                var matchingRoutes = _this.lfRouter
                    .matchingRoutes(path, { navigateToParent: false })
                    .filter(function (matchingRoute) {
                    return _this.matchingRouteComponentLevel(matchingRoute) ===
                        _this._componentLevel;
                });
                return matchingRoutes.length > 0;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "nonNullChildrenIds", {
        get: function () {
            var _this = this;
            return this.childrenIds.filter(function (id) { return _this.relativeStorage.get(id.toString()) !== null; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeEntryComponent.prototype, "nullChildrenIds", {
        get: function () {
            var _this = this;
            return this.childrenIds.filter(function (id) { return _this.relativeStorage.get(id.toString()) === null; });
        },
        enumerable: true,
        configurable: true
    });
    TreeEntryComponent.prototype.ngOnInit = function () {
        var _this = this;
        _super.prototype.ngOnInit.call(this);
        // Validate the path whenever `displayAsRoot` changes
        this.disposeOnDisplayAsRootChanges = observe(this, 'displayAsRoot', function () {
            _this.validatePath();
        });
        // Set `componentLevel` when not defined
        if (this._componentLevel === undefined) {
            this._componentLevel = this.matchingRouteComponentLevel(this.matchingRoutes[0]);
        }
    };
    TreeEntryComponent.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
        this.disposeOnDisplayAsRootChanges();
    };
    TreeEntryComponent.prototype.childLabel = function (id) {
        var childPath = appendToPath(this.path, id);
        return this.lfI18n.getFromPath(childPath, I18N_VALUE_LABEL_KEY) || id;
    };
    TreeEntryComponent.prototype.addToList = function () {
        var _a = this.lfStorage
            .pathInfo(this.path, { fetchValues: true })
            .slice(-1)[0], schema = _a.schema, value = _a.value;
        this.lfStorage.push(this.path, undefined);
        this.lfRouter.navigate(appendToPath(this.path, isListSchema(schema)
            ? value.length - 1
            : getRowId(value[value.length - 1])), { queryParamsHandling: 'merge' });
    };
    TreeEntryComponent.prototype.initializeChild = function (id) {
        this.relativeStorage.initialize(id);
        this.lfRouter.navigate(appendToPath(this.path, id), {
            queryParamsHandling: 'merge'
        });
    };
    TreeEntryComponent.prototype.validatePath = function () {
        if (this.matchingRoutes.length === 0) {
            throw pathError(this.path, 'The path or one of its children must have an associated route');
        }
        var schema = this.relativeStorage.schema();
        if (this.displayAsRoot && !isComplexSchema(schema)) {
            throw pathError(this.path, 'Schema must be complex to display the entry as "root"');
        }
    };
    /**
     * The "component" level of the provided matching route (basically the number
     * of outlets used by the route).
     * @param matchingRoute Matching of a route with a provided path.
     * @returns Component level for the matching route.
     */
    TreeEntryComponent.prototype.matchingRouteComponentLevel = function (matchingRoute) {
        return matchingRoute.routes.reduce(function (level, route) {
            return level + (route.component || route.redirectTo !== undefined ? 1 : 0);
        }, 0);
    };
    var TreeEntryComponent_1;
    TreeEntryComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter }
    ]; };
    __decorate([
        observable,
        Input()
    ], TreeEntryComponent.prototype, "displayAsRoot", void 0);
    __decorate([
        Input()
    ], TreeEntryComponent.prototype, "_componentLevel", void 0);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "label", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "retryValidateText", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "addOptionalValueButtonText", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "addValueToListButtonText", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "matchingRoutes", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "navigateableRoute", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "url", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "isActive", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "isList", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "childrenIds", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "nonNullChildrenIds", null);
    __decorate([
        computed
    ], TreeEntryComponent.prototype, "nullChildrenIds", null);
    __decorate([
        action
    ], TreeEntryComponent.prototype, "addToList", null);
    __decorate([
        action
    ], TreeEntryComponent.prototype, "initializeChild", null);
    TreeEntryComponent = TreeEntryComponent_1 = __decorate([
        Component({
            selector: 'lf-tree-entry',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: TreeEntryComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <ng-container *ngIf=\"relativeStorage.has() && relativeStorage.get() !== null\">\n    <!-- Root entry (only show children) -->\n    <ng-container *ngIf=\"displayAsRoot\">\n      <!-- Children -->\n      <ng-container [ngTemplateOutlet]=\"childrenTemplate\"></ng-container>\n\n      <!-- Action at the bottom (with label) -->\n      <ng-container\n        [ngTemplateOutlet]=\"actionsTemplate\"\n        [ngTemplateOutletContext]=\"{\n          addOptionalValueButtonText: addOptionalValueButtonText,\n          addValueToListButtonText: addValueToListButtonText\n        }\"\n      ></ng-container>\n    </ng-container>\n\n    <!-- Non-root entry (show entry + children) -->\n    <div\n      *ngIf=\"!displayAsRoot\"\n      [ngClass]=\"{ 'nav-item': true, active: isActive }\"\n      [class.is-warning]=\"relativeStorage.shouldShowWarning()\"\n      [class.is-invalid]=\"relativeStorage.shouldShowError()\"\n    >\n      <!-- Item content -->\n      <div class=\"item-content\">\n        <!-- Icon + label (either in link form or not, depending on whether a\n             link is available) -->\n        <a\n          *ngIf=\"url\"\n          class=\"nav-link\"\n          [routerLink]=\"url\"\n          queryParamsHandling=\"merge\"\n        >\n          <ng-container [ngTemplateOutlet]=\"linkTemplate\"></ng-container>\n        </a>\n        <div *ngIf=\"!url\" class=\"nav-link is-disabled\">\n          <ng-container [ngTemplateOutlet]=\"linkTemplate\"></ng-container>\n        </div>\n\n        <!-- Pending validation -->\n        <div\n          class=\"status pending\"\n          *ngIf=\"relativeStorage.shouldShowPending()\"\n        ></div>\n        <!-- Rejected validation -->\n        <div\n          class=\"status rejected\"\n          *ngIf=\"relativeStorage.shouldShowRejected()\"\n          (click)=\"relativeStorage.recomputeStateProperties()\"\n        >\n          <lf-tooltip [help]=\"retryValidateText\">\n            <lf-icon icon=\"warning\"></lf-icon>\n          </lf-tooltip>\n        </div>\n\n        <!-- Actions -->\n        <ng-container\n          [ngTemplateOutlet]=\"actionsTemplate\"\n          [ngTemplateOutletContext]=\"{ alignRight: true }\"\n        ></ng-container>\n      </div>\n\n      <!-- Children -->\n      <ng-container\n        *ngIf=\"isActive\"\n        [ngTemplateOutlet]=\"childrenTemplate\"\n      ></ng-container>\n    </div>\n  </ng-container>\n</ng-container>\n\n<ng-template #linkTemplate>\n  <!-- Icon for items with sub-items, either \"v\" or \">\" or bars for lists -->\n  <span *ngIf=\"isList || nonNullChildrenIds.length > 0\" class=\"item-icon\">\n    <lf-icon\n      [icon]=\"isList ? 'bars' : isActive ? 'angle-down' : 'angle-right'\"\n      [fixedWidth]=\"true\"\n    >\n    </lf-icon>\n  </span>\n\n  <!-- Entry label -->\n  <div class=\"item-label\">{{ label }}</div>\n</ng-template>\n\n<!-- Template to show all children -->\n<ng-template #childrenTemplate>\n  <!-- Children -->\n  <ng-container *ngFor=\"let id of nonNullChildrenIds\">\n    <nav class=\"nav flex-column\">\n      <lf-tree-entry\n        [path]=\"id\"\n        [displayAsRoot]=\"false\"\n        [_componentLevel]=\"_componentLevel\"\n      ></lf-tree-entry>\n    </nav>\n  </ng-container>\n</ng-template>\n\n<!-- Template to show the item's action (if appropriate), either a button to add\n     a new element to the list, or a menu to add an optional value; possibly,\n     each action may be labelled and the menu aligned to the right -->\n<ng-template\n  #actionsTemplate\n  let-addOptionalText=\"addOptionalValueButtonText\"\n  let-addToListText=\"addValueToListButtonText\"\n  let-alignRight=\"alignRight\"\n>\n  <!-- Add optional value -->\n  <div *ngIf=\"!isList && nullChildrenIds.length > 0\" class=\"value-add\">\n    <lf-dropdown>\n      <button\n        lf-button\n        [style]=\"'outline-secondary'\"\n        size=\"sm\"\n        [dropdownToggle]=\"true\"\n        [block]=\"true\"\n      >\n        <lf-icon icon=\"plus-circle\"></lf-icon> {{ addOptionalText }}\n      </button>\n      <!-- Align to the right when not -->\n      <lf-dropdown-menu [alignRight]=\"alignRight\">\n        <button\n          lf-dropdown-item\n          *ngFor=\"let id of nullChildrenIds\"\n          (click)=\"initializeChild(id)\"\n        >\n          {{ childLabel(id) }}\n        </button>\n      </lf-dropdown-menu>\n    </lf-dropdown>\n  </div>\n\n  <!-- Add value to list -->\n  <div *ngIf=\"isList\" class=\"value-add\">\n    <button\n      lf-button\n      [style]=\"'outline-secondary'\"\n      [isDisabled]=\"\n        relativeStorage.size() >=\n        relativeStorage.getStateProperty('.', 'maxSize')\n      \"\n      size=\"sm\"\n      (click)=\"addToList()\"\n    >\n      <lf-icon icon=\"plus-circle\"></lf-icon> {{ addToListText }}\n    </button>\n  </div>\n</ng-template>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], TreeEntryComponent);
    return TreeEntryComponent;
}(PathBased));

/**
 * Component used to show a tree to navigate between values.
 */
var TreeNavComponent = /** @class */ (function (_super) {
    __extends(TreeNavComponent, _super);
    function TreeNavComponent(parentPathBasedComponent, lfStorage, lfI18n, lfRouter) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.lfRouter = lfRouter;
        return _this;
    }
    TreeNavComponent_1 = TreeNavComponent;
    Object.defineProperty(TreeNavComponent.prototype, "_hasRoutes", {
        get: function () {
            return (this.lfRouter.matchingRoutes(this.path, { navigateToParent: false })
                .length > 0);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Hide the tree-nav.
     */
    TreeNavComponent.prototype.hideTreeNav = function () {
        this.parentPathBasedComponent.hideTreeNav();
    };
    var TreeNavComponent_1;
    TreeNavComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: SkipSelf }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter }
    ]; };
    __decorate([
        computed
    ], TreeNavComponent.prototype, "_hasRoutes", null);
    TreeNavComponent = TreeNavComponent_1 = __decorate([
        Component({
            selector: 'lf-tree-nav',
            changeDetection: ChangeDetectionStrategy.OnPush,
            providers: [{ provide: PathBased, useExisting: TreeNavComponent_1 }],
            template: "<ng-container *mobxAutorun>\n  <nav class=\"nav flex-column\" role=\"navigation\">\n    <!-- Small screen: hide tree-nav button -->\n    <div class=\"tree-nav-actions d-md-none\">\n      <button class=\"tree-nav-hide close\" (click)=\"hideTreeNav()\">\n        &times;\n      </button>\n    </div>\n\n    <!-- Recursively render tree entries -->\n    <lf-tree-entry *ngIf=\"_hasRoutes\" [path]=\"path\"></lf-tree-entry>\n  </nav>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, SkipSelf()),
        __param(0, Inject(PathBased))
    ], TreeNavComponent);
    return TreeNavComponent;
}(PathBased));

/**
 * Component used to debug information about the state of a value.
 */
var ValueStateComponent = /** @class */ (function (_super) {
    __extends(ValueStateComponent, _super);
    function ValueStateComponent(parentPathBasedComponent, lfStorage, lfI18n) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        /**
         * Whether the application is in production mode.
         */
        _this.inProduction = process.env.NODE_ENV === 'production';
        return _this;
    }
    Object.defineProperty(ValueStateComponent.prototype, "stateProperties", {
        /**
         * State properties where each "promise" is transformed into an object for
         * easier rendering as a JSON. Also hides the `$mobx` property.
         */
        get: function () {
            var schema = this.relativeStorage.schema();
            var state = this.relativeStorage.getState();
            var value = this.relativeStorage.get();
            return Array.from(Object.keys(state.props)).reduce(function (obj, prop) {
                var propValue = null;
                // When the value is `null`, other validations shouldn't be executed
                if (value !== null ||
                    !isReservedStateProp(schema, prop) ||
                    prop === 'isRequired' ||
                    prop === 'validationIssues') {
                    propValue = getStateProperty(schema, state, prop);
                    if (isPromiseBasedObservable(propValue)) {
                        var res = propValue.value;
                        propValue = {
                            isPromise: true,
                            state: propValue.state,
                            value: res instanceof Error ? "Error(" + res.message + ")" : res
                        };
                    }
                }
                obj[prop] = propValue;
                return obj;
            }, {});
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValueStateComponent.prototype, "hasAsyncProperties", {
        /**
         * Whether the state properties contain at least one async property.
         */
        get: function () {
            var props = this.stateProperties;
            return Object.keys(props).some(function (prop) {
                var val = props[prop];
                return typeof val === 'object' && val && val.isPromise;
            });
        },
        enumerable: true,
        configurable: true
    });
    ValueStateComponent.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n }
    ]; };
    __decorate([
        computed
    ], ValueStateComponent.prototype, "stateProperties", null);
    __decorate([
        computed
    ], ValueStateComponent.prototype, "hasAsyncProperties", null);
    ValueStateComponent = __decorate([
        Component({
            selector: 'lf-value-state',
            changeDetection: ChangeDetectionStrategy.OnPush,
            template: "<!-- Show state properties when not in production -->\n<ng-container *ngIf=\"!inProduction\">\n  <ng-container *mobxAutorun>\n    <ng-container *ngIf=\"relativeStorage.has()\">\n      <!-- Icon/button used to toggle the state properties modal -->\n      <lf-icon class=\"value-state-icon\" icon=\"bug\" (click)=\"stateModal.show()\">\n      </lf-icon>\n\n      <!-- Modal displayed the path's information -->\n      <lf-modal #stateModal size=\"lg\">\n        <lf-modal-header>\n          <code>{{ path }}</code>\n        </lf-modal-header>\n        <lf-modal-body>\n          <h6>Value:</h6>\n          <pre>{{ relativeStorage.get() | json }}</pre>\n          <h6>State properties:</h6>\n          <pre>{{ stateProperties | json }}</pre>\n        </lf-modal-body>\n        <lf-modal-footer *ngIf=\"hasAsyncProperties\">\n          <button\n            lf-button\n            [style]=\"'outline-secondary'\"\n            size=\"sm\"\n            (click)=\"relativeStorage.recomputeStateProperties('.', true)\"\n          >\n            Recompute promises\n          </button>\n        </lf-modal-footer>\n      </lf-modal>\n    </ng-container>\n  </ng-container>\n</ng-container>\n"
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased))
    ], ValueStateComponent);
    return ValueStateComponent;
}(PathBased));

/**
 * Protocol prefix used for LF links.
 */
var LF_URL_PROTOCOL = 'lf://';
/**
 * Validation message directive.
 */
var ValidationIssueDirective = /** @class */ (function (_super) {
    __extends(ValidationIssueDirective, _super);
    function ValidationIssueDirective(parentPathBasedComponent, lfStorage, lfI18n, lfRouter, router, markdownService) {
        var _this = _super.call(this, parentPathBasedComponent, lfStorage, lfI18n) || this;
        _this.lfRouter = lfRouter;
        _this.router = router;
        _this.markdownService = markdownService;
        return _this;
    }
    Object.defineProperty(ValidationIssueDirective.prototype, "issueMessageHTML", {
        /**
         * HTML string with the issue message to display.
         */
        get: function () {
            // Value as obtained from the i18n file
            var i18nValue = this.lfI18n.getFromPath(this.path, I18N_VALIDATIONS_KEY + "." + this.issue.code, { callFunctionWithContext: false });
            // Obtain markdown message from the value
            return this.markdownService.compile(typeof i18nValue === 'function'
                ? i18nValue(this.lfStorage.relativeStorage(this.path), this.issue.data)
                : i18nValue != null
                    ? i18nValue
                    : this.issue.code);
        },
        enumerable: true,
        configurable: true
    });
    ValidationIssueDirective.prototype.ngOnInit = function () {
        var _this = this;
        var renderer = this.markdownService.renderer;
        var originalLink = renderer.link;
        this.markdownService.renderer.link = function (href, title, text) {
            // Replace links with the "LF protocol" with the appropriate paths
            if (href && href.startsWith(LF_URL_PROTOCOL)) {
                var path = resolvePath(_this.path, href.slice(LF_URL_PROTOCOL.length));
                var route = _this.lfRouter.navigateableRoute(path);
                if (href === text) {
                    text = _this.labelOf(path);
                }
                href = route && _this.lfRouter.createUrlFromNavigateableRoute(route);
            }
            var anchor = originalLink.call(renderer, href, title, text);
            return anchor.replace('<a', '<a class="lfPathLink"');
        };
        _super.prototype.ngOnInit.call(this);
    };
    // Intercept clicks on links with class `lfPathLink` to use the router.
    // Adapted from Angular's `routerLink` implementation.
    ValidationIssueDirective.prototype._onClick = function (target, button, ctrlKey, metaKey, shiftKey) {
        if (button !== 0 ||
            ctrlKey ||
            metaKey ||
            shiftKey ||
            !target.classList.contains('lfPathLink')) {
            return true;
        }
        this.router.navigateByUrl(target.getAttribute('href'), {
            queryParamsHandling: 'merge'
        });
        return false;
    };
    /**
     * Label associated with the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    ValidationIssueDirective.prototype.labelOf = function (path) {
        return this.lfI18n.getFromPath(path, I18N_VALUE_LABEL_KEY) || path;
    };
    ValidationIssueDirective.ctorParameters = function () { return [
        { type: PathBased, decorators: [{ type: Optional }, { type: Inject, args: [PathBased,] }] },
        { type: LfStorage },
        { type: LfI18n },
        { type: LfRouter },
        { type: Router },
        { type: MarkdownService }
    ]; };
    __decorate([
        observable,
        Input()
    ], ValidationIssueDirective.prototype, "issue", void 0);
    __decorate([
        computed,
        HostBinding('innerHTML')
    ], ValidationIssueDirective.prototype, "issueMessageHTML", null);
    __decorate([
        HostListener('click', [
            '$event.target',
            '$event.button',
            '$event.ctrlKey',
            '$event.metaKey',
            '$event.shiftKey'
        ])
    ], ValidationIssueDirective.prototype, "_onClick", null);
    ValidationIssueDirective = __decorate([
        Directive({
            selector: 'lf-validation-issue, [lfValidationIssue]',
            exportAs: 'lfValidationIssue'
        }),
        __param(0, Optional()),
        __param(0, Inject(PathBased))
    ], ValidationIssueDirective);
    return ValidationIssueDirective;
}(PathBased));

/**
 * Exported/declared components and directives.
 */
var DECLARATIONS = [
    ActionsMenuComponent,
    AlertComponent,
    AppComponent,
    ButtonComponent,
    CardComponent,
    CardContentComponent,
    CheckboxComponent,
    CheckboxGroupComponent,
    DateComponent,
    DateRangeComponent,
    DropdownComponent,
    DropdownItemComponent,
    DropdownMenuComponent,
    FileComponent,
    FormComponent,
    HelpTooltipComponent,
    IconComponent,
    ModalBodyComponent,
    ModalComponent,
    ModalFooterComponent,
    ModalHeaderComponent,
    NumberComponent,
    RadioComponent,
    SelectComponent,
    TableCellComponent,
    TableComponent,
    TableRowComponent,
    TextareaComponent,
    TextComponent,
    TooltipComponent,
    TopBarComponent,
    TreeEntryComponent,
    TreeNavComponent,
    ValidationIssueDirective,
    ValidationPanelComponent,
    ValueStateComponent
];
/**
 * LF Bootstrap theme module.
 */
var LfBootstrapThemeModule = /** @class */ (function () {
    function LfBootstrapThemeModule() {
    }
    LfBootstrapThemeModule = __decorate([
        NgModule({
            imports: [
                BrowserAnimationsModule,
                CommonModule,
                RouterModule.forChild([]),
                BsDatepickerModule.forRoot(),
                LfCoreModule,
                LfTableHeaderModule,
                MarkdownModule.forRoot(),
                MobxAngularModule,
                ScrollingModule,
                TooltipModule.forRoot()
            ],
            declarations: DECLARATIONS,
            exports: __spread([
                LfCoreModule,
                LfTableHeaderModule,
                MobxAngularModule
            ], DECLARATIONS)
        })
    ], LfBootstrapThemeModule);
    return LfBootstrapThemeModule;
}());
/**
 * Theme services that should be provided for each provided `LF_APP_SCHEMA`.
 * Currently empty, reserved for future use.
 */
var LF_BOOTSTRAP_THEME_SERVICES = [];

var _a, _b;
/**
 * Default english translations for Bootstrap theme strings.
 */
var I18N_EN_US = {
    '*': (_a = {},
        // App
        _a[I18N_BS_LOCALE_KEY] = 'en',
        // Unload alert service
        _a[I18N_UNLOAD_ALERT_MESSAGE_KEY] = 'Are you sure you want to leave? Changes that you made may not be saved.',
        // Value
        _a[I18N_VALUE_RETRY_VALIDATE_TEXT_KEY] = 'Retry validation',
        // Tree-nav
        _a[I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY] = 'Add',
        _a[I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY] = 'Add',
        // Closeable
        _a[I18N_CLOSE_BUTTON_TOOLTIP_KEY] = 'Close',
        // Actions-menu
        _a[I18N_ACTIONS_MENU_BUTTON_TEXT_KEY] = 'Actions',
        // Validation panel
        _a[I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY] = 'Errors:',
        _a[I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY] = 'Warnings:',
        _a[I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY] = 'Everything looks great!',
        _a[I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY] = 'Focus field',
        _a[I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY] = 'Next field',
        _a[I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY] = 'Previous field',
        // Form
        _a[I18N_FORM_HELP_ACTION_TEXT_KEY] = 'Help',
        _a[I18N_FORM_REMOVE_ACTION_TEXT_KEY] = 'Remove',
        _a[I18N_FORM_ENSURE_REMOVE_TEXT_KEY] = 'Please confirm that you wish to remove this form.',
        _a[I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY] = 'Cancel',
        _a[I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY] = 'Confirm',
        // Date
        _a[I18N_DATE_FORMAT_KEY] = 'M/D/YYYY',
        _a[I18N_DATE_PLACEHOLDER_KEY] = 'm/d/yyyy',
        // Date-range
        _a[I18N_DATE_RANGE_SEPARATOR_KEY] = ' - ',
        // File
        _a[I18N_FILE_CHOOSE_PLACEHOLDER_KEY] = 'Choose file',
        _a[I18N_FILE_BROWSE_TEXT_KEY] = 'Browse',
        _a[I18N_FILE_NONE_CHOSEN_KEY] = 'No file chosen',
        _a[I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY] = 'Clear',
        // Number
        _a[I18N_NUMBER_DECIMAL_SEPARATOR_KEY] = '.',
        _a[I18N_NUMBER_THOUSANDS_SEPARATOR_KEY] = '',
        // Table
        _a[I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY] = 'Add row',
        _a[I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY] = 'Remove rows',
        _a[I18N_TABLE_NO_ROWS_TEXT_KEY] = 'No rows to display.',
        // Selection
        _a[I18N_SELECTION_NO_OPTIONS_TEXT_KEY] = 'No options available.',
        // Validations
        _a[I18N_VALIDATIONS_KEY] = (_b = {},
            _b[IS_REJECTED_CODE] = 'An error occurred validating this field.',
            _b[IS_REQUIRED_CODE] = 'The field is required.',
            _b[DISALLOWED_VALUE_CODE] = function (ctx, _a) {
                var allowedValues = _a.allowedValues;
                if (isBooleanSchema(ctx.schema()) && allowedValues.length === 1) {
                    return "The field must" + (allowedValues[0] === true ? '' : ' not') + " be ticked.";
                }
                return "The field's value must be one of: " + allowedValues.join(', ') + ".";
            },
            _b[DATE_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var minDate = _a.minDate, maxDate = _a.maxDate;
                // TODO: Format date properly
                return maxDate === undefined
                    ? "The date mustn't be before " + minDate + "."
                    : minDate === undefined
                        ? "The date mustn't be after " + maxDate + "."
                        : "The date must be between " + minDate + " and " + maxDate + ".";
            },
            _b[SIZE_OUT_OF_BOUNDS_CODE] = function (ctx, _a) {
                var size = _a.size, minSize = _a.minSize, maxSize = _a.maxSize;
                if (size === 0 && minSize > 0) {
                    return 'The field is required.';
                }
                // Checkbox group
                if (ctx.hasStateProperty('.', "i18n(" + I18N_SELECTION_OPTIONS_KEY + ")")) {
                    return maxSize === undefined
                        ? "A minimum of " + +minSize + " option" + (+minSize === 1 ? '' : 's') + " must be selected."
                        : minSize === undefined
                            ? "A maximum of " + +maxSize + " option" + (+maxSize === 1 ? '' : 's') + " must be selected."
                            : maxSize === minSize
                                ? +maxSize + " option" + (+maxSize === 1 ? '' : 's') + " must be selected."
                                : "Between " + +minSize + " and " + +maxSize + " options must be selected.";
                }
                // Tables and form-lists
                return maxSize === undefined
                    ? "The collection must have at least " + +minSize + " element" + (+minSize === 1 ? '' : 's') + "."
                    : minSize === undefined
                        ? "The collection must have no more than " + +maxSize + " element" + (+maxSize === 1 ? '' : 's') + "."
                        : maxSize === minSize
                            ? "The collection must have " + +maxSize + " element" + (+maxSize === 1 ? '' : 's') + "."
                            : "The collection must have between " + +minSize + " and " + +maxSize + " " +
                                'elements.';
            },
            _b[NUMBER_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var min = _a.min, max = _a.max;
                return max === undefined
                    ? "The value mustn't be lesser than " + +min + "."
                    : min === undefined
                        ? "The value mustn't be greater than " + +max + "."
                        : "The value must be between " + +min + " and " + +max + ".";
            },
            _b[LENGTH_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var length = _a.length, minLength = _a.minLength, maxLength = _a.maxLength;
                if (length === 0 && minLength > 0) {
                    return 'The field is required.';
                }
                return maxLength === undefined
                    ? "The value must have at least " + +minLength + " character" + (+minLength === 1 ? '' : 's') + "."
                    : minLength === undefined
                        ? "The value must have at most " + +maxLength + " character" + (+maxLength === 1 ? '' : 's') + "."
                        : maxLength === minLength
                            ? "The value must have " + +maxLength + " character" + (+maxLength === 1 ? '' : 's') + "."
                            : "The value must have " + +minLength + " to " + +maxLength + " characters.";
            },
            _b),
        _a)
};

var _a$1, _b$1;
// Define `es` locale
defineLocale('es', esLocale);
/**
 * Default spanish translations for Bootstrap theme strings.
 */
var I18N_ES_ES = {
    '*': (_a$1 = {},
        // App
        _a$1[I18N_BS_LOCALE_KEY] = 'es',
        // Unload alert service
        _a$1[I18N_UNLOAD_ALERT_MESSAGE_KEY] = 'Estás seguro que quieres irte? Es posible que los cambios realizados no se guarden.',
        // Value
        _a$1[I18N_VALUE_RETRY_VALIDATE_TEXT_KEY] = 'Reintentar la validación',
        // Tree-nav
        _a$1[I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY] = 'Añadir',
        _a$1[I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY] = 'Añadir',
        // Actions-menu
        _a$1[I18N_ACTIONS_MENU_BUTTON_TEXT_KEY] = 'Comportamiento',
        // Closeable
        _a$1[I18N_CLOSE_BUTTON_TOOLTIP_KEY] = 'Cerrar',
        // Validation panel
        _a$1[I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY] = 'Errores:',
        _a$1[I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY] = 'Advertencias:',
        _a$1[I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY] = '¡Todo parece genial!',
        _a$1[I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY] = 'Seleccionar campo',
        _a$1[I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY] = 'Siguiente campo',
        _a$1[I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY] = 'Campo anterior',
        // Form
        _a$1[I18N_FORM_HELP_ACTION_TEXT_KEY] = 'Ayuda',
        _a$1[I18N_FORM_REMOVE_ACTION_TEXT_KEY] = 'Eliminar',
        _a$1[I18N_FORM_ENSURE_REMOVE_TEXT_KEY] = 'Confirme que desea eliminar este formulario.',
        _a$1[I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY] = 'Cancelar',
        _a$1[I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY] = 'Confirmar',
        // Date
        _a$1[I18N_DATE_FORMAT_KEY] = 'DD/MM/YYYY',
        _a$1[I18N_DATE_PLACEHOLDER_KEY] = 'dd/mm/aaaa',
        // Date-range
        _a$1[I18N_DATE_RANGE_SEPARATOR_KEY] = ' - ',
        // File
        _a$1[I18N_FILE_CHOOSE_PLACEHOLDER_KEY] = 'Elija el archivo',
        _a$1[I18N_FILE_BROWSE_TEXT_KEY] = 'Buscar',
        _a$1[I18N_FILE_NONE_CHOSEN_KEY] = 'Ningún archivo elegido',
        _a$1[I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY] = 'Limpiar',
        // Number
        _a$1[I18N_NUMBER_DECIMAL_SEPARATOR_KEY] = ',',
        _a$1[I18N_NUMBER_THOUSANDS_SEPARATOR_KEY] = '',
        // Table
        _a$1[I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY] = 'Añadir fila',
        _a$1[I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY] = 'Eliminar filas',
        _a$1[I18N_TABLE_NO_ROWS_TEXT_KEY] = 'No hay filas para mostrar.',
        // Selection
        _a$1[I18N_SELECTION_NO_OPTIONS_TEXT_KEY] = 'No hay opciones disponibles.',
        // Validations
        _a$1[I18N_VALIDATIONS_KEY] = (_b$1 = {},
            _b$1[IS_REJECTED_CODE] = 'Se produjo un error al validar este campo.',
            _b$1[IS_REQUIRED_CODE] = 'El campo es obligatorio.',
            _b$1[DISALLOWED_VALUE_CODE] = function (ctx, _a) {
                var allowedValues = _a.allowedValues;
                if (isBooleanSchema(ctx.schema()) && allowedValues.length === 1) {
                    return "El campo" + (allowedValues[0] === true ? '' : ' no') + " debe estar marcado.";
                }
                return "El valor del campo debe ser uno de: " + allowedValues.join(', ') + ".";
            },
            _b$1[DATE_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var minDate = _a.minDate, maxDate = _a.maxDate;
                // TODO: Format date properly
                return maxDate === undefined
                    ? "La fecha no puede ser anterior al " + minDate + "."
                    : minDate === undefined
                        ? "La fecha no puede ser posterior al " + maxDate + "."
                        : "La fecha debe ser entre el " + minDate + " y el " + maxDate + ".";
            },
            _b$1[SIZE_OUT_OF_BOUNDS_CODE] = function (ctx, _a) {
                var size = _a.size, minSize = _a.minSize, maxSize = _a.maxSize;
                if (size === 0 && minSize > 0) {
                    return 'El campo es obligatorio.';
                }
                // Checkbox group
                if (ctx.hasStateProperty('.', "i18n(" + I18N_SELECTION_OPTIONS_KEY + ")")) {
                    var numOptions = function (n) { return (n === 1 ? 'una' : n === 2 ? 'dos' : n); };
                    return maxSize === undefined
                        ? "Debes seleccionar al menos " + numOptions(+minSize) + " " + (+minSize === 1 ? 'opción' : 'opciones') + "."
                        : minSize === undefined
                            ? "Debes seleccionar un m\u00E1ximo de " + numOptions(+maxSize) + " " + (+minSize === 1 ? 'opción' : 'opciones') + "."
                            : maxSize === minSize
                                ? "Debes seleccionar " + numOptions(+maxSize) + " " + (+maxSize === 1 ? 'opción' : 'opciones') + "."
                                : "Debes seleccionar entre " + numOptions(+minSize) + " y " + numOptions(+maxSize) + " opciones.";
                }
                // Tables and form-lists
                return maxSize === undefined
                    ? "La colecci\u00F3n debe tener al menos " + +minSize + " elemento" + (+minSize === 1 ? '' : 's') + "."
                    : minSize === undefined
                        ? "La colecci\u00F3n debe tener un m\u00E1ximo de " + +maxSize + " elemento" + (+maxSize === 1 ? '' : 's') + "."
                        : maxSize === minSize
                            ? "La colecci\u00F3n debe tener " + +maxSize + " elemento" + (+maxSize === 1 ? '' : 's') + "."
                            : "La colecci\u00F3n debe tener entre " + +minSize + " y " + +maxSize + " elementos.";
            },
            _b$1[NUMBER_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var min = _a.min, max = _a.max;
                return max === undefined
                    ? "El valor no puede ser inferior a " + +min + "."
                    : min === undefined
                        ? "El valor no puede ser superior a " + +max + "."
                        : "El valor debe estar entre " + +min + " y " + +max + ".";
            },
            _b$1[LENGTH_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var length = _a.length, minLength = _a.minLength, maxLength = _a.maxLength;
                if (length === 0 && minLength > 0) {
                    return 'El campo es obligatorio.';
                }
                return maxLength === undefined
                    ? "El valor debe tener al menos " + +minLength + " " + (+minLength === 1 ? 'carácter' : 'caracteres') + "."
                    : minLength === undefined
                        ? "El valor debe tener un m\u00E1ximo de " + +maxLength + " " + (+maxLength === 1 ? 'carácter' : 'caracteres') + "."
                        : maxLength === minLength
                            ? "El valor debe tener " + +maxLength + " " + (+maxLength === 1 ? 'carácter' : 'caracteres') + "."
                            : "El valor debe tener entre " + +minLength + " y " + +maxLength + " " +
                                'caracteres.';
            },
            _b$1),
        _a$1)
};

var _a$2, _b$2;
// Define `pt` locale
defineLocale('pt', ptBrLocale);
/**
 * Default portuguese translations for Bootstrap theme strings.
 */
var I18N_PT_PT = {
    '*': (_a$2 = {},
        // App
        _a$2[I18N_BS_LOCALE_KEY] = 'pt',
        // Unload alert service
        _a$2[I18N_UNLOAD_ALERT_MESSAGE_KEY] = 'Tem a certeza que pretende sair? Alterações feitas podem não estar guardadas.',
        // Value
        _a$2[I18N_VALUE_RETRY_VALIDATE_TEXT_KEY] = 'Voltar a tentar validar',
        // Tree-nav
        _a$2[I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY] = 'Adicionar',
        _a$2[I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY] = 'Adicionar',
        // Actions-menu
        _a$2[I18N_ACTIONS_MENU_BUTTON_TEXT_KEY] = 'Ações',
        // Closeable
        _a$2[I18N_CLOSE_BUTTON_TOOLTIP_KEY] = 'Fechar',
        // Validation panel
        _a$2[I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY] = 'Erros:',
        _a$2[I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY] = 'Avisos:',
        _a$2[I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY] = 'Nenhum problema a reportar!',
        _a$2[I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY] = 'Selecionar campo',
        _a$2[I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY] = 'Campo seguinte',
        _a$2[I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY] = 'Campo anterior',
        // Form
        _a$2[I18N_FORM_HELP_ACTION_TEXT_KEY] = 'Ajuda',
        _a$2[I18N_FORM_REMOVE_ACTION_TEXT_KEY] = 'Remover',
        _a$2[I18N_FORM_ENSURE_REMOVE_TEXT_KEY] = 'Por favor confirme que pretende remover este formulário.',
        _a$2[I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY] = 'Cancelar',
        _a$2[I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY] = 'Confirmar',
        // Date
        _a$2[I18N_DATE_FORMAT_KEY] = 'DD/MM/YYYY',
        _a$2[I18N_DATE_PLACEHOLDER_KEY] = 'dd/mm/aaaa',
        // Date-range
        _a$2[I18N_DATE_RANGE_SEPARATOR_KEY] = ' - ',
        // File
        _a$2[I18N_FILE_CHOOSE_PLACEHOLDER_KEY] = 'Escolher ficheiro',
        _a$2[I18N_FILE_BROWSE_TEXT_KEY] = 'Procurar',
        _a$2[I18N_FILE_NONE_CHOSEN_KEY] = 'Nenhum ficheiro escolhido',
        _a$2[I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY] = 'Limpar',
        // Number
        _a$2[I18N_NUMBER_DECIMAL_SEPARATOR_KEY] = ',',
        _a$2[I18N_NUMBER_THOUSANDS_SEPARATOR_KEY] = '',
        // Table
        _a$2[I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY] = 'Adicionar linha',
        _a$2[I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY] = 'Remover linhas',
        _a$2[I18N_TABLE_NO_ROWS_TEXT_KEY] = 'Nenhuma linha a mostrar.',
        // Selection
        _a$2[I18N_SELECTION_NO_OPTIONS_TEXT_KEY] = 'Nenhuma opção disponível.',
        // Validations
        _a$2[I18N_VALIDATIONS_KEY] = (_b$2 = {},
            _b$2[IS_REJECTED_CODE] = 'Ocorreu um erro ao validar este valor.',
            _b$2[IS_REQUIRED_CODE] = 'Campo de preenchimento obrigatório.',
            _b$2[DISALLOWED_VALUE_CODE] = function (ctx, _a) {
                var allowedValues = _a.allowedValues;
                if (isBooleanSchema(ctx.schema()) && allowedValues.length === 1) {
                    return "O campo " + (allowedValues[0] === true ? 'tem de ser' : 'não pode ser') + " marcado.";
                }
                return "O valor do campo tem de ser um de: " + allowedValues.join(', ') + ".";
            },
            _b$2[DATE_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var minDate = _a.minDate, maxDate = _a.maxDate;
                // TODO: Format date properly
                return maxDate === undefined
                    ? "A data n\u00E3o pode ser anterior a " + minDate + "."
                    : minDate === undefined
                        ? "A data n\u00E3o pode ser posterior a " + maxDate + "."
                        : "A data tem de estar entre " + minDate + " e " + maxDate + ".";
            },
            _b$2[SIZE_OUT_OF_BOUNDS_CODE] = function (ctx, _a) {
                var size = _a.size, minSize = _a.minSize, maxSize = _a.maxSize;
                if (size === 0 && minSize > 0) {
                    return 'Campo de preenchimento obrigatório.';
                }
                // Checkbox group
                if (ctx.hasStateProperty('.', "i18n(" + I18N_SELECTION_OPTIONS_KEY + ")")) {
                    var numOptions = function (n) { return (n === 1 ? 'uma' : n === 2 ? 'duas' : n); };
                    return maxSize === undefined
                        ? "Tem de selecionar no m\u00EDnimo " + numOptions(+minSize) + " " + (+minSize === 1 ? 'opção' : 'opções') + "."
                        : minSize === undefined
                            ? "Tem de selecionar no m\u00E1ximo " + numOptions(+maxSize) + " " + (+minSize === 1 ? 'opção' : 'opções') + "."
                            : maxSize === minSize
                                ? "Tem de selecionar " + numOptions(+maxSize) + " " + (+maxSize === 1 ? 'opção' : 'opções') + "."
                                : "Entre " + numOptions(+minSize) + " e " + numOptions(+maxSize) + " op\u00E7\u00F5es t\u00EAm de ser selecionadas.";
                }
                // Tables and form-lists
                return maxSize === undefined
                    ? "A cole\u00E7\u00E3o tem de ter no m\u00EDnimo " + +minSize + " elemento" + (+minSize === 1 ? '' : 's') + "."
                    : minSize === undefined
                        ? "A cole\u00E7\u00E3o tem de ter no m\u00E1ximo " + +maxSize + " elemento" + (+maxSize === 1 ? '' : 's') + "."
                        : maxSize === minSize
                            ? "A cole\u00E7\u00E3o tem de ter " + +maxSize + " elemento" + (+maxSize === 1 ? '' : 's') + "."
                            : "A cole\u00E7\u00E3o tem de ter entre " + +minSize + " e " + +maxSize + " elementos.";
            },
            _b$2[NUMBER_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var min = _a.min, max = _a.max;
                return max === undefined
                    ? "O valor n\u00E3o pode ser menor do que " + +min + "."
                    : min === undefined
                        ? "O valor n\u00E3o pode ser maior do que " + +max + "."
                        : "O valor tem de estar entre " + +min + " e " + +max + ".";
            },
            _b$2[LENGTH_OUT_OF_BOUNDS_CODE] = function (_, _a) {
                var length = _a.length, minLength = _a.minLength, maxLength = _a.maxLength;
                if (length === 0 && minLength > 0) {
                    return 'Campo de preenchimento obrigatório.';
                }
                return maxLength === undefined
                    ? "O valor tem de ter no m\u00EDnimo " + +minLength + " " + (+minLength === 1 ? 'carácter' : 'caracteres') + "."
                    : minLength === undefined
                        ? "O valor tem de ter no m\u00E1ximo " + +maxLength + " " + (+maxLength === 1 ? 'carácter' : 'caracteres') + "."
                        : maxLength === minLength
                            ? "O valor tem de ter " + +maxLength + " " + (+maxLength === 1 ? 'carácter' : 'caracteres') + "."
                            : "O valor tem de ter entre " + +minLength + " e " + +maxLength + " " +
                                'caracteres.';
            },
            _b$2),
        _a$2)
};

// Module

/**
 * Generated bundle index. Do not edit.
 */

export { ActionsMenuComponent, AlertComponent, AppComponent, BsLocaleChanger, ButtonComponent, CardComponent, CardContentComponent, CheckboxComponent, CheckboxGroupComponent, DateComponent, DateRangeComponent, DropdownComponent, DropdownItemComponent, DropdownMenuComponent, FileComponent, FormComponent, HelpTooltipComponent, I18N_ACTIONS_MENU_BUTTON_TEXT_KEY, I18N_ACTIONS_MENU_KEY, I18N_ACTIONS_MENU_OPTIONS_KEY, I18N_BS_LOCALE_KEY, I18N_CLOSE_BUTTON_TOOLTIP_KEY, I18N_DATE_FORMAT_KEY, I18N_DATE_PLACEHOLDER_KEY, I18N_DATE_RANGE_SEPARATOR_KEY, I18N_EN_US, I18N_ES_ES, I18N_FILE_BROWSE_TEXT_KEY, I18N_FILE_CHOOSE_PLACEHOLDER_KEY, I18N_FILE_CLEAR_BUTTON_TOOLTIP_KEY, I18N_FILE_NONE_CHOSEN_KEY, I18N_FORM_CANCEL_REMOVE_BUTTON_TEXT_KEY, I18N_FORM_CONFIRM_REMOVE_BUTTON_TEXT_KEY, I18N_FORM_ENSURE_REMOVE_TEXT_KEY, I18N_FORM_HELP_ACTION_TEXT_KEY, I18N_FORM_REMOVE_ACTION_TEXT_KEY, I18N_NUMBER_DECIMAL_SEPARATOR_KEY, I18N_NUMBER_PREFIX_KEY, I18N_NUMBER_SUFFIX_KEY, I18N_NUMBER_THOUSANDS_SEPARATOR_KEY, I18N_PT_PT, I18N_SELECTION_NO_OPTIONS_TEXT_KEY, I18N_SELECTION_OPTIONS_KEY, I18N_TABLE_ADD_ROW_ACTION_TEXT_KEY, I18N_TABLE_COLUMN_LABELS_KEY, I18N_TABLE_NO_ROWS_TEXT_KEY, I18N_TABLE_REMOVE_ROWS_ACTION_TEXT_KEY, I18N_TREE_NAV_ADD_OPTIONAL_VALUE_BUTTON_TEXT_KEY, I18N_TREE_NAV_ADD_VALUE_TO_LIST_BUTTON_TEXT_KEY, I18N_VALIDATIONS_KEY, I18N_VALIDATION_PANEL_ERRORS_TEXT_KEY, I18N_VALIDATION_PANEL_FOCUS_TEXT_KEY, I18N_VALIDATION_PANEL_NEXT_BUTTON_TOOLTIP_KEY, I18N_VALIDATION_PANEL_NO_ISSUES_TEXT_KEY, I18N_VALIDATION_PANEL_PREV_BUTTON_TOOLTIP_KEY, I18N_VALIDATION_PANEL_WARNINGS_TEXT_KEY, I18N_VALUE_CODE_KEY, I18N_VALUE_HELP_MESSAGE_KEY, I18N_VALUE_LABEL_KEY, I18N_VALUE_LEGEND_KEY, I18N_VALUE_RETRY_VALIDATE_TEXT_KEY, IconComponent, InlineValue, LF_BOOTSTRAP_THEME_SERVICES, LF_URL_PROTOCOL, LfBootstrapThemeModule, ModalBodyComponent, ModalComponent, ModalFooterComponent, ModalHeaderComponent, NumberComponent, RadioComponent, SELECTION_COLUMN_WIDTH, SelectComponent, SelectionValue, SingleSelectionValue, TableCellComponent, TableComponent, TableRowComponent, TextComponent, TextareaComponent, Toggleable, TooltipComponent, TopBarComponent, TreeEntryComponent, TreeNavComponent, ValidationIssueDirective, ValidationPanelComponent, Value, ValueStateComponent, dateRangeSchema, isDateRangeSchema };
//# sourceMappingURL=lightweightform-bootstrap-theme.js.map
